C   21/11/78 C9071601   MEMBER NAME  ZBOS10   (S)           FORTRAN
      SUBROUTINE BSCOM
C     ----------------------------------------------------------------1000000200
C
C     10.  PRINTING STATISTIC AND A DUMP
C
C     THE STATUS OF THE BOS-SYSTEM, EXPECIALLY STATISTICS ON INPUT/
C     OUTPUT IS PRINTED BY
C
C     CALL BSTA
C
C
C
C     A DUMP CONTAINING RELEVANT STATUS INFORMATION AND NDMP
C     WORDS OF THE COMMON/BCS/IW(NSPACE) IS PRINTED BY
C
C     CALL BDMP
C
C     THE PROGRAM STOPS CALLING ABEND.
C     BDMP IS CALLED AUTOMATICALLY IN BOS-ROUTINES UNDER SEVERAL
C     ERROR CONDITIONS, DESCRIBED BELOW. IT IS ALSO CALLED IN
C     CASE OF A SYSTEM COMPLETION CODE 0CX, IF THE STATEMENT
C
C     CALL DUMP0C
C
C     IS USED AFTER BINT.
C
C
C
C     ICOND  SUBPGM   CONDITION                               REMARK
C     -----  ------   --------------------------------------  -------
C         1    IBLN   TOO MANY NAMES USED                     1,2
C        11  BREADC   NOT ENOUGH SPACE IN COMMON/BCS/         3
C        12    BRDS   NOT ENOUGH SPACE IN COMMON/BCS/         3
C        13    BWRS   NOT ENOUGH SPACE IN COMMON/BCS/         3
C        14  BLOADA   NOT ENOUGH SPACE IN COMMON/BCS/, OR     3,4
C                     ILLEGAL DADS
C        15    PODA   NOT ENOUGH SPACE IN COMMON/BCS/, OR     3,4
C                     ILLEGAL DADS
C        21    BRDS   TOO MANY READ ERRORS                    5,1
C        22    BRDS   RECORD READ TOO LONG                    5,3
C        23    BRDS   WRITE-UNIT USED FOR READING
C        24    BWRS   READ-UNIT USED FOR WRITING
C        31    ----   FORTRAN ERROR 240 (0CX)                 6,7
C        32    BGAR   WRONG INDEX FOUND                       6
C        41   BREADC  INCORRECT CARD FOR FORMATED INPUT
C
C
C     REMARKS
C     1   CHANGE PARAMETERS IN BINT1
C     2   PROBABLY USER ERROR, WRONG VARIABLE USED AS A NAME
C     3   INCREASE TOTAL SPACE IN COMMON/BCS/
C     4   PROBABLY USER ERROR, WRONG DATA SET USED
C     5   READ ERRORS
C     6   PROBABLY USER ERROR, BANK STRUCTURE OVERWRITTEN
C     7   PROBABLY USER ERROR, IN MOST CASES A WRONG INDEX IS USED
C
C
C
C
C     DESCRIPTION OF THE VARIABLES OF THE COMMON/ACS/, PRINTED
C     IN A DUMP.

C     INDEX    VARIABLE     MEANING
C
C       1      ICOND        ERROR CONDITION
C       2      NLAST        LENGTH OF COMMON/BCS/
C       3      NDUMP        NR OF WORDS PRINTED IN A DUMP
C       4      NSPL         NR OF WORDS FOR LOW PRIORITY BANKS
C       5      NAMAX        NR OF DIFFERENT NAMES ALLOWED
C       6      NAMAX1       NAMAX+1
C       7      NLIST        NR OF ENTRIES IN LISTS ALLOWED
C       8      NPRIME       PRIME NR USED IN IBLN
C       9      NFRS         FIRST LOCATION FOR BANKS
C      10      NLST         LAST LOCATION FOR BANKS
C
C      11      NEXT         NEXT LOCATION FOR BANKS
C      12      NCI          ACTUAL NR OF DIFFERENT NAMES
C      13      NFRE         NR OF FREE LOCATIONS
C      14      IN           ACTUAL NR OF NAMES IN LIST
C      15      KPOS         INDEX FROM BPOS/CPOS
C      16      LIND         INDEX OF LAST CREATED BANK
C      17      ILOW         LOWEST INDEX OF DELETED BANK
C      18      LFDI         LAST I-INDEX
C      19      LFDK         LAST K-INDEX
C      20      NCPL         ACTUAL NR OF WORDS OF LOW PRIORITY SPACE
C
C      21-30   NHISTH(10)   HISTOGRAM FOR TOTAL SPACE
C
C      31      NHISTH(11)   OVERFLOWS TOTAL SPACE
C      32      NCOL         NR OF GARBAGE COLLECTIONS
C      33      NZT          TIME OF BOS-START
C      34      IBFI         INDEX FOR BUFF-BANK
C      35      NLAST1       COPY OF NLAST
C      36      ISLST        INDEX FOR SPECIAL LIST OF NAMES
C      37      IMLST        INDEX FOR MARKERS OF SP. LIST O.N.
C      38      INAMV        INDEX FOR NAMES
C      39      IOLST        INDEX FOR IO-LIST
C      40      IPLST        INDEX FOR POINTERS TO NAMES
C
C      41-50   NER(10)      INPUT ERROR CODES FROM BINP/BRDS
C
C      51      NRECL        DEFAULT RECORD LENGTH FOR OUTPUT
C      52      NERRL        NR OF ERRORS ALLOWED
C      53      NRIN         NR OF INPUT EVENTS
C      54      NROUT        NR OF OUTPUT EVENTS
C      55      NS           ACTUAL NR OF NAMES IN SPECIAL LIST
C      56      NEXTI        NEXT INDEX FOR BANKS IN BRDS
C      57      NEXTA        INDEX OF BEGIN OF NEW EVENT
C      58      NEXTB        INDEX BEHIND NEW EVENT
C      59      ISAVB        INDEX OF SAVED LOCATION IN BWRS
C      60      NSAVB        CONTENT OF SAVED LOCATION IN BWRS
C
C      61-70   NHISTL(10)   HISTOGRAM FOR LOW PRIORITY SPACE
C
C      71      NHISTL(11)   OVERFLOWS OF LOW PRIORITY SPACE
C      72      MARKWR       MARKER FOR BSEQ
C      73-75   NOUT(3)      OUTPUT UNITS FOR BSEQ
C      76      IASW         SWITCH FOR FORTRAN/ASSEMBLER READ (BSEQ)
C      77      NPRE         NR OF BPRE PRINTOUTS
C      78      IDUMMY(1)    ONE DUMMY WORD (ZERO)
C      79      NEOTP        NR OF LISTINGS FOR INPUT-BANK ERRORS WITH
C                           ERROR CODE LESS THAN 6
C      80      NDUMP1       SAME AS NDUMP
C
C
C
C
C     DESCRIPTION OF BANKS ('+BUF',IUN) FOR INPUT AND OUTPUT
C
C
C
C     BUFFER FOR INPUT = BANK ('+BUF',IUN), LENGTH = 11,
C              LENGTH = 10 + NRECL FOR M-RECORDS
C
C     IBF+ 1   =1 (INPUT)
C          2   BUFFER SIZE USED
C          3   NR OF IO-ERRORS
C          4   NR OF RECORDS
C          5   NR OF EVENTS ACCEPTED
C          6   NR OF EVENTS, WHICH ARE TOO LARGE
C          7   SUM OF NR OF WORDS IN ALL EVENTS
C          8   MAX NR OF WORDS IN AN EVENT
C          9   LIMIT FOR NR OF ERRORS
C         10   POINTER WITHIN RECORD TO NEXT EVENT
C         ----------------
C         11   NTOT (= NR OF WORDS IN THE RECORD FOLLOWING)
C         12   RECORD
C          .   . . .
C          .   . . .
C
C     BUFFER FOR OUTPUT = BANK ('$BUF',IUN), LENGTH = 11
C              LENGTH = 10 + NRECL FOR M RECORDS
C
C     IBF+ 1   =2 (OUTPUT)
C          2   BUFFER SIZE
C          3   OUTPUT MODE
C          4   NR OF RECORDS
C          5   NR OF EVENTS ACCEPTED
C          6   NR OF EVENTS, WHICH ARE TOO LARGE
C          7   SUM OF NR OF WORDS IN ALL EVENTS
C          8   MAX NR OF WORDS IN AN EVENT
C          9   HIDD-NR
C         10   POINTER WITHIN RECORD TO NEXT EVENT
C         ----------------
C         11   NTOT (= NR OF WORDS IN THE RECORD FOLLOWING)
C         12   RECORD
C          .   . . .
C          .   . . .
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
C
      RETURN
      END
