***HEADER*** MEMBER  MVTRCE    SAVED BY F22RAM  ON 86/12/15  AT 14:04      
C
      COMMON / CVTRCE / IVCELL,IVSIDE,VDRFT,
     *                  VSIGMA,HVMSK(7),VRES(7),ITDST
C                                                              
