C   07/06/96 606071817  MEMBER NAME  BGAC     (S4)          FORTG1
      SUBROUTINE BGAC(IGA,NWD)
C     BOS SUBPROGRAM =1.21=
      IGA=0
      CALL BSPC(NA,NB,NC,ND)
      IF(NB.GT.NWD+4) GOTO 100
      CALL BGAR(IGA)
  100 RETURN
      END
