C   21/11/78 C9071601   MEMBER NAME  ZBOS07   (S)           FORTRAN
      SUBROUTINE BSCOM
C     -----------------------------------------------------------------700000200
C     7.  INPUT FROM CARDS
C
C     DATA CAN BE READ FROM CARDS IN FREE FORMAT OR IN A FORMAT GIVEN
C     ON THE CARDS ITSELF, AND STORED IN BANKS. THE LAST 8 COLS OF THE
C     CARDS ARE NOT USED IN FREE FORMAT MODE.
C
C     CALL BREADC
C
C     DATA ARE READ FROM CARDS (UNIT 5) UNTIL DATA END OR A CARD WITH
C     ENDQ IS READ.
C
C
C
C     7.1 FREE FORMAT
C
C     READING A CARD OF THE TYPE
C     NAME A B C . . .
C     CREATES A BANK (NAME,0) WITH DATA A, B ,C . . .
C     A SECOND CARD WITH THE SAME NAME CREATES A BANK (NAME,1) ETC.
C     IF THE FIRST CHARACTER OF NAME IS THE DOLLARSIGN $, THAN
C     THE INPUT IS ACCORDING TO THE MODE DESCRIBED BELOW.
C
C     NAME N / A B C . . .
C     CREATES A BANK (NAME,N) WITH DATA A, B, C . . .
C     A SECOND CARD WITH THE SAME (NAME,N) IS NOT STORED.
C
C     THE BANK NAME  CONSISTS OF THE FIRST FOUR CHARACTERS OF
C     NAME.
C     N, A, B, C, . . . ARE CONSTANTS.
C     INTEGER CONSTANTS ARE TO BE WRITTEN WITHOUT A DOT (.),
C     REAL CONSTANTS WITH DOT (.) AND OPTIONALLY WITH EXPONENT.
C     CONTINUATION CARDS STARTING IMMEDIATELY WITH CONSTANTS ARE
C     ALLOWED. NON-NUMERIC CHARACTERS BETWEEN CONSTANTS ARE
C     IGNORED.
C
C     7.2  FORMATED
C
C     AFTER READING A CARD
C
C     NAME N NW '(FORMAT)
C
C     NW WORDS ARE READ ACCORDING TO THE GIVEN FORMAT FROM CONSECUTIVE
C     CARDS AND STORED IN A BANK (NAME,N). THE FORMAT
C     SHOULD START WITH 1X (SEE EXAMPLE), TO ALLOW ECHO-PRINTOUT
C     WITHOUT LINE SKIPPING.
C
C
C     7.3  SPECIAL CARDS
C
C                                 ACTION
C
C     ENDQ                        BREADC RETURNS
C
C     POFF                        PRINTING OF CARDS IS SWITCHED OFF
C
C     PON                         PRINTING OF CARDS IS SWITCHED ON AGAIN
C
C     UNIT N     (N = INTEGER)    THE NEXT CARDS ARE READ FROM
C                                 UNIT N UNTIL DATA END, THEN AGAIN
C                                 FROM UNIT 5.
C
C
C
C     7.4  EXAMPLE
C
C
C     CONSTANTS 1.7 2.3 7 1.23E-4
C     RUN 2769 / 1.520 16.0
C     0.7 2.0
C     TITL 2000 5 '(1X,5A4)
C      PI+ PI+ PI- PI- PI0
C     ENDQ
C
C
C
C
C     BANKS STORED
C
C     NAME             CONS   RUN    TITL
C     NUMBER              0   2769   2000
C     NR.OF WORDS         4      4      5
C
C     1.DATA WORD       1.7  1.520   PI+
C     2.DATA WORD       2.3   16.0   PI+
C     3.DATA WORD         7    0.7   PI-
C     4.DATA WORD   1.23E-4    2.0   PI-
C     5.DATA WORD                    PI0
C
C     INDICES ARE OBTAINED BY
C     CALL BLOC(IND,'CONS',0,&S1)
C     CALL BLOC(IND,'RUN ',2769,&S1)
C     CALL BLOC(IND,'TITL',2000,&S1)   RESP.
C
      RETURN
      END
