C./ I 0 MACRO
C./ INSERT 1 1
C---------------------------------------
C  MACRO CBOSIBLN .... BOS BANK POINTERS
C---------------------------------------
      COMMON/CBOSIB/
     +             IBHEAD,IBPATR,IBJHTL,IBTPEV,IBTPTR,IBFADC
     +            ,IBGVTX,IBLGCL,IBDEDX,IBATOF,IBTOFR,IBACLS
     +            ,IBLATC,IBTRIG,IBATST,IBATBP,IBALGL,IBTAGG
     +            ,IBATAG,IBJETC,IBJETV,IBTAGC,IBMUEV,IBMPRS
     +            ,IBN50S,IBALGN,IBZVTX,IBMUR1,IBMUR2,IBTPVX
     +            ,IBMTCO,IBMUCO,IBMJET,IBVECT,IBDUM1,IBDUM2
C------- END OF MACRO CBOSIBLN ---------
