C   18/09/80 503012017  MEMBER NAME  TOFBK    (JADEGS)      FORTRAN
      SUBROUTINE TOFBK
       COMMON/CWORK/NR,RAW(5,42),NC,ICRT1(5,42),NTRK,ICRT2(50),TRK(5,50)
     - ,ITRC(50),NTC,ITRK(5,42),INFM(4),IRELT(14,50)
       DIMENSION IW(704)
       EQUIVALENCE (IW(1),INFM(1))
C
C  BSAT CHANGED TO BSAW,  1.3.1985   J.O.
C
C=========   STORE RESULT INTO CURRENT BUFFER
C
       LTFR= 14*NTRK+4
       CALL BCRE(INTR,'TOFR',0,LTFR,*3000,IER)
       IF(INTR.EQ.0.AND.IER.EQ.2) GO TO 3000
       CALL BSTR(INTR,IW,LTFR)
       CALL BSAW(1,'TOFR')
       RETURN
3000   CONTINUE
C/////////
             WRITE(6,9300)
9300         FORMAT(1X,'BOS ERROR IN TOFBK')
      RETURN
      END
