C   27/06/80 010081657  MEMBER NAME  GGFAC3   (S)           FORTRAN
      SUBROUTINE GGFAC3
C---  COPY CALIBRATION CONSTANTS OF LEAD-GLASS INTO COMMON /CALICO/
C---  RUN 2751 TO RUN 4864
C
C     H.WRIEDT    13.09.79     19:00
C     LAST MODIFICATION    27.07.80   16:35
C
      COMMON /CFACT3/ FACT3(191)
      COMMON /CALICO/ FAKTOR(191)
C
        DO 1 I = 1,191
    1   FAKTOR(I) = FACT3(I)
      WRITE(6,600)
  600 FORMAT(/' *** THIRD SET OF LEAD-GLASS CALIBRATION CONSTANTS',
     &        ' INCLUDED ***')
      RETURN
      END
      BLOCK DATA
C
      COMMON /CFACT3/ FACT3
C     THIS DATA APPLICABLE FROM RUN 2751 TO RUN 4864
C     THE GAIN ASSUMES ENERGY(MEV)=CHANNEL*5.0
      REAL*4 FACT3(191)/191*1.65/
      END
