C   09/02/79 311181555  MEMBER NAME  TOFMAK   (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE TOFMAK
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       INTEGER *2 HDATA
       COMMON/CTWRK/ IADC(2,42),ITDC(2,42)
       COMMON/CTOF/  HDATA(188)
C
       DO 100 I=1,42
       IM= I-1
       I2= 2*I
       IAA= IM/6+I2+1
       IAT= IM/4+I2+92
       HDATA(IAA)=   IADC(1,I)
       HDATA(IAA+1)= IADC(2,I)
       HDATA(IAT)=   ITDC(1,I)
       HDATA(IAT+1)= ITDC(2,I)
 100   CONTINUE
C
C BANK DESCRIPTOR WORD SET TO 1, J.OLSSON,B.NAROSKA  18.11.1983
C
       HDATA(1)= 1
C
C      DO 200 I=1,42
C200   WRITE(6,9000) I,(IADC(J,I),J=1,2),(ITDC(K,I),K=1,2)
C9000  FORMAT(11I10)
C      WRITE(6,9000) HDATA
       RETURN
       END
