C   29/03/80 004242330  MEMBER NAME  MUFFLZ   (JADEMUS1)    FORTRAN
C LAST CHANGE 19.46 31/03/80 JOHN ALLISON.
      SUBROUTINE MUFFLZ
     *(HC,NHITS,NWHIT,
     * HLUN,
     * IMUR,AMUR,NWMUR,
     * HTC,HAMB,NTPH)
C
      IMPLICIT INTEGER*2 (H)
C
      DIMENSION
     * HC(1),
     * HLUN(1),
     * IMUR(1),AMUR(1),
     * HTC(1),HAMB(1)
C
C CALLED AFTER EACH 'GOOD' MUON.
C
C HC CONTAINS MUON HIT COORDINATES.
C NHITS IS THE NUMBER OF MUON HITS.
C NWHIT IS NUMBER OF WORDS PER HIT IN HIT COORDINATE ARRAY.
C HLUN IS HIT STATUS ARRAY.
C IMUR,AMUR IS MU-RESULTS 'MUR2' BANK 1 - FILLED BY MUFFLE.
C NWMUR IS NUMBER OF WORDS PER INNER DTECTOR TRACK IN 'MUR2' BANK 1.
C HTC IS HIT-TRACK CORELLATION ARRAY - FILLED BY MUFFLE.
C HAMB IS AMBIGUITY FLAG FOR EACH ENTRY IN HTC.
C NTPH IS NUMBER OF TRACKS PER HIT ALLOCATED IN HTC.
C
C-----------------------------------------------------------------------
C
C COMMONS.
C
#include "cmucalib.for"
#include "cmuffl.for"
#include "cmufwork.for"
#include "cmureg.for"
C
C-----------------------------------------------------------------------
C
C DON'T FORGET TO ACTIVATE THESE STATEMENTS.  THERE MAY BE MORE THAN 10
C   ASSOCIATED HITS, BUT MANY ARRAYS ARE LIMITED TO 10.
C
C     NTHISS=NTHIS
C     IF(NTHIS.GT.10)NTHISS=10
C
C-----------------------------------------------------------------------
C
C++++
C     N3=3*NTHISS
C     WRITE(6,2857)(DALONG(I),I=1,NTHISS)
C2857 FORMAT('0DALONG',T20,10F10.1)
C     WRITE(6,2858)(DEV(I),I=1,N3)
C2858 FORMAT(' DEVIATIONS',T20,10F10.1/(T20,10F10.1))
C     WRITE(6,2859)(VXYDA(I),I=1,NTHISS)
C2859 FORMAT(' VXYDA',T20,10F10.0)
C     WRITE(6,2860)(VZDA(I),I=1,NTHISS)
C2860 FORMAT(' VZDA',T20,10F10.0)
C     WRITE(6,2861)(CXYA(I),I=1,NTHISS)
C2861 FORMAT(' CXYA',T20,10F10.5)
C     WRITE(6,2862)(CZA(I),I=1,NTHISS)
C2862 FORMAT(' CZA',T20,10F10.5)
C     WRITE(6,2863)(INCUT(I),I=1,N3)
C2863 FORMAT(' INCUT',T20,30L2)
C     WRITE(6,2864)(BADA(I),I=1,N3)
C2864 FORMAT(' BADA',T20,30L2)
C     WRITE(6,2865)(ITHISA(I),I=1,NTHISS)
C2865 FORMAT(' ITHISA',T20,10I5)
C     WRITE(6,2866)(IJA(I),I=1,NTHISS)
C2866 FORMAT(' IJA',T20,10I5)
C     WRITE(6,2867)INEFF
C2867 FORMAT(I5,' INEFFICIENCIES.')
C     IF(INEFF.EQ.0)GO TO 2870
C     WRITE(6,2868)(INCHAM(I),I=1,INEFF)
C2868 FORMAT(' INEFFICIENT CHAMBERS',10I5)
C     WRITE(6,2869)(INREG(I),I=1,INEFF)
C2869 FORMAT(' INEFFICIENT REGIONS (PLANES)',10I5)
C2870 CONTINUE
C++++
C     N=NTPH*NHITS
C     WRITE(6,2871)(HAMB(I),I=1,N)
C2871 FORMAT(' AMBIGUITY FLAGS',T20,20I5/(T20,20I5))
C++++
C     WRITE(6,2856)((EM(I,J),I=1,12),J=1,12)
C2856 FORMAT('0FIRST 12 ENTRIES IN ERROR MATRIX'/(12F10.0))
C++++
C++++
C     WRITE(6,1735)CHISQT,NDFT,CHIPRT
C1735 FORMAT(' CHISQT,NDFT,CHIPRT',F10.4,I5,G15.5)
C++++
C++++
C     WRITE(6,3735)CHISTL,NDFTL,CHIPTL
C3735 FORMAT(' CHISTL,NDFTL,CHIPTL',F10.4,I5,G15.5)
C++++
C
C-----------------------------------------------------------------------
C
      RETURN
      END
