C   30/05/80 803301135  MEMBER NAME  RDATA    (JADEGS)      FORTRAN
      SUBROUTINE RDATA(IER,HRUN)
C---
C---     TABLE FOR REAL DATA TAKING RUNS, RETURNS FLAG IER
C---     IER = 0 IF REAL DATA,  OTHERWISE IER = 1
C---     IER = 0 IF MONTE CARLO, I.E. HRUN < 100
C---          LAST CHANGE  30.03.88           J.OLSSON  30.05.80
C---
      IMPLICIT INTEGER*2 (H)
C
      IER = 1
      IF(HRUN.LT.100) GO TO 100
      IF(HRUN.GT. 539.AND.HRUN.LT. 673) GO TO 100
      IF(HRUN.GT. 698.AND.HRUN.LT. 710) GO TO 100
      IF(HRUN.GT. 763.AND.HRUN.LT. 799) GO TO 100
      IF(HRUN.GT. 803.AND.HRUN.LT.1055) GO TO 100
      IF(HRUN.GT.1055.AND.HRUN.LT.1180) GO TO 100
      IF(HRUN.GT.1209.AND.HRUN.LT.1374) GO TO 100
      IF(HRUN.GT.1375.AND.HRUN.LT.1398) GO TO 100
      IF(HRUN.GT.1496.AND.HRUN.LT.1548) GO TO 100
      IF(HRUN.GT.1557.AND.HRUN.LT.1687) GO TO 100
      IF(HRUN.GT.1710.AND.HRUN.LT.1814) GO TO 100
      IF(HRUN.GT.1845.AND.HRUN.LT.2227) GO TO 100
      IF(HRUN.GT.2294.AND.HRUN.LT.2309) GO TO 100
      IF(HRUN.GT.2310.AND.HRUN.LT.2521) GO TO 100
      IF(HRUN.GT.2744.AND.HRUN.LT.3019) GO TO 100
      IF(HRUN.GT.3036.AND.HRUN.LT.3183) GO TO 100
      IF(HRUN.GT.3184.AND.HRUN.LT.3297) GO TO 100
      IF(HRUN.GT.3324.AND.HRUN.LT.3541) GO TO 100
      IF(HRUN.GT.3560.AND.HRUN.LT.4708) GO TO 100
      IF(HRUN.GT.4709.AND.HRUN.LT.4842) GO TO 100
      IF(HRUN.GT.4852.AND.HRUN.LT.4865) GO TO 100
      IF(HRUN.GT.4993.AND.HRUN.LT.5057) GO TO 100
      IF(HRUN.GT.5057.AND.HRUN.LT.5404) GO TO 100
      IF(HRUN.GT.6310.AND.HRUN.LT.6329) GO TO 100
C KNOWN COSMIC RUNS, TEST RUNS
      IF(HRUN.EQ. 6185) GO TO 200
      IF(HRUN.EQ.15870) GO TO 200
      IF(HRUN.GE.17691.AND.HRUN.LE.17695) GO TO 200
      IF(HRUN.GE.11796.AND.HRUN.LE.11798) GO TO 200
      IF(HRUN.GE. 8630.AND.HRUN.LE. 8631) GO TO 200
      IF(HRUN.EQ.18283) GO TO 200
      IF(HRUN.EQ.18284) GO TO 200
      IF(HRUN.EQ.18287) GO TO 200
      IF(HRUN.EQ.25688) GO TO 200
C
      IF(HRUN.GT.5404                 ) GO TO 100
      GO TO 200
100   IER = 0
200   RETURN
      END
