C   30/04/96 604301841  MEMBER NAME  STAR     (BOSLIB.S)    FORTRAN
      REAL STAR/Z0000005C/,FF/Z000000FF/
      EQUIVALENCE (XNAME,INAME)
      LOGICAL NOTLOW
      REAL AND
      EXTERNAL AND
      NOTLOW(XNAME)=AND(XNAME,FF).NE.STAR
