C   11/09/79 C9091101   MEMBER NAME  MUERR    (S)           FORTRAN
C LAST CHANGE 10.37 11/09/79 JOHN ALLISON.
      SUBROUTINE MUERR(NAME,INF,MESS,N)
C
      REAL*8 NAME
      LOGICAL*1 MESS(1)
C
C PRINTS MU ERROR MESSAGES.
C
C PROVIDE SUBROUTINE NAME IN NAME.
C PROVIDE INFORMATION IN INTEGER*4 WORD INF.
C PROVIDE MESSAGE IN MESS, LENGTH N CHARACTERS
C
      COMMON /CMUPRN/MUPRIN
C
      IF(MUPRIN.EQ.0)GO TO 99
C
      N=IABS(N)
      IF(N.GT.200)N=200
C
      WRITE(6,100)NAME,INF,(MESS(I),I=1,N)
 100  FORMAT('0***** MU ERROR IN ',A8,4X,', INFORMATION WORD',I10,
     *4X,70A1/(1X,132A1))
C
 99   CONTINUE
      RETURN
      END
