C
C-----------------------------  MACRO CGRCOM  --------------------------
C
C                            THIS MACRO DEFINES THE NAMES OF THE
C                            VARIABLES WHICH POINT TO COMMAND WORDS.
C
C
      COMMON / CGRCO1 /   HADC,   HADD,   HALTER, HAMPL,  HAXES,
     +                    HBANK,  HCAPS,  HCHAM,  HCHANG, HCLUST,
     +                    HCOMMD, HCOMEN, HCONT,  HCOPY,  HCOUNT,
     +                    HCWORK, HCYL,   HDATA,  HDEDX,  HDEL,
     +                    HDETLS, HDET,   HDISP,  HDRAW,  HEDIT,
     +                    HENDC,  HEVENT, HEXT
C
      COMMON / CGRCO2 /   HFAMP,  HFILTR, HFIND,  HFIT,   HFLAG,
     +                    HFLASH, HFORWD, HFRONT, HFW,    HGLASS,
     +                    HGOOD,  HHARD,  HHELP,  HID,    HINNER,
     +                    HJET,   HJETC,  HJUMP,  HLEAD,  HLEVEL,
     +                    HLG,    HLIMIT, HLIST,  HMAP,   HMASS,
     +                    HMENU,  HMUON,  HMUPT
C
      COMMON / CGRCO3 /   HNEWS,  HNEXT,  HNO,    HNORD,  HNR,
     +                    HNUMB,  HOPT,   HPARAM, HPARMS, HPATR,
     +                    HPATRN, HPHI,   HPICK,  HPLOTS, HPROJ,
     +                    HQ,     HRECAL, HRECOG, HREGN,  HRESET,
     +                    HRESLT, HRETRN, HR,     HRZ,    HSAVE,
     +                    HSCALE, HSET,   HSHOW
C
      COMMON / CGRCO4 /   HSIDE,  HSTAND, HSTAT,  HTAGG,  HTOF,
     +                    HTOP,   HTRACK, HTRUE,  HTRIG,  HT1,
     +                    HT2,    HT3,    HVERTX, HVIEW,  HVTXC,
     +                    HWRK,   HWRITE, HXY,    HXZ,    HZ
C
C----------------------------  END OF MACRO CGRCOM  --------------------
C
