C   10/09/79 002222000  MEMBER NAME  KALCOP   (JADESR)      FORTRAN
      SUBROUTINE KALCOP
      IMPLICIT INTEGER*2 (H)
C---
C---     SIMPLE COPY.
C---                                   L.H. O'NEILL 10.09.79
C---
      DIMENSION JBUF(10000),IDAT(9991),HBUF(20000),ITIME(6),NAME( 7)
      EQUIVALENCE(JBUF(1),HBUF(1))
      EQUIVALENCE(JBUF(10),IDAT(1))
C---
      NREC=0
    1 CONTINUE
      CALL EVREA1(2,NWORD,JBUF,IRET)
      IF(IRET.EQ.1) GO TO 1000
      IF(IRET.EQ.2) GO TO 2000
      NREC=NREC+1
C     IOUT=NWORD
C     IF(IOUT.GT.10) IOUT=10
C     WRITE(6,100) NREC,NWORD,(JBUF(I),I=1,IOUT)
  100 FORMAT(1X,I4,I12,10I10)
      CALL KALBNK(3,NWORD,JBUF)
      GO TO 1
 1000 CONTINUE
      WRITE(6,101) NREC
  101 FORMAT(' *** READ ERROR ENCOUNTERED AFTER ',I4,' RECORDS.')
      RETURN
 2000 CONTINUE
      WRITE(6,102) NREC
  102 FORMAT('0NORMAL END OF FILE AFTER',I4,' RECORDS.')
      RETURN
      END
