C   17/10/77 C8041301   MEMBER NAME  SHOWR    (TESTS)       FORTRAN
      FUNCTION SHOWR(E,XX,DX)
C
C      CALCULATE ENERGY LOSS IN AN ELECTROMAGNETIC SHOWER AS A FUNCTION
C      OF INCIDENT ENERGY E, DEPTH X AND SLAB THICKNESS DX USING
C      LHO SHOWER PROFILE FIT
C      ENERGIES IN MEV, XX AND DX IN RADLENGTH
C
      REAL SL/0.9034/,BE/5.419/,RK/0.3418/,THIRD/0.33333/,CU16/2.5198/
C
      X=XX+1.5
      IF(E.LT.10.) GO TO 1
      XMAX=SL*ALOG(E/BE)
      ROOT=SQRT(1.-((RK*XMAX)**3)/54.)
      C1=(1.+ROOT)**THIRD
      C2=(1.-ROOT)**THIRD
      RA=RK*XMAX*(C1+C2)/CU16
      A=XMAX*(RA**THIRD)
      ARG=RK*(A-(A**3+X**3)**THIRD)
      SHOWR=E*RK*EXP(ARG)*X**2/(A**3+X**3)**0.666667
      SHOWR=SHOWR*DX
      RETURN
    1 SHOWR=E*RK*DX/EXP(RK*X)
      RETURN
      END
