C   06/06/84 406062125  MEMBER NAME  FINWRD   (S)           FORTRAN
***PMF      SUBROUTINE FINWRD(H,L,N1,N1two,N2,HW,IS)
      SUBROUTINE FINWRD(H,L,N1,N1two,N2,HW,IS)
      IMPLICIT INTEGER*2 (H)
      RETURN
      END
