C   03/12/83 403011611  MEMBER NAME  MCVSUM   (S)           FORTRAN
C
C-----------------------------------------------------------------------
      SUBROUTINE MCVSUM
C-----------------------------------------------------------------------
C
C   AUTHOR:   C. BOWDERY   17/11/83 :  PRINTS VALIDATION ERROR SUMMARY
C
C        MOD: C. BOWDERY   22/11/83 :  FOR FURTHER SUMMARY OUTPUT.
C        MOD: C. BOWDERY   24/11/83 :  FORMAT CHANGE I5 --> I6
C        MOD: C. BOWDERY    2/12/83 :  ADD NEW ERROR PRINTOUT
C   LAST MOD: C. BOWDERY    1/03/84 :  CORRECT PRINTOUT
C
C   THIS ROUTINE PRINTS A SUMMARY OF THE VALIDATION ERRORS DETECTED BY
C   BY MCVERR CALLED FROM BRVECT.
C
C   ADDITIONALLY, ERRORS 18 - 20 RECORD THE NUMBER OF READ ERRORS AND
C   BOS ERRORS IN BRVECT AND THE TOTAL NUMBER OF EVENTS REJECTED
C   DUE TO THE ABOVE ERRORS.
C
C-----------------------------------------------------------------------
C
      IMPLICIT INTEGER*2 (H)
C
      COMMON / CVERR / MESSAG(20)
C
C-------------------  C O D E  -----------------------------------------
C
      WRITE(6,100)
 100  FORMAT(/)
C
      IF( MESSAG(1)  .NE. 0 ) WRITE(6,1)  MESSAG(1)
      IF( MESSAG(2)  .NE. 0 ) WRITE(6,2)  MESSAG(2)
      IF( MESSAG(3)  .NE. 0 ) WRITE(6,3)  MESSAG(3)
      IF( MESSAG(4)  .NE. 0 ) WRITE(6,4)  MESSAG(4)
      IF( MESSAG(5)  .NE. 0 ) WRITE(6,5)  MESSAG(5)
      IF( MESSAG(6)  .NE. 0 ) WRITE(6,6)  MESSAG(6)
      IF( MESSAG(7)  .NE. 0 ) WRITE(6,7)  MESSAG(7)
      IF( MESSAG(8)  .NE. 0 ) WRITE(6,8)  MESSAG(8)
      IF( MESSAG(9)  .NE. 0 ) WRITE(6,9)  MESSAG(9)
      IF( MESSAG(10) .NE. 0 ) WRITE(6,10) MESSAG(10)
      IF( MESSAG(11) .NE. 0 ) WRITE(6,11) MESSAG(11)
      IF( MESSAG(12) .NE. 0 ) WRITE(6,12) MESSAG(12)
      IF( MESSAG(13) .NE. 0 ) WRITE(6,13) MESSAG(13)
      IF( MESSAG(14) .NE. 0 ) WRITE(6,14) MESSAG(14)
      IF( MESSAG(15) .NE. 0 ) WRITE(6,15) MESSAG(15)
      IF( MESSAG(16) .NE. 0 ) WRITE(6,16) MESSAG(16)
      IF( MESSAG(17) .NE. 0 ) WRITE(6,17) MESSAG(17)
C
      IF( MESSAG(18) .NE. 0 ) WRITE(6,18) MESSAG(18)
      IF( MESSAG(19) .NE. 0 ) WRITE(6,19) MESSAG(19)
      IF( MESSAG(20) .NE. 0 ) WRITE(6,20) MESSAG(20)
C
      RETURN
C
C                            THE MESSAGES
C
  1   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  1.  BEAM ENERGY WAS '
     +   ,'NEGATIVE, ZERO OR .GE. 1000 GEV')
C
  2   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  2.  MOMENTUM COMPONE'
     +            ,'NTS WERE NON-ZERO BUT .LE. E-20 GEV ',
     +             'OR GREATER THAN BEAM ENERGY')
C
  3   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  3.  ENERGY COMPONE'
     +   ,'NT WAS .LE. E-20 GEV OR GREATER THAN 2 * BEAM ENERGY')
C
  4   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  4.  PARTICLE MASS '
     +   ,'DID NOT AGREE WITH STANDARD MASS FOR TYPE WITHIN 10 MEV')
C
  5   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  5.  ENERGY, MOMENT'
     +   ,'UM AND MASS WERE NOT CONSISTENT TO 5% OF THE ENERGY')
C
  6   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  6.  COMPONENTS OF '
     +   ,'THE PRODUCTION VERTEX WERE .LE. E-20 OR .GE. 5000 MM')
C
  7   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  7.  THE PRODUCTION'
     +   ,' VERTEX WAS .GE. 8000 MM FROM THE INTERACTION POINT')
C
  8   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  8.  TOTAL MOMENTUM'
     +   ,' OF A SINGLE PARTICLE WAS GREATER THAN THE BEAM ENERGY')
C
  9   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR  9.  PARTICLE MASS '
     +   ,'WAS SMALLER THAN E-20 GEV OR GREATER THAN 2 * BEAM ENERGY')
C
 10   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 10.  NO INFORMATION'
     +   ,' AVAILABLE FOR THIS ERROR !!')
C
 11   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 11.  ILLEGAL PARTICLE'
     +   ,' TYPE FOUND. NOT IN THE RANGE 1 TO 6 OR A PARTON')
C
 12   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 12.  ILLEGAL ELECTRIC'
     +   ,' CHARGE FOUND. NOT -1, 0 , +1')
C
 13   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 13.  ILLEGAL EVENT '
     +   ,'NUMBER. ALLOWED RANGE IS  0  TO  9999999')
C
 14   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 14.  COUNT OF TOTAL '
     +   ,'NUMBER OF FINAL PARTICLES (NF) NOT IN RANGE 1 TO 300')
C
 15   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 15.  COUNT OF NUMBER '
     +   ,'OF FINAL CHARGED PARTICLES (NCF) NOT IN RANGE 0 TO 300')
C
 16   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 16.  COUNT OF NUMBER '
     +   ,'OF FINAL NEUTRAL PARTICLES (NNF) NOT IN RANGE 0 TO 300')
C
 17   FORMAT(1X,I6,' OCCURRENCE(S) OF INPUT ERROR 17.  TOTAL COUNT OF '
     +   ,'FINAL PARTICLES .NE. SUM OF COUNTS FOR CHARGED AND NEUTRALS')
C
 18   FORMAT(1X,I6,' OCCURRENCE(S) OF M.C.  ERROR 18.  EVENT COULD NOT'
     +   ,' BE READ BY BRVECT DUE TO FORTRAN READ ERROR')
C
 19   FORMAT(1X,I6,' OCCURRENCE(S) OF M.C.  ERROR 19.  BOS ERROR CODE'
     +   ,' DETECTED IN S/R BRVECT WHEN CREATING VECT OR PALL BANK')
C
 20   FORMAT(/1X,I6,' EVENT(S) REJECTED IN TOTAL BECAUSE OF THE ABOVE'
     +   ,' READ ERRORS, INVALID INPUT AND BOS ERRORS IN BRVECT')
C
      END
