C   25/06/78            MEMBER NAME  PAIRC1   (LGSOURCE)    FORTRAN
      SUBROUTINE PAIRC1(ENE,EPSI)
      COMMON /BRPAR/BRA,BRB,BDEL
      COMMON /PAPAR/CP
      COMMON /SFCPA/SF,SFE
      BH(X)=4.184*ALOG(X+0.952)-0.280
      XR=RN(DAM)
      EPSI=XR
      XR=RN(DAM)
      DEL=BDEL/(ENE*EPSI*(1.-EPSI))
      IF(DEL-1.)20,20,21
 20    G1=1.-CP*DEL*(2.914-0.447*DEL)
      GOTO2
 21    G1=1.-CP*BH(DEL)
 2    IF(SF*XR-G1)30,30,31
 30    RETURN
 31    EPSI=0.
      RETURN
      END
