C   17/01/79 203120911  MEMBER NAME  TFSTOR4  (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE TFSTOR(NTK,NTR,IFL,NCNT,TOF,PL,TDCL,TDCR,ADCL,ADCR,
     -                   TAUM1,TAUP1,ITFW,P2,ZTOF1)
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       COMMON/CWORK/NR,RAW(5,42),NC,ICRT1(5,42),NTRK,ICRT2(50),TRK(5,50)
     - ,ITRC(50),NTC,ITRK(5,42),INFM(4),IR(14,50)
       DIMENSION RE(14,50)
       EQUIVALENCE (IR(1,1),RE(1,1))
            IR( 1,NTK)= NTK
            IR( 2,NTK)= IFL
            IR( 3,NTK)= NCNT
            RE( 4,NTK)= TOF
            RE( 5,NTK)= PL
            RE( 6,NTK)= TDCL
            RE( 7,NTK)= TDCR
            RE( 8,NTK)= ADCL
            RE( 9,NTK)= ADCR
            RE(10,NTK)= TAUM1
            RE(11,NTK)= TAUP1
            IR(12,NTK)= ITFW
            RE(13,NTK)= 0.
            RE(14,NTK)= ZTOF1
C     PRINT 408,NTK,(RE(J,NTK),J=1,14)
C 408 FORMAT(1X,I2,14F8.0)
            RETURN
            END
