C   11/01/88 801271714  MEMBER NAME  UNITS    (S)        M  MACROFOR
C
C                            JUNITA is the event output unit number
C                                   for accepted events.
C
      PARAMETER  ( JUNITA = 2 )
C
C                            JUNITR is the event output unit number
C                                   for rejected events.
C
      PARAMETER  ( JUNITR = 3 )
C
