C   29/11/78 C9021401   MEMBER NAME  LGEERR   (JADELGS)     FORTRAN
      SUBROUTINE LGEERR(IP,ENERGY,SIGENG)
C
C     S.YAMADA   29-11-78  15:50
C     LAST MODIFICATION   14-02-79   18:05
C
C----CALCULATES SIGMA OF THE LG-CLUSTER ENERGY.
C
C---- INPUTS
C     IP=0,FOR THE BARREL,  IP=+-1,FOR THE END CAP.
C     ENERGY=CLUSTER ENERGY IN GEV
C---- OUTPUT
C     SIGENG=EXPECTED SIGMA FOR THE INPUT IN GEV
C
      SIGENG = 0.
      IF(ENERGY.LT.0.) RETURN
C
      IF(ENERGY.GT.2.8) GO TO 1
      SIG = 0.058*SQRT(ENERGY)
      GO TO 2
    1 SIG = 0.035*ENERGY
    2 IF(IP.NE.0) SIG = 2.0*SIG
      SIGENG = SIG
      RETURN
      END
