C   27/03/97 703271243  MEMBER NAME  JEOSUM2  (JMC.S)       FVS
C   27/03/97 703271242  MEMBER NAME  CCOMP    (JMC.S)       FVS
      COMMON/CCOMP/NCOMP(80)
C   23/08/85 511061940  MEMBER NAME  CMCTAG   (S)           FORTRAN
C
C   COMMON FOR NEW FORWARD TAGGER MC
C
      COMMON/CMCTAG/MARKMC,HGG(192),IHIT,INMARK,NCHANS,SIGMAS,CALIBS
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C   27/03/97 703271242  MEMBER NAME  CMUBCS   (JMC.S)       FVS
C----------START OF MACRO CMUBCS----------------------------------------
      COMMON /BCS/IDATA(1)
      DIMENSION HDATA(1),ADATA(1)
      EQUIVALENCE (HDATA(1),ADATA(1),IDATA(1))
C----------END OF MACRO CMUBCS------------------------------------------
C   27/08/83 310201406  MEMBER NAME  CPROD    (S)           FORTRAN
C ------------------ MACRO CPROD -----------------
C                                       4-VECTOR FORMAT FOR JADE
C
      COMMON/CPROD/ NEV,BEAM,PT,PHI,THETA,IFLAVR,
     *        NP,NC,NN,PP(4,500),XM(500),JCH(500),JTP(500),JP(500,2),
     *        NF,NCF,NNF,PF(4,300),XMF(300),ICF(300),ITF(300),
     *        PSTRT(3,300)
C
C ---------------END MACRO CPROD -----------------
C   18/05/79            MEMBER NAME  CUNIT    (S)           FORTRAN
C---------------START OF MACRO CUNIT (LOGICAL UNIT NUMBERS)-------------
C
      COMMON /CUNIT/LUNMUC,LUNMUE
C
C LUNMUC  LOGICAL UNIT FOR MU CALIBRATION DATA.
C LUNMUE  LOGICAL UNIT FOR MU CALIBRATION DATA EDIT FILE.
C
C---------------END OF MACRO CUNIT--------------------------------------
C   27/03/97 703271242  MEMBER NAME  CMUBCS   (JMC.S)       FVS
