C   24/06/82 302201628  MEMBER NAME  PLSMP    (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE PLSMP
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      IMPLICIT INTEGER*2 (H)
      COMMON/SMPTOF/MTOF,TTOF(42),NTOF,HTOF(42)
      COMMON/EVRUN/NRUN,IEV,ITYP,NEV,IMISS
C
      DATA IBUG/ 0/,IENTRY/0/
C
      IF(IENTRY.NE.0)  GOTO  19
      IENTRY = 1
      CALL HBOOK2(170,15H TSMP  ITOF   $,100,-5.,15.,42,0.,42.)
      CALL HBPRO(170)
C
   19 CONTINUE
C
      IBUG = IBUG + 1
      IF(IBUG.LE.10) PRINT 100 ,NRUN,IEV,NEV
  100 FORMAT(' TOFSMP RESULTS',3I10)
      DO   1   I=1,42
      IF(HTOF(I).LE.0)  GOTO  1
      CALL HFILL(170,TTOF(I),FLOAT(I))
      IF(IBUG.LE.10) PRINT 101,I,TTOF(I)
  101 FORMAT(' TOF',I5,F12.2)
    1 CONTINUE
      RETURN
       END
