C   13/06/81         2  MEMBER NAME  SPINNR0  (JADEGS)      FORTRAN
      SUBROUTINE SPINNR(NBL,IER,HRUN)
C---
C---     CHECK WHETHER BLOCK NBL IS A SPINNER, AS FAR AS IS KNOWN
C---     IER = 0 IF NO SPINNER, OTHERWISE IER = 1
C---          LAST CHANGE  06.01.81           J.OLSSON  15.04.81
C---
      IMPLICIT INTEGER*2 (H)
C
      IER = 0
      IF(HRUN.LT.100) GO TO 200
C PERMANENT SPINNERS IN 1979, 1980
      IF(HRUN.GT.6000) GO TO 255
      IF(NBL.EQ.2384) GO TO 100
      IF(NBL.EQ. 566) GO TO 100
      IF(HRUN.LT.100) GO TO 200
      IF(HRUN.GT.1496) GO TO 101
C   SUMMER DATA 1979
      IF(NBL.EQ.  45) GO TO 100
      IF(NBL.EQ. 112) GO TO 100
      IF(NBL.EQ. 144) GO TO 100
      IF(NBL.EQ. 146) GO TO 100
      IF(NBL.EQ. 150) GO TO 100
      IF(NBL.EQ. 168) GO TO 100
      IF(NBL.EQ. 225) GO TO 100
      IF(NBL.EQ. 327) GO TO 100
      IF(NBL.EQ. 333) GO TO 100
      IF(NBL.EQ. 377) GO TO 100
      IF(NBL.EQ. 507) GO TO 100
      IF(NBL.EQ. 527) GO TO 100
      IF(NBL.EQ. 641) GO TO 100
      IF(NBL.EQ. 669) GO TO 100
      IF(NBL.EQ. 754) GO TO 100
      IF(NBL.EQ. 803) GO TO 100
      IF(NBL.EQ. 810) GO TO 100
      IF(NBL.EQ. 966) GO TO 100
      IF(NBL.EQ. 982) GO TO 100
      IF(NBL.EQ.1075) GO TO 100
      IF(NBL.EQ.1078) GO TO 100
      IF(NBL.EQ.1137) GO TO 100
      IF(NBL.EQ.1224) GO TO 100
      IF(NBL.EQ.1257) GO TO 100
      IF(NBL.EQ.1353) GO TO 100
      IF(NBL.EQ.1419) GO TO 100
      IF(NBL.EQ.1468) GO TO 100
      IF(NBL.EQ.1474) GO TO 100
      IF(NBL.EQ.1481) GO TO 100
      IF(NBL.EQ.1487) GO TO 100
      IF(NBL.EQ.1491) GO TO 100
      IF(NBL.EQ.1497) GO TO 100
      IF(NBL.EQ.1626) GO TO 100
      IF(NBL.EQ.1749) GO TO 100
      IF(NBL.EQ.1796) GO TO 100
      IF(NBL.EQ.1807) GO TO 100
      IF(NBL.EQ.1859) GO TO 100
      IF(NBL.EQ.1884) GO TO 100
      IF(NBL.EQ.1890) GO TO 100
      IF(NBL.EQ.1893) GO TO 100
      IF(NBL.EQ.1958) GO TO 100
      IF(NBL.EQ.1959) GO TO 100
      IF(NBL.EQ.1969) GO TO 100
      IF(NBL.EQ.2020) GO TO 100
      IF(NBL.EQ.2095) GO TO 100
      IF(NBL.EQ.2131) GO TO 100
      IF(NBL.EQ.2215) GO TO 100
      IF(NBL.EQ.2238) GO TO 100
      IF(NBL.EQ.2472) GO TO 100
      IF(NBL.EQ.2473) GO TO 100
      IF(NBL.EQ.2474) GO TO 100
      IF(NBL.EQ.2534) GO TO 100
      IF(NBL.EQ.2827) GO TO 100
      GO TO 200
101   IF(HRUN.GT.2294) GO TO 102
C   ENERGY SCAN PERIOD
      IF(NBL.EQ.  45) GO TO 100
      IF(NBL.EQ.  74) GO TO 100
      IF(NBL.EQ. 112) GO TO 100
      IF(NBL.EQ. 137) GO TO 100
      IF(NBL.EQ. 141) GO TO 100
      IF(NBL.EQ. 169) GO TO 100
      IF(NBL.EQ. 233) GO TO 100
      IF(NBL.EQ. 234) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 311) GO TO 100
      IF(NBL.EQ. 377) GO TO 100
      IF(NBL.EQ. 392) GO TO 100
      IF(NBL.EQ. 410) GO TO 100
      IF(NBL.EQ. 413) GO TO 100
      IF(NBL.EQ. 428) GO TO 100
      IF(NBL.EQ. 453) GO TO 100
      IF(NBL.EQ. 457) GO TO 100
      IF(NBL.EQ. 463) GO TO 100
      IF(NBL.EQ. 489) GO TO 100
      IF(NBL.EQ. 528) GO TO 100
      IF(NBL.EQ. 540) GO TO 100
      IF(NBL.EQ. 541) GO TO 100
      IF(NBL.EQ. 555) GO TO 100
      IF(NBL.EQ. 566) GO TO 100
      IF(NBL.EQ. 586) GO TO 100
      IF(NBL.EQ. 619) GO TO 100
      IF(NBL.EQ. 621) GO TO 100
      IF(NBL.EQ. 624) GO TO 100
      IF(NBL.EQ. 646) GO TO 100
      IF(NBL.EQ. 652) GO TO 100
      IF(NBL.EQ. 656) GO TO 100
      IF(NBL.EQ. 688) GO TO 100
      IF(NBL.EQ. 695) GO TO 100
      IF(NBL.EQ. 712) GO TO 100
      IF(NBL.EQ. 721) GO TO 100
      IF(NBL.EQ. 737) GO TO 100
      IF(NBL.EQ. 743) GO TO 100
      IF(NBL.EQ. 753) GO TO 100
      IF(NBL.EQ. 754) GO TO 100
      IF(NBL.EQ. 793) GO TO 100
      IF(NBL.EQ. 810) GO TO 100
      IF(NBL.EQ. 814) GO TO 100
      IF(NBL.EQ. 845) GO TO 100
      IF(NBL.EQ. 848) GO TO 100
      IF(NBL.EQ. 877) GO TO 100
      IF(NBL.EQ. 884) GO TO 100
      IF(NBL.EQ. 887) GO TO 100
      IF(NBL.EQ. 940) GO TO 100
      IF(NBL.EQ. 966) GO TO 100
      IF(NBL.EQ.1039) GO TO 100
      IF(NBL.EQ.1078) GO TO 100
      IF(NBL.EQ.1093) GO TO 100
      IF(NBL.EQ.1127) GO TO 100
      IF(NBL.EQ.1137) GO TO 100
      IF(NBL.EQ.1138) GO TO 100
      IF(NBL.EQ.1141) GO TO 100
      IF(NBL.EQ.1142) GO TO 100
      IF(NBL.EQ.1167) GO TO 100
      IF(NBL.EQ.1192) GO TO 100
      IF(NBL.EQ.1224) GO TO 100
      IF(NBL.EQ.1257) GO TO 100
      IF(NBL.EQ.1272) GO TO 100
      IF(NBL.EQ.1304) GO TO 100
      IF(NBL.EQ.1333) GO TO 100
      IF(NBL.EQ.1334) GO TO 100
      IF(NBL.EQ.1346) GO TO 100
      IF(NBL.EQ.1347) GO TO 100
      IF(NBL.EQ.1351) GO TO 100
      IF(NBL.EQ.1354) GO TO 100
      IF(NBL.EQ.1363) GO TO 100
      IF(NBL.EQ.1365) GO TO 100
      IF(NBL.EQ.1391) GO TO 100
      IF(NBL.EQ.1397) GO TO 100
      IF(NBL.EQ.1419) GO TO 100
      IF(NBL.EQ.1449) GO TO 100
      IF(NBL.EQ.1468) GO TO 100
      IF(NBL.EQ.1474) GO TO 100
      IF(NBL.EQ.1481) GO TO 100
      IF(NBL.EQ.1487) GO TO 100
      IF(NBL.EQ.1508) GO TO 100
      IF(NBL.EQ.1520) GO TO 100
      IF(NBL.EQ.1537) GO TO 100
      IF(NBL.EQ.1538) GO TO 100
      IF(NBL.EQ.1545) GO TO 100
      IF(NBL.EQ.1563) GO TO 100
      IF(NBL.EQ.1565) GO TO 100
      IF(NBL.EQ.1580) GO TO 100
      IF(NBL.EQ.1592) GO TO 100
      IF(NBL.EQ.1593) GO TO 100
      IF(NBL.EQ.1615) GO TO 100
      IF(NBL.EQ.1626) GO TO 100
      IF(NBL.EQ.1640) GO TO 100
      IF(NBL.EQ.1648) GO TO 100
      IF(NBL.EQ.1649) GO TO 100
      IF(NBL.EQ.1679) GO TO 100
      IF(NBL.EQ.1682) GO TO 100
      IF(NBL.EQ.1729) GO TO 100
      IF(NBL.EQ.1739) GO TO 100
      IF(NBL.EQ.1741) GO TO 100
      IF(NBL.EQ.1743) GO TO 100
      IF(NBL.EQ.1747) GO TO 100
      IF(NBL.EQ.1749) GO TO 100
      IF(NBL.EQ.1769) GO TO 100
      IF(NBL.EQ.1779) GO TO 100
      IF(NBL.EQ.1781) GO TO 100
      IF(NBL.EQ.1796) GO TO 100
      IF(NBL.EQ.1807) GO TO 100
      IF(NBL.EQ.1859) GO TO 100
      IF(NBL.EQ.1872) GO TO 100
      IF(NBL.EQ.1884) GO TO 100
      IF(NBL.EQ.1890) GO TO 100
      IF(NBL.EQ.1964) GO TO 100
      IF(NBL.EQ.1993) GO TO 100
      IF(NBL.EQ.2033) GO TO 100
      IF(NBL.EQ.2095) GO TO 100
      IF(NBL.EQ.2199) GO TO 100
      IF(NBL.EQ.2151) GO TO 100
      IF(NBL.EQ.2203) GO TO 100
      IF(NBL.EQ.2220) GO TO 100
      IF(NBL.EQ.2215) GO TO 100
      IF(NBL.EQ.2238) GO TO 100
      IF(NBL.EQ.2254) GO TO 100
      IF(NBL.EQ.2256) GO TO 100
      IF(NBL.EQ.2259) GO TO 100
      IF(NBL.EQ.2342) GO TO 100
      IF(NBL.EQ.2351) GO TO 100
      IF(NBL.EQ.2354) GO TO 100
      IF(NBL.EQ.2407) GO TO 100
      IF(NBL.EQ.2411) GO TO 100
      IF(NBL.EQ.2418) GO TO 100
      IF(NBL.EQ.2424) GO TO 100
      IF(NBL.EQ.2440) GO TO 100
      IF(NBL.EQ.2448) GO TO 100
      IF(NBL.EQ.2451) GO TO 100
      IF(NBL.EQ.2474) GO TO 100
      IF(NBL.EQ.2530) GO TO 100
      IF(NBL.EQ.2552) GO TO 100
      IF(NBL.EQ.2554) GO TO 100
      IF(NBL.EQ.2597) GO TO 100
      IF(NBL.EQ.2689) GO TO 100
      IF(NBL.EQ.2760) GO TO 100
      IF(NBL.EQ.2810) GO TO 100
      IF(NBL.EQ.2811) GO TO 100
      GO TO 200
C**    12 GEV DATA
102   IF(HRUN.GT.2520) GO TO 103
      IF(NBL.EQ.   9) GO TO 100
      IF(NBL.EQ.  35) GO TO 100
      IF(NBL.EQ.  45) GO TO 100
      IF(NBL.EQ. 112) GO TO 100
      IF(NBL.EQ. 119) GO TO 100
      IF(NBL.EQ. 141) GO TO 100
      IF(NBL.EQ. 169) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 305) GO TO 100
      IF(NBL.EQ. 377) GO TO 100
      IF(NBL.EQ. 399) GO TO 100
      IF(NBL.EQ. 423) GO TO 100
      IF(NBL.EQ. 425) GO TO 100
      IF(NBL.EQ. 489) GO TO 100
      IF(NBL.EQ. 646) GO TO 100
      IF(NBL.EQ. 649) GO TO 100
      IF(NBL.EQ. 667) GO TO 100
      IF(NBL.EQ. 754) GO TO 100
      IF(NBL.EQ. 810) GO TO 100
      IF(NBL.EQ. 816) GO TO 100
      IF(NBL.EQ. 904) GO TO 100
      IF(NBL.EQ. 966) GO TO 100
      IF(NBL.EQ.1077) GO TO 100
      IF(NBL.EQ.1095) GO TO 100
      IF(NBL.EQ.1096) GO TO 100
      IF(NBL.EQ.1125) GO TO 100
      IF(NBL.EQ.1142) GO TO 100
      IF(NBL.EQ.1191) GO TO 100
      IF(NBL.EQ.1192) GO TO 100
      IF(NBL.EQ.1255) GO TO 100
      IF(NBL.EQ.1256) GO TO 100
      IF(NBL.EQ.1257) GO TO 100
      IF(NBL.EQ.1285) GO TO 100
      IF(NBL.EQ.1288) GO TO 100
      IF(NBL.EQ.1353) GO TO 100
      IF(NBL.EQ.1354) GO TO 100
      IF(NBL.EQ.1386) GO TO 100
      IF(NBL.EQ.1391) GO TO 100
      IF(NBL.EQ.1419) GO TO 100
      IF(NBL.EQ.1425) GO TO 100
      IF(NBL.EQ.1437) GO TO 100
      IF(NBL.EQ.1644) GO TO 100
      IF(NBL.EQ.1749) GO TO 100
      IF(NBL.EQ.1796) GO TO 100
      IF(NBL.EQ.1807) GO TO 100
      IF(NBL.EQ.1884) GO TO 100
      IF(NBL.EQ.1890) GO TO 100
      IF(NBL.EQ.1964) GO TO 100
      IF(NBL.EQ.2001) GO TO 100
      IF(NBL.EQ.2130) GO TO 100
      IF(NBL.EQ.2151) GO TO 100
      IF(NBL.EQ.2203) GO TO 100
      IF(NBL.EQ.2238) GO TO 100
      IF(NBL.EQ.2256) GO TO 100
      IF(NBL.EQ.2376) GO TO 100
      IF(NBL.EQ.2440) GO TO 100
      IF(NBL.EQ.2472) GO TO 100
      IF(NBL.EQ.2474) GO TO 100
      IF(NBL.EQ.2504) GO TO 100
      IF(NBL.EQ.2587) GO TO 100
      IF(NBL.EQ.2713) GO TO 100
      IF(NBL.EQ.2726) GO TO 100
      IF(NBL.EQ.2760) GO TO 100
      IF(NBL.EQ.2810) GO TO 100
      IF(NBL.EQ.2834) GO TO 100
      IF(NBL.EQ.2835) GO TO 100
      IF(NBL.EQ.2859) GO TO 100
      GO TO 200
C**    33 GEV DATA AND HIGHER, SPRING 1980
103   IF(HRUN.GT.3318.AND.HRUN.LT.3358) GO TO 100
      IF(HRUN.GT.3728) GO TO 105
      IF(NBL.EQ.  14) GO TO 100
      IF(NBL.EQ.  41) GO TO 100
      IF(NBL.EQ.  45) GO TO 100
      IF(NBL.EQ.  49) GO TO 100
      IF(NBL.EQ.  50) GO TO 100
      IF(NBL.EQ.  57) GO TO 100
      IF(NBL.EQ.  72) GO TO 100
      IF(NBL.EQ.  81) GO TO 100
      IF(NBL.EQ.  87) GO TO 100
      IF(NBL.EQ.  91) GO TO 100
      IF(NBL.EQ. 116) GO TO 100
      IF(NBL.EQ. 119) GO TO 100
      IF(NBL.EQ. 120) GO TO 100
      IF(NBL.EQ. 137) GO TO 100
      IF(NBL.EQ. 141) GO TO 100
      IF(NBL.EQ. 144) GO TO 100
      IF(NBL.EQ. 168) GO TO 100
      IF(NBL.EQ. 169) GO TO 100
      IF(NBL.EQ. 172) GO TO 100
      IF(NBL.EQ. 179) GO TO 100
      IF(NBL.EQ. 204) GO TO 100
      IF(NBL.EQ. 211) GO TO 100
      IF(NBL.EQ. 253) GO TO 100
      IF(NBL.EQ. 265) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 293) GO TO 100
      IF(NBL.EQ. 294) GO TO 100
      IF(NBL.EQ. 297) GO TO 100
      IF(NBL.EQ. 299) GO TO 100
      IF(NBL.EQ. 359) GO TO 100
      IF(NBL.EQ. 373) GO TO 100
      IF(NBL.EQ. 412) GO TO 100
      IF(NBL.EQ. 423) GO TO 100
      IF(NBL.EQ. 424) GO TO 100
      IF(NBL.EQ. 432) GO TO 100
      IF(NBL.EQ. 459) GO TO 100
      IF(NBL.EQ. 490) GO TO 100
      IF(NBL.EQ. 491) GO TO 100
      IF(NBL.EQ. 521) GO TO 100
      IF(NBL.EQ. 523) GO TO 100
      IF(NBL.EQ. 533) GO TO 100
      IF(NBL.EQ. 551) GO TO 100
      IF(NBL.EQ. 571) GO TO 100
      IF(NBL.EQ. 585) GO TO 100
      IF(NBL.EQ. 619) GO TO 100
      IF(NBL.EQ. 641) GO TO 100
      IF(NBL.EQ. 646) GO TO 100
      IF(NBL.EQ. 661) GO TO 100
      IF(NBL.EQ. 664) GO TO 100
      IF(NBL.EQ. 667) GO TO 100
      IF(NBL.EQ. 685) GO TO 100
      IF(NBL.EQ. 688) GO TO 100
      IF(NBL.EQ. 697) GO TO 100
      IF(NBL.EQ. 711) GO TO 100
      IF(NBL.EQ. 722) GO TO 100
      IF(NBL.EQ. 753) GO TO 100
      IF(NBL.EQ. 754) GO TO 100
      IF(NBL.EQ. 783) GO TO 100
      IF(NBL.EQ. 785) GO TO 100
      IF(NBL.EQ. 816) GO TO 100
      IF(NBL.EQ. 844) GO TO 100
      IF(NBL.EQ. 856) GO TO 100
      IF(NBL.EQ. 887) GO TO 100
      IF(NBL.EQ. 909) GO TO 100
      IF(NBL.EQ. 919) GO TO 100
      IF(NBL.EQ. 950) GO TO 100
      IF(NBL.EQ. 951) GO TO 100
      IF(NBL.EQ. 966) GO TO 100
      IF(NBL.EQ. 982) GO TO 100
      IF(NBL.EQ. 990) GO TO 100
      IF(NBL.EQ.1015) GO TO 100
      IF(NBL.EQ.1022) GO TO 100
      IF(NBL.EQ.1027) GO TO 100
      IF(NBL.EQ.1033) GO TO 100
      IF(NBL.EQ.1041) GO TO 100
      IF(NBL.EQ.1043) GO TO 100
      IF(NBL.EQ.1065) GO TO 100
      IF(NBL.EQ.1074) GO TO 100
      IF(NBL.EQ.1076) GO TO 100
      IF(NBL.EQ.1077) GO TO 100
      IF(NBL.EQ.1104) GO TO 100
      IF(NBL.EQ.1111) GO TO 100
      IF(NBL.EQ.1128) GO TO 100
      IF(NBL.EQ.1162) GO TO 100
      IF(NBL.EQ.1171) GO TO 100
      IF(NBL.EQ.1224) GO TO 100
      IF(NBL.EQ.1239) GO TO 100
      IF(NBL.EQ.1246) GO TO 100
      IF(NBL.EQ.1272) GO TO 100
      IF(NBL.EQ.1285) GO TO 100
      IF(NBL.EQ.1305) GO TO 100
      IF(NBL.EQ.1308) GO TO 100
      IF(NBL.EQ.1317) GO TO 100
      IF(NBL.EQ.1354) GO TO 100
      IF(NBL.EQ.1359) GO TO 100
      IF(NBL.EQ.1367) GO TO 100
      IF(NBL.EQ.1391) GO TO 100
      IF(NBL.EQ.1429) GO TO 100
      IF(NBL.EQ.1438) GO TO 100
      IF(NBL.EQ.1445) GO TO 100
      IF(NBL.EQ.1457) GO TO 100
      IF(NBL.EQ.1467) GO TO 100
      IF(NBL.EQ.1584) GO TO 100
      IF(NBL.EQ.1608) GO TO 100
      IF(NBL.EQ.1611) GO TO 100
      IF(NBL.EQ.1636) GO TO 100
      IF(NBL.EQ.1643) GO TO 100
      IF(NBL.EQ.1644) GO TO 100
      IF(NBL.EQ.1684) GO TO 100
      IF(NBL.EQ.1708) GO TO 100
      IF(NBL.EQ.1712) GO TO 100
      IF(NBL.EQ.1743) GO TO 100
      IF(NBL.EQ.1748) GO TO 100
      IF(NBL.EQ.1752) GO TO 100
      IF(NBL.EQ.1776) GO TO 100
      IF(NBL.EQ.1859) GO TO 100
      IF(NBL.EQ.1893) GO TO 100
      IF(NBL.EQ.1921) GO TO 100
      IF(NBL.EQ.1934) GO TO 100
      IF(NBL.EQ.1944) GO TO 100
      IF(NBL.EQ.1964) GO TO 100
      IF(NBL.EQ.1968) GO TO 100
      IF(NBL.EQ.1969) GO TO 100
      IF(NBL.EQ.2029) GO TO 100
      IF(NBL.EQ.2062) GO TO 100
      IF(NBL.EQ.2063) GO TO 100
      IF(NBL.EQ.2126) GO TO 100
      IF(NBL.EQ.2129) GO TO 100
      IF(NBL.EQ.2130) GO TO 100
      IF(NBL.EQ.2131) GO TO 100
      IF(NBL.EQ.2154) GO TO 100
      IF(NBL.EQ.2160) GO TO 100
      IF(NBL.EQ.2163) GO TO 100
      IF(NBL.EQ.2171) GO TO 100
      IF(NBL.EQ.2209) GO TO 100
      IF(NBL.EQ.2212) GO TO 100
      IF(NBL.EQ.2219) GO TO 100
      IF(NBL.EQ.2221) GO TO 100
      IF(NBL.EQ.2224) GO TO 100
      IF(NBL.EQ.2227) GO TO 100
      IF(NBL.EQ.2247) GO TO 100
      IF(NBL.EQ.2256) GO TO 100
      IF(NBL.EQ.2260) GO TO 100
      IF(NBL.EQ.2376) GO TO 100
      IF(NBL.EQ.2377) GO TO 100
      IF(NBL.EQ.2384) GO TO 100
      IF(NBL.EQ.2398) GO TO 100
      IF(NBL.EQ.2407) GO TO 100
      IF(NBL.EQ.2416) GO TO 100
      IF(NBL.EQ.2428) GO TO 100
      IF(NBL.EQ.2439) GO TO 100
      IF(NBL.EQ.2448) GO TO 100
      IF(NBL.EQ.2489) GO TO 100
      IF(NBL.EQ.2520) GO TO 100
      IF(NBL.EQ.2534) GO TO 100
      IF(NBL.EQ.2543) GO TO 100
      IF(NBL.EQ.2568) GO TO 100
      IF(NBL.EQ.2739) GO TO 100
      IF(NBL.EQ.2760) GO TO 100
      IF(NBL.EQ.2810) GO TO 100
      IF(NBL.EQ.2834) GO TO 100
      GO TO 200
C**    33-35 GEV DATA , SUMMER 1980
105   IF(HRUN.GT.4860) GO TO 106
      IF(NBL.EQ.   5) GO TO 100
      IF(NBL.EQ.  22) GO TO 100
      IF(NBL.EQ.  23) GO TO 100
      IF(NBL.EQ.  24) GO TO 100
      IF(NBL.EQ.  35) GO TO 100
      IF(NBL.EQ.  43) GO TO 100
      IF(NBL.EQ.  45) GO TO 100
      IF(NBL.EQ.  62) GO TO 100
      IF(NBL.EQ.  92) GO TO 100
      IF(NBL.EQ. 118) GO TO 100
      IF(NBL.EQ. 141) GO TO 100
      IF(NBL.EQ. 158) GO TO 100
      IF(NBL.EQ. 169) GO TO 100
      IF(NBL.EQ. 237) GO TO 100
      IF(NBL.EQ. 253) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 294) GO TO 100
      IF(NBL.EQ. 303) GO TO 100
      IF(NBL.EQ. 377) GO TO 100
      IF(NBL.EQ. 403) GO TO 100
      IF(NBL.EQ. 418) GO TO 100
      IF(NBL.EQ. 427) GO TO 100
      IF(NBL.EQ. 437) GO TO 100
      IF(NBL.EQ. 463) GO TO 100
      IF(NBL.EQ. 513) GO TO 100
      IF(NBL.EQ. 533) GO TO 100
      IF(NBL.EQ. 541) GO TO 100
      IF(NBL.EQ. 566) GO TO 100
      IF(NBL.EQ. 653) GO TO 100
      IF(NBL.EQ. 661) GO TO 100
      IF(NBL.EQ. 664) GO TO 100
      IF(NBL.EQ. 667) GO TO 100
      IF(NBL.EQ. 688) GO TO 100
      IF(NBL.EQ. 694) GO TO 100
      IF(NBL.EQ. 697) GO TO 100
      IF(NBL.EQ. 725) GO TO 100
      IF(NBL.EQ. 726) GO TO 100
      IF(NBL.EQ. 727) GO TO 100
      IF(NBL.EQ. 729) GO TO 100
      IF(NBL.EQ. 730) GO TO 100
      IF(NBL.EQ. 731) GO TO 100
      IF(NBL.EQ. 732) GO TO 100
      IF(NBL.EQ. 738) GO TO 100
      IF(NBL.EQ. 741) GO TO 100
      IF(NBL.EQ. 746) GO TO 100
      IF(NBL.EQ. 747) GO TO 100
      IF(NBL.EQ. 748) GO TO 100
      IF(NBL.EQ. 749) GO TO 100
      IF(NBL.EQ. 754) GO TO 100
      IF(NBL.EQ. 755) GO TO 100
      IF(NBL.EQ. 756) GO TO 100
      IF(NBL.EQ. 758) GO TO 100
      IF(NBL.EQ. 759) GO TO 100
      IF(NBL.EQ. 761) GO TO 100
      IF(NBL.EQ. 762) GO TO 100
      IF(NBL.EQ. 765) GO TO 100
      IF(NBL.EQ. 830) GO TO 100
      IF(NBL.EQ. 844) GO TO 100
      IF(NBL.EQ. 856) GO TO 100
      IF(NBL.EQ. 859) GO TO 100
      IF(NBL.EQ. 881) GO TO 100
      IF(NBL.EQ. 922) GO TO 100
      IF(NBL.EQ. 945) GO TO 100
      IF(NBL.EQ. 951) GO TO 100
      IF(NBL.EQ. 982) GO TO 100
      IF(NBL.EQ. 987) GO TO 100
      IF(NBL.EQ. 993) GO TO 100
      IF(NBL.EQ.1027) GO TO 100
      IF(NBL.EQ.1036) GO TO 100
      IF(NBL.EQ.1086) GO TO 100
      IF(NBL.EQ.1118) GO TO 100
      IF(NBL.EQ.1146) GO TO 100
      IF(NBL.EQ.1150) GO TO 100
      IF(NBL.EQ.1164) GO TO 100
      IF(NBL.EQ.1223) GO TO 100
      IF(NBL.EQ.1224) GO TO 100
      IF(NBL.EQ.1246) GO TO 100
      IF(NBL.EQ.1272) GO TO 100
      IF(NBL.EQ.1275) GO TO 100
      IF(NBL.EQ.1283) GO TO 100
      IF(NBL.EQ.1328) GO TO 100
      IF(NBL.EQ.1334) GO TO 100
      IF(NBL.EQ.1354) GO TO 100
      IF(NBL.EQ.1390) GO TO 100
      IF(NBL.EQ.1415) GO TO 100
      IF(NBL.EQ.1473) GO TO 100
      IF(NBL.EQ.1489) GO TO 100
      IF(NBL.EQ.1501) GO TO 100
      IF(NBL.EQ.1518) GO TO 100
      IF(NBL.EQ.1542) GO TO 100
      IF(NBL.EQ.1545) GO TO 100
      IF(NBL.EQ.1549) GO TO 100
      IF(NBL.EQ.1572) GO TO 100
      IF(NBL.EQ.1667) GO TO 100
      IF(NBL.EQ.1680) GO TO 100
      IF(NBL.EQ.1691) GO TO 100
      IF(NBL.EQ.1720) GO TO 100
      IF(NBL.EQ.1740) GO TO 100
      IF(NBL.EQ.1757) GO TO 100
      IF(NBL.EQ.1807) GO TO 100
      IF(NBL.EQ.1899) GO TO 100
      IF(NBL.EQ.1960) GO TO 100
      IF(NBL.EQ.1961) GO TO 100
      IF(NBL.EQ.1965) GO TO 100
      IF(NBL.EQ.2044) GO TO 100
      IF(NBL.EQ.2063) GO TO 100
      IF(NBL.EQ.2071) GO TO 100
      IF(NBL.EQ.2073) GO TO 100
      IF(NBL.EQ.2077) GO TO 100
      IF(NBL.EQ.2078) GO TO 100
      IF(NBL.EQ.2083) GO TO 100
      IF(NBL.EQ.2090) GO TO 100
      IF(NBL.EQ.2093) GO TO 100
      IF(NBL.EQ.2104) GO TO 100
      IF(NBL.EQ.2116) GO TO 100
      IF(NBL.EQ.2117) GO TO 100
      IF(NBL.EQ.2124) GO TO 100
      IF(NBL.EQ.2125) GO TO 100
      IF(NBL.EQ.2126) GO TO 100
      IF(NBL.EQ.2128) GO TO 100
      IF(NBL.EQ.2129) GO TO 100
      IF(NBL.EQ.2130) GO TO 100
      IF(NBL.EQ.2135) GO TO 100
      IF(NBL.EQ.2154) GO TO 100
      IF(NBL.EQ.2158) GO TO 100
      IF(NBL.EQ.2160) GO TO 100
      IF(NBL.EQ.2164) GO TO 100
      IF(NBL.EQ.2165) GO TO 100
      IF(NBL.EQ.2191) GO TO 100
      IF(NBL.EQ.2192) GO TO 100
      IF(NBL.EQ.2212) GO TO 100
      IF(NBL.EQ.2215) GO TO 100
      IF(NBL.EQ.2243) GO TO 100
      IF(NBL.EQ.2244) GO TO 100
      IF(NBL.EQ.2262) GO TO 100
      IF(NBL.EQ.2264) GO TO 100
      IF(NBL.EQ.2268) GO TO 100
      IF(NBL.EQ.2289) GO TO 100
      IF(NBL.EQ.2299) GO TO 100
      IF(NBL.EQ.2305) GO TO 100
      IF(NBL.EQ.2307) GO TO 100
      IF(NBL.EQ.2316) GO TO 100
      IF(NBL.EQ.2325) GO TO 100
      IF(NBL.EQ.2380) GO TO 100
      IF(NBL.EQ.2384) GO TO 100
      IF(NBL.EQ.2388) GO TO 100
      IF(NBL.EQ.2393) GO TO 100
      IF(NBL.EQ.2395) GO TO 100
      IF(NBL.EQ.2401) GO TO 100
      IF(NBL.EQ.2442) GO TO 100
      IF(NBL.EQ.2447) GO TO 100
      IF(NBL.EQ.2449) GO TO 100
      IF(NBL.EQ.2456) GO TO 100
      IF(NBL.EQ.2459) GO TO 100
      IF(NBL.EQ.2460) GO TO 100
      IF(NBL.EQ.2471) GO TO 100
      IF(NBL.EQ.2472) GO TO 100
      IF(NBL.EQ.2474) GO TO 100
      IF(NBL.EQ.2476) GO TO 100
      IF(NBL.EQ.2478) GO TO 100
      IF(NBL.EQ.2479) GO TO 100
      IF(NBL.EQ.2481) GO TO 100
      IF(NBL.EQ.2482) GO TO 100
      IF(NBL.EQ.2483) GO TO 100
      IF(NBL.EQ.2493) GO TO 100
      IF(NBL.EQ.2494) GO TO 100
      IF(NBL.EQ.2517) GO TO 100
      IF(NBL.EQ.2529) GO TO 100
      IF(NBL.EQ.2531) GO TO 100
      IF(NBL.EQ.2533) GO TO 100
      IF(NBL.EQ.2537) GO TO 100
      IF(NBL.EQ.2538) GO TO 100
      IF(NBL.EQ.2542) GO TO 100
      IF(NBL.EQ.2543) GO TO 100
      IF(NBL.EQ.2593) GO TO 100
      IF(NBL.EQ.2601) GO TO 100
      IF(NBL.EQ.2611) GO TO 100
      IF(NBL.EQ.2618) GO TO 100
      IF(NBL.EQ.2634) GO TO 100
      IF(NBL.EQ.2646) GO TO 100
      IF(NBL.EQ.2653) GO TO 100
      IF(NBL.EQ.2657) GO TO 100
      IF(NBL.EQ.2658) GO TO 100
      IF(NBL.EQ.2662) GO TO 100
      IF(NBL.EQ.2663) GO TO 100
      IF(NBL.EQ.2664) GO TO 100
      IF(NBL.EQ.2665) GO TO 100
      IF(NBL.EQ.2682) GO TO 100
      IF(NBL.EQ.2684) GO TO 100
      IF(NBL.EQ.2713) GO TO 100
      IF(NBL.EQ.2716) GO TO 100
      IF(NBL.EQ.2721) GO TO 100
      IF(NBL.EQ.2810) GO TO 100
      GO TO 200
C**   DATA AUTUMN 1980
106   IF(NBL.EQ.  35) GO TO 100
      IF(NBL.EQ.  43) GO TO 100
      IF(NBL.EQ. 220) GO TO 100
      IF(NBL.EQ. 253) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 301) GO TO 100
      IF(NBL.EQ. 312) GO TO 100
      IF(NBL.EQ. 313) GO TO 100
      IF(NBL.EQ. 314) GO TO 100
      IF(NBL.EQ. 315) GO TO 100
      IF(NBL.EQ. 343) GO TO 100
      IF(NBL.EQ. 427) GO TO 100
      IF(NBL.EQ. 548) GO TO 100
      IF(NBL.EQ. 661) GO TO 100
      IF(NBL.EQ. 667) GO TO 100
      IF(NBL.EQ. 694) GO TO 100
      IF(NBL.EQ. 756) GO TO 100
      IF(NBL.EQ. 757) GO TO 100
      IF(NBL.EQ. 758) GO TO 100
      IF(NBL.EQ. 816) GO TO 100
      IF(NBL.EQ. 830) GO TO 100
      IF(NBL.EQ. 842) GO TO 100
      IF(NBL.EQ. 856) GO TO 100
      IF(NBL.EQ. 908) GO TO 100
      IF(NBL.EQ. 915) GO TO 100
      IF(NBL.EQ. 922) GO TO 100
      IF(NBL.EQ. 951) GO TO 100
      IF(NBL.EQ.1016) GO TO 100
      IF(NBL.EQ.1077) GO TO 100
      IF(NBL.EQ.1117) GO TO 100
      IF(NBL.EQ.1146) GO TO 100
      IF(NBL.EQ.1227) GO TO 100
      IF(NBL.EQ.1457) GO TO 100
      IF(NBL.EQ.1525) GO TO 100
      IF(NBL.EQ.1549) GO TO 100
      IF(NBL.EQ.1691) GO TO 100
      IF(NBL.EQ.1777) GO TO 100
      IF(NBL.EQ.1899) GO TO 100
      IF(NBL.EQ.1938) GO TO 100
      IF(NBL.EQ.1962) GO TO 100
      IF(NBL.EQ.2033) GO TO 100
      IF(NBL.EQ.2082) GO TO 100
      IF(NBL.EQ.2107) GO TO 100
      IF(NBL.EQ.2152) GO TO 100
      IF(NBL.EQ.2158) GO TO 100
      IF(NBL.EQ.2214) GO TO 100
      IF(NBL.EQ.2215) GO TO 100
      IF(NBL.EQ.2269) GO TO 100
      IF(NBL.EQ.2287) GO TO 100
      IF(NBL.EQ.2293) GO TO 100
      IF(NBL.EQ.2340) GO TO 100
      IF(NBL.EQ.2384) GO TO 100
      IF(NBL.EQ.2410) GO TO 100
      IF(NBL.EQ.2446) GO TO 100
      IF(NBL.EQ.2447) GO TO 100
      IF(NBL.EQ.2523) GO TO 100
      IF(NBL.EQ.2595) GO TO 100
      IF(NBL.EQ.2627) GO TO 100
      IF(NBL.EQ.2737) GO TO 100
      GO TO 200
255   CONTINUE
C  SPRING 1981
      IF(NBL.EQ. 147) GO TO 100
      IF(NBL.EQ. 161) GO TO 100
      IF(NBL.EQ. 253) GO TO 100
      IF(NBL.EQ. 281) GO TO 100
      IF(NBL.EQ. 661) GO TO 100
      IF(NBL.EQ. 665) GO TO 100
      IF(NBL.EQ. 667) GO TO 100
      IF(NBL.EQ. 688) GO TO 100
      IF(NBL.EQ. 790) GO TO 100
      IF(NBL.EQ. 814) GO TO 100
      IF(NBL.EQ.1647) GO TO 100
      IF(NBL.EQ.1691) GO TO 100
      IF(NBL.EQ.2205) GO TO 100
      IF(NBL.EQ.2627) GO TO 100
      GO TO 200
100   IER = 1
200   RETURN
      END
