C   10/09/79 C9091001   MEMBER NAME  EVREAH   (JADEGS)      FORTRAN
      SUBROUTINE EVREAH(NUNIT,NWORD,HDATA,IRET)
      IMPLICIT INTEGER*2 (H)
      DIMENSION HDATA(NWORD)
      READ(NUNIT,ERR=1,END=2) NWORD,HDATA
      IRET=0
      RETURN
    1 CONTINUE
      IRET=1
      RETURN
    2 IRET=2
      RETURN
      END
