C   29/06/82 206291130  MEMBER NAME  CMUED    (JADEMUS)     FORTRAN
C             11.20 29/06/82 HUGH MCCANN
      COMMON /CMUED/NCHAN
C  NCHAN IS THE NO. OF I*2 WORDS WHICH ARE CHANGED BY THE CURRENT EDITS.
C    THIS APPROACH IS ADOPTED IN ORDER TO AVOID INITIALISING LOCATIONS
C  IN /CWORK/ .
