C--------------------------------------
C  MACRO CXYFIT .... XYFIT EQUIVALENCES
C--------------------------------------
          LOGICAL TBIT
          EQUIVALENCE(ADWRK(1),TYPE1)
          EQUIVALENCE(ADWRK(2),XSTR)
          EQUIVALENCE(ADWRK(3),YSTR)
          EQUIVALENCE(ADWRK(4),RSTR)
          EQUIVALENCE(ADWRK(5),DXSTR)
          EQUIVALENCE(ADWRK(6),DYSTR)
          EQUIVALENCE(ADWRK(7),DRSTR)
          EQUIVALENCE(ADWRK(8),TYPE2)
          EQUIVALENCE(ADWRK(9),XEND)
          EQUIVALENCE(ADWRK(10),YEND)
          EQUIVALENCE(ADWRK(11),REND)
          EQUIVALENCE(ADWRK(12),DXEND)
          EQUIVALENCE(ADWRK(13),DYEND)
          EQUIVALENCE(ADWRK(14),DREND)
          EQUIVALENCE(ADWRK(15),NPTYPE)
          EQUIVALENCE(ADWRK(16),COEFF1)
          EQUIVALENCE(ADWRK(17),COEFF2)
          EQUIVALENCE(ADWRK(18),COEFF3)
          EQUIVALENCE(ADWRK(19),COEFF4)
          EQUIVALENCE(ADWRK(20),RMSFIT)
          EQUIVALENCE(ADWRK(21),NPUSED)
          EQUIVALENCE(ADWRK(22),CURVT)
          EQUIVALENCE(ADWRK(23),DCURV)
          EQUIVALENCE(ADWRK(24),CURV1)
          EQUIVALENCE(ADWRK(25),CURV2)
CC
          INTEGER*2JTR(10),NHITIN(10)
          REAL*4CHITR(10)
          EQUIVALENCE(ADWRK(26),JTR(1))
          EQUIVALENCE(ADWRK(31),NHITIN(1))
          EQUIVALENCE(ADWRK(36),CHITR(1))
C         - - - - - - - - - - - - - - - -
C         EQUIVALENCE(ADWRK(45),CHITR(10))
          EQUIVALENCE(ADWRK(46),NTRTOT)
CC
          EQUIVALENCE(ADWRK(47),NHIT)
          EQUIVALENCE(ADWRK(48),NTRAK)
          EQUIVALENCE(ADWRK(49),KNTROL)
          EQUIVALENCE(ADWRK(50),ISTORY)
          LOGICAL*1LARR(4),PRINT,FATAL,BADFIT,SETFLG
          EQUIVALENCE(ADWRK(51),LARR(1),PRINT)
          EQUIVALENCE(          LARR(2),FATAL)
          EQUIVALENCE(          LARR(3),BADFIT)
          EQUIVALENCE(          LARR(4),SETFLG)
CC
          EQUIVALENCE(ADWRK(61),SP1,ISP1)
          EQUIVALENCE(ADWRK(62),SP2,ISP2)
          EQUIVALENCE(ADWRK(63),SP3,ISP3)
          EQUIVALENCE(ADWRK(64),SP4,ISP4)
          EQUIVALENCE(ADWRK(65),SP5,ISP5)
          EQUIVALENCE(ADWRK(66),SUMX)
          EQUIVALENCE(ADWRK(67),SUMY)
          EQUIVALENCE(ADWRK(68),SUMXY)
          EQUIVALENCE(ADWRK(69),SUMX2)
          EQUIVALENCE(ADWRK(70),SUMX3)
          EQUIVALENCE(ADWRK(71),SUMX4)
          EQUIVALENCE(ADWRK(72),SUMX2Y)
          EQUIVALENCE(ADWRK(73),X1)
          EQUIVALENCE(ADWRK(74),Y1)
          EQUIVALENCE(ADWRK(75),X2)
          EQUIVALENCE(ADWRK(76),Y2)
CCC
          EQUIVALENCE(ADWRK(93),NMPROG)
          EQUIVALENCE(ADWRK(94),NPTS)
C         EQUIVALENCE(ADWRK(95),NDF)
          EQUIVALENCE(ADWRK(96),XMID)
          EQUIVALENCE(ADWRK(97),YMID)
          EQUIVALENCE(ADWRK(98),SINTH)
          EQUIVALENCE(ADWRK(99),COSTH)
          EQUIVALENCE(ADWRK(100),C2)
          EQUIVALENCE(ADWRK(101),C3)
          EQUIVALENCE(ADWRK(102),C4)
          EQUIVALENCE(ADWRK(103),CURV)
          EQUIVALENCE(ADWRK(104),CHIFIT)
          EQUIVALENCE(ADWRK(105),CHICIR)
          EQUIVALENCE(ADWRK(106),XFIRST)
          EQUIVALENCE(ADWRK(107),XLAST)
          EQUIVALENCE(ADWRK(108),NGOOD)
          EQUIVALENCE(ADWRK(109),NBAD)
          EQUIVALENCE(ADWRK(110),NEXTRA)
          LOGICAL*1USED(80)
          EQUIVALENCE(ADWRK(111),USED(1))
C          - - - - - - - - - - - - - -
C         EQUIVALENCE(ADWRK(130),USED(80))
          REAL*4AX(80),AY(80)
          EQUIVALENCE(ADWRK(131),AX(1))
C          - - - - - - - - - - - - - -
C         EQUIVALENCE(ADWRK(210),AX(80))
          EQUIVALENCE(ADWRK(211),AY(1))
C          - - - - - - - - - - - - - -
C         EQUIVALENCE(ADWRK(290),AY(80))
C---------- END OF MACRO CXYFIT --------------
