C   23/03/97 703231949  MEMBER NAME  MTRINF   (PATRECSR)    SHELTRAN
C**HEADER*** MEMBER  MTRINF         SAVED BY F22HAG  ON 87/04/03  AT 18:35
C
C     -------------- GENERALL TRACK-INFO COMMON -------------------
      DIMENSION IP(10,400)
      COMMON // P(10,400)
      EQUIVALENCE(IP(1,1),P(1,1))
C
      DIMENSION IPE(10,400)
      COMMON /CTRCK0 / NTCH,NTALL,PE(10,400),INDTRK(400),ITRFLG(400)
      EQUIVALENCE(IPE(1,1),PE(1,1))
C
