C   08/02/79 C9092001   MEMBER NAME  LGCRNR   (SOURCE)      FORTRAN
      SUBROUTINE LGCRNR( IPART, IDZ, IPN, ICLS)
C
C      S.YAMADA   08-02-79  23:40
C      LAST MODIFICATION  10-09-79  19:50  Y.WATANABE
C
C---- FLAG IF THE COUNTER IS A CORNER BLOCK IN THE CLUSTER.
C
C---- INPUTS:
C        IPART=BARREL(0), OR END CAPS(+/-1)
C        IZD= IZ(BARREL) OR ID(NO.IN THE QUODRANT FOR END CAPS, 1-24)
C        IPN= IPHI(BARREL) OR IN( NO. IN THE END CAPS,  1--96)
C---- OUTPUT:
C        ICLS=1 IF THE BLOCK IS ON AN EDGE. =0 IF NOT.
C
C
      ICLS=0
      IF(IPART) 20,10,20
C
C---- BARREL (RING 1 AND 32 ARE MISSING NOW)
   10 IF(IDZ.LE.1 .OR. IDZ.GE.30) GO TO 50
      RETURN
C
C---- END CAP
   20 IF(IDZ.LE.4) GO TO 50
      IF(IDZ.LT.16) GO TO 100
      IF(IDZ.EQ.20) GO TO 100
C
C---- EDGE BLOCK
   50 ICLS=1
C
  100 RETURN
      END
