C   07/06/96 606071841  MEMBER NAME  DEFIND   (S4)          FORTG1
      SUBROUTINE DEFIND
      COMMON/BCS/IW(1000)
      COMMON/BNKIND/ISTAT,IRN,IHD,IVT,INDT(32),INDZ,MASK,INDH
      CALL BGAR(IGA)
      CALL VZERO(ISTAT,39)
      CALL BLOC(IRN,'RUN ',0,&1)
    1 CALL BLOC(IVT,'VERT',1,&2)
    2 CALL BLOC(IHD,'HEAD',0,&3)
    3 CONTINUE
      NTR=IW(IVT+2)
      CALL BLOC(IND,'PART',32,&4)
      GOTO 5
    4 CALL BCRE(IND,'PART',32,20,&100,IER)
      CALL BSAW(1,'PART')
      IW(IND+6)=3
      IW(IND+7)=1
    5 INDT(32)=IND
      IF(NTR.EQ.0) GOTO 15
      DO 10 I=1,NTR
      N=IW(IVT+10+I)
      CALL BLOC(IND,'PART',N,&6)
      GOTO 7
    6 CALL BLOC(IND,'TRAC',N,&10)
      CALL TRPART(IND,&10)
      CALL BLOC(IND,'PART',N,&10)
    7 INDT(N)=IND
   10 CONTINUE
   15 CONTINUE
  100 RETURN
      END
