C   11/03/80 106101752  MEMBER NAME  ERRPRT   (JADEGS)      FORTRAN
      SUBROUTINE ERRPRT(IRETCD,IERRNO)
C
C     PRINTOUT OF RUN + EVENT # FOR EACH ERROR OCCURRENCE
C     P. STEFFEN 11/03/80
C
      IMPLICIT INTEGER*2 (H)
C
#include "cheadr.for"
      LOGICAL*1 LBREAD
      COMMON /CADMIN/ IEVTP,NRREAD,NRWRIT,NRERR,LBREAD(4),IFLG
      EQUIVALENCE (HHEADR(18),HRUN) , (HHEADR(19),HEV)
C
  100 FORMAT(' *** ERROR TRAP ***')
      WRITE(6,100)
      WRITE(6,100)
      WRITE(6,100)
      PRINT 2001, IERRNO,NRREAD,HRUN,HEV
 2001 FORMAT(' ERROR',I4,' AT',I6,' TH EVENT. RUN, EVNT. NOS. = ',2I6)
      WRITE(6,100)
      WRITE(6,100)
      WRITE(6,100)
      IF(IERRNO.EQ.214) WRITE(6,2002)
 2002 FORMAT(1X,' ERROR 214 HAS OCCURRED. CALL ABEND.')
      IF(IERRNO.EQ.214) CALL ABEND
      IRETCD = 0
      RETURN
      END
