C   25/11/80 011262001  MEMBER NAME  PREDIT   (JADEGS)      FORTRAN
      SUBROUTINE PREDIT
      IMPLICIT INTEGER*2 (H)
C
C     MAIN SUBROUTINE FOR PATREC IN JET CHAMBERS
C     PETER STEFFEN 15/ 9/79
C *****  GRAPHICS EDITING VERSION ** LAST CHANGE 21.02.80   J.OLSSON ***
C *****  CHANGED TO NEW FORMATS FOR HITLABEL ARRAY AND MIDOUT        ***
#include "cworkpr.for"
#include "cgraph.for"
#include "cpatlm.for"
      IF(ACMD.EQ.0.) GO TO 92
      CALL PATRC1(0)
      CALL TRMOUT(80,' EDIT ENTERED AFTER BACKTRACE, NO CALL TO FIT AND
     +ADMINISTRATION PROGRAM DONE^')
      CALL TRMOUT(80,' TO STOP AUTOMATIC DELETION OF LOW ENERGY TRACKS,
     +USE COMMAND NR 33^')
      GO TO 93
92    CALL PATREC(0)
93    NTRLM = 0
      ACMD = 0.
      CALL CREDIT
      RETURN
      END
