C   12/03/84 412041824  MEMBER NAME  TAGSET   (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      SUBROUTINE TAGSET(IMARK)
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C THIS IS A SPECIAL ROUTINE PROVIDED FOR USERS TO FORCE
C ANALYSIS ROUTINES TO USE A PARTICULAR ANALYSIS - I.E.
C MARK 1 OR 2 OF TAGGTP WHEN NOT USING THE TAGAN ROUTINE
C
C IMARK - INPUT - REQUIRED MARK OF TAGGER
C                 MARK 1 = PRE 1981
C                 MARK 2 = 1981/2
C                 MARK 3 = 1983 ONWARDS
C
C A.J.FINCH 6/3/83
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
#include "cwktag.for"
C
      MARK = IMARK - 1
      IF(MARK.EQ.1)RETURN
      IF(MARK.EQ.2)RETURN
      WRITE(6,600)
600   FORMAT(' WARNING - VALUE OF MARK PROVIDED TO TAGSET IS
     1ILLEGAL THIS IS PROBABLY DISASTEROUS   ')
      RETURN
      END
