C----------------------------------------------------------------------
C      MACRO CGEO3COM..  COMMENTS TO CONTENT OF COMMON /CGEO3/
C----------------------------------------------------------------------
C  ZMINM2 AND ZPLUM2 ARE DISTANCES FROM INTERACTION POINT TO FRONT SUR-
C  FACE OF -Z AND +Z FORWARD LEADGLASS, 1981-82 VERSION. THE BLOCK
C  DIMENSIONS ARE THE SAME AS FOR 1979-80, IN CGEO2
C
C  1983- ... TAGGING APPARATUS: LEAD SCINTILLATER UNITS
C  NRPBSC ARE NUMBER OF MODULES ON ONE SIDE IN Z
C  PBSCR1-4 ARE THE RADII FROM BEAMLINE TO SEGMENT JOINTPOINTS
C  PBSCZ1-4 GIVE THE Z COORDINATES, FROM MINUS Z TO PLUS Z
C------------------------ END OF MACRO CGEO3COM -----------------------
