C   28/05/82 206291132  MEMBER NAME  CMUEDWRK (JADEMUS)     FORTRAN
C   27/05/82 205271447  MEMBER NAME  CMUEDWRK (S)           FORTRAN
C   17/06/81 106170953  MEMBER NAME  CMUED    (JADEMUS1)    FORTRAN
C   12/06/81 106151117  MEMBER NAME  CMUED    (S)           FORTRAN
C
C LAST CHANGE 11.20 29/06/82 HUGH MCCANN  - FIX BUG..PUT NCHAN IN/CMUED/
C      CHANGE 10.00 28/05/82 HUGH MCCANN  - REDUCE CORE REQUIREMENTS FOR
C                                          PRODUCTION OF UPDATE DATASETS
C
      COMMON /CWORK/KTIME,HUPDAT(8370),HLOC(8370),IALPH,NHMUCA
C       N.B.  SEE  ALSO  CMUED.
C
C  THIS FITS IN WITHIN THE MAXIMUM SIZE OF CWORK....PATREC CWORK
C  IS APPROX 40 KBYTES.
C
      DIMENSION HMUCAL(8370)
      EQUIVALENCE (HMUCAL(1),MUCAL(1))
C  KTIME IS THE TIME AT WHICH THIS SET OF EDITS IS TO BE IMPLEMENTED
C         ( IN SECONDS FROM THE START OF 1979 VIA KTMCON)
C  HUPDAT IS AN ARRAY CONTAINING THESE NEW VALUES  (HUPDAT(I),I=1,NCHAN)
C  HLOC   IS AN ARRAY CONTAINING THEIR HALF-WORD ADDRESSES IN THE MUCAL
C         PART OF THE JADE CALIBRATION COMMON.
C  IALPH  IS THE NUMERICAL INDEX (1-20) OF THE ALPHABETIC IDENTIFIER OF
C         CURRENT MUCONE EDIT (ONLY USED DURING MUCONE OPERATIONS) .
C  NHMUCA IS THE HMUCAL LOCATION OF THE HMUCAL WORD WHICH IS CURRENTLY
C         BEING CHANGED ( ONLY USED DURING MUCONE OPERATIONS ).
