C   31/08/79 C9083101   MEMBER NAME  PATDUM   (JADENS)      FORTRAN
      SUBROUTINE INPATC
      RETURN
      END
      SUBROUTINE INPATR
      RETURN
      END
      SUBROUTINE PATREC
      RETURN
      END
