C   05/02/79 C9032101   MEMBER NAME  REPSIT   (JADEGS)      FORTRAN
      SUBROUTINE REPSIT(IUNIT)
C---
C---     REPOSITIONS A FILE SO THAT THE SECOND LOGICAL RECORD IS READY
C---     TO BE READ.
C---
      REWIND IUNIT
      READ(IUNIT) IDUMMY
      RETURN
      END
