C   22/03/97 703221802  MEMBER NAME  JEOSUM1  (JADEGS)      FORTRAN
C   22/03/97 703221757  MEMBER NAME  #CALNEWS (JADEGS)      FORTRAN
         THIS MEMBER DESCRIBES CHANGES TO THE STANDARD
          CALIBRATION FILES MADE SINCE 14 NOVEMBER 1980

          NEW TOF CALIBRATION CONSTANTS INSTALLED FOR RUN 4863 ON.
          (1 SEPT. 1980 0H 59MIN 21 SEC). INSTALLATION DONE 19.45
          ON 25 NOVEMBER 1980.

          THE TOF CALIBRATION CONSTANTS WHICH WENT INTO EFFECT FROM
          RUN 4863 ON (1 SEPT. 1980 0H 59MIN 21 SEC) HAVE BEEN
          MOVED SO THAT THEY GO INTO EFFECT FROM RUN 4993 ON
          (1 OCT. 1980 3H 52MIN 7SEC). A NEW SET OF TOF UPDATES WAS
          INTRODUCED AND GOES INTO EFFECT FROM RUN 4842 ON
          (29 AUG. 1980 22H 7MIN 30 SEC). CHANGES INSTALLED 16.39 ON
          6 DECEMBER 1980. FILE F11LHO.CUPDAT1 ALSO CHANGED IN THE
          SAME WAY.

          THE "BIG FIASCO" CHANGEOVER OF THE STANDARD CALIBRATION
          DATA TO INCLUDE THE LATEST GREATEST NOSAKI CORRECTIONS
          WAS IMPLEMENTED BETWEEN 20.35 AMD 20.45 ON 8 DECEMBER 1980.

          A COMPLETE NEW SET OF MUON CALIBRATION CONSTANTS HAS BEEN
          INSTALLED.
                                  22.54 ON 17 DECEMBER 1980.

          DURING THE NIGHT OF JANUARY 11 TO JANUARY 12, 1981 THE
          FILE F11LHO.ASTART0 WAS SOMEHOW DESTROYED. BACKUP WAS
          RESTORED ABOUT 12.00 ON 12 JANUARY OF THE 8 DECEMBER 1980
          VERSION, WHICH DOES NOT INCLUDE THE LATEST NOSAKI CONSTANTS
          OR THE LATEST MUON CALIBRATION DATA. THE FILE WAS LATER
          DESTROYED AGAIN FOR UNKNOWN REASONS. FINALLY ABOUT 14.45
          ON 12 JANUARY 1981 A FULLY CORRECTED F11LHO.ASTART0 WAS
          RESTORED, WITH ALL THE LATEST CALIBRATION DATA. BACKUP
          COPIES F11LHO.KB81012A, B, C AND D CONTAIN DATA OF F11LHO.
          ASTART0, AUPDAT0, ASTART1 AND AUPDAT1 RESPECTIVELY AFTER THE
          LATEST JET CHAMBER AND MUON DATA WERE REINSTALLED.
                                  15.04 ON 12 JANUARY 1981.

          THE JTPL BANK RECORDS ON ASTART1 WERE CHANGED TO ACCOMODATE
          THE NEW JET CHAMBER WIRE RESISTANCES. ASTART1 NOW GOES INTO
          EFFECT AT 0H, 0MIN, 0SEC ON 12 FEB. 1981. CHANGE EFFECTIVE
                                  13.24 ON 26 FEBRUARY 1981.
          THE JTPL AND JTAB BANKS ON ASTART1 WERE CHANGED TO INCORPORATE
          NEW JET CHABER CONSTANTS EFFECTIVE RETROACTIVELY TO THE START
          OF 1981 RUNNING.
                                  21.55 ON 25 MARCH 1981.

          INSTALLED NEW MUON CALIBRATION RECORDS ON ASTART0 AND ASTART1.
          NEW AUPDAT1 IS READY TO BE OVERWRITTEN FROM WRKSPE1, BUT NEED
          MORE SPACE ON STOR05.
                                  00.30 ON 10 APRIL 1981.
          AUPDAT0 NOW 120 TRACKS LONG AND UPDATED WITH NEW MUON
          CONSTANTS.
                                  10.00 ON 10 APRIL 1981.
          FIXED SHIFT OF ONE I*4 ADDRESS IN MUCA DATA ON ASTART0
          AND ASTART1.
                                  22.24 ON 01 MAY 1981.
          BETWEEN 19-20.5.81 ASTART0 WAS OVERWRITTEN AGAIN, THE THIRD
          TIME THIS YEAR. IT WAS REPAIRED AT 20.5.81, AT 18.15, BY
          OVERWRITING IT WITH THE CONTENT OF THE LATEST BACKUP, THE
          FILE F11LHO.KB81121A, WHICH PRESUMABLY CONTAINS THE STATUS
          FROM 1.5.81
                                     J.OLSSON   20.5.81   18.18

          AT 22.00 ON 20.5.81, F22MCC OVERWROTE ASTART0 AGAIN. IT WAS
          REPAIRED WITH HELP OF KB81121A ON 21.5.81, AT 10.00. HOPE-
          FULLY IT WILL NOT HAPPEN AGAIN....

    FROM 2.6.81 P. STEFFEN TOOK OVER UPDATING OF CALIBRATION FILES

    THAT WAS THE END OF THIS MEMBER

    ALL FURTHER NEWS AND CHANGES CAN BE FOUND ON
               'F11PST.LHOLIB.S(#CALNEWS)'
                IN CASE IT SHOULD BE EMIGRATED: THERE ARE NO NEWS


   BACKUPS EXISTING ON 20.5.1981:

F11LHO.KB81012A                              M08931 32008003 00070
F11LHO.KB81012B                              M08588 32008003 00087
F11LHO.KB81012C                              M08931 32008003 00069
F11LHO.KB81012D                              M08712 32008003 00013
F11LHO.KB81047A                              M00955 32008003 00013
F11LHO.KB81047B                              M08491 32008003 00030
F11LHO.KB81047C                              M07898 32008003 00042
F11LHO.KB81047D                              M08896 32008003 00027
F11LHO.KB81057A                              M03127 32008003 00083
F11LHO.KB81057B                              M08948 32008003 00025
F11LHO.KB81057C                              M03127 32008003 00084
F11LHO.KB81057D                              M03959 32008003 00005
F11LHO.KB81072A                              M05819 32008003 00089
F11LHO.KB81072B                              M10476 32008003 00001
F11LHO.KB81072C                              M05819 32008003 00090
F11LHO.KB81072D                              M05047 32008003 00021
F11LHO.KB81084C                              M05154 32008003 00083
F11LHO.KB81099A                              M05947 32008003 00087
F11LHO.KB81099B                              M00786 32008003 00047
F11LHO.KB81099C                              M05947 32008003 00091
F11LHO.KB81099D                              M05562 32008003 00069
F11LHO.KB81100B                              M03736 32008003 00022
F11LHO.KB81121A                              M03823 32008003 00005
F11LHO.KB81121B                              M09264 32008003 00057
F11LHO.KB81121C                              M03823 32008003 00004
F11LHO.KB81121D                              M03823 32008003 00055
C   22/03/97 703221757  MEMBER NAME  #GRAPHIX (JADEGS)      FORTRAN




     THIS MEMBER WAS ONCE USED TO CREATE GRAPHICS MODULES.



                   N O   M O R E !



     PLEASE USE THE MEMBER 'F11LHO.GRAFIX.S(#GRAPHIX)'.



C   22/03/97 703221757  MEMBER NAME  #JADE    (JADEGS)      FORTRAN
F11AMB
F11BAR
F11BEK
F11BET
F11BOC
F11DIE
F11DIK
F11HAG
F11HEI
F11HEL
F11HEU
F11HUG
F11JVK
F11KUH
F11LAU
F11MEI
F11NOZ
F11OLS
F11PEA
F11PIE
F11PRC
F11PST
F11RAM
F11RIE
F11SPI
F11WAG
F11WIE
F22ALL
F22BAC
F22BOW
F22CAR
F22CHR
F22COD
F22COR
F22DUE
F22FEL
F22FIN
F22FKL
F22GLE
F22GRE
F22HAG
F22HAI
F22HEM
F22HIL
F22HOW
F22JTB
F22KAD
F22KAN
F22KLE
F22KMT
F22KOB
F22KOM
F22KRB
F22MCC
F22MIN
F22NAR
F22NOZ
F22ODA
F22ORI
F22PAU
F22PET
F22PWA
F22RAM
F22RIP
F22RJB
F22ROW
F22SAT
F22SAU
F22SMN
F22SNE
F22TAK
F22TKE
F22TOT
F22VAL
F22WEN
F22YAM
F32BOB
F32BSZ
F32DSD
F32GLA
F32GTZ
F32GUS
F32HJU
F32JAS
F32KNA
F32KNE
F32KNI
F32RGG
F32WAG
C   22/03/97 703221757  MEMBER NAME  #START0  (JADEGS)      FORTRAN
ALLOC F(MACRO) DA('F11GOD.PATRECSR')
./ SHOW '  THIS IS THE "FULL BOS" STANDARD LIBRARY.                    '
./ SHOW '     EFFECTIVE 08.45 06.09.79.                                '
./ SHOW '  MUON ROUTINES ARE NOW ALL ON F22ALL.JADEMUL.                '
./ SHOW '  OLD MINIBOS LIBRARIES, WITH MUON ROUTINES ARE BACKED UP     '
./ SHOW '  AS F11LHO.MBGRAPHS, F11LHO.MBGRAPHL, F11LHO.MBJADEGS AND    '
./ SHOW '  F11LHO.MBJADEGL.                                            '
./ SHOW 'REPLACED KLREAD AND OVERWROTE F11LHO.ASTART0, ASTART1,       '
./ SHOW 'AUPDAT0, AUPDAT1. TOF DATA NOW IN STANDARD CALIBRATION       '
./ SHOW 'SCHEME.   12.00 10.09.79                 L.H. ONEILL         '
./ SHOW 'CHANGED MUINI CALLING SEQUENCE IN SUPERV IN COORDINATION   '
./ SHOW 'WITH J. ALLISON AND H. PROSPER. INTRODUCED CALL TO MUREG   '
./ SHOW 'IN KALIBR RIGHT AFTER KLREAD CALL. GOT RID OF INITIALIZATION'
./ SHOW 'OF MUON CALIBRATION UNIT NUMBERS IN GPHMAIN AND SUPERV.     '
./ SHOW 'IT IS NOT NECESSARY TO ATTACH THESE FILES. ASKED J. A. AND   '
./ SHOW 'H. P. TO INFORM USERS.              L. ONEILL 21.28 25.09.79 '
./ SHOW '  TOOK OUT MUCON CALL IN EVREAD.  11.40 05.10.79. L.H. ONEILL '
./ SHOW 'COPIED F1EBLO.BOSLIB.S/L TO F11LHO.BOSBAK.S/L AND ANTIFASTED. '
./ SHOW '                            L.H. ONEILL 09.10.79 19.49        '
./ SHOW 'COPIED NEW RDMTCO AND RDTRG1, RDTRG2 AND TAGSIM FROM          '
./ SHOW 'F22ELS.JMC.S                L.H. ONEILL 18.46 11.10.79        '
./ SHOW 'REINSTALLED MUCON CALL IN EVREAD FOR MONTE CARLO AND       '
./ SHOW 'TAUGHT KLREAD TO IGNORE MUON CALIBRATION DATA ON DISK      '
./ SHOW 'IN THE CASE OF MONTE CARLO DATA. RELINKED GRAPHL(JADEZ)    '
./ SHOW '                  DONE 19.30      18.10.79    L.H. ONEILL  '
./ SHOW 'GOT RID OF 9 SPECIAL MUON COMMONS IN EVWRIT AND INSTALLED '
./ SHOW 'CALL TO MUCONW.               L.H. ONEILL 14.50. 14.11.79   '
./ SHOW '  INSTALLED NEW RDMTCO FROM F22ELS.JMC.S. L.H. ONEILL      '
./ SHOW '                                    10.22 04.12.79         '
./ SHOW 'CORRECTED BUG IN JETCAL CAUSING AMPLITUDE SLEWING CORRECTION '
./ SHOW 'TO BE APPLIED FOR LARGE RATHER THAN SMALL PULSE HEIGHTS.     '
./ SHOW '                              19.02 15.01.80. L.H. ONEILL.   '
./ SHOW 'INSTALLED DITTMANNS VERTEX PROGRAM + DISPLAY. FOLLOWING'
./ SHOW 'ROUTINES NEWLY INSTALLED OR UPDATED:   RSDISP VXDISP TRKROL'
./ SHOW 'VERTEX VTXAFT VTXPRE VTXEE VTXSRC VTXINI SUPERV VTXBNK VTXPNT'
./ SHOW 'KOMMAN DISPLY SCANNR BANKPR                 J.OLSSON 08.02.80'
./ SHOW 'UPDATED VXDISP                              J.OLSSON 09.02.80'
./ SHOW 'UPDATED VXDISP VERTEX VTXSRC VTXEE BANKPR   J.OLSSON 11.02.80'
./ SHOW 'CHANGED SUPERV TO SET IPFAST IN CPATLM TO 2 BEFORE USER(0).  '
./ SHOW '                              19.25 12.02.80. L.H. ONEILL.   '
./ SHOW 'INSTALLED COMMAND DEDX.  FOLLOWING ROUTINES UPDATED OR NEW:'
./ SHOW 'DEDXAN DEDXDS DEDXBK KOMMAN DISPLY SCANNR BANKPR NEWS MENU   '
./ SHOW 'UPDATED CHANGE AND JBMENU AND VTXSRC       J.OLSSON 16.02.80'
./ SHOW 'INSTALLED SR TRACK,MOMGAM,PARMIN FOR DEDX  J.OLSSON 17.02.80'
./ SHOW 'INSTALLED COMMAND BL   INVOLVED ROUTINES ARE: '
./ SHOW ' KOMMAN SCANNR DISPLY BLSHOW BLNUMB SPINNR'
./ SHOW 'CHANGED SUPERV TO OVERWRITE WRONG YEAR IN EVENT HEADER.     '
./ SHOW '                              12.43 25.02.80. L.H. ONEILL.   '
./ SHOW 'REMOVED LAST USELESS CHANGE - ONLY EFFECTIVE AT USER(2)     '
./ SHOW 'AND REINSTALLED IUHR SINCE TEST JOB AT 15.48 SHOWS IT WORKS.'
./ SHOW '                              16.41 25.02.80. L.H. ONEILL.   '
./ SHOW 'ZVERTF CHANGED', OLD VERSION "ZVERTF0"  P.ST. 03.03.80'
./ SHOW 'INSTALLED DISPLAY OF TOF COUNTER NUMBERS IN THE R-PHI VIEWS '
./ SHOW 'FOR THOSE COUNTERS ACTUALLY HIT, AND INSTALLED DISPLAY OF   '
./ SHOW 'TOF COUNTERS THEMSELVES IN THE Z-X AND Z-Y VIEWS. THESE     '
./ SHOW 'DISPLAYS INVOLVE CHANGES TO EVDISP AND JADISP RESPECTIVELY. '
./ SHOW 'IN SUPERV CHANGED THE TOF HALF-LENGHTS FROM 1500 TO 1615 MM '
./ SHOW 'IN BLOCK DATA ACCORDING TO INFORMATION RECEIVED FROM        '
./ SHOW 'B. NAROSKA. INSTALLED EXTERNAL STATEMENT AND ERRSET CALLS   '
./ SHOW 'FOR NEW PST IBCOM ERROR TRAP ROUTINE ERRPRT, ALSO IN SUPERV.'
./ SHOW '                              17.51 11.03.80. L.H. ONEILL.   '
./ SHOW 'CRTREL RENAMED TO CRTREL0. CRTREL COPIED TO PATRECSR. '
./ SHOW 'THIS IS TO PREPARE FOR CHANGE OF /CCYCP/ IN PATREC PACKAGE'
./ SHOW 'ALL INVOLVED ROUTINES ON PATRECSR        J.OLSSON 18.3.80'
./ SHOW 'INSTALLED COMMAND QP, TO SHOW KOBAYASHI Q-PLOTS'
./ SHOW 'INVOLVED ROUTINES ARE : KOMMAN DISPLY SCANNR MENU NEWS'
./ SHOW 'AND THE PACKAGE QPLOTS: '
./ SHOW '     SUBROUTINES QPLOTS EVIPR4 EVIPR2 BOX BOX3 TRIANQ PSCALE'
./ SHOW '                 PLIMIT SUMPAT CHCLSP SPHRIX EHIST OUTPRD '
./ SHOW '                 MOTAPR MTOPRM KIPRCR'
./ SHOW '  THEY CAN ALL BE OVERLAYED IN ONE BRANCH'
./ SHOW '  THEY REQUIRE FURTHER THE ROUTINES EIGEN AND LOC'
./ SHOW '                                       J.OLSSON  24.03.80'
./ SHOW 'INSTALLED NEW SUPERV VERSION WITH SINGLE CALLS TO IBLN   '
./ SHOW 'AND OTHER MINOR CHANGES                L.H.O 11.04 28.03.80'
./ SHOW 'CHANGED BUG IN KLREAD CAUSING CLEARING OF MUON CALIBRATION'
./ SHOW 'DATA IN MONTE CARLO CASE.              L.H.O 17.25 02.04.80'
./ SHOW 'UPDATE OF DEDXBN: THIS IS THE GRAPHICS VERSION OF DEDXAN ON '
./ SHOW 'THE TP-LIBRARY. IT IS DIFFERENT IN THE FOLLOWING ASPECTS:'
./ SHOW '   THE MEMBER CONTAINS THE SUBROUTINE POLINT'
./ SHOW '   TRACK LOOP OVER PATR AND NOT OVER TP TRACK BANKS'
./ SHOW '   RESULTS WRITTEN INTO COMMON /CWORK1/, NOT INTO TP BANK'
./ SHOW '   MOMENTUM COMPUTED FROM PATR BANK VIA SUBROUTINE TRACK '
./ SHOW '   SUBROUTINE DEDXDS ALSO UPDATED TO CALL DEDXBN '
./ SHOW '                           J.OLSSON 16.04.80'
./ SHOW ' UPDATED GAMDIS AND SPINNR              J.OLSSON  24.4.80'
./ SHOW ' UPDATED SCANNR, SPINNR AND BANKPR   J.OLSSON  28.4.80'
./ SHOW ' UPDATED DEDXBN,DEDXDS,EBEAM,SPINNR,NEWS  J.OLSSON  08.5.80'
./ SHOW ' INSTALLED DEDXVW, UPDATED NOTICE     J.OLSSON  08.5.80'
./ SHOW ' UPDATED SPINNR,DEDXDS,DEDXVW,BANKPR,NEWS,MENU,NOTICE'
./ SHOW ' INSTALLED COMMAND -TOF- INVOLVED MEMBERS ARE TOFDS,TOFVW'
./ SHOW '    AS WELL AS KOMMAN,SCANNR,DISPLY    THE MEMBER TOFDS IS A'
./ SHOW '    PACKAGE OF ROUTINES THAT CAN ALL BE OVERLAYED, SEE MEMBER'
./ SHOW '    JADEOVLY IN F11PEA.DATA           J.OLSSON  15.5.80'
./ SHOW ' INSTALLED NEW VERSIONS OF THE FOLLOWING MONTE CARLO READING'
./ SHOW ' ROUTINES, COPIED FROM F22ELS.JMC.S ON 31.5.80:              '
./ SHOW '  RDMTCO (WITH ENTRY RDJETC), RDMODN, RDDDCL, RDDOUB, RDINEF,'
./ SHOW '  RDMERG, RDPOIN, RDRDMH, RDPATR, RDRESO, NVERT, RDTRG1, '
./ SHOW '  RDTRG2, TAGSIM, RDSTAT. THESE ARE NOW ALL UNDER MEMBER '
./ SHOW '  RDMTCO AND THE DUPLICATE OLD MEMBERS HAVE BEEN SCRATCHED.'
./ SHOW '                                    L. ONEILL 15.55 04.06.80 '
./ SHOW 'UPDATED EVDISP(TRIG DISPLAY), EBEAM AND SPINNR           '
./ SHOW 'CORRECTED LONGSTANDING ERROR IN RDMTCO(RDJETC) CAUSING NON-'
./ SHOW 'CREATION OF TRIGGER BANKS IF JETC DATA MISSING (NEUTRALS)'
./ SHOW '                                      J.OLSSON  08.6.80'
./ SHOW 'CORRECTED 3 ERRORS IN VTXSRC, AFTER DITTMANNS DIRECTIONS   '
./ SHOW 'THEY CAUSED TIME LOOPS AND WRONG NR IN BANKS             '
./ SHOW '                                      J.OLSSON  09.6.80'
./ SHOW '  INSTALLED CALL TO MUHDSP IN TRKHIT.                      '
./ SHOW '                                    L. ONEILL 21.30 16.06.80 '
./ SHOW '  CHANGED TWISTING ANGLE IN KALIBR FOR DATA FROM RUN 3730. '
./ SHOW '                                    L. ONEILL 11.18 17.06.80 '
./ SHOW '  INSTALLED FWMUCN AND FWMUHT, COUNTER AND HIT DISPLAY     '
./ SHOW '  ROUTINES FOR THE FORWARD MUON COUNTERS. NEW COMMAND      '
./ SHOW '  FWMU SHOWS THESE IN X-Y PLANE.                           '
./ SHOW '  THESE ROUTINES CAN BE OVERLAYED IN THE JADISP    '
./ SHOW '  AND EVDISP BRANCHES RESPECTIVELY.                        '
./ SHOW '                                    L. ONEILL 19.58 17.06.80 '
./ SHOW '  TOOK ZOFFS OFFSET OUT OF EVDISP.                         '
./ SHOW '                                    L. ONEILL 11.06 01.07.80 '
./ SHOW '  UPDATED DEDXBN,TOFDS ON UNDEF VARIABLES, ERRORS          '
./ SHOW '  UPDATED NUMBWR,DISPLY ON UNDEF. VARIABLES         '
./ SHOW '  UPDATED EBEAM,IDFUN               J.OLSSON 08.07.80 '
./ SHOW '  ZVERTF: ALLOW FOR DEAD CELL IN RING 1  P.STEFFEN 25/07/80'
./ SHOW '  UPDATED EBEAM,EFMASS,INSTALLED JEGAIN '
./ SHOW '  UPDATED CREDIT,KOMMAN,DISPLY,SCANNR    J.OLSSON 25/07/80'
./ SHOW '  UPDATED JADISP,BANKPR   J.OLSSON 28/07/80'
./ SHOW ' INSTALLED COMMAND -VRES- INVOLVED MEMBERS ARE VXDISP,'
./ SHOW '   RSDISP,LINDIS,CIRDIS,PARDIS,DISPLY,KOMMAN,SCANNR,NOTICE'
./ SHOW '   MENU AND NEWS.  UPDATED EBEAM,IDFUN    J.OLSSON  30.07.80'
./ SHOW '  CORRECTED MASS ERROR IN EFMASS    J.OLSSON  30.07.80'
./ SHOW '  CORRECTED TOFDS AND TOFVW. IN LINKING NEW MODULE, ONE'
./ SHOW '  HAS TO LINK IN F22NAR.TOFLIB.L.    ALSO NEW OVERLAY, SEE'
./ SHOW '  E.G. F11OLS.JADESR(JBOVER)          J.OLSSON  24.8.80'
./ SHOW '  UPDATED EBEAM.  INSTALLED SUBROUTINES REDONE,REDTVA AS '
./ SHOW '  DESCRIBED IN COMP.NOTE 60.  INVOLVED SUPPORT ROUTINES ARE:'
./ SHOW '  TRGCHK,LGCUT,TAGFLG,HWORLD,TOFCHK,RDATA.  J.OLSSON 25.8.80'
./ SHOW '  INSTALLED NEW VERSIONS OF RDSTAT AND RDTRG1 UNDER MEMBER '
./ SHOW '  RDMTCO.                           L. ONEILL 19.00 26.08.80 '
./ SHOW ' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - '
./ SHOW '  JETCAL CHANGED (OLD VERSION = JETCAL0):                   '
./ SHOW '                 NEGATIVE DRIFT TIMES ALLOWED'              '
./ SHOW '                 BANK DESCRIPTOR INCREASED BY 200          '
./ SHOW '                                  P. STEFFEN 11.00 12.09.80 '
./ SHOW '  SUPERV CHANGED TO BLOCK DATA SET NEW CJDRCH               '
./ SHOW '  TOFBK NOW SEPARATE ROUTINE, PREVIOUSLY IN MEMBER TOFDS    '
./ SHOW '                                  J. OLSSON 14.50 18.09.80 '
./ SHOW ' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - '
./ SHOW '  UPDATED BANKPR                     J.OLSSON 01.10.80    '
./ SHOW '  UPDATED EBEAM AND RDATA            J.OLSSON 07.10.80    '
./ SHOW '  UPDATED TRGCHK AND JOINED IT TO MEMBER REDONE '
./ SHOW '  REDONE AND REDTVA ALSO UPDATED TO LATEST STAND OF REDUC1,2'
./ SHOW '  ADDED SUBR. MEWT3 FOR THOSE WHO DO NOT LINK JADEPR.JADELD'
./ SHOW '                                                 J.O. 17.10.80'
./ SHOW '  UPDATED EBEAM AND RDATA            J.OLSSON 21.10.80    '
./ SHOW '  UPDATED TAGCHK AND FWCHEV          J.OLSSON 25.10.80    '
./ SHOW '  NOZAKIS NEW CONSTANT SCHEME INTRODUCED UNDER ALIAS NAMES'
./ SHOW '  MEMBERS : SUPERVN,JETCALN,KALIBRN,KLREADN   J.O.  25.10.80'
./ SHOW '  UPDATED EBEAM                      J.OLSSON 02.11.80    '
./ SHOW '  REMOVED CALL TO CORLAR IN SUPERV AND SCRATCHED TOFSMP   '
./ SHOW '                    15.20 ON 03.11.80. L.H. ONEILL        '
./ SHOW '  INSERTED NRUN IN ARGUMENT FIELD OF TOFSMP CALL IN EVDISP.'
./ SHOW '                    19.30 ON 04.11.80. L.H. ONEILL        '
./ SHOW '  INSERTED ARGUMENT NRUN IN TOFCHK/TOFSMP CALL IN REDTVA'
./ SHOW '  AND UPDATED SPINNR                 J.OLSSON 05.11.80    '
./ SHOW '  UPDATED KALIBRN,SUPERVN FOR A MC-VALUE  J.OLSSON 10.11.80'
./ SHOW '  UPDATED EBEAM                      J.OLSSON 10.11.80    '
./ SHOW '  CHANGED SUPERV SO THAT PATTERN RECOGNITION IS NOT CALLED '
./ SHOW '  EVEN IF PATR BANK IS NOT PRESENT IF THE CURRENT EVENT HAS'
./ SHOW '  ALREADY BEEN PROCESSED BY REDUC1, I.E. IF THE 27TH I*2   '
./ SHOW '  DATA WORD OF THE HEADER BANK IS NOT ZERO.                '
./ SHOW '                    12.12 ON 14.11.80. L.H. ONEILL        '
./ SHOW '  UPDATED PREDIT,CREDIT,SPINNR            J.OLSSON 17.11.80'
./ SHOW '  INSTALLED SERVICE MEMBERS USREDUC2&JBREDUC2  J.O. 22.11.80'
./ SHOW '  UPDATED PREDIT,CREDIT                   J.OLSSON 26.11.80'
./ SHOW '  CHANGED SUPERV SO THAT PATTERN RECOGNITION IS CALLED EVEN'
./ SHOW '  IF 27TH I*2 WORD OF HEADER IS NON-ZERO IF SUPERV IS RUNNING'
./ SHOW '  UNDER GRAPHICS.   18.39 ON 28.11.80. L.H. ONEILL           '
./ SHOW '  UPDATED BANKPR         J.OLSSON 29.11.80'
./ SHOW '  IMPLEMENTED THE CHANGEOVER TO ROUTINES WHICH HANDLE THE    '
./ SHOW '  NEW NOSAKI JET CHAMBER CALIBRATION CONSTANTS.             '
./ SHOW '  ROUTINES CHANGED ARE SUPERV, KALIBR, KLREAD JETCAL        '
./ SHOW '  AND JRECAL. BACKUP VERSIONS ARE KEPT UNDER THE NAMES      '
./ SHOW '  SUPERV1, KALIBR1, ETC.                                    '
./ SHOW '                    20.35 ON 08.12.80. L.H. ONEILL           '
./ SHOW '  UPDATED DEDXBN         J.OLSSON 06.01.81'
./ SHOW '  UPDATED CREDIT AND SPINNR    J.OLSSON 12.01.81'
./ SHOW '  CORRECTED CREDIT  J.OLSSON 13.01.81'
./ SHOW '  CHANGED THE PARTICLE LIST OPTION IN TRUTH.'
./ SHOW '                    14.10 ON 14.01.81. L.H. ONEILL           '
./ SHOW '  UPDATED BANKPR  J.OLSSON 05.02.81'
./ SHOW '  UPDATED RSDISP VXDISP LINDIS KOMMAN SETSCL NEWS  '
./ SHOW '                                J.OLSSON 06.02.81'
./ SHOW '  UPDATED EVDISP, FWCHEV, JADISP, TAGCHK AND XYTAG,'
./ SHOW '  AND ADDED XYTAGD.                                '
./ SHOW '                    11.34 ON 27.02.81. L.H. ONEILL'
./ SHOW '  CHANGED SUPERV, SCANNR, DISPLY AND KOMMAN IN ORDER TO '
./ SHOW '  IMPLEMENT NEW COMMAND REVT.                      '
./ SHOW '                    21.31 ON 02.03.81. L.H. ONEILL'
./ SHOW '  INSTALLED NEW RDMTCO FROM F22ELS.JMC.S(RDMESS) '
./ SHOW '                    15.55 ON 19.03.81. L.H. ONEILL'
./ SHOW '  CHANGED KALIBR AND JETCAL FOR NEW CONSTANTS. OLD VERSIONS'
./ SHOW '  AS KALIBO AND JETCAL8'
./ SHOW '                    21.50 ON 25.03.81. L. ONEILL AND T. NOZAKI'
./ SHOW '  UPDATED RSDISP VXDISP GAMDIS BANKPR FOR PHOTON DISPLAY  '
./ SHOW '                                J.OLSSON 29.03.81'
./ SHOW '  KILLED YAMADA CALL IN RSDISP AND INTRODUCED IT FOR RU VIEW'
./ SHOW '  INTO THE FIVE ROUTINES WHICH CALL RSDISP: SCANNR, DISPLY,'
./ SHOW '  PROJEC, CREDIT AND MUR2DS.                               '
./ SHOW '                    11.57 ON 01.04.81. L.H. ONEILL            '
./ SHOW '  AGAIN INSTALLED NEW RDMTCO FROM F22ELS.JMC.S(RDMESS) '
./ SHOW '                    11.09 ON 10.04.81. L.H. ONEILL'
./ SHOW '  UPDATED EBEAM USREDUC2 REDTVA   (NEW TRIGGERS) '
./ SHOW '                                J.OLSSON 14.04.81'
./ SHOW '  UPDATED SPINNR,USREDUC2    J.OLSSON  22.4.81'
./ SHOW '  UPDATED LINDIS,USREDUC2    J.OLSSON  23.4.81'
./ SHOW '  UPDATED RDATA   J.OLSSON  24.4.81'
./ SHOW '  INTRODUCED NEW FORWARD TAGGING GAIN AND PEDESTAL FOR THE  '
./ SHOW '  TIME AFTER RUN 2781. TOOK THE NUMBERS WHICH ARE IN FWCHEV.'
./ SHOW '                    14.15 ON 27.04.81. L.H. ONEILL            '
./ SHOW '  ----------------------------------------------------------- '
./ SHOW '  F11GOD.PATRECSR(CWORKZV) CORRECTED + ZVERTF RECOMPILED '
./ SHOW '                    11.50 ON 28.04.81. P S T                  '
./ SHOW '  MEMBER MCGJET ADDED, ON REQUEST OF M.GODDARD.  7.5.81  J.O.'
./ SHOW '  CORRECTED ERROR IN TRUTH    8.5.81  J.O.'
./ SHOW '--------------------------------------------------------------'
./ SHOW '  KALIBR: LORENTZ ANGLE VRIATION WITH MAGNETIC FIELD          '
./ SHOW '          IF FIELD VARIATION > 1%                           '
./ SHOW '  KALIBR0 = OLD VERSION             P. STEFFEN 81/05/12  10.05'
./ SHOW '--------------------------------------------------------------'
./ SHOW '  UPDATED JBOVER  J.O.  13.5.81'
./ SHOW '  CORRECTED ERROR IN RUTRCK   J.O.  13.5.81'
./ SHOW '  CORRECTED ERROR IN COMMAND FIND, PREVIOUSLY REVT.  INVOLVED'
./ SHOW '  ROUTINES DISPLY,SCANNR,KOMMAN,MENU,NEWS      J.O.  19.5.81'
./ SHOW '  UPDATED RDMTCO FROM JMC.S   NEW VERSION HAS SPURIOUS ID HITS'
./ SHOW '  ALSO IN NEUTRAL EVENTS. OLD VERSION RDMTCO0.   SUBR. TAGSIM'
./ SHOW '  REMOVED FROM MEMBER RDMTCO (NO LONGER CALLED IN SYSTEM),  '
./ SHOW '  BUT KEPT AS INDEPENDENT SUBR. TO SATISFY POSSIBLE OVERLAY '
./ SHOW '  PROGRAMS THAT STILL HAS IT IN.       J.O. 19.5.81  '
./ SHOW '  KILLED DSPDTL30 PRINT IN SUPERV !    J.O. 25.5.81  '
./ SHOW '  UPDATED RDMTCO FROM F11ELS.JMC.S(RDMESS)   ELSEN HAS '
./ SHOW '  CORRECTED UNIMPORTANT BUG IN JETC SMEARING   J.O. 26.5.81'
./ SHOW '  UPDATED KALIBR TO CORRECT YEAR 0 IN RUNS 7423-28.  REMOVED'
./ SHOW '  DEBUG PRINT IN JETCAL (DSPDTL30)             J.O. 29.5.81'
./ SHOW '  EXTENDED /CJTRIG/ AND /CADMIN/, TO DOCUMENT NR OF CALIBRA-'
./ SHOW '  TION ERRORS IN SUPERV PRINT. AFFECTED ROUTINES SUPERV,'
./ SHOW '  KALIBR,KTMCON,EVREAD              J.OLSSON  30.5.81'
./ SHOW '  INTRODUCED FWMU AS STANDARD VIEW. GENERAL UPDATE OF MANY'
./ SHOW '  ROUTINES :  KOMMAN, SCANNR, DISPLY, TRKHIT, SETSCL, FWMUCN'
./ SHOW '  FWMUHT, GPHMAIN, MENU, EVDISP, JADISP,CREDIT, NEWS, NOTICE'
./ SHOW '   OVERLAY UPDATED IN JBOVER        J.OLSSON  04.06.81'
./ SHOW '  KALIBR UPDATED (29.FEBRUARY...)   J.OLSSON  05.06.81'
./ SHOW '  TRNUMB UPDATED (SMALL NR IN ZC)   J.OLSSON  09.06.81'
./ SHOW '  ZVERTF CORRECTED(BACKGR. SUBTR.)  P.STEFFEN 10.06.81'
./ SHOW '  LGCUT DELETED (ITS ON JADEPR.JADESR)  P.STEFFEN 10.06.81'
./ SHOW '  MEWT3 DELETED (ITS ON JADEPR.JADESR)  P.STEFFEN 10.06.81'
./ SHOW '  MEWT3 AND LGCUT REINSTALLED . MEWT3 SHOULD NOT BE DELETED'
./ SHOW '  WITHOUT TELLING PEOPLE THAT REDONE LINKS IT IN AND THAT'
./ SHOW '  JADEPR.JADELD HAS TO BE LINKED IN STANDARDLY. MOREOVER,'
./ SHOW '  LGCUT IS DIFFERENT (NO CALL TO HFILL, NO STATUS) AND '
./ SHOW '  SHOULD NOT BE DELETED AT ALL.       J.OLSSON  10.06.81'
./ SHOW '                                                        '
./ SHOW '  THE ABOVE PROBLEM SHOULD NEVER HAVE ARISEN. WHENEVER A '
./ SHOW '  NON-STANDARD COPY OF A STANDARD ROUTINE ON A STANDARD  '
./ SHOW '  LIBRARY IS MADE AND STORED ON ANOTHER STANDARD LIBRARY '
./ SHOW '  THEN THE COPY SHOULD ALWAYS HAVE A DIFFERENT NAME. THIS'
./ SHOW '  SYSTEM WAS AGREED LONG AGO AND MAKES A LOT OF SENSE. TO'
./ SHOW '  HAVE MANY DIFFERENT VERSIONS OF A ROUTINE SCATTERED ABOUT'
./ SHOW '  THE VARIOUS STANDARD LIBRARIES ALL WITH THE SAME NAME IS'
./ SHOW '  DANGEROUS AND CAUSES PEOPLE (LIKE ME) MANY PROBLEMS.     '
./ SHOW '  IN MY OPINION SUCH ILLEGAL ROUTINES SHOULD ALWAYS BE     '
./ SHOW '  DELETED ON SIGHT.  G.F.P (12/6/81)                       '
./ SHOW '                                                        '
./ SHOW '  LGCUT RENAMED TO LGCUTX, REDONE CHANGED  J.O. 11.6.81'
./ SHOW '  CORRECTED ERROR IN TRKHIT AND CREDIT, DUE TO H.E.M. OPTI-'
./ SHOW '  MIZATION. UPDATED DISPLY AND JBOVER. CHANGED CAPMRK IN'
./ SHOW '  EVDISP, FULFILLING BEATES LATEST WISH(CAMACTIME) J.O.11.6.81'
./ SHOW '  CORRECTED SLIGHT BUG IN GPHMAIN                  J.O.12.6.81'
./ SHOW '  UPDATED SPINNR                                   J.O.13.6.81'
./ SHOW '  CORRECTED SEVERAL ERRORS IN GRAPHICS DISPLAY OF MONTE CARLO '
./ SHOW '  INVOLVED ROUTINES: TAGCHK,FWCHEV,BLNUMB,BLSHOW,TRUTH,XYTAG  '
./ SHOW '                                  J.O.16.6.81'
./ SHOW '  UPDATED DEDXBN(FUNC DRUCK) ACC. TO R.EICHLER     J.O.17.6.81'
./ SHOW '  KILLED XYTAGD (IDENT. TO XYTAG), UPDATED JADISP  J.O.17.6.81'
./ SHOW '  UPDATED KALIBR, FOR YEAR 0 SCREW UP IN 1981      J.O.22.6.81'
./ SHOW '  UPDATE OF GRAPHICS ROUTINES: DEDXBN(LONGSTANDING ERROR), '
./ SHOW '      TOFDS, TOFVW, CAPMRK(IN EVDISP), DEDXDS, BLSHOW'
./ SHOW '      JBOVER,DEDXVW,EFMASS                     J.O. 1.7.81'
./ SHOW '  UPDATE OF EFMASS, IDFUN                      J.O. 2.7.81'
./ SHOW '  UPDATE OF TRNUMB, DISPLY,SCANNR,IDFUN        J.O.16.7.81'
./ SHOW '  QPLOTS MODIFIED FOR TRACING 0C4              J.O.16.7.81'
./ SHOW '  JBOVER CHANGED, PSCALE OUT OF OVERLAY        J.O.16.7.81'
./ SHOW '  UPDATED SETSCL AND NEWS                      J.O.20.7.81'
./ SHOW '  KALIBR T0 SET FOR RUNS > 7592                PST 20.7.81'
./ SHOW '  VRTPOS INSTALLED (EVENT VERTEX OF RUNS)      PST 24.7.81'
./ SHOW '  UPDATE OF REDTVA,DISPLY,EVDISP               J.O.28.7.81'
./ SHOW '  UPDATE OF GPHMAIN,GAMDIS,DISPLY,EVDISP  '
./ SHOW '  JBOVER CHANGED, (SPINNR OUT OF OVERLAY)      J.O.02.8.81'
./ SHOW '  UPDATE OF SCANNR,DISPLY,KOMMAN,VXDISP,BLSHOW,NEWS'
./ SHOW '  INSTALLED DRAWER,REALNM   (COMMAND DRAW)     '
./ SHOW '  UPDATE OF USREDUC2 AND REDTVA         J.O. 07.08.81'
./ SHOW '  UPDATE OF JBMENU                      J.O. 15.08.81'
./ SHOW '  CORRECTION OF ERROR IN REALNM         J.O. 06.09.81'
./ SHOW '  COMMAND HX INSTALLED, CHANGED ROUTINES ARE: KOMMAN,SCANNR,'
./ SHOW '          DISPLY,NEWS,MENU          J.O.  07.09.81'
./ SHOW '  UPDATED TOFCHK AND USREDUC2       J.O.  09.09.81'
./ SHOW '  KLREAD CHANGED (NEW CALIBRATION FILES)                 '
./ SHOW '         OLD VERSION KLREAD0 MUST BE USED WITH OLD   '
./ SHOW ' CALIBRATION FILES F11PST.BUPDAT0 + BUPDAT1  PST.14.9.81,12.45'
./ SHOW '  GPHMAIN UPDATED FOR NEW CAL.FILE SITUATION  J.O.15.9.81,'
./ SHOW '  COMMAND AX INSTALLED, CHANGED ROUTINES ARE: KOMMAN,SCANNR,'
./ SHOW '  DISPLY,NEWS,MENU.  ALSO INSTALLED IS THE NEW MEMBER AXSHOW,'
./ SHOW '  WITH THE ROUTINES AXSHOW,ARROW,SPHERC  '
./ SHOW '  JBOVER ALSO UPDATED IN RSDISP BRANCH        J.O.  15.9.81'
./ SHOW '  SPINNR UPDATED TO COVER SUMMER 1981         J.O.  25.9.81'
./ SHOW '-----------------------------------------------------------'
./ SHOW '  KALIBR: T0 + LORENZ ANGLES FOR 81                        '
./ SHOW '          OLD VERSION = KALIBR0                PST  9.10.81'
./ SHOW '  KALIBR: T0, LORENZ ANG. + DRIFT VELOC. FOR SUMMER 81'
./ SHOW '          OLD VERSION = KALIBR0                PST 14.10.81'
./ SHOW '-----------------------------------------------------------'
./ SHOW '  BANKPR UPDATED, FORMAT FOR TPVX BANKS       J.O. 16.10.81'
./ SHOW '  TRKHIT UPDATED, MUON DISPLAY DETAILS        J.O. 17.10.81'
./ SHOW ' REPLACED RDMTCO WITH RDMESS FROM F22ELS.JMC.S    THIS IS  '
./ SHOW '    REPAIR FOR ..JETC BANK ALREADY EXISTING... ERROR '
./ SHOW '                                              J.O. 19.10.81'
./ SHOW '  NEW VERSION OF MUON ANALYSIS AND GRAPHICS INSTALLED. NEW '
./ SHOW '  VERSIONS OF GPHMAIN,SUPERV,SCANNR,DISPLY,NEWS,NOTICE HAVE'
./ SHOW '  BEEN INSTALLED. OLD ROUTINES ARE NOW SUPERV0,SCANNR0,    '
./ SHOW '   DISPLY0. ALSO JBOVER CHANGED(MUFFLT).  XYMUD RENAMED TO '
./ SHOW ' XYMUD0. NEW VERSION OF XYMUD ON JADEMUS/L    J.O. 20.10.81'
./ SHOW ' CORRECTED BUGS IN GPHMAIN AND DISPLY(JOYS)   J.O. 21.10.81'
./ SHOW ' REMOVED OLD DEBUG PRINT IN EVDISP            J.O. 23.10.81'
./ SHOW ' UPDATED MCGJET AND JBOVER                    J.O. 26.10.81'
./ SHOW ' UPDATED EFMASS                               J.O. 28.10.81'
./ SHOW ' UPDATED BANKPR                              J.O. 29.10.81'
./ SHOW ' * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *'
./ SHOW ' UPDATED VRTPOS                              PST   6.11.81'
./ SHOW ' UPDATED EVWRIT TO ACCOM.CHANGE TO MUCONW    J.O. 12.11.81'
./ SHOW ' UPDATED CREDIT, ARGUMENT CHANGE IN JOYS     J.O. 12.11.81'
./ SHOW ' UPDATED BANKPR,TRUTH                        J.O. 13.11.81'
./ SHOW ' UPDATED  TRUTH AGAIN, ERROR FOUND..   J.O. 16.11.81'
./ SHOW ' REPLACED RDMTCO WITH RDMESS FROM ELSENS LIBRARY. OLD RDMTCO '
./ SHOW ' IS RENAMED TO RDMTCO0 AND OLD RDMTCO0 SCRATCHED. DEFAULT  '
./ SHOW ' TRIGGER AND DETECTOR CONDITIONS ARE NOW FOR 1981   '
./ SHOW '                                       J.O. 19.11.81'
./ SHOW ' CORRECTED ERROR IN COMMAND STVW: INVOLVED ROUTINES ARE'
./ SHOW ' GPHMAIN,SCANNR,DISPLY,JADISP          J.O. 20.11.81'
./ SHOW ' ANOTHER SUBTLE BUG IN DISPLY CHANGED  J.O. 22.11.81'
./ SHOW ' RDMTCO COPLANAR ERROR TEMPORARILY CORRECTED  J.O. 22.11.81'
./ SHOW ' UPDATE OF GRPHMAIN,SCANNR,DISPLY FOR DSPDTL9 J.O. 25.11.81'
./ SHOW ' UPDATE OF LINDIS AND PARDIS                  J.O. 25.11.81'
./ SHOW ' UPDATE OF SUPERV (CGEO1 BLOCK DATA)          J.O. 25.11.81'
./ SHOW ' UPDATE OF CREDIT AND DISPLY  (COM.STVW)      J.O. 27.11.81'
./ SHOW ' ADJUSTED ZXC,ZYC VIEW IN SETSCL              J.O. 27.11.81'
./ SHOW ' CORRECTED SMALL ERROR IN MOMGAM              J.O. 03.12.81'
./ SHOW ' CORRECTED SMALL ERROR IN LINDIS              J.O. 04.12.81'
./ SHOW ' CORRECTED SMALL ERRORS IN GAMDIS AND RSDISP  J.O. 11.12.81'
./ SHOW ' UPDATE OF SPINNR FOR AUTUMN 1981             J.O. 14.12.81'
./ SHOW ' UPDATE OF BANKPR                             J.O. 17.12.81'
./ SHOW ' VRTPOS: VERTEX = 0. FOR MC-EVENTS            P.S. 22.12.81'
./ SHOW ' CORRECTED SERIOUS ERROR IN RDMTCO (SUBR. RDALGN)          '
./ SHOW '   THIS ERROR MAKES ANY PHOTON OR LEADGLASS ANALYSIS IN MC '
./ SHOW '   EVENTS PRACTICALLY USELESS, SINCE 19.11.1981  '
./ SHOW '                                          J.O.  22.12.1981'
./ SHOW ' ADDED EVREADX: ALLOWS PROGRAM TO CONTINUE IF MC DATA HAS NO'
./ SHOW '  MUON CONSTANTS RECORD AFTER THE ID CONSTANTS   J.O. 7.1.82'
./ SHOW ' EVREAD NOW IDENTICAL TO EVREADX             J.O. 7.1.1982'
./ SHOW ' ADDED PRINT IN USREDUC2                    J.O. 20.1.1982'
./ SHOW ' INSTALLED COMMAND TRLG: BG AND TOF TRIGGER FOR NEW DATA'
./ SHOW ' INVOLVED ROUTINES: KOMMAN,DISPLY,SCANNR,NEWS,MENU,NOTICE'
./ SHOW ' NEW ROUTINES: TBGDIS,TBGSTR,ECAPQ,CIRSEG,   ALL IN THE '
./ SHOW ' MEMBER TBGDIS.  JBOVER CHANGED ACCORDINGLY   J.O. 02.2.1982'
./ SHOW ' UPDATED TBGDIS AND FWMUHT FOR NEW DATA       J.O. 05.2.1982'
./ SHOW ' SCRATCH MEWT3: DUPLICATE ON JADEPR.JADESR    J.O. 09.2.1982'
./ SHOW ' JBOVER UPDATED WITH NEW TOF SUBROUTINE TFARNW  J.O. 10.2.1982'
./ SHOW ' DRTRCK INSTALLED : DISTANCE (TRACK-VERTEX)     P.S. 12.2.1982'
./ SHOW ' KALIBR CORRECTED  (YEAR WAS SET TO 1981)       P.S. 12.2.1982'
./ SHOW ' UPDATE OF TBGDIS AND CAPMRK. CAPMRK NOW MEMBER BY ITS OWN'
./ SHOW ' AND NO LONGER CONTAINED IN EVDISP.  INSTALLED COMMAND FADC'
./ SHOW ' CONCERNED ROUTINES ARE KOMMAN,SCANNR,DISPLY,MENU,DSFADC'
./ SHOW ' JBOVER UPDATED WITH NEW BRANCH                 J.O. 12.2.1982'
./ SHOW ' KALIBR UPDATED (DRIFT VEL.,LOR.ANGLE, T0)      PST. 24.2.1982'
./ SHOW ' SHIFTED KALPRE FROM JADEPR.JADESR TO F11LHO.JADEGS FOR       '
./ SHOW ' CONSISTENCY AND SIMPLICITY                        GFP 27/2/82'
./ SHOW ' VRTPOS (VERTEX X-Y FOR DIFFERENT RUNS) UPDATED  PST 82/03/09'
./ SHOW ' KALIBR CORRECTED FOR SERIOUS ERROR !!     J.O.  12.3.1982'
./ SHOW ' KALIBR CORRECTED FOR FEB 29.              PST.  30.3.1982'
C   22/03/97 703221757  MEMBER NAME  #START1  (JADEGS)      FORTRAN
FREE F(MACRO,CLIST)
ALLOC F(MACRO) DA('F11GOD.PATRECSR') SHR
ALLOC F(CLIST) DA('F11PEA.JDCLIST') SHR
CLEBR
./ SHOW '  ALL OLD MESSAGES CAN BE FOUND IN MEMBER #START0  '
./ SHOW '                                        P. STEFFEN 81/12/04'
./ SHOW '***********************************************************'
./ SHOW ' KALIBR UPDATED WITH CONSTANTS FOR RUNS > 11036           '
./ SHOW ' OLD VERSION RETAINED AS KALIBR0           GFP   17.5.1982'
./ SHOW ' UPDATED SPINNR, SMALL CHANGES IN BLSHOW,SCANNR'
./ SHOW '                                           J.O.  18.5.1982'
./ SHOW ' SUPERV EXTENDED TO 27000 WORDS IN BCS,BINT  J.O.  20.5.1982'
./ SHOW ' UPDATED SPINNR,CAPMRK,DEDXVW,TOFDS,TOFVW  J.O.  28.5.1982'
./ SHOW ' KALIBR CHANGED: 1982 FORCED FOR RUNS > 10000'
./ SHOW '                                           P.S.  82/06/15 '
./ SHOW ' UPDATED BANKPR,JBOVER                     J.O.  19.6.1982'
./ SHOW ' KALIBR UPDATED, NEW TZEROS FOR 1982       P.S.  21.6.1982'
./ SHOW ' UPDATED BANKPR                            J.O.  21.6.1982'
./ SHOW ' UPDATED SPINNR,DRAWER                     J.O.  22.6.1982'
./ SHOW ' JRECAL CORRECTED                          P.S.  22.6.1982'
./ SHOW ' INSTALLED COMMAND GVTX: VERTEX FIT FOR SELECTED TRACKS'
./ SHOW ' INVOLVED ROUTINES: GVTXFT,DISPLY,SCANNR,NEWS,MENU,NOTICE'
./ SHOW '                    KOMMAN,JBOVER   J.O.  23.6.82'
./ SHOW ' DELETED AXSHOW AND INSTALLED IT ON GRAPHS, TOGETHER WITH'
./ SHOW ' MODIFIED VERSION OF MCGJET (ALL COMMONS IN CWORK) IN ORDER'
./ SHOW ' TO GAIN SOME 10 KBYTES OF SPACE    J.O.  23.6.82'
./ SHOW ' CHANGED EBEAM INTO MORE SPACE SAVING FORM AND CORRECTED OLD'
./ SHOW ' ERROR (RUNS 4600-4700). OLD VERSION EBEAM0  J.O.  25.6.82'
./ SHOW ' KLREADSC + KALIBRSC INSTALLED (SPECIAL VERSION FOR IMPROVED'
./ SHOW '            MOMENTUM RESOLUTION FOR SPRING 82 DATA          '
./ SHOW '                                             P.ST. 82/06/28 '
./ SHOW ' KLREAD CHANGED TO PRINT FIRST EVENT DATE. SUBR. RDDATE     '
./ SHOW ' COPIED FROM JMC.S, WITH DEFAULT SETTING OF MC TIME TO JAN.81'
./ SHOW ' RDMTCO CHANGED TO CALL RDDATE.  ALL THIS WAS DONE TO COPE  '
./ SHOW ' WITH KLREAD ERROR, REASON UNKNOWN AT PRESENT  J.O. 13.7.82 '
./ SHOW ' KALIBR ALSO CHANGED, TO OVERWRITE YEAR 1982 IN MONTE CARLO '
./ SHOW ' WITH 1981. THIS IS BECAUSE TPMAIN PROGRAM CALLS KALIBR     '
./ SHOW ' BEFORE RDJETC !!!!                            J.O. 14.7.82 '
./ SHOW ' UNDEFINED VARIABEL IMUR2 IN SUPERV CHANGED !!  OUR THANKS  '
./ SHOW ' GO TO R.BARLOW...                             J.O. 16.7.82 '
./ SHOW ' KLREAD: CHANGE OF EOF HANDLING:                            '
./ SHOW '         GENERATE DUMMY DATA WITH YEAR ==2000               '
./ SHOW '         OLD VERSION = KLREAD0                              '
./ SHOW '         OLD KLREAD0 + KLREAD1 SCRATCHED       P.S.  5.8.82 '
./ SHOW ' KLREAD: ALLOW FOR ONLY 1 CALIBR. FILE,                     '
./ SHOW '         HANDLE "RVTX" CONSTANTS (RUN VERTICES)             '
./ SHOW '         OLD VERSION = KLREAD0 (KLREAD0 -> KLREAD1)         '
./ SHOW '                                               P.S. 11.8.82 '
./ SHOW ' KALIBR: RUNS 12255-12270 GET NOW MAGNETIC FIELD WRITTEN INTO'
./ SHOW '         THE HEADER BANK. IN RAW DATA IT IS ==0  J.O. 11.8.82'
./ SHOW ' REFITV: TRACK FITTING ROUTINE WITH VERTEX CONSTRAINT       '
./ SHOW '         USING NEW CHAMBER CALIBRATION + RUN VERTICES'
./ SHOW '                                               P.S. 12.8.82 '
./ SHOW ' KALIBR: RUNS 11908       GET NOW MAGNETIC FIELD WRITTEN INTO'
./ SHOW '         THE HEADER BANK. IN RAW DATA IT IS ==0  J.O. 16.8.82'
./ SHOW ' VTXPRE CHANGED TO MODIFY HEAD BANK IN SAME WAY AS KALIBR, FOR'
./ SHOW '      RUNS WITH MAGNETIC FIELD=0 ERRONEOUSLY     J.O. 16.8.82'
./ SHOW ' RESTRUCTURING OF GRAPHICS; INVOLVED ROUTINES ARE:'
./ SHOW '  GPHMAIN SUPERV KLREAD KOMMAN DISPLY SCANNR STPLST STWADD'
./ SHOW '  WALLOK JADISP CAPMRK TOFVW RETTEN CREDIT GRAPHS(USER) MENU'
./ SHOW '  NOTICE NEWS JBOVER.    BACKUPS: GPHMAIN0 SCANNR0 STPLST0 '
./ SHOW '  RETTEN0 GRAPHS(USER0) STWADD0 NEWS0 NOTICE0 SUPERV0'
./ SHOW '  OBS: SUPERV NOW HAS /BCS/IDATA(33000)  TO COPE WITH RECENT'
./ SHOW '       COMPLAINTS ABOUT LOST EVENTS IN BOS.      J.O. 01.9.82'
./ SHOW '   THE ABOVE CHANGES LEAD TO PROBLEMS IN PATREC. THEREFORE    '
./ SHOW '   THE OLD SUPERV0 WAS REINSTALLED AND THE NEW SUPERV AGAIN  '
./ SHOW '   MADE TO SUPERVX. TEMPORARILY FOR GRAPHICS: SUPERVY. JBOVER'
./ SHOW '   WAS CHANGED TO ACCOUNT FOR THE TEMPORARY VERSIONS, UNTIL  '
./ SHOW '   THE PATREC PROBLEM HAS BEEN FOUND.            J.O. 02.9.82'
./ SHOW '   ERROR IN SUPERVX FOUND (MISSING INPATC,PST) J.O. 02.9.82'
./ SHOW '   SUPERVX NOW MADE STANDARD, AFTER TESTING    J.O. 03.9.82'
./ SHOW '   JBMENU, NOTICE, GPHMAIN UPDATED             J.O. 04.9.82'
./ SHOW '   KLREAD: SET LABEL(NO LG-CALIBR.) FOR LGCALB    P.S. 06.9.82'
./ SHOW '   SUPERV: CALL LGCALB ONLY IF ALGL-BANK EXISTING P.S. 07.9.82'
./ SHOW '   KLREAD: CONSTANTS = 0 FOR MC-EVENTS            P.S. 08.9.82'
./ SHOW '           OLD VERSION = KLREAD0                              '
./ SHOW '   UPDATED NOTICE AND RSDISP, SMALL BUGS          J.O. 14.9.82'
./ SHOW '   KALIBR: E-BEAM=17300 FOR RUN 11790             P.S. 21.9.82'
./ SHOW '   UPDATED BLSHOW AND SPINNR                     J.O. 12.10.82'
./ SHOW '   UPDATED EFMASS AND IDFUN                      J.O. 21.10.82'
./ SHOW '   UPDATED DISPLY, OLD VERSION DISPLY0           J.O. 22.10.82'
./ SHOW '   KALIBR01, KLREAD01: COPIES OF KALIBR + KLREAD P.S. 26.10.82'
./ SHOW '   PREPARATION FOR CHANGE ANNOUNCED FOR 28TH.                 '
./ SHOW '   KALIBR + KLREAD  REPLACED BY NEW VERSION      P.S. 28.10.82'
./ SHOW '   KLREAD CORRECTED (CALIBR NOT PROPERLY ZEROED) P.S. 29.10.82'
./ SHOW 'CORRECTIONS IN WALLOK AND SCANNR (WRIT)          J.O. 03.11.82'
./ SHOW 'UPDATE OF DEDXDS, DISPLY, CAPMRK                 J.O. 03.11.82'
./ SHOW 'KALIBR: NO YEAR-CHANGE FOR RUNS <100             P.S. 18.11.82'
./ SHOW 'KLREAD: GET MUCA-CONSTANTS FOR RUNS<100                       '
./ SHOW '        OLD VERSION = KLREAD0                    P.S. 19.11.82'
./ SHOW 'RDMTCO: CALL TO RDDATE COMMENTED OUT UNTIL FURTHER NOTICE. THE'
./ SHOW '        UPDATING OF RDMTCO WILL BE INVESTIGATED  J.O. 19.11.82'
./ SHOW 'DEDXDS UPDATED: PROTECT AGAINST MC DATA          J.O. 22.11.82'
./ SHOW 'IDFUN UPDATED                                   J.O. 23.11.82'
./ SHOW 'UPDATE FOR JADISP,EVDISP,RSDISP,KOMMAN,SETSCL,GPHMAIN,'
./ SHOW 'BANKPR,DEDXBN.  INSTALLED RZROLL,RZTRCK.  ALL CONCERNED WITH '
./ SHOW 'THE NEW VIEW RZ.   JBOVER STRUCTURE UPDATED.    J.O. 01.12.82'
./ SHOW 'UPDATED KALIBR,EBEAM FOR RUNS 12804-805         J.O. 08.12.82'
./ SHOW 'GRAPHICS UPDATE:  RSDISP,EVDISP,JADISP,KOMMAN,SCANNR,DISPLY,'
./ SHOW '        IDFUN,CROAX,MENU,NEWS,JBOVER,GPHMAIN    J.O. 08.12.82'
./ SHOW ' INSTALLED USRED282,JBRED282,TWOELS (REDUC2 1982)J.O. 08.12.82'
./ SHOW 'KLREAD: NEW T0, V-DRIFT, ALFA FOR DATA OF FALL 82             '
./ SHOW '        REVISED T0, V-DRIFT, ALFA FOR SUMMER 82  P.S.  8.12.82'
./ SHOW ' CORRECTED UNDEFINED VARIABLES, ALL OF MINOR OR NO IMPORTANCE '
./ SHOW '  HELDIS: IJ --> IF, IN PRINT STATEMENT'
./ SHOW '  REDTVA: RLG,ZENDPL NEED CGEO1. USED IN COLL.CHECK FOR NTR=0'
./ SHOW '  USREDUC2: MSKLM1=Z100, FROM 100.   SOME LUMITRIGGERS MAY BE'
./ SHOW '            ON REDUC2 TAPES..........         J.O.  6.1.1983'
./ SHOW '  KLREAD: CORRECT UNDEFINE VARIABLE "IDRUN0"  P.S. 10.1.1983 '
./ SHOW '  FITEVR: CORRECT UNDEFINE VARIABLE "IQZVTX"  P.S. 10.1.1983 '
./ SHOW '  RZTRCK: CORRECT UNDEFINE VARIABLE "RRZCHI"  J.O. 12.1.1983 '
./ SHOW '  TRUTH: CORRECTED DARCOS ERROR               J.O. 26.1.1983 '
./ SHOW '  CORRECTED ERROR IN RDMTCO, SUBR. RDTRG1 CONCERNING T1 POST-'
./ SHOW '  PONE SIMULATION. SAME ERROR EXISTS ON JMC.S !!  AFFECTS THE'
./ SHOW ' COPLANAR TRIGGER CONDITION                   J.O. 30.1.1983 '
./ SHOW ' CORRECTED LOOP STRUCTURE IN RDMTCO(RDTRG1), WHICH CAUSES '
./ SHOW ' ERROR IN RUTHERFORD. JMC.S ALREADY HAD IT OK.   J.O. 11.2.83 '
./ SHOW '  TRUTH: CORRECTED DARCOS ERROR AGAIN         J.O. 17.2.1983 '
./ SHOW 'TR3DSP UPDATED (ERROR CORRECTED BY C.BOWDERY)  J.O. 22.2.1983 '
./ SHOW 'EFMASS UPDATED (SMALL BUG IN PHOTON CONV.)     J.O. 22.2.1983 '
./ SHOW 'EFMASS UPDATED (BUG WAS STILL PRESENT !        J.O. 04.3.1983 '
./ SHOW 'SUPERV: TRY IUHR TWICE IF TIME LIMIT           P.S. 15.3.1983 '
./ SHOW 'KLREAD: INCREASE AREA FOR JTAB CONSTANTS                      '
./ SHOW '        OLD VERSION = KLREAD0                  P.S. 19. 4.1983'
./ SHOW 'JETCAL,JRECAL SET AMPLITUDES = 0 IF OVERFLOW   P.S. 21. 4.1983'
./ SHOW 'KLREAD: UPDATE T0,ALFA,VD FOR RUNS 13000..     P.S. 29. 4.1983'
./ SHOW 'ZSREAD DELETED. IT IS NOW AGAIN ON F11DIT.HELIX  J.O. 3.5.1983'
./ SHOW '  COMMAND PATR INSTALLED IN GRAPHICS; INVOLVED ROUTINES ARE:'
./ SHOW ' KOMMAN,SCANNR,DISPLY,VXDISP,GVTXFT,EFMASS,NEWS,MENU,JBMENU.'
./ SHOW ' IDFUN UPDATED                                   J.O. 4.5.1983'
./ SHOW ' JRECAL CHANGED (SLEWING CORRECTION RUNS 6185..) P.S.11.5.1983'
./ SHOW ' UPDATED RSDISP,BANKPR,TRUTH                     J.O.16.5.1983'
./ SHOW ' Z-RECALIBRATION + FIT ROUTINES INSTALLED:       P.S.17.5.1983'
./ SHOW ' MVB, ZRECAL, ZSFIT, ZSLINE, ZSPUR, ZSREAD, ZSSPEC, ZSXY      '
./ SHOW ' CORRECTED ERROR IN BANKPR                       J.O.18.5.1983'
./ SHOW ' UPDATED BANKPR WITH N50S PRINT OPTION;  ALSO UPDATED IDFUN'
./ SHOW ' INSTALLED TEMPORARY MEMBER MUHITSX, TO BE USED IN GRAPHICS   '
./ SHOW '    UNTIL OVERLAY ERROR WITH PRESENT MUHITS ON JADEMUL HAS '
./ SHOW ' BEEN CLEARED UP, JBOVER CHANGED ACCORDINGLY     J.O.28.5.1983'
./ SHOW ' MUHITSX SCRATCHED, MUHITS OK AGAIN              J.O.30.5.1983'
./ SHOW ' BANKPR UPDATED, N50S AND MPRS PRINT ENHANCED    J.O.30.5.1983'
./ SHOW ' IDFUN UPDATED   J.O.04.6.1983'
C   22/03/97 703221757  MEMBER NAME  #START2  (JADEGS)      FORTRAN
./ SHOW '  ALL OLD MESSAGES CAN BE FOUND IN MEMBERS #START0,#START1'
./ SHOW '                                        J.OLSSON   83/08/08'
./ SHOW '***********************************************************'
./ SHOW 'KLREADMI: T0-CHANGE (SPEC.VERS. FOR MINOWA)    P.S. 10. 6.1983'
./ SHOW 'KALIBR UPDATED, B=0 IN RUNS 13651-53 CORRECTED J.O. 13. 6.1983'
./ SHOW 'DEDXDS,DEDXVW UPDATED                          J.O. 14. 6.1983'
./ SHOW 'KALIBR UPDATED, EBEAM  RUNS 13707-14 CORRECTED J.O. 14. 6.1983'
./ SHOW 'KLREAD: IMPROVED T0,VD FOR RUNS 13000..        P.S. 16. 6.1983'
./ SHOW 'FRFITV, REFIT, REFITV: CLOSE WIRE CORR. ACTIV. P.S. 16. 6.1983'
./ SHOW 'KLREAD: CHANGED FIRST PRINT TO RECOGNIZE IT..  J.O. 19. 6.1983'
./ SHOW 'ZSSPEC: CORRECTED BUG, EFFECTIVE FOR 1983 DATA J.O. 27. 6.1983'
./ SHOW 'UPDATED BANKPR (FAMP=BK17), DEDXVW(OPTION-5)   J.O. 04. 7.1983'
./ SHOW 'AND STPLST (TRAILING NUMBER)                   J.O. 04. 7.1983'
./ SHOW 'KLREAD9: IMPROVED T0 FOR RUNS 13000...(TEST)   P.S. 21. 7.1983'
./ SHOW 'KLREAD: IMPROVED T0,VD FOR RUNS 13000..        P.S. 16. 6.1983'
./ SHOW 'UPDATED SUPERV BLOCK DATA, NEG. LOR.ANGLE      J.O.  1. 8.1983'
./ SHOW '   THE CHANGE WAS REMADE AT 15.23 DUE TO ERROR J.O.  1. 8.1983'
./ SHOW 'BEAM ENERGY CORRECTIONS IN KALIBR AND EBEAM    J.O.  1. 8.1983'
./ SHOW ' IDFUN UPDATED   J.O.   01. 8. 1983'
./ SHOW ' BEAMENERGY WARNING IN KALIBR AMENDED   J.O. 2.8.1983'
./ SHOW ' BEAMENERGY FOR R13826 IN KALIBR,EBEAM MENDED  J.O. 5.8.1983'
./ SHOW '  SUPERV UPDATED TO CORRECT ALL EVENTS IN CERTAIN RUNS FOR  '
./ SHOW '         FAULTY MAGFIELD, EBEAM ETC. OLD SUPERV NOW SUPERV0'
./ SHOW ' ALSO UPDATED VTXPRE ACC. TO BOB GLASSER   '
./ SHOW '       OLD VTXPRE NOW VTXPRE0          J.O.  6.8.83'
./ SHOW 'CORRECT R10666 IN EBEAM,SUPERV,KALIBR  J.O.  8.8.83'
./ SHOW 'KLREADNC, JFETCHNC, FRFITVNC, REFITNC:                       '
./ SHOW '         NEW ROUTINES FOR NEW CALIBRATION     P.S. 10. 8.1983'
./ SHOW 'FRFITVNC,REFITVNC,REFITNC CORRECTED           P.S. 15. 8.1983'
./ SHOW 'FITEVR CORRECTED                              P.S. 15. 8.1983'
./ SHOW '  LOGICAL ERROR IN LAST CHANGE OF SUPERV NOW CORRECTED'
./ SHOW '    COMMON /CHEADR/ WAS NOT FILLED FOR FIRST EVENT IN THE RUN'
./ SHOW ' AT LEVEL 1, ONLY AT LEVEL2         ERROR WAS ACTIV BETWEEN'
./ SHOW '  5.8.83 AND 17.30 ON 15.8.83                 J.O. 15. 8.1983'
./ SHOW ' BARRY WHITTAKER COMPLAINS ABOUT THE LAST CHANGE OF SUPERV'
./ SHOW ' UNTIL IT IS CLEAR IF ERROR IS IN SUPERV, THE OLD VERSION,   '
./ SHOW '  SAVED AS SUPERV0, IS RENAMED SUPERV. THE NEW VERSION IS NOW'
./ SHOW '  SUPERV9                J.O. 16. 8.1983,   20.25'
./ SHOW 'JFETCH: FETCH TRACK-HITS + CALC. COORDINATES  P.S. 29. 8.1983'
./ SHOW 'FRFITV,REFITV,REFIT: NEW REFIT-ROUTINES        P.S. 29. 8.1983'
./ SHOW '       OLD VERSIONS ARE FRFITV0,REFITV0,REFIT0                '
./ SHOW 'KLREAD: NEW VERSION (CELL DEPENDENT DRIFT VEL.) P.S. 30.8.1983'
./ SHOW '        USED FOR NEW VERSION OF CALIBR. CONSTANTS             '
./ SHOW '        OLD VERSIONS IS KLREAD0                               '
./ SHOW 'TRKROL: UPDATE FOR COMMAND RES N                J.O. 30.8.1983'
./ SHOW '  UPDATE OF MINOR BUG IN COMMAND WRIT, AFFECTED ROUTINES ARE  '
./ SHOW '  SUPERV AND SCANNR   (SUPERV9 ALSO UPDATED)    J.O. 31.8.1983'
./ SHOW 'KLREAD: NEW T0,VD,ALFA FOR MAY82 DATA           P.S.  7.9.1983'
./ SHOW 'JFETCH: MINOR ERROR CORRECTED                   P.S. 12.9.1983'
./ SHOW 'KLREADFI: TEST VERSION FOR TAGF-CONSTANTS       P.S. 15.9.1983'
./ SHOW 'KLREAD: NEW T0,VD,ALFA FOR SUMMER-82 DATA       P.S. 16.9.1983'
./ SHOW 'FRFITV: CORRECT OCCASIONAL -VE SQRT             P.S. 20.9.1983'
./ SHOW 'FZFITV, ZRFITO: ELIMINATE PRINTOUT              P.S. 20.9.1983'
./ SHOW 'FITEVF: NO REFIT IF PT < 20 MEV                 P.S. 22.9.1983'
./ SHOW 'REFIT : ELIMINATE PRINTOUT                      P.S. 22.9.1983'
./ SHOW 'SMALL UPDATES, TO PREPARE FOR COMMAND ZTRG. INVOLVED ROUTINES '
./ SHOW 'ARE: CAPMRK,BANKPR,DEDXVW,DSFADC,TOFVW,DISPLY   J.O. 24.9.1983'
./ SHOW 'FRFITV: CORRECT OCCASIONAL DIV.CHECK            P.S. 27.9.1983'
./ SHOW 'INSTALLED COMMAND ZTRG IN GRAPHICS.  INVOLVED ROUTINES ARE:'
./ SHOW ' KOMMAN,SCANNR,DISPLY,MENU,NEWS,ZTRGVW,JBOVER   J.O. 27.9.1983'
./ SHOW 'FRFITV: CORRECT OCCASIONAL DIV.CHECK            P.S. 30.9.1983'
./ SHOW 'INSTALLED COMMAND JETC IN GRAPHICS.  INVOLVED ROUTINES ARE:'
./ SHOW ' KOMMAN,SCANNR,DISPLY,EVDISP,MENU,NEWS          J.O. 4.10.1983'
./ SHOW 'KLREAD: TAGF-CONSTANTS --> /CALIBR/             P.S. 6.10.1983'
./ SHOW '        OLD VERSION = KLREAD0                   P.S. 6.10.1983'
./ SHOW 'INSTALLED DEDXDN: NEW VERSION OF DEDXBN, TO REPLACE PRESENT'
./ SHOW ' ONE AFTER INTRODUCTION TO JADE MEETING         J.O. 6.10.1983'
./ SHOW 'CHANGE OF DEDXDN: A BUG REPAIR BY J.A. SKARD DOES NOT DO THE'
./ SHOW ' JOB. THE OLD BUG REPAIR OF J.O. REASSUMED.     J.O. 9.10.1983'
./ SHOW 'KLREAD: NEW T0,VD,ALFA FOR FALL-82 DATA         PST 13.10.1983'
./ SHOW 'KLREAD: NEW T0,VD (PROV.) FOR FALL-83 DATA      PST 18.10.1983'
./ SHOW ' INSTALLED MCTRCB AND MCTR4V  (JCN 69)         J.O. 19.10.1983'
./ SHOW ' INSTALLED RDMTCOGS AND RDTRIGGS, TO REPLACE RDMTCO TOMORROW.'
./ SHOW ' TOGETHER WITH RDDATE THEY CONSTITUE A COMPLETE SET OF THE NEW'
./ SHOW ' SMEARING AND TRIGGER SIMULATION ROUTINES      J.O. 19.10.83'
./ SHOW '   MAJOR REPLACEMENT OF GRAPHIC AND OTHER ROUTINES          '
./ SHOW '  INVOLVED ROUTINES:  SUPERV,SUPERV9,GPHMAIN,SCANNR,SETSCL, '
./ SHOW '    JADISP,EVDISP,RSDISP,FWCHEV,BLNUMB,XYTAG,CROAX,TAGCHK,  '
./ SHOW '    TRKHIT,SPINNR,EVREAD,EVWRIT,RDMTCO,RDTRIG,RDDATE,BLSHOW '
./ SHOW '    JADEOVLY,JBOVER.  COMMENTS, SEE  JADEPR.TEXT(JBIMPNOT)  '
./ SHOW '                               J.O.  20.10.1983             '
./ SHOW 'REFIT : CORRECTED (1. + LAST POINT OF TRACK)    PST 20.10.1983'
./ SHOW 'JFETCH: COORD.CORR. OF MC = 0.                  PST 20.10.1983'
./ SHOW 'UPDATED JADEOVLY,MCTRCB AND INSTALLED MCHTRB   J.O. 26.10.1983'
./ SHOW 'UPDATED SPINNR                                 J.O. 26.10.1983'
./ SHOW 'UPDATED JADEOVLY (ERROR IN OVERLAY DISCOVERED) J.O. 27.10.1983'
./ SHOW 'UPDATE JBOVER (RENAME TAGGING.L --> TAGG.L)    J.O. 28.10.1983'
./ SHOW 'MCTR4V HAD A SERIOUS BUG FOR ABOUT 8 HOURS     J.O. 31.10.1983'
C   22/03/97 703221757  MEMBER NAME  #START3  (JADEGS)      FORTRAN
./ SHOW 'OLD MESSAGES CAN BE FOUND IN MEMBERS #START0,#START1,#START2'
./ SHOW '                                        C.BOWDERY  21/02/84'
./ SHOW '***********************************************************'
./ SHOW 'SUPERV CHANGED TO CALL LGCDIR (ALSO SUPERV9)   J.O. 09.11.1983'
./ SHOW 'RDTRIG SPLIT UP IN RDTRIG,RDTRG1,RDTRG2,RDHEAD.  REASON IS A'
./ SHOW 'A CURIOUS COMPILER ERROR. RDTRG2 DOESNT WORK IF COMPILED WITH '
./ SHOW 'THE REST, IN OPT(2), OR OPT(3)                 J.O. 11.11.1983'
./ SHOW 'NEWS AND NOTICE ALTERED.                       C.B. 11.11.1983'
./ SHOW 'S/R HELPUS ON MEMBER MENU UPDATED              C.B. 14.11.1983'
./ SHOW 'JBOVER UPDATED IN VARIOUS UNIMPORTANT WAYS     J.O. 14.11.1983'
./ SHOW 'UPDATE OF BANKPR AND JBOVER                    J.O. 16.11.1983'
./ SHOW 'ADD RDDATEMC FOR CURE OF MUON MC CALIBR.CONST. J.O. 18.11.1983'
./ SHOW 'NEW DEDX ROUTINES + CALIBR.CONST. INSTALLED    PST  21.11.1983'
./ SHOW '  DEDXBN,MOMENP,DSORT,ERRMOM,DECHIF,CHIFT1,DETHRY,THDEDX'
./ SHOW 'FURTHER CHANGES:  DEDXVW AND JADEOVLY      J.O.   23.11.83'
./ SHOW 'KLREAD: T0, VD, LOR.ANGLE FOR RUNS 6184-7591    PST 24.11.1983'
./ SHOW 'EVREAD,RDTRIG AND RDDATE MODIFIED TO USE                      '
./ SHOW 'NEW CADMIN MACRO CONTAINING COMMON CADMIN.                    '
./ SHOW 'RDDATE ALSO INCLUDES CODE TO FORCE JETC SMEARING              '
./ SHOW 'DATE TO BE MUON TRACKING DATE WHEN MUEV BANK                  '
./ SHOW 'FOUND. RDDATEMC SCRATCHED AS NOW OBSOLETE       C.B. 24/11/83 '
./ SHOW 'DEDXBN GRAPHICS PRINTING PROBLEM SOLVED  &                    '
./ SHOW 'NOTICE UPDATED. JADE RELINKED.                  C.B. 25/11/83 '
./ SHOW 'GRAPHICS COMMAND NWCL INTRODUCED. AFFECTED MEMBERS ARE: '
./ SHOW 'GPHMAIN,KOMMAN,SCANNR,DISPLY,MENU,NEWS,NOTICE,NEWCAL,JADEOVLY '
./ SHOW 'MEMBER JBMENU WAS MOVED TO JADEPR.TEXT(JBJCN34) J.O. 26/11/83 '
./ SHOW 'MEMBER IDFUN UPDATED                            J.O. 26/11/83 '
./ SHOW 'KLREAD: NEW TREATMENT OF MC-MU-CHAMBER CONST.   PST 28.11.1983'
./ SHOW 'KLREADCA = OLD VERSION                                        '
./ SHOW 'CORRECTION TO NEWCAL                            J.O. 28/11/83 '
./ SHOW 'KLREAD: NEW T0,VD, LORENTZ ANGLE FOR FALL 81    PST 29.11.1983'
./ SHOW 'KLREAD0 = OLD VERSION                                         '
./ SHOW 'KLREADBK = TEST VERSION FOR ZCAL CONSTANTS                    '
./ SHOW 'NEW ZCAL ROUTINES + CALIBR.CONST. INSTALLED    PST  05.12.1983'
./ SHOW '  NEW ROUTINES: KLREAD,ZSFIT,ZRECAL,ZSLINE,ZSPUR,ZSREAD       '
./ SHOW '  OLD ROUTINES: KLREAD0,ZSFIT0, ...                           '
./ SHOW 'KLREAD: NEW T0,VD, LORENTZ ANGLE FOR SUMMER 81  PST  8.12.1983'
./ SHOW '        REVISED T0, LORENTZ ANGLE FOR FALL82'
./ SHOW 'KLREAD0 = OLD VERSION                                         '
./ SHOW 'UPDATE OF NEWCAL, ADJUST TO NEW ZSFIT CHANGES   J.O. 08/12/83 '
./ SHOW 'NEW DEDXB1 ROUTINE INSTALLED                     PST   9.12.83'
./ SHOW 'CORRECT PRINT STATEMENT IN DEDXB1                J.O. 12.12.83'
./ SHOW 'INSTAL NEW COMMAND FAMP. AFFECTED ROUTINES ARE KOMMAN,MENU,'
./ SHOW '  SCANNR,DISPLY,NEWS,FAMPDS,FAMPFT,JADEOVLY      J.O. 12.12.83'
./ SHOW 'EVREAD CHANGE: JUSCRN SET TO 6 IF UNDEFINED                   '
./ SHOW '             : CALL TO MUREG ADDED AFTER MUCON   C.B. 13.12.83'
./ SHOW ' GVTXFT UPDATED                                  J.O. 13.12.83'
./ SHOW ' JADEOVLY CHANGED, DUE TO MUREG MOVE YESTERDAY   J.O. 14.12.83'
./ SHOW ' RECOMMENTED  USER/USER0/USERB/USERCP/USERRJ     C.B. 14.12.83'
./ SHOW 'AXSHOW MOVED TO JADEGS/L FROM GRAPHS/L           J.O. 15.12.83'
./ SHOW 'ERROR IN RDMTCO CORRECTED...                     J.O. 15.12.83'
./ SHOW 'KLREAD UPDATE: DONT READ FILES IF ALL LBMC=0, MC J.O. 15.12.83'
./ SHOW 'UPDATE REDONE AND LGCUTX FOR PRTOCI CALL, INSTALLED PRTOCI'
./ SHOW 'TO COINCIDE WITH PRTOCI ON TPSOURCE             J.O.  17.12.83'
./ SHOW 'MOFRCI MOVED FROM TPSOURCE TO HERE.             C.B.  19.12.83'
./ SHOW 'CORRECT ERROR FOR MUON MC IN KLREAD        J.O.,C.B.  20.12.83'
./ SHOW 'CORRECT DEAD LOOP IN RDMODN (RDMTCO)  J.O.,J.HAGEMANN 23.12.83'
./ SHOW 'NEW SUPERV RELEASED ALONG WITH THE                            '
./ SHOW 'NEW BLOCK DATA MEMBER JADEBD. OLD USER                        '
./ SHOW 'ROUTINES SCRATCHED AND CURRENT USER REDUCED TO                '
./ SHOW 'MINIMUM CODE ONLY. KALIBR AND KLREAD NOW HAVE                 '
./ SHOW 'EXTERNAL JADEBD TO ENSURE JADEBD IS LOADED.    C.B.    9/01/84'
./ SHOW 'ADDED LIST OF JADE MEMBERS INTO #JADE          C.B.    9/01/84'
./ SHOW 'JDMAIN0 EDITED TO REMOVE  JUSCRN=6 & CGRAPH    C.B.   11/01/84'
./ SHOW 'USER NOW CALLS BSTA AT LEVEL 100               C.B.   11/01/84'
./ SHOW 'SUPERV NOW PRINTS A HEADLINE BANNER            C.B.   16/01/84'
./ SHOW 'SUPERV AND GPHMAIN HAVE /BCS/IDATA(40000)      C.B.   16/01/84'
./ SHOW 'NEW DEDXBN DEDXB1,CHIFT1,THDEDX,/CDEDEDX/      PST    17.01.84'
./ SHOW 'MCTR4V SPEEDED UP CONSIDERABLY                 C.B.   17/01/84'
./ SHOW 'UPDATE JADEOVLY,RDMODN(MEMBER RDMTCO) AND ZSFIT J.O.  19/01/84'
./ SHOW 'NEW CBCSMX MACRO USED IN SUPERV & GPHMAIN      C.B.   19/01/84'
./ SHOW 'UPDATE SPINNR FOR RUNS > 14216                 J.O.   27/01/84'
./ SHOW 'CHANGES TO NEWS AND HELPUS (LATTER IS ON MENU) C.B.   01/02/84'
./ SHOW 'SERIOUS BUG IN DEDXVW AND TOFVW REMOVED        C.B.   03/02/84'
./ SHOW 'NEW VERSION OF DEDXVW WITH SMALLER SYMBOLS     C.B.   03/02/84'
./ SHOW 'SMALL CORRECTION OF DATE IN RDTRIG BLOCKDATA   J.O.   04/02/84'
./ SHOW 'RDMTCO1 WITH CHANGED RDALGN,RDRESO'
./ SHOW '  TO BE CHANGED AFTER CIRCULATION OF JCN 66A   J.O.   08.02.84'
./ SHOW 'IDFUN UPDATED FOR ROBIN MIDDLETON F22MID       C.B    08.02.84'
./ SHOW 'COMPRESSED TAGGING CODE IN EVDISP. AFFECTED ROUTINES FWCHEV'
./ SHOW 'AND JADEOVLY                                   J.O.   08.02.84'
./ SHOW '/CADMIN/ BLOCKDATA SET IN JADEBD NOW NOT EVREAD.              '
./ SHOW 'CADMIN MACRO MOVED TO PATRECSR. THE FOLLOWING                 '
./ SHOW 'HAVE BEEN CHANGED AND RECOMPILED:                             '
./ SHOW 'CORRECTED ERROR PRINT IN DEDXBN                J.O.   09.02.84'
./ SHOW 'RDTRIG AND RDMTCO UPDATED ACCORDING TO SPECIFICATION IN '
./ SHOW 'JCN 66 ADDENDUM  RDMTCO1 SCRATCHED             J.O.   09.02.84'
./ SHOW 'RDALGN IN RDMTCO NO LONGER PRINTS IN JADEZ     C.B.   13.02.84'
./ SHOW 'EVREAD ERROR MESSAGES IMPROVED                 C.B.   13.02.84'
./ SHOW 'SMALL CHANGE TO BANKPR TO AVOID ERROR MESSAGE  C.B.   13.02.84'
./ SHOW 'SMALL COSMETIC CHANGE TO EVREAD                C.B.   14.02.84'
./ SHOW 'IMPROVED VERSION OF SUPERV RELEASED            C.B.   15.02.84'
./ SHOW 'DEDXVW REPLACED BY DEDXVW,DRTHCV AND DRAWPI    C.B.   16.02.84'
./ SHOW 'JADEOVLY UPDATED BY ADDING DRTHCV              C.B.   16.02.84'
./ SHOW 'SERIOUS BUG IN SUPERV CORRECTED WRT RE-PATREC                 '
./ SHOW 'FOR REAL DATA. MC DATA AND UNANALYSED DATA WERE               '
./ SHOW 'NOT AFFECTED.  NEW JADEZ CREATED.              C.B.   17.02.84'
./ SHOW 'CHANGES TO GRAPHICS. NEW COMMAND CDST ADDED                   '
./ SHOW 'ALONG WITH CODE FOR VRX,VRZX & VRZY COMMANDS WHICH            '
./ SHOW 'ARE NOT ACTIVE YET. NEW MEMBERS ADDED:                        '
./ SHOW 'CDST , PROJEC , JOYS                                          '
./ SHOW 'CHANGED MEMBERS: SCANNR,DISPLY,KOMMAN,CREDIT,JADEOVLY,MENU,   '
./ SHOW 'NEWS , NOTICE .  S/R CDTLCO HAS GONE.     C.B. P.H.   17.02.84'
$   28/06/85            MEMBER NAME  #START4  (JADEGS)      NEWLIB
CLEAR
./ SHOW 'OLD MESSAGES NOW IN MEMBERS #START0,#START1,#START2,#START3'
./ SHOW 'NEW MESSAGES ARE IN #START              C.BOWDERY  28/06/85'
./ SHOW '***********************************************************'
./ SHOW '  NEW STANDARD VIEWS VRX,VRZX,VRZY INTRODUCED IN GRAPHICS'
./ SHOW '  INVOLVED MEMBERS ARE:    CAPMRK,CIRDIS,CROAX,EVDISP,TRNUMB,'
./ SHOW '  GAMDIS,LINDIS,PARDIS,JADISP,RSDISP,SAEGE,TRUTH,SETSCL,'
./ SHOW '  VRXCIR,VXDISP,NEWS,MENU,NOTICE,JADEOVLY      J.O.   19.02.84'
./ SHOW 'NEW VERSION OF EVREAD ALONG WITH NEW S/R EVBKPR            '
./ SHOW 'TO PRINT BANK LIST. ALSO USED BY BANKPR WHICH IS ALSO      '
./ SHOW 'NEWLY REPLACED ON JADEGS. NEW JADEZ MADE.      C.B.   19.02.84'
./ SHOW 'RDMTCO HAS BEEN SPLIT. MANY NEW MEMBERS.                      '
./ SHOW 'RDMTCO ONLY HAS ENTRY RDJETC AND BLOCKDATA.    C.B.   19.02.84'
./ SHOW 'IMPROVED EVWRIT. PRINTS WARNING IF NO HEAD.    C.B.   20.02.84'
./ SHOW 'IMPROVED EVWRIT AND EVREAD. ZSSPEC0 SCRATCHED  C.B.   21.02.84'
./ SHOW '2000 K REGION SIZE STANDARD NOW FOR TSO -----                 '
./ SHOW 'NEW GRAPHICS LINKING JOB CALLED #GRAPHIX                      '
./ SHOW 'INSTALLED WHICH DOES NOT HAVE OVERLAYS.        C.B.   21.02.84'
./ SHOW 'SMALL BUT FAIRLY SERIOUS BUG IN MCHTRB KILLED  C.B.   22.02.84'
./ SHOW ' BUG IN RDTRG1 CORRECTED                       J.O.   27.02.84'
./ SHOW ' GVTXFT UPDATED (FOR VIEWS VRX..)              J.O.   28.02.84'
./ SHOW 'UPDATE OF PRINT IN RDSTAT,GPHMAIN,NOTICE       J.O.   02.03.84'
./ SHOW 'CORRECT UNINIT.ARRAY NHTRNG IN REFITV          J.O.   02.03.84'
./ SHOW 'CORRECT UNINIT PARAMETER IQZVTX IN FITEVR      J.O.   03.03.84'
./ SHOW '  NOTE: THIS ERROR MAY AFFECT PHYSICS RESULTS !!'
./ SHOW '                    NO, IT DOESN T !!'
./ SHOW 'CORRECT UNINIT.ARRAY NHTRNG IN REFIT           J.O.   03.03.84'
./ SHOW 'PROTECT JRECAL AGAINST MONTE CARLO EVENTS J.O.,C.B.   07.03.84'
./ SHOW 'PROTECT JOYS AGAINST ZERO AREA BOX ERROR       C.B.   09.03.84'
./ SHOW 'SEVERAL IMPROVEMENTS TO JOYS. NOTICE CHANGED.  C.B.   11.03.84'
./ SHOW 'JOYS PROTECTED AGAINST -VE MAGNIFICATION.      C.B.   12.03.84'
./ SHOW 'PROMPT IMPROVED.                               C.B.   12.03.84'
./ SHOW 'ERROR IN ZSFIT CORRECTED.                 L.B.,C.B.   13.03.84'
./ SHOW 'CDTL 12/13/20/21/31/32: MEANING AND DEFAULTS REVERSED'
./ SHOW 'BECAUSE CDST COMMENTS DISAGREE WITH VALUES'
./ SHOW 'CHANGED ROUTINES: TRNUMB,CREDIT,EVDISP,RSDISP  '
./ SHOW '                  GPHMAIN,JADEBD,GPHMAINX      '
./ SHOW 'RSDISP FOUND TO HAVE 2 DIR ENTRIES. REPORTED   '
./ SHOW 'THIS TO BUTENSHOEN.  CIRDIS TOO.               C.B.   13.03.84'
./ SHOW 'MAJOR OVERHAUL OF GPHMAIN. LINKDS,GETDS AND DSERR ADDED'
./ SHOW 'CIRDIS CHANGED TO CHANGE POSITION OF TRACK NO. C.B.   13.03.84'
./ SHOW 'CIRDIS & RSDISP CORRUPTION CURED BY BUTENSHOEN C.B.   14.03.84'
./ SHOW 'CIRDIS GOT FROM BACK-UP. 13.03.84 CHANGES LOST C.B.   15.03.84'
./ SHOW 'NOTICE,MENU AND NEWS UPDATED ==> MUPT CHANGES  C.B.   15.03.84'
./ SHOW 'MENU CORRECTED                                 C.B.   16.03.84'
./ SHOW 'N50SDS AND N50SCO ADDED TO DRAW N50 RESULTS.                  '
./ SHOW 'FAMPDS AND FAMPCO ADDED/CHANGED.                              '
./ SHOW 'SCANNR,KOMMAN,DISPLY,NEWS,NOTICE,MENU UPDATED.                '
./ SHOW 'TOFVW HAS BEEN IMPROVED. NOT FINISHED COMPLETELY.             '
./ SHOW 'BUG IN EVDISP (NOT CALLING FWCHEV) CORRECTED.                 '
./ SHOW 'DEDXVW IMPROVED. BETTER MESSAGE IF NO TRACKS.                 '
./ SHOW 'FWCHEV,BLNUMB & TAGCHK UPGRADED.               C.B.   21.03.84'
./ SHOW 'TRKHIT IMPROVED BY K.-H. HELLENBRAND                  21.03.84'
./ SHOW 'NOTICE UPDATED AGAIN. JADEOVLY UPDATED FOR N50 C.B.   21.03.84'
./ SHOW 'SMALL BUG IN EVDISP CORRECTED.                 C.B.   23.03.84'
./ SHOW 'JADISP SPLIT INTO SEPARATE ROUTINES. JADEOVLY UPDATED.        '
./ SHOW 'BARREL REPLACED BY BARSEC WHICH DRAWS AN ARC                  '
./ SHOW 'WITH OPTIONS FOR THE START AND END.            C.B.   10.04.84'
./ SHOW 'RZDET ADDED TO DRAW Z CHAMBER IN ROLLED OUT VIEW              '
./ SHOW 'CODE REMOVED FROM JADISP. JADEOVLY UPDATED  S.C. C.B. 12.04.84'
./ SHOW 'SPINNR UPDATED FOR SPRING 1984                   J.O. 29.04.84'
./ SHOW 'TAGCHK CHANGED TO REMOVE BUG                     C.B. 14.05.84'
./ SHOW 'ADD NEW RUNS WITH VERTICES FROM J.SPITZER        W.B. 17.05.84'
./ SHOW 'RDALGN LOCAL VAR NWORD CHANGED TO NWRD      J.O. C.B. 16.06.84'
./ SHOW 'NEW DEDXBN                                       L.B. 23.08.84'
./ SHOW 'BUG IN DEDXVW CORRECTED                          J.O. 23.08.84'
./ SHOW 'BUG IN EVREAD,IF REAL DATA FOLLOWS MC, KILLED    C.B. 17.09.84'
./ SHOW 'PRSTAT SEPARATED FROM RDTRIG. NOW IN OWN MEMBER  C.B. 17.09.84'
./ SHOW 'DSERR CHANGED TO RECOGNISE ERROR 584 FROM GETPDD C.B. 20.09.84'
./ SHOW 'UPDATE KALIBR,EBEAM FOR RUN 16342                J.O. 27.09.84'
./ SHOW 'NEW KLREAD RUNVTX FROM RUN 16803 ON              W.B. 08.10.84'
./ SHOW 'DEDXB1 (OLD) MOVED TO F11BEK.DEDX.S              L.B. 17.10.84'
./ SHOW 'FAMPDS AND BANKPR UPDATED                        J.O. 28.10.84'
./ SHOW 'JADEBD,RDMTCO,RDRESO UPDATED                C.B. J.H.  1.11.84'
./ SHOW 'RDDOUV,RDIEFV,RDMODV,RDMRGV,RDPOIV,RDRESV,                    '
./ SHOW 'RDRNHV   ROUTINES ADDED FOR VERTEX CHAMBER  C.B. J.H.  1.11.84'
./ SHOW 'MANY GRAPHICS ROUTINES SCRATCHED HERE       C.B. J.H.  1.11.84'
./ SHOW 'SAFCHK WAS FOUND REMOVED, REINSTALLED 18.30 1.11.84'
./ SHOW 'MCGJET TOO.                       C.B., J.O.           1.11.84'
./ SHOW 'VERTEX CHAMBER CHANGES TO KLREAD. C.B., J.H.           1.11.84'
./ SHOW 'EVWRIT,RDMTCO UPDATED             C.B., J.H.           9.11.84'
./ SHOW 'UPDATE EBEAM WARNING PRINT                       J.O. 14.11.84'
./ SHOW 'EXTENDED VERSION OF FITEVR ADDED                 C.B. 10.12.84'
./ SHOW 'ZSFIT CHANGED                                    L.B. 13.12.84'
./ SHOW 'BLSHOW CORRECTED, TO CARE FOR ERROR IN LGDEAD    J.O. 16.12.84'
C   22/03/97 703221757  MEMBER NAME  #START5  (JADEGS)      FORTRAN
FREE F(MACRO,CLIST)
ALLOC F(MACRO) DA('F11GOD.PATRECSR') SHR
ALLOC F(CLIST) DA('F22BOW.JADE.CLISTS','F11PEA.JDCLIST') SHR
CLEAR
./ SHOW 'OLD MESSAGES NOW IN MEMBERS #START0,#START1,#START2,#START3'
./ SHOW 'AND #START4                             C.BOWDERY  28/06/86'
./ SHOW '***********************************************************'
./ SHOW 'NEW DEDXBN                                       L.B. 06.02.85'
./ SHOW 'TOFBK: CALL TO BSAT REPLACED WITH BSAW           J.O. 01.03.85'
./ SHOW 'UPDATE OF DECHIF    (J.A.SKARD)                  J.O. 04.03.85'
./ SHOW 'CORRECTED QPLOTS   KOMAMIYA/OLSSON                    02.04.85'
./ SHOW 'NEW VERSION OF SUPERV - CALL KALIBR AND INPATC FOR            '
./ SHOW 'EVERY EVENT NOW                                C.B.   15.04.85'
./ SHOW 'TBGDIS UPDATED FOR TRIG 1, BANKDESCR.4         J.O.   15.04.85'
./ SHOW 'KLREAD CHANGED FOR VERTEX CHAMBER DRVELO       C.B.   24.04.85'
./ SHOW 'NEW VERSION OF KALIBR + NEW RUNFIX ADDED       C.B.   29.04.85'
./ SHOW 'FITTYP ADDED (WAS TPFITF ON TP LIBRARY)        C.B.   28.06.85'
./ SHOW 'MANY GRAPHICS ROUTINES SCRATCHED --> GRAFIX.S  C.B.    8.07.85'
./ SHOW 'EFMASS MOVED TO GRAFIX.S AND SCRATCHED HERE    C.B.   17.07.85'
./ SHOW 'SUPERV RENAMED TO SUPERV0.                     C.B.   17.07.85'
./ SHOW 'NEW SUPERV HAS SMALL CHANGE FOR GRAPHICS (L11) C.B.   17.07.85'
./ SHOW 'UPDATE OF SPINNR                               J.O.   31.07.85'
./ SHOW 'DELETE TAGCHK, IT NOW SITS UPDATED ON TAGG.S   J.O.   16.08.85'
./ SHOW 'FITTYP WAS GIVING EXACT OPPOSITE ANSWERS       C.B.   19.08.85'
./ SHOW 'MOMENT PROTECTED AGAINST ATAN2 ERROR           J.O.    7.09.85'
./ SHOW 'ZSFIT CORRECTED                                L.B.   11.09.85'
./ SHOW 'DEBUG PRINT IN REFIT,REFITV REMOVED            J.O.   16.09.85'
./ SHOW 'RUNFIX UPDATED FOR BAD BEAM IN R22357          J.O.   16.10.85'
./ SHOW 'KLREAD: PRINT(T0) MOVED TO END OF KLREAD       P.S.   14.11.85'
./ SHOW '2 NEW FUNCTIONS ADDED: RBPIPE, XBPIPE          C.B.   18.12.85'
./ SHOW 'KLREAD: T0,VD,LORENTZ ANG. FOR RUNS 16800...   P.S.   19.12.85'
./ SHOW 'RUNFIX:  PRINT EXTENDED ...                    J.O.   14. 1.86'
./ SHOW 'NEW DEDXBN                                     L.B.   23.01.86'
./ SHOW 'FITEVR + FITEVF CORRECTED                      P.S.   23.01.86'
./ SHOW 'JETCAL ,JRECAL : NEW VERSIONS FOR FADC-READOUT'
./ SHOW 'JETCAL0,JRECAL0: OLD VERSIONS                  P.S.   05.02.86'
./ SHOW 'RUNFIX WARNING FORMAT MODIFIED FOR GRAPHICS    J.O.   09.02.86'
./ SHOW 'EBEAM UPDATED FOR RUN 22357                    J.O.   10.02.86'
./ SHOW 'RUNFIX9 WITH 29.2.86 BUG CORRECTED             J.O.   04.03.86'
./ SHOW 'DL300 SWITCH IN ZRECAL                         L.B.   10.03.86'
./ SHOW 'MC RETURN FOR ZSFIT AND DEDXBN                 L.B.   24.03.86'
./ SHOW 'KLREAD CHANGED (SPITZER)                 W.B./ L.B.   02.06.86'
./ SHOW 'UPDATE OF XBPIPE,RBPIPE,RDMTCO, ACC. TO J.HAGEMANN    09.06.86'
./ SHOW 'UPDATE OF RADIATION LENGTH IN XBPIPE              .   09.06.86'
./ SHOW 'THE OLD VERSIONS ARE RDMTCO0, RBPIPE0,XBPIPE0  J.O.   09.06.86'
./ SHOW 'RDMTCO INSTALLED YESTERDAY HAD BY MISTAKE WRONG SMEARING      '
./ SHOW 'THE CORRECT ONE INSTALLED 11.50                J.O.   10.06.86'
./ SHOW 'JADEBD UPDATE: VTXCH CONSTANTS AND /TODAY/     J.O.   10.06.86'
./ SHOW 'GETINT ADDED FROM F22HAG.GRAPHV.S              C.B.   10.06.86'
./ SHOW 'UPDATE OF RADIATION LENGTH IN XBPIPE           J.O.   11.06.86'
./ SHOW 'UPDATE OF RDMTCO (VTXC BANK NUMBER)      J.H./ J.O.   16.06.86'
./ SHOW 'UPDATE OF RUNFIX AND EBEAM                     J.O.   21.06.86'
./ SHOW 'UPDATE OF RUNFIX AND EBEAM    (R 26435)        J.O.   10.07.86'
./ SHOW 'UPDATE OF SPINNR FOR END 1985,BEG 1986 DATA    J.O.   11.07.86'
./ SHOW 'UPDATE OF JADEBD (VERTEX CH RAD LENGTH)    J.H./J.O.  17.07.86'
./ SHOW 'UPDATE OF RUNFIX  (R 4841)                      J.O.  29.07.86'
./ SHOW 'CORRECT BUG IN FRFITV  (OR WITH 32..)           J.O.  11.08.86'
./ SHOW 'UPDATE OF RUNFIX  (R 4544,5662)                 J.O.  13.08.86'
./ SHOW 'UPDATE OF RUNFIX  (R13106-13145)                J.O.  25.08.86'
./ SHOW 'NEW USER COMMON IN DEDXBN                       L.B.  27.08.86'
./ SHOW 'UPDATE OF RUNFIX  (R11396) MAG FIELD            J.O.  27.08.86'
./ SHOW 'CL2PRC: DL300 FADC SERVICE ROUTINE INSTALLED    J.O.  27.08.86'
./ SHOW 'DEDXBN: MINOR MODIFICATIONS IN PRINT      J.A.S./J.O. 28.08.86'
./ SHOW 'INSTALLED SUBR. PRAGAI, UPDATE OF RDMTCO,PRSTAT,'
./ SHOW 'RDALGN,RDDATE,RDMTCO,RDTRG1,RDTRG2,RDTRIG. CHANGES ONLY IN'
./ SHOW 'SOURCE, UNTIL CHANGEOVER SHALL TAKE PLACE, SOON. ALL THESE'
./ SHOW 'CHANGES ARE DESCRIBED IN SUPPL.2, JCN 66        J.O.  28.08.86'
./ SHOW 'UPDATE OF RUNFIX  (R24354) JUNK WARNING         J.O.  28.08.86'
./ SHOW 'THE ABOVE RD-ROUTINES COMPILED TO LOAD. OLD VERSIONS AVAILABLE'
./ SHOW 'AS -0 VERSIONS                                  J.O.  29.08.86'
./ SHOW 'ERROR IN PRSTAT KORREKTED, GAVE WRONG PRINTOUT  J.O.  29.08.86'
./ SHOW 'UPDATE OF RUNFIX AND EBEAM, R25688 COSMIC WARN. J.O.  02.09.86'
./ SHOW 'INSTAL KTMCON9 FOR MORE PRINT IN KTMCON ERRORS. J.O.  02.09.86'
./ SHOW 'UPDATE RUNFIX R28382  EBEAM                     J.O.  03.09.86'
./ SHOW 'UPDATE KTMCON ACC. TO KTMCON9                   J.O.  03.09.86'
./ SHOW 'ERROR PRINT IN JETCAL, IF DIVIDE WITH 0         J.O.  08.09.86'
./ SHOW 'MORE PRINT IN JETCAL FOR DEBUG PURPOSE          J.O.  10.09.86'
./ SHOW 'INSTAL MEMBER WERTEX: MODIFIED ROUTINES AND FUNCTIONS FOR     '
./ SHOW 'THE VERTEX FINDING PROGRAM VERTEX. CONTAINED SUBROUTINES ARE: '
./ SHOW ' VERTEX,VTXINI,VTXPRE,VTXSRC,VTXEE,VTXAFT,VTXEER,VTXERR,      '
./ SHOW ' VTXBNK,VTXPNT,VTXCRV.   FUNCTIONS:  PARKOR,XFWID,XFWVXC.     '
./ SHOW 'INSTALLED ALSO FUNCTION DRPIPE: BEAMPIPE THICKNESS.           '
./ SHOW '                                                J.O.  02.10.86'
./ SHOW 'PRINT LIMIT IN RDDATE INSTALLED                 J.O.  29.10.86'
./ SHOW 'TYPE ERROR IN PRAGAI CORRECTED                  J.O.  07.11.86'
./ SHOW 'RUNFIX UPDATE FOR RUN 6185                      J.O.  10.11.86'
./ SHOW 'JETCAL CORRECTED FOR LONGSTANDING BUG       E.E,J.O.  26.11.86'
./ SHOW 'KLREAD UPDATED FOR 1986                     E.E,J.O.  26.11.86'
./ SHOW 'CL2PRC UPDATED                              E.E,J.O.  26.11.86'
$   21/12/87 903021645  MEMBER NAME  #START   (JADEGS)      NEWLIB
FREE F(MACRO,CLIST)
ALLOC F(MACRO) DA('F11GOD.PATRECSR') SHR
ALLOC F(CLIST) DA('F22BOW.JADE.CLISTS','F11PEA.JDCLIST') SHR
CLEAR
./ SHOW 'OLD MESSAGES NOW IN MEMBERS #START0,#START1,#START2,#START3'
./ SHOW '#START4 AND #START5                 J.OLSSON  28/05/87'
./ SHOW '***********************************************************'
./ SHOW 'RUNFIX UPDATED, RUN 29828                       J.O.  30.01.87'
./ SHOW 'RUNFIX UPDATED, COSMIC RUNS AT END OF 1986      J.O.  11.02.87'
./ SHOW 'UPDATE KALIBR AND JFETCH, JFETCH0 BACKUP                      '
./ SHOW 'INSTAL CNEWID,JFTNEW,                       J.O.,J.S. 13.03.87'
./ SHOW 'INSTAL DISTXY,SAGCIR,SHELL9,SQTVAL,XYRFTV,XYRFT1              '
./ SHOW '  ALL MEMBERS USED IN SPITZERS NEW FITTING  J.O.,J.S.,13.03.87'
./ SHOW 'INSTAL KOMAKS: KOMAMIYAS V0 FINDER          P.H.,J.O.,13.03.87'
./ SHOW 'UPDATE KOMAKS: PREVIOUS WAS WRONG VERSION!  P.H.,J.O.,15.03.87'
./ SHOW 'UPDATE JFETCH,JFTNEW,                       J.O.,J.S. 18.03.87'
./ SHOW 'UPDATE        JFTNEW                        J.O.,J.S. 19.03.87'
./ SHOW 'CHANGE JFETCH (CORRECT EVAL. OF CIRCLE PARAM.)   P.S. 25.03.87'
./ SHOW 'CHANGE XYRFT1                     J.O.,J.S. 25.03.87, 27.03.87'
./ SHOW 'CHANGE XYRFT1                     J.O.,J.S. 01.04.87'
./ SHOW 'UPDATE JFTNEW                     J.O.,J.S. 04.04.87'
./ SHOW 'UPDATE XYRFTV,XYRFT1 (NEW ARG.LIST)         J.O.,J.S.10.4.87'
./ SHOW 'INSTAL EXPATR                     J.O.,J.S. 10.04.87'
./ SHOW 'CHANGE XYRFT1,                           J.O.,J.S  12.04.87'
./ SHOW 'CNEWID WITH NEW.CAL. DEFAULT J.O.,J.S   12.04.87'
./ SHOW 'MOMENT CHANGE ARCOS TO ACOS  W.BA.   28.4.87'
./ SHOW 'MOMENT CHANGE PZ FOR HELIX TYPE FIT  J.O.,J.S.  29.4.87'
./ SHOW 'JADEBD AND DEDXBN UPDATED, COMMON /CDEDXU/   J.O.  04.5.87'
./ SHOW 'UPDATE MOMENP, ACC. TO RECENT CHANGES IN MOMENT    J.O.04.5.87'
./ SHOW 'AMBRUS NEW DEDX PROGRAM INSTALLED, UNDER NAME OF DEDXCN '
./ SHOW '       IT IS AN UPDATE OF DEDXBN. THE MEMBER DEDXCN CONTAINS'
./ SHOW '       SEVERAL NEW SUBROUT. AND FUNCTIONS, AS WELL AS CHANGED '
./ SHOW '       VERSIONS OF CHIFT1, DECHIF, DETHRY, ERRMOM. AFTER TEST'
./ SHOW '       THE PRESENT DEDXBN WILL BE REPLACED BY THE NEW DEDXCN'
./ SHOW '                                           J.O.     04.5.87'
./ SHOW 'UPDATE DEDXBN WITH NEW SMOLIK DATA         W.B.     04.5.87'
./ SHOW ' UPDATE JFETCH,JFTNEW, INSTAL AMPS2Z,ZSRFTV,ZSRFT1'
./ SHOW ' INSTAL  NEW VERSIONS OF ZSFIT,ZSLINE,ZSPUR UNDER THE NAMES'
./ SHOW ' ZSFIT9,ZSLINE9,ZSPUR9 FOR TESTS (WITH DEDXBN)'
./ SHOW '                                           J.O.,J.S. 07.5.87'
./ SHOW ' ZSFIT9,ZSLINE9,ZSPUR9 RENAMED TO STANDARD VERSIONS. THE OLD'
./ SHOW ' VERSIONS ARE NOW ZSFIT0,ZSLINE0,ZSPUR0         J.O. 14.5.87'
./ SHOW ' INTEGER*2 HDATA INTRODUCED IN SEVERAL ROUTINES:'
./ SHOW '  ERRMOM, KOMAKS, PREVTX, RDPATR, WERTEX    J.O. E.E. 21.5.87'
./ SHOW ' UPDATE OF RDALGN, READOUT THRESHOLD 1986        J.O. 25.5.87'
./ SHOW 'DEDXBN UPDATED AGAIN, COMMON /CDEDXU/,LOST BY LAST CHANGE BY'
./ SHOW 'W.B. ON 4.5.87 (SAME DAY !)                      J.O.  28.5.87'
./ SHOW 'UPDATE OF JADEBD WITH 2 COMMONS FROM JFTNEW,ZSRFTV. AT THE'
./ SHOW 'SAME TIME, UPDATE OF JFTNEW AND ZSRFTV     J.O.,J.S.  01.06.87'
./ SHOW 'GENERAL UPDATE OF DEDXCN                  J.O.,K.A.  04.06.87'
./ SHOW 'UPDATE OF XYRFT1 TO DOUBLE PRECISION      J.O.,J.S.  05.06.87'
./ SHOW 'CORRECTED SMALL BUG IN RDTRG1 (KREHBIEL TR.)   J.0.  08.06.87'
./ SHOW 'UPDATE OF JADEBD, ZSRFTV COMMONS               J.0.  10.06.87'
./ SHOW 'UPDATE OF ZSFIT (OLD VERSION ZSFIT0), NEW ROUTINE ZSPDBK     '
./ SHOW 'UPDATE OF JADEBD, CZSPRM COMMON, AND AMPS2Z E.E J.0.  16.06.87'
./ SHOW 'UPDATE OF ZSRFTV                             J.S. J.O. 17.6.87'
./ SHOW 'CORRECTION OF MISPRINT IN XYRFT1             J.S. J.O. 18.6.87'
./ SHOW ' UPDATE OF ZRECAL,AMPS2Z,DEDXBN,DEDXCN, ACC. TO JCN 96      '
./ SHOW ' DELETE ANCIENT VERSION DEDXDN                              '
./ SHOW ' OLD VERSIONS KEPT: ZRECAL0,DEDXBN0,AMPS2Z0  E.E.,J.O. 20.6.87'
./ SHOW ' UPDATED MEMBER DEDXCN WHICH HAS NEW DEDXBN  E.E.,CKB. 20.7.87'
./ SHOW ' MEMBERS PARCIR AND ADJCIR HERE FROM TPSOURCE     CKB. 22.7.87'
./ SHOW ' JADEBD NOW INCLUDES Z CHAMBER BLOCK DATA         CKB. 24.7.87'
./ SHOW ' RDTRIG UPDATED WITH 1986 Z-RESOLUTION FOR JETC   JO. 26.7.87'
./ SHOW ' Z CHAMBER ROUTINES ADDED FROM F11SPI.ZS                     '
./ SHOW ' JADEBD BLOCK DATA CHANGED. ONE NEW VARIABLE ADDED.          '
./ SHOW ' ALSO JFETCH AND JFTNEW REPLACED             J.S. CKB 29.7.87'
./ SHOW ' UPDATE XYRFTV,ZSRFTV,ZSRFT1 WITH PRINT AND BIT SETTINGS'
./ SHOW '                                            J.S. J.O.  4.8.87'
./ SHOW ' UPDATE ZCFTNW AND JADEBD WITH PRINT ETC.  J.S. J.O. 12.8.87'
./ SHOW ' MEMBER TRCROS COPIED FROM (TPSOURCE) TPTCRS    CKB  26.8.87'
./ SHOW ' BACKUP OF DEDXBN = DEDXBN0                                   '
./ SHOW ' UPDATE DEDXBN TO STATUS OF DEDXCN, NEW VERSION BY K.AMBRUS   '
./ SHOW ' MEMBER DEDXCN KEPT FOR A WHILE, TO ALLOW USE OF INCLUDE STILL'
./ SHOW '                                        J.O.   1.9.1987       '
./ SHOW ' UPDATE OF DEDXBN FOR MC SIMULATION OF DEDX INFO. NEW INSTAL- '
./ SHOW ' MENT OF SUBR. IZT2RN,DXMCSP,DXMCSS. UPDATE OF ZSFIT          '
./ SHOW ' OLD VERSIONS DEDXBN00 AND ZSFIT0    E.E., J.O   16.11.1987 '
./ SHOW ' REMOVED DIRECT SETTING OF MOMENTUM AND HIT LIMITS IN DEDXBN, '
./ SHOW ' SINCE THEY ARE SET IN JADEBD AND CAN BE REMOTELY CHANGED. '
./ SHOW ' UPDATED JADEBD ON A MISTAKE IN TAGGING DETECTOR DIMENSIONS.  '
./ SHOW '                                          J.O.  17.11.87     '
./ SHOW ' FURTHER CHANGES IN DEDX FOR MC: UPDATE OF DEDXBN,ZSPDBK     '
./ SHOW '  OLD VERSION IS ZSPDBK0             E.E.,J.O.  20.11.87     '
./ SHOW ' CORRECTION OF RARE DIVIDE CHECK IN DEDXBN  '
./ SHOW '                                     E.E.,J.O.  26.11.87     '
./ SHOW ' CORRECTION OF SMALL, UNIMPORTANT BUG IN DEDXBN,DEDXBK'
./ SHOW '                                     E.E.,J.O.  30.11.87     '
./ SHOW ' GENERAL UPDATE AFTER SOFTWARE MEETING, CHANGED ROUTINES:     '
./ SHOW ' EVWRIT,PRPATR,PRAGAI,RDMTCO,RDRESO,RDRESV,RDTRIG.  BACKUPS:  '
./ SHOW ' EVWRIT0,PRPATR0,PRAGAI0,RDMTCO0,RDRESO0,RDRESV0,RDTRIG0  '
./ SHOW '                                     E.E.,J.O.  14.12.87     '
./ SHOW ' RDDATE CHANGED ACCORDING TO NEW SMEARING DATE SCHEME.       '
./ SHOW ' OLD COPY IS RDDATE0.                C.B.       17/12/87     '
./ SHOW ' RDTRIG BLOCKDATA FOR /CBINV/ CORRECTED  J.O., J.H. 18.12.87 '
./ SHOW ' EVREAD UPDATED WITH INFO PRINT FOR MC-EVENTS  '
./ SHOW ' OLD EVREAD IS NOW EVREAD0                 J.O. 20.12.1987 '
./ SHOW ' #START now has line zero, language NEWLIB and ASIS=MIX    '
./ SHOW ' RDDATE updated. Old version is RDDATE00   E.E., C.B. 21/12/87'
./ SHOW ' RDiefv and nvert updated        c.k. j.h.  j.o. 22/12/87'
./ SHOW ' UPDATE OF XYRFTV AND XYRFT1       J.S.  J.O.    11.01/88'
./ SHOW ' UPDATE OF XYRFT1, ZSRFT1,ZSRFTV   J.S.  J.O.    12.01/88'
./ SHOW ' UPDATE OF KLREAD FOR VTX CONSTS                         '
./ SHOW '        OLD VERSION IN KLREAD2     E E.          15.01/88'
./ SHOW ' LIBRARY RATIONALISATION:                               '
./ SHOW ' MEMBERS NUMFUN AND LOCFLD MOVED HERE FROM GRAFIX.S     '
./ SHOW ' MEMBERS IDFELD, STRNUM AND CMPDCT MOVED HERE FROM TP9.S'
./ SHOW '                                   C.B.           18/01/88'
./ SHOW ' CORRECT BUG IN XYRFT1             E E         19/01/88 '
./ SHOW ' CORRECT BUG IN DEDXBK             E E         21/01/88 '
./ SHOW ' MINOR CHANGES TO FORMAT STATEMENTS IN KLREAD AND CNEWID'
./ SHOW ' PLUS MCREDU MOVED HERE FROM JMC.S       C.B.  29/01/88 '
./ SHOW ' UPDATE OF ZSRFT1, (Z-CHAMBER FLAG)     J.S,J.O. 15/02/88 '
./ SHOW ' UPDATE OF JFETCH,JFTNEW WITH VTXC ADDITIONS '
./ SHOW ' OLD VERSIONS KEPT AS JFETCH0 AND JFTNEW0, J.O., J.S. 18/02/88'
./ SHOW ' CHANGE MVC TO MVCL IN ROUTINES THAT COPY MORE THAN 256 BYTES '
./ SHOW ' INVOLVED ROUTINES ZSRFTV, ZSRFT1, XYRFT1  J.H. J.O. 22/2/88  '
./ SHOW ' LDATYP TO DISTINGUISH DL8 AND DL300 DATA                     '
./ SHOW ' INTRODUCE INTO    ZSRFTV, ZSRFT1, XYRFT1                     '
./ SHOW ' UPDATE AMPS2Z FOR 2 TRACK LIMIT IN MC     E.E.      18/3/88  '
./ SHOW ' ZSFIT NEW HIT COUNTING (ALSO OK FOR MC NOW)  E.E.   18/3/88  '
./ SHOW ' UPDATED VERSIONS OF RDTRIG,RDRESO,RDMTCO,PRSTAT,PRAGAI '
./ SHOW ' INSTALLED AS 9-VERSIONS, FOR TEST BEFORE MAKING STANDARD.'
./ SHOW ' THEY INTRODUCE NON-GAUSSIAN TAILS IN Z-SMEARING  J.O. 25.3.88'
./ SHOW ' UPDATE ZSRFTV FOR MINOR BUG        '
./ SHOW '   OLD VERSION KEPT AS ZSRFTV0         J.O. J.S.  25.3.88'
./ SHOW ' SUPERV CHANGED TO GIVE MORE LOW PRIORITY BANK SPACE          '
./ SHOW ' AND TOTAL SPACE ALSO INCREASED BY 5000 (CBCSMX)  CKB  28.3.88'
./ SHOW ' UPDATE EBEAM AND RDATA                          J.O.  30.3.88'
./ SHOW ' NEW VERSIONS FOR EVWRIT,RDTRIG,RDRESO,RDMTCO,PRSTAT,PRAGAI'
./ SHOW ' INTRODUCING DOUBLE GAUSS SMEARING IN Z           EE   31.3.88'
./ SHOW ' DEDXBN,DXMCSS UPDATE FOR HIT CLEANING IN MC      EE   31.3.88'
./ SHOW ' OLD VERSIONS AVAILABLE AS 0-VERSIONS             EE   31.3.88'
./ SHOW '                                                        '
./ SHOW ' CORRECT VDFACT BUG IN DEDXBN                     EE   05.4.88'
./ SHOW ' RDTRIG: VTXC CHAMBER INEFF 0.995 -> .871    JH,  EE   05.4.88'
./ SHOW ' ZCHCAL: PEDESTAL SETTING FOR RUN<20000           EE   06.4.88'
./ SHOW ' RDRESO: NO NEG AMPLITUDES                   JH,  EE   28.4.88'
./ SHOW ' ZSRFTV,ZSRFT1:  SEVERE BUGS CORRECTED, AFFECTING LOW-MOMENTUM'
./ SHOW '                 TRACKS, CONVERSIONS, V-PARTICLES, ETC.    '
./ SHOW ' OLD VERSIONS: ZSRFTV2,ZSRFT12    J.H., G.E., J.O.  13.5.1988'
./ SHOW ' AFTER TEST OF ABOVE CORRECTIONS, A NEW CORRECTION WAS MADE '
./ SHOW ' TO ZSRFT1 (TEST OF ARGUMENT OF ARSIN)!    G.E.  J.O. 14.5.88'
./ SHOW ' AND TO ZSRFTV (ARSIN)                     E.E.       16.5.88'
./ SHOW ' EXTEND COMMON ZCTRK IN ZCDATA, ZCFTNW AND ZCASS AND ADD     '
./ SHOW ' CODE TO AVOID DIVIDE CHECK FOR Z-SLOPE=0 E.E.       20.5.88'
./ SHOW ' JADEBD AMPS2Z WEIGHT TUNED               E.E., J.H. 20.5.88'
./ SHOW ' ZSRFT1 SMOOTH CUTOFF PROCEDURE           E.E., J.H. 24.5.88'
./ SHOW ' DEDXBN CORRECT FOR COS(THETA) DEPENDENCE       E.E. 10.6.88'
./ SHOW ' ZSRFTV EXTRA COMMENT IN SUBR. DESCRIPTION      E.E. 27.6.88'
./ SHOW ' ZCFTNW CORRECT IMI TYPING ERROR                E.E. 27.6.88'
./ SHOW ' BOS COMMON SIZE INCREASED TO 60000 (MACRO CBCSMX ON PATRECSR,'
./ SHOW ' SUPERV BINT CALL WITH BINT(LDATA,LDATA,...) '
./ SHOW ' JADEBD UPDATED WITH CONTENT OF BDVTXC ON F22KLE.JVTXC.GS   '
./ SHOW '                                     J.H.,G.E.,J.O.  29.6.88'
./ SHOW ' MEMBER WERTEX RESTRUCTURED. SEE LONG COMMENT IN MEMBER ITSELF'
./ SHOW '                                               J.O.  03.7.88'
./ SHOW ' UPDATED PRAGAI, MORE PRINT, BETTER FORMAT      J.O. 23.7.88'
./ SHOW ' CORRECT TYPO IN ZCASS                          E.E. 25.7.88'
./ SHOW ' LEAP YEAR PROBLEM IN IDATTM CORRECT.      C.B. J.P. 25.7.88'
./ SHOW ' IMPROVED VERSIONS OF NUMFUN, EVBKPR       C.B. J.H. 25.7.88'
./ SHOW ' SPHRCY, AKOP, THRUNB FROM JVTXC.S         C.B. J.H. 25.7.88'
./ SHOW ' THRUST  FROM TPSOURCE FOR COMPLETENESS    C.B. J.H. 25.7.88'
./ SHOW ' UPDATE OF RDMTCO (SMEARING BUG), PRAGAI        J.O. 25.7.88'
./ SHOW '      THE PRAGAI CHANGE STEERS EVWRIT CONSTANT WRITING   '
./ SHOW ' INSTAL MUCON WITHOUT UNNECESSARY PRINTING      J.O. 25.7.88'
./ SHOW '    (NOTE: OLD VERSION OF MUCON ON JADEMUS/L NOT CHANGED  '
./ SHOW ' SCRATCH MUCON AGAIN, CHANGE WILL BE MADE ON JADEMUS/L  '
./ SHOW '                                           C.B.,J.O. 26.7.88'
./ SHOW ' STRNUM CHANGED TO ENSURE "/" IS ILLEGAL        C.B. 26.7.88'
./ SHOW ' XYRFTV SETS EXTRA BITS FOR STRONG/WEAK CONSTR  E E. 27.7.88'
./ SHOW ' THE CHANGE IN PRAGAI DOESNOT WORK:'
./ SHOW '    DATA SETS WITHOUT CONSTANTS BANKS ARE SOMETIMES WRITTEN'
./ SHOW '    THEY CAN NOT BE READ BY EVREAD     OLD PRAGAI0 NOW RENAMED'
./ SHOW '    TO PRAGAI, THE NEW VERSION IS NOW PRAGAI9 UNTIL FURTHER'
./ SHOW '                                        J.O.  1.8.88, 11:15'
./ SHOW 'PRAGAI9 DELETED, EVWRIT9 RDMTCO9 INSTALLED. NFLAGS(9) NOW USED'
./ SHOW 'BY RDMTCO9-EVWRIT9, SOLVES PRAGAI PROBLEM. WHEN MORE TESTS'
./ SHOW 'HAVE BEEN MADE, 9-VERSIONS SHOULD BE STANDARD    J.O.  11.8.88'
./ SHOW ' XYRFT1   COVARIANCE MATRIX CORRECTED       C.K., E.E.  2.9.88'
./ SHOW ' RDMTCO9: PRINT STATEMENT REMOVED                 J.O. 10.9.88'
./ SHOW ' ZCFTNW INHIBIT EXCESSIVE P/O FOR EVENT NR<0      E E. 20.9.88'
./ SHOW ' PROTECT AGAINST DIVISION BY ZERO IN SPHRCY       C.B. 4.10.88'
./ SHOW ' CORRECT TAGGING BUG IN RDTRG1 (RD82T1)     A.W. J.O. 28.11.88'
./ SHOW ' OLD VERSION RDTRG10    '
./ SHOW ' CORRECT WRONG PRINT IN IZT2RN  (IZT2RN)         J.O. 19.12.88'
./ SHOW ' IDFELD AND CMPDCT DELETED AND PUT ON TP9.S      C.B.  9.1.89'
./ SHOW ' IZT2RN WRITE COMMENTED OUT FOR TESTS *TEMP*     C.B. 10.1.89'
./ SHOW ' IZT2RN WRITE PUT IN DOWHILE OUT                 E.E. 11.1.89'
./ SHOW ' ZSPDBK & REPLACED BY * FOR STANDARD FORTRAN 77  C.B. 10.1.89'
./ SHOW ' DXMCSP REMOVE DO .. WHILE'S                     E.E. 13.1.89'
./ SHOW ' DEDXBN REPLACE LAND/SHFTL BY IAND/ISHFT         C.B. 16.1.89'
./ SHOW ' JADEBD UPDATE OF TAGGING DIMENSIONS             J.O. 02.3.89'
./ SHOW '                                                        '
./ SHOW '                                                        '
./ SHOW ' ----> DELETE THIS LINE WHEN KLREAD BUG (MC) IS FIXED!    '
