C   10/01/82 201101910  MEMBER NAME  PRSMP    (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE PRSMP
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      IMPLICIT INTEGER*2 (H)
      COMMON/SMPTOF/MTOF,TTOF(42),NTOF,HTOF(42)
C
      PRINT 100
  100 FORMAT(' TOFSMP RESULTS')
      DO   1   I=1,42
      IF(HTOF(I).LE.0)  GOTO  1
      PRINT 101,I,TTOF(I)
  101 FORMAT(' TOF',I5,F12.2)
    1 CONTINUE
      RETURN
       END
