C   07/06/96 606071922  MEMBER NAME  BANDPR   (S4)          FORTG1
      SUBROUTINE BANDPR(A,N,M)
      REAL A(M,N)
      WRITE(6,101)
      DO 10 I=1,N
      WRITE(6,101) (A(J,I),J=1,M)
   10 CONTINUE
      WRITE(6,101)
  100 RETURN
  101 FORMAT(1X,10G13.5)
      END
