C   09/10/79 910180047  MEMBER NAME  ANOM62   (S)           FORTRAN
      SUBROUTINE ANOM62(IRUN)
C---  ANOMALIES OF RUNS 1561 - 1576
C---  15.26 GEV      SEPTEMBER 1979
C
C     H.WRIEDT    27.07.79     02:20
C     LAST MODIFICATION     18.10.79     00:35
C
      IMPLICIT INTEGER*2 (H)
C
      COMMON /CPHASE/ LIMEVT,KCONST(192),LIMIT(192),LCHANN(192),
     &                LTHRES(192),LDEAD(192),LSUB(240)
      LOGICAL LCHANN,LTHRES,LDEAD,LSUB
C
C---  LCHANN:  CHANNELS WITH CONSTANT PEDESTALS
C---  LDEAD:   CHANNELS WHICH MUST BE SET TO 0 (E.G. FOR MISSING BITS
C              IN THE ADC
C---  KCONST:  CHANNELS FOR WHICH THE SUBTRACTION CONSTANT MUST BE
C              HIGHER (-1) OR LOWER (+1) THAN THE PROGRAM WOULD
C              AUTOMATICALLY CALCULATE
C---  LIMIT:   GIVES THE LOWER BOUND OF THE SUBTRACTION CONSTANT
C---  LTHRES:  CHANNELS FOR WHICH THE LOWER CUT BOUND IS SET TO 100
C              INSTEAD OF 50
C
      GOTO (1561,1562,13,1564,1565,1566,1567,13,1569,1570,1571,13,
     &      1573,13,1575,1576),IRUN
   13 RETURN
C
 1561 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
      LCHANN(173) = .TRUE.
C
      KCONST(97) = -1
      LIMIT(97) = 120
      KCONST(101) = -1
      LIMIT(101) = 75
      KCONST(150) = -1
      LIMIT(150) = 45
      KCONST(155) = -1
      LIMIT(155) = 60
      KCONST(171) = -1
      LIMIT(171) = 75
C
      RETURN
C
 1562 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
      LCHANN(173) = .TRUE.
C
      KCONST(148) = -1
      LIMIT(148) = 45
C
      RETURN
C
 1564 LCHANN(79) = .TRUE.
      LCHANN(173) = .TRUE.
C
      RETURN
C
 1565 LCHANN(79) = .TRUE.
C
      RETURN
C
 1566 LCHANN(79) = .TRUE.
C
      KCONST(154) = -1
      LIMIT(154) = 45
C
      RETURN
C
 1567 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
C
      KCONST(101) = -1
      LIMIT(101) = 60
C
      RETURN
C
 1569 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
      LCHANN(173) = .TRUE.
C
      KCONST(154) = -1
      LIMIT(154) = 45
C
      RETURN
C
 1570 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
C
      RETURN
C
 1571 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
C
      KCONST(101) = -1
      LIMIT(101) = 45
C
      RETURN
C
 1573 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
      LCHANN(173) = .TRUE.
C
      RETURN
C
 1575 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
      LCHANN(173) = .TRUE.
C
      KCONST(101) = -1
      LIMIT(101) = 60
      KCONST(154) = -1
      LIMIT(154) = 45
C
      RETURN
C
 1576 LCHANN(79) = .TRUE.
      LCHANN(107) = .TRUE.
C
      RETURN
C
      END
