C   10/09/79 008242137  MEMBER NAME  CORCST                 FORTRAN
      SUBROUTINE CORCST(NRUN)
       REAL *8 DYC1,DYC2
       COMMON/TFPRM/ NRNC1,NRNC2,DYC1,DYC2,IFLC(42),CMC(42),CPC(42),
     -DTC(42),WMC(42),WPC(42),VELC(42),DMC(42),DPC(42),PDMC(42),PDPC(42)
C
      COMMON/CALIBR/JPOINT(8)
      DIMENSION ACALIB(8)
      EQUIVALENCE (ACALIB(1),JPOINT(1))
C
      DATA IENTRY/0/,IPRNT1/0/,IPRNT2/0/ ,IENMC/0/
C
      IENTRY = IENTRY + 1
      IF(NRUN.EQ.0)  GOTO  10
      IND = JPOINT(6)
      DO   1   N=1,378
      IDUM = 0
      IF(N.GT.84) IDUM = 42
      CMC(N+IDUM) = ACALIB(IND+N)
    1 CONTINUE
C     IF(IENTRY.EQ.1)PRINT 100,CMC,CPC,WMC,WPC,VELC,DMC,DPC,PDMC,PDPC
C 100 FORMAT(/4(1X,10F12.3/),1X,2F12.3)
      RETURN
C
C  CONSTANTS FOR MONTE CARLO
C
   10 CONTINUE
      IENMC = IENMC + 1
      DO   5   I=1,42
      CMC(I) = 40.+1500./162.
      CPC(I) = 40.+1500./162.
      DMC(I) = .05
      DPC(I) = .05
      WMC(I) = -50.
      WPC(I) = -51.
      VELC (I) = 162.
    5 CONTINUE
C     IF(IENMC.EQ.1)PRINT 100,CMC,CPC,WMC,WPC,VELC,DMC,DPC,PDMC,PDPC
      RETURN
      END
