C   07/06/96 606071805  MEMBER NAME  BDLMX    (S4)          FORTG1
      SUBROUTINE BDLM
C     BOS SUBPROGRAM =0.6=
#include "acs.for"
      COMMON/BCS/IW(1)
      REAL FF/Z000000FF/
      EQUIVALENCE (INAME,XNAME)
      INTEGER ISTAR/Z0000005C/
      REAL AND
      EXTERNAL AND
C
C     DELETE ALL BANKS WITH NAMES OF THE CURRENT LIST
      IF(IN.LE.0) GOTO 100
      ILS=0
      JLOW=NLST
      NDEL=0
      DO 20 J=1,IN
      K=IW(NLST+J)
      I=IW(K)
      IF(I.EQ.0) GOTO 20
      IW(K)=0
      NAMDEL=NDEL
      IF(ILS.EQ.0) ILS=I
      GOTO 15
   10 I=IW(I-1)
   15 IF(I.EQ.0) GOTO 18
      NN=4+IW(I)
      JLOW=MIN0(I,JLOW)
      NDEL=NDEL+NN
      IW(I)=-NN
      IF(ILS-IW(ILS).EQ.I) GOTO 16
      ILS=I
      GOTO 10
   16 IW(ILS)=IW(ILS)-NN
      GOTO 10
   18 INAME=IW(INAMV+K)
      XNAME=AND(XNAME,FF)
      IF(INAME.EQ.ISTAR) NCPL=NCPL-NDEL+NAMDEL
   20 CONTINUE
      IF(JLOW+NDEL-3.NE.NEXT) GOTO 22
C     LAST BANKS
      NK=1+((10*(NEXT-2))/NLAST)
      NHISTH(NK)=NHISTH(NK)+1
      NK=1+((10*NCPL)/NLAST)
      NK=MIN0(10,NK)
      NHISTL(NK)=NHISTL(NK)+1
      NCOL=NCOL+1
      NEXT=NEXT-NDEL
      GOTO 100
C     NOT LAST BANKS
   22 NFRE=NFRE+NDEL
      ILOW=MIN0(ILOW,JLOW)
C
  100 RETURN
      END
