C--------START OF MACRO CMUANP------------------------------------------
C
C MU ANALYSIS PARAMETERS. FOR DESCRIPTION SEE BLOCK DATA IN MUINI.
C
      COMMON/CMUANP/IMUANP(30)
      EQUIVALENCE (CUTP,IMUANP(1))
      EQUIVALENCE (WRES,IMUANP(2))
      EQUIVALENCE (CUTT,IMUANP(3))
      EQUIVALENCE (CUTL,IMUANP(4))
      EQUIVALENCE (FT,IMUANP(5))
      EQUIVALENCE (FL,IMUANP(6))
      EQUIVALENCE (DRES,IMUANP(7))
      EQUIVALENCE (DLRES,IMUANP(8))
      EQUIVALENCE (FS,IMUANP(9))
      EQUIVALENCE (CUTC,IMUANP(10))
      EQUIVALENCE (FR,IMUANP(11))
      EQUIVALENCE (FAT,IMUANP(12))
      EQUIVALENCE (FAL,IMUANP(13))
      EQUIVALENCE (CUTDT,IMUANP(14))
      EQUIVALENCE (CUTDL,IMUANP(15))
C
C-----END OF MACRO CMUANP-----------------------------------------------
