C   25/06/78 C8062601   MEMBER NAME  PARSET   (LGSOURCE)    FORTRAN
      SUBROUTINE PARSET(FRAC,N,A,Z,CUTM,CUTB2,ROH,XX0,X0,ABR1,ABR2,
     @    ALPPA1,ALPPA2,ALPM,ALPBH,ACM,BGAM,AMEAN,ZMEAN)
C
C      A.SATO
C
      DIMENSION FRAC(N),Z(N),A(N),X0(N)
C     DIMENSION ABR1(10),ABR2(10),ALPPA1(10),ALPPA2(10)
      DATA CTCON/3.1764E-09/, CONM0/0.90162/
C     DATA CUTBT2/0.001/
C
      TIV0=0.
      AMEAN=0.
      ZMEAN=0.
      ABR1=0.
      ABR2=0.
      ALPPA1=0.
      ALPPA2=0.
      ALPM=0.
      ALPBH=0.
      ACM=0.
      FRACTT=0.
      DO1010I=1,N
      FRACTT=FRACTT+FRAC(I)
1010  CONTINUE
      DO1020I=1,N
      FRAC(I)=FRAC(I)/FRACTT
1020  CONTINUE
      DO 10 I=1,N
      CALL SRLICA(Z(I),A(I),1.,X0(I),AL,XI)
      PFR=FRAC(I)*X0(I)
      TIV0=TIV0+PFR
      AMEAN=AMEAN+FRAC(I)/A(I)
      ZMEAN=ZMEAN+FRAC(I)*Z(I)/A(I)
      ALF=AL-FF(Z(I))
      CON=ALF/AL
      ABR1=ABR1+CON*(1.333333+0.1111111/ALF)*PFR
      ABR2=ABR2+CON*0.5*PFR
      ALPPA1=ALPPA1+CON*(0.66666667+1./(36.*ALF))*PFR
C     ABR1(I)=CON*(1.33333+0.1111111/ALF)*PFR
C     ABR2(I)=CON*0.5*PFR
C     ALPPA1(I)=CON*(0.6666667+1./(36.*ALF))*PFR
 10   CONTINUE
      CUTB2=CTCON*ROH*ZMEAN
      BGAM=0.5*ALOG((1.+CUTB2)/CUTB2)
      XX0=1./TIV0
C     BGAM=0.5*ALOG((1.+CUTB2)/(CUTBT2+CUTB2))
C     DO 2010I=1,N
      ABR1=XX0*ABR1
      ABR2=XX0*ABR2
      ALPPA1=XX0*ALPPA1
      ALPPA2=ABR1/12.
      ABR1=ABR1*BGAM
 2010  CONTINUE
      ALPM=XX0*CONM0*ZMEAN/CUTM
      ALPBH=ALPM
      ACM=ALPM*CUTM/3.
      AMEAN=1./AMEAN
      ZMEAN=ZMEAN*AMEAN
      DO20I=1,N
20    X0(I)=1./X0(I)
      RETURN
      END
