C   14/03/84 403221753  MEMBER NAME  ANATAG   (S)           FORTRAN
C
C SPECIAL  VERSION OF ANATAG WRITTEN BY A.J.FINCH
C
C     SUBROUTINE ANAOLD(IER)
C
#include "cwktag.for"
C
       CALL ANAL79(IER)
C
       RETURN
       END
