C   07/06/96 606071909  MEMBER NAME  SMOPS    (S4)          FORTG1
      SUBROUTINE SMOPS(YI,Y,N)
      REAL YI(120),Y(120),A(500)
      INTEGER NR/0/
C
      NR=NR+1
      DO 10 I=1,N
   10 Y(I)=YI(I)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMPTEQ(Y,N)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,5)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,1)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,2)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,3)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
C     CALL SMOPER(Y,N,4)
C     IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,5)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,7)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,7)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMOPER(Y,N,6)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL LSQSPL(Y,N,A,3+(N-1)/2,CHDF)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
C     CALL SMOPER(Y,N,6)
C     IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
      CALL SMEQTP(Y,N)
      IF(NR.EQ.50) CALL HISTPR(Y,N,0.0,1.0)
C
C
  100 RETURN
      END
