C   10/04/84            MEMBER NAME  FORWRD   (JADEGS)      FORTRAN
      SUBROUTINE FORWRD
      IMPLICIT INTEGER*2 (H)
C
C DRAW TAGGING APPARATUS IN SIDE VIEWS. RUN NR IS CHECKED FOR VERSION
C
#include "cgraph.for"
#include "cgeo2.for"
#include "cgeo3.for"
#include "cdata.for"
      COMMON /CHEADR/ HEAD(108)
      DIMENSION ZSC(2)
      EQUIVALENCE (ZSC(1),ZMINBL)
C
      IF(HEAD(18).LT.6000) GO TO 1
      IF(HEAD(18).LT.13000) GO TO 641
C 1983 CAPS, SIDE VIEWS IN ZXD,ZYD VIEWS
      CALL FW83
      GO TO 1000
641   CALL FWNEW
C 1981-2 CAPS, SIDE VIEWS IN ZXD,ZYD VIEWS
      GO TO 1000
    1 CONTINUE
C 1979-80 CAPS, SIDE VIEWS IN ZXD,ZYD VIEWS
      K = 1
      IF(LASTVW.EQ.11) K = 2
C      DO 1602  I = 1,4
C      IF(K.EQ.1) CALL FWCHM2(I,CHZ(2,I),CHX(2,I),CHZ(3,I),CHX(3,I),
C     $ CHZ(1,I),CHX(1,I))
C      IF(K.EQ.2) CALL FWCHM1(I,CHZ(1,I),CHY(1,I),CHZ(2,I),CHY(2,I))
C1602  CONTINUE
      DO 1603  I = 1,2
      CALL FWCAP1(ZSC(I),0.,I,K)
C     J = 2*I-1
C     CALL FWSCN1(ZMISC(I),0.,J)
C     J = J + 1
C     CALL FWSCN1(ZPLSC(I),0.,J)
1603  CONTINUE
C
1000  CONTINUE
      RETURN
      END
