C   16/02/79 107080122  MEMBER NAME  CDATA    (SOURCE)      FORTRAN
C
      COMMON /BCS/ IDATA(24000)
      DIMENSION ADATA(24000)
      INTEGER *2 HDATA(48000)
      EQUIVALENCE (IDATA(1),ADATA(1)), (HDATA(1),IDATA(1))
      DATA LDATA/24000/
C
