C   07/06/96 606071902  MEMBER NAME  PMEAN    (S4)          FORTG1
      SUBROUTINE PMEAN(NA)
      COMMON/BCS/IW(1)
      REAL Q(10)
      IF(NA.EQ.0) GOTO 10
      CALL BLOC(IND,'MEA*',NA,&100)
      GOTO 30
   10 CALL BPOS('MEA*')
   20 CALL BNXT(IND,&100)
   30 NNA=IW(IND-2)
      KAMAX=IW(IND)/50+1
      IP=0
      DO 40 K=1,KAMAX
      KA=K-1
      CALL QMEAN(NNA,KA,Q)
      IF(Q(1).EQ.0.0) GOTO 40
      IF(IP.EQ.1) GOTO 35
      WRITE(6,101) NNA
      IP=1
   35 WRITE(6,102) KA,Q
   40 CONTINUE
      IF(NA.EQ.0) GOTO 20
  100 RETURN
  101 FORMAT('0-------------'/' UMEAN',I8,' KA ENTRIES',5X,'MEAN',
     1   7X,'TRMEAN',7X,'MEDIAN',5X,'SIGMA',5X,'-LEFT',4X,'-RIGHT',
     2   5X,'OUT',4X,'X - RANGE')
  102 FORMAT(12X,I5,F8.0,3G13.5,3G10.3,F4.0,2G10.3)
      END
