C   12/03/84 406221856  MEMBER NAME  ACOL     (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      SUBROUTINE ACOL(M,P,THETA)
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C THIS ROUTINE CALCULATES THE ANGLE BETWEEN A CLUSTER IN - Z TAGGER
C AND ONE IN + Z TAGGER
C
C M - INPUT - POINTER TO CLUSTER IN - Z PART OF ATAGG2
C P - INPUT - POINTER TO CLUSTER IN + Z PART OF ATAGG2
C
C THETA - OUTPUT - ANGLE BETWEEN THEM
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      IMPLICIT INTEGER * 2 (H)
      INTEGER P
#include "ctaggo.for"
C
C
C------------------- C O D E -------------------------------------------
C
C
C                                   CALCULATE POINTERS
C
      MIB = (M - 1) * HWPCL
      PIB = (P - 1) * HWPCL
C
C                                   FETCH DIRECTION COSINES
C
      AMDX = ATAGG2(MIB + 11)
      AMDY = ATAGG2(MIB + 12)
      AMDZ = ATAGG2(MIB + 13)
      APDX = ATAGG2(PIB + 11)
      APDY = ATAGG2(PIB + 12)
      APDZ = ATAGG2(PIB + 13)
C
C                                   CALCULATE THETA
C
      THETA = ACOS( AMDX * APDX  +  AMDY * APDY  +  AMDZ * APDZ )
      RETURN
      END
