C   12/03/84 406222025  MEMBER NAME  TGDCOS   (S)           FORTRAN
C
C
C
C
C  SUBROUTINE TO CALCULATE DIRECTON COSINES GIVEN X,Y,Z
C
C X,Y,Z - INPUT
C DX,DY,DZ - OUTPUT
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE TGDCOS(X,Y,Z,DX,DY,DZ)
C
       R = SQRT(X**2 + Y**2 + Z**2)
       DX = X / R
       DY = Y / R
       DZ = Z / R
       RETURN
       END
