C   17/02/81            MEMBER NAME  PRCYCP   (PATRECSR)    FORTRAN
      SUBROUTINE PRCYCP
C
C     SETUP POINTER ARRAY FOR ALL CELLS: P.STEFFEN(78/11/15)
C
      IMPLICIT INTEGER*2 (H)
      COMMON /CDATA/ NWORD,HJCA(120),IPJCA4
      COMMON /CCYCP/ HPTSEC(98)
      COMMON /CLBPGM/ LBPGM(30)
C
C     SET PROGRAM LABEL
      LBPGM(1) = LBPGM(1) + 1
C     ADDRESS OF POINTERS TO CELLS (-1)
      IPJCA2 = IPJCA4 * 2
C
C     COPY CELL POINTERS + CALC. LENGTH
      IP0 = IPJCA2 + 98
      DO 100 ISEG=1,96
        ISEGO = ISEG + IPJCA2
        HPTSEC(ISEG) = HJCA(ISEGO) + IP0
 100  CONTINUE
      HPTSEC(97) = HJCA(ISEGO+1) + IP0
      HPTSEC(98) = 0
      RETURN
      END
