C   07/06/96 606071850  MEMBER NAME  IBLN     (S4)          FORTG1
      FUNCTION IBLN(NAME)
C     BOS SUBPROGRAM =0.3=
C   18/10/82            MEMBER NAME  ACS      (S)           FORTRAN
      COMMON/ACS/
     1   ICOND,NLAST,NDUMP,NSPL,NAMAX,NAMAX1,NLIST,NPRIM,NFRS,NLST,
     2   NEXT,NCI,NFRE,IN,KPOS,LIND,ILOW,LFDI,LFDK,NCPL,
     3   NHISTH(11),
     4        NCOL,NZT,IBFI,NLAST1,ISLST,IMLST,INAMV,IOLST,IPLST,
     5   NER(10),
     6   NRECL,NERRL,NRIN,NROUT,NS,NEXTI,NEXTA,NEXTB,ISAVB,NSAVB,
     7   NHISTL(11),
     8        MARKWR,NOUT(3),IASW,NPRE,IDUMMY(1),NEOTP,NDUMP1
      COMMON/BCS/IW(1)
      IW(INAMV)=NAME
      LFDI=MOD(IABS(NAME),NPRIM)+NAMAX1
   10 K=LFDI
      LFDI=IW(K+IPLST)
      IF(IW(LFDI+INAMV).NE.IW(INAMV)) GOTO 10
      IF(LFDI.NE.0) GOTO 90
      IF(NCI.GE.NAMAX) CALL BDMPA(1)
      NCI=NCI+1
      LFDI=NCI
      IW(INAMV+LFDI)=NAME
      IW(K+IPLST)=LFDI
   90 IBLN=LFDI
  100 RETURN
      END
