C   19/03/79 C9032101   MEMBER NAME  HPRS     (JADEMUS1)    FORTRAN
C   12/03/79 C9031301   MEMBER NAME  HPRS     (S)           FORTRAN
C   05/03/79 C9030501   MEMBER NAME  HPRINT   (S)           FORTRAN
      SUBROUTINE HPRS(NAME,NUMBER)
C PRINTS BOS BANK NAME,NUMBER IN I*2 FORMAT.
      IMPLICIT INTEGER*2 (H)
      COMMON /BCS/IDATA(1)
      DIMENSION HDATA(1)
      EQUIVALENCE (HDATA(1),IDATA(1))
      CALL CLOC(INDEX,NAME,NUMBER)
      IF(INDEX.LE.0)GO TO 99
      WRITE(6,100)
 100  FORMAT('0 HALF-WORD',8X,'NAME',10X,'NR',9X,'PTR',10X,'NW',
     * 8X,'INDX')
      NWORDS=IDATA(INDEX)
      WRITE(6,101)NAME,NUMBER,IDATA(INDEX-1),NWORDS,INDEX
 101  FORMAT(A23,4I12)
      IF(NWORDS.LE.0)GO TO 99
      IP2=2*INDEX
      NWORD2=2*NWORDS
      I1=1
 1    CONTINUE
      I2=MIN0(I1+19,NWORD2)
      I3=MOD(I2,1000)
      WRITE(6,102)I1,I3,(HDATA(IP2+I),I=I1,I2)
 102  FORMAT(I6,' -',I3,20I6)
      I1=I1+20
      IF(I2.LT.NWORD2)GO TO 1
 99   CONTINUE
      RETURN
      END
