C   26/03/80 003281033  MEMBER NAME  OC4TRC   (JADEGS)      FORTRAN
      SUBROUTINE OC4TRC
C
C     PRINTOUT OF RUN + EVENT # FOR FATAL ERROR OCCURRENCE
C     L.H. O'NEILL 26.03.80
C
      IMPLICIT INTEGER*2 (H)
C
#include "cheadr.for"
      LOGICAL*1 LBREAD
      COMMON /CADMIN/ IEVTP,NRREAD,NRWRIT,NRERR,LBREAD(4),IFLG
      EQUIVALENCE (HHEADR(18),HRUN) , (HHEADR(19),HEV)
C
  100 FORMAT(' *** ERROR TRAP ***')
      WRITE(6,100)
      WRITE(6,100)
      WRITE(6,100)
      PRINT 2001, NRREAD,HRUN,HEV
 2001 FORMAT(' FATAL ERROR AT',I6,' TH EVENT. RUN, EVNT. NOS. = ',2I6)
      WRITE(6,100)
      WRITE(6,100)
      WRITE(6,100)
      CALL ERRTRA
      CALL ABEND
      STOP
      END
