C   21/11/78 C9012301   MEMBER NAME  ZBOS06   (S)           FORTRAN
      SUBROUTINE BSCOM
C     -----------------------------------------------------------------600000200
C     6.  DELETING BANKS AND GARGAGE COLLECTION
C
C
C     6.1  SINGLE BANKS
C
C
C               -- --
C     CALL BDLS(NA,NR)
C
C
C        WHERE NA = NAME
C              NR = NUMBER OF BANK TO BE DELETED
C
C     IF THE DELETED BANK IS THE LAST IN STORAGE, ITS SPACE IS
C     IMMEDIATELY FREE FOR NEW BANKS, OTHERWISE BGAR HAS TO BE CALLED
C
C
C     6.2  SETS OF BANKS
C
C     CALL BDLM                   CALL BDLG
C
C     ALL BANKS OF THE CURRENT LIST OF NAMES ARE DELETED. IN BDLG
C     IN ADDITION A GARBAGE COLLECTION IS DONE.
C     A DELETED BANK IS NO LONGER ACCESSIBLE BY A CALL BLOC. IF THE
C     DELETED BANKS ARE THE LAST BANKS IN STORAGE, THEIR SPACE
C     IS IMMEDIATELY FREE FOR NEW BANKS ALSO FOR BDLM. OTHERWISE
C     THERE HAS TO BE AN EXTRA CALL OF BGAR.
C
C
C     6.3  GARBAGE COLLECTION
C
C     IN A GARBAGE COLLECTION THE ACTIVE (NOT DELETED) BANKS ARE
C     SHIFTED IN STORAGE, IF THERE ARE BANKS DELETED.
C
C
C
C     CALL BGAR(IGA)
C               ---
C
C        IGA = 0 NO GARBAGE COLLECTION DONE (IF NO BANKS WERE DELETED)
C        IGA = 1 GARBAGE COLLECTION DONE
C
C     WARNING. BECAUSE IN A GARBAGE COLLECTION, SOME BANKS (ALL BANKS
C     BEHIND DELETED BANKS) ARE SHIFTED, THE INDICES OF THE BANKS
C     CHANGE. AUTOMATIC GARBAGE COLLECTIONS ARE DONE IN THE INPUT-
C     OUTPUT ROUTINES (SEE 9.)
C
C
C     6.4   CALL OF THE PREVIOUS VERSION
C
C                   --
C     CALL BGAC(IGA,NW)
C               ---
C
C        WHERE NW = NR.OF WORDS OF A NEW BANK
C     NO GARBAGE COLLECTION IS DONE, IF THERE IS SPACE ENOUGH
C     FOR AN ADDITIONAL BANK WITH NW WORDS
C
C
      RETURN
      END
