C   07/06/96 606071823  MEMBER NAME  BLNA     (S4)          FORTG1
      SUBROUTINE BLNA
      COMMON/BCS/IW(1)
#include "acs.for"
      WRITE(6,101) NCI
      IF(NCI.EQ.0) GOTO 100
      WRITE(6,102) (IW(INAMV+I),I=1,NCI)
  100 RETURN
  101 FORMAT('0ORDERED LIST OF ALL',I4,' NAMES USED')
  102 FORMAT(20X,10A8)
      END
