C   29/08/78 C8082901   MEMBER NAME  SETSCV   (LGSOURCE)    FORTRAN
      SUBROUTINE SETSCV(E)
C
C     S.YAMADA    29-08-78  21:30
C
C---- NORMALIZED INTEGRAL SHOWER CURVE IS MADE FOR E-MEV ELECTRON.
C
      COMMON /CLEPTB/ ESPRFL(100)
      DIMENSION EB(22),EPFMST(100,22)
      DATA JRD/0/
C
      IF(JRD) 1,1,10
C
C---- READ THE DISK DATA AND MAKE THE MAIN TABLE.
    1   DO 2 K=1,22
        READ(11,END=4) LNG,EB(K),(EPFMST(KK,K),KK=1,100)
    2   CONTINUE
      GO TO 4
    3 WRITE(6,600) K
  600 FORMAT(' **** DATA ENDS BEFORE K=22  AT K=',I4)
    4 JRD = 1
C
C---- SEARCH THE ENERGY INTERVAL.
   10   DO 11 K=1,22
        IF(E.LT.EB(K)) GO TO 12
   11   CONTINUE
C
C---- OVER THE MAX ENERGY. FIXED TO THE MAX ENERGY BIN.
      K = 22
      GO TO 20
C
C---- TOO LOW ENERGY IS ALSO FIXED TO THE MIN.ENERGY BIN.
   12 IF(K.EQ.1) GO TO 20
C---- INTERPOLATION
      D = (E-EB(K-1))/(EB(K)-EB(K-1))
        DO 13 KK=1,100
        ESPRFL(KK) = EPFMST(KK,K-1)+D*(EPFMST(KK,K)-EPFMST(KK,K-1))
   13   CONTINUE
      RETURN
C
C---- USE OF THE END VALUES.
   20   DO 21 KK=1,100
   21   ESPRFL(KK) = EPFMST(KK,K)
C
      RETURN
      END
