C   24/06/79 C9062401   MEMBER NAME  KALBNK   (JADEGS)      FORTRAN
      SUBROUTINE KALBNK(IUNIT,LENG,IAOUT)
      IMPLICIT INTEGER*2 (H)
      DIMENSION IAOUT(LENG)
      WRITE(IUNIT) LENG,IAOUT
      RETURN
      END
