C   07/06/96 606071828  MEMBER NAME  BPRINT   (S4)          FORTG1
      SUBROUTINE BPRINT(N1,N2,N3)
#include "acs.for"
      COMMON/BCS/IW(1)
#include "ccs.for"
C     TEST PROGRAM
      LOGICAL CURR/.FALSE./
      WRITE(6,101) N1,N2
      IF(CURR) GOTO 10
      CURR=.TRUE.
      WRITE(6,102)
   10 CALL UWP(ICOND,1,80)
      CALL UWU(IW,1,N3)
  100 RETURN
  101 FORMAT('0BPRINT',2I10)
  102 FORMAT('0PRINTOUT OF COMMON/ACS/'/
     112X,' ICOND,NLAST,NDUMP,NSPL,NAMAX,NAMAX1,NLIST,NPRIM,NFRS,NLST,'/
     212X,' NEXT,NCI,NFRE,IN,KPOS,LIND,ILOW,LFDI,LFDK,NCPL,'/
     312X,' NHISTH(11),                              '/
     412X,'      NCOL,NZT,IBFI,NLAST1,ISLST,IMLST,INAMV,IOLST,IPLST,'/
     512X,' NER(10),                                 '/
     612X,' NRECL,NERRL,NRIN,NROUT,NS,NEXTI,NEXTA,NEXTB,ISAVB,NSAVB,'/
     712X,' NHISTL(11),                              '/
     812X,'      MARKWR,NOUT(3),IASW,NPRE,IDUMMY(2),NDUMP1 '/)
      END
