C   07/06/96 606071838  MEMBER NAME  CCHL     (S4)          FORTG1
      SUBROUTINE CCHL(NW,IER)
C     BOS SUBPROGRAM =1.20=
#include "acs.for"
      COMMON/BCS/IW(1)
      CALL BCHM(LIND,NW,IER)
      GOTO  90
C
      ENTRY CMVE(NW,IER)
      CALL BCHM(NW,0,IER)
      LIND=NW
C
   90 IF(IER.EQ.2) GOTO 100
      IER=0
  100 RETURN
      END
