C   16/02/81 104100757  MEMBER NAME  MURES1   (JADEMUS)     FORTRAN
C   11/02/81 102112050  MEMBER NAME  MURES1P  (S)           FORTRAN
C   26/03/80 102112028  MEMBER NAME  MURES1   (S)           FORTRAN
C LAST CHANGE 07.30 10/04/81 HUGH MCCANN  - JADEMUS UPDATE.
C  LAST CHANGE 15.05  19/02/81  HUGH MCCANN.
      SUBROUTINE MURES1(I0,I1,I2,I3,I4,I5,I6,I7)
C
C  THIS ROUTINE CONTROLS THE PRINTING OF THE MUON ANALYSIS
C  PHILOSOPHY1 RESULTS BANKS.IF ANY OF I0,I1 ETC IS
C  SET TO 1 , THE CORRESPONDING MUR1 BANK IS PRINTED OUT.
C  ******* N.B. I1 NON-ZERO CAUSES MUR1 BANKS 1 & 2 TO BE PRINTED.
C     AT PRESENT , ROUTINES EXIST ONLY FOR THE OUTPUT OF
C  BANKS 0,1 AND 2 . IT IS INTENDED TO ADD THE
C  NECESSARY ROUTINES FOR THE OTHERS AS THE NEED ARISES.)
C
      IMPLICIT INTEGER*2 (H)
#include "cmubcs.for"
      COMMON /CMUIEV/IEV,NEV,IRD,KRUN,KREC,
     *ISECS,IMINS,IHOURS,IDAY,IMONTH,IYEAR
C PICK UP HEADER POINTER.
      IPHEAD=IDATA(IBLN('HEAD'))
C PICK UP RUN NUMBER ,RECORD NUMBER ETC
      ISECS = HDATA(2*IPHEAD+3)
      IMINS = HDATA(2*IPHEAD+4)
      IHOURS= HDATA(2*IPHEAD+5)
      IDAY  = HDATA(2*IPHEAD+6)
      IMONTH= HDATA(2*IPHEAD+7)
      IYEAR = HDATA(2*IPHEAD+8)
      KRUN  = HDATA(2*IPHEAD+10)
      KREC  = HDATA(2*IPHEAD+11)
C
C  WRITE EVENT HEADER.
C
      WRITE(6,1000)KRUN,KREC,IEV,IHOURS,IMINS,
     *ISECS,IDAY,IMONTH,IYEAR
 1000 FORMAT('0**********',2X,'RUN',I6,2X,'RECORD',I6,
     *2X,'EVENT (FILE)',I6,2X,'TIME =',I3,':',I2,':',I2,
     *2X,'DATE =',I3,':',I2,':',I4)
C
C LOOK THROUGH ARGUMENTS AND PRINT OUT REQUESTED BANKS.
C
      IF(I0.EQ.1)GO TO 10
  100 CONTINUE
      IF(I1.EQ.1)GO TO 11
  110 CONTINUE
      IF(I2.EQ.1)GO TO 12
  120 CONTINUE
      IF(I3.EQ.1)GO TO 13
  130 CONTINUE
      IF(I4.EQ.1)GO TO 14
  140 CONTINUE
      IF(I5.EQ.1)GO TO 15
  150 CONTINUE
      IF(I6.EQ.1)GO TO 16
  160 CONTINUE
      IF(I7.EQ.1)GO TO 17
  170 CONTINUE
      GO TO 200
C
C
   10 CONTINUE
C
C---------OUTPUT BANK 0 .
      CALL MUPR10(IHNUM,IWNUM)
      GO TO 100
   11 CONTINUE
C
C--------OUTPUT BANKS 1 & 2 . FIRST , WRITE HEADER.
      WRITE(6,1101)
 1101 FORMAT('0HIT NO.  CHAMBER/HIT')
      WRITE(6,1201)
 1201 FORMAT('+',20X,'  QTRAN  QLONG QZ QY QX  ?Z ?Y ?X  FOUR?')
      WRITE(6,1102)
 1102 FORMAT(' -------  -----------')
      WRITE(6,1202)
 1202 FORMAT('+',20X,'  -----  ----- -- -- --  -- -- --  ----')
      N1=IHNUM
      N2=IWNUM
      CALL MUPR11(N1,N2)
      GO TO 110
   12 CONTINUE
      GO TO 120
   13 CONTINUE
      GO TO 130
   14 CONTINUE
      GO TO 140
   15 CONTINUE
      GO TO 150
   16 CONTINUE
      GO TO 160
   17 CONTINUE
      GO TO 170
  200 CONTINUE
      RETURN
      END
