C   13/03/84 406221947  MEMBER NAME  FITAG    (S)           FORTRAN
C   11/03/84 403110517  MEMBER NAME  FI       (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C FIND THE VALUE OF FI (PHI ?) OF ADC WITH SOFTWARE ADDRESS I
C    TAN FI = Y/X
C
      FUNCTION FITAG(I)
C
C NEW VERSION 13/3/84
C A.J.FINCH
C
C RENAMED TO FITAG 20/3/84
C A.J.FINCH
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      DATA PIBY4 / 0.785398163 /
      DATA PIBY8 / 0.392699081 /
      ISAVE = I
C
C
      IF ( (I .GE.  1) .AND. (I .LE.  6) ) J = I + 2
      IF ( (I .GE.  7) .AND. (I .LE.  8) ) J = I - 6
      IF ( (I .GE.  9) .AND. (I .LE. 14) ) J = I + 2 -  8
      IF ( (I .GE. 15) .AND. (I .LE. 16) ) J = I - 6 -  8
      IF ( (I .GE. 17) .AND. (I .LE. 22) ) J = I + 2 - 16
      IF ( (I .GE. 23) .AND. (I .LE. 24) ) J = I - 6 - 16
      IF ( (I .GE. 25) .AND. (I .LE. 26) ) J = I + 6 - 24
      IF ( (I .GE. 27) .AND. (I .LE. 32) ) J = I - 2 - 24
      IF ( (I .GE. 33) .AND. (I .LE. 34) ) J = I + 6 -  8 - 24
      IF ( (I .GE. 35) .AND. (I .LE. 40) ) J = I - 2 -  8 - 24
      IF ( (I .GE. 41) .AND. (I .LE. 42) ) J = I + 6 - 16 - 24
      IF ( (I .GE. 43) .AND. (I .LE. 48) ) J = I - 2 - 16 - 24
C

      FITAG = (J * PIBY4) - PIBY8
      I = ISAVE
      RETURN
      END
