C   28/03/97 703282256  MEMBER NAME  JEOSUM4  (JADE56.S)    FORTRAN
C   03/03/89 903031529  MEMBER NAME  GEANTCOM (S)        M  FORTRAN
*
*   Modifications of JADE MC, version SF56, for use of GEANT in tagger
*                                                (acc. to C. Howarth)
*

MCJADE:   LFLAG(8) is set .TRUE. for the usage of GEANT in tagger. Note
=======   that LFLAG(7) invokes GEANT for the lead glass (D. Pitzl).
          Present version of MCJADE does not support this.

          IF(LFLAG(8)) CALL GEANTI

MCTAGM:   LFLAG(8) steers the inner acceptance:  19.4 mrad with Geant,
=======   32 mrad without. MCTAGE is not called, after CALL TGEANT the
          subroutine is left. The preceeding call to MCTAGC is of no
          consequence, XSH and YSH, which are calculated, are used as
          input to MCTAGE and thus dummy with GEANT. Note that XSH, YSH
          are calculated using the radiation length, which for a long
          time was wrong for the MarkIII tagger  (22.39 mm instead of
          25.3 mm).

STHEAD:   Word 15 (overflow word) is set to 1 if LFLAG(8)=.TRUE.
=======


It is possible to use MCJADEGE and MCTAGMGE, with and without GEANT,
by including the member GEANTDUM (holds subr. GEANTI and TGEANT).
Member #LINKMCG on F11OLS.JADE56.S

C   03/03/89 903031529  MEMBER NAME  JOBINFO  (S)        M  FORTRAN
***********************************************************************
   INFORMATION ON JOBS ON JADE56.S
***********************************************************************

#CERTST1:    GENERATE DATA FOR NPECER DETERMINATION, SF6 VERSION
   USES @CERTST1                             NTRY=100, N=1.76
#CERTST2:    GENERATE DATA FOR NPECER DETERMINATION, SF5 VERSION
   USES @CERTST3                             NTRY=100, N=1.6725,1.76
#CERTST3:    GENERATE DATA FOR NPECER DETERMINATION, SF5 VERSION
   USES @CERTST3                             NTRY=20, N=1.6725,1.76
#CERTST4:    GENERATE DATA FOR NPECER DETERMINATION, SF6 VERSION
   USES @CERTST1                            NTRY=100, N=1.805
#CERTST5:    GENERATE DATA FOR NPECER DETERMINATION, SF5 VERSION
   USES @CERTST3, CORRECTED                  NTRY=20, N=1.6725
   LATER UPDATED FOR GEP USES (FILES CERTST5.NR1...
   USES @CERTST4, WITH GEP PLOTS


#CERFIT1-D:  FIT PE/X0 DATA, SF6(N=1,76)
#CERSF51-5:  FIT PE/X0 DATA, SF5(N=1,76)   FROM #CERTST3
    #CERSF55 IS THE GEP VERSION
#CERSF56  :  FIT PE/X0 DATA, SF5(N=1,6725), FROM #CERTST5

#CERFJTA:  FIT PE/X0 DATA, SF6(N=1,805)

#FNPECER:  GRAPHICAL DISPLAY OF NPECER.
 USES @FNPECER AND VERSION FNPECER, WITH EXTRA ARGUMENT FOR PASSING A1-2


#CERSF6E:    FITTING SF6 DATA WITH 2-PARAMETER
#CERSF6G:    FITTING SF6 DATA WITH 3-PARAMETER

#UNIGAM:    CREATE 4V-DATASET OF MONOCHROMATIC PHOTONS
JBUNIGAM:   ANALYSE TRACKED UNIGAM EVENTS

C   23/05/87 705251722  MEMBER NAME  SUMCOR   (S)           FORTRAN

LGECORX: LGECOR, CORRECTED FOR SYSTEMATIC ERROR AT LOWEST ENERGIES

LGECORY: LGECORX, THICKER ABSORBER FOR 1984-1986

LGECORZ: LGECORY, BUT CALL ENLOSG INSTEAD OF ENGLOS

LGECORYT: LGECORY, BUT CALL THCORR IN ADDITION

LGECORZT: LGECORZ, BUT CALL THCORR IN ADDITION

LGECORWT: LGECORZT, BUT CALL LKCORR IN ADDITION

C   25/04/82 706031308  MEMBER NAME  SUMETPRF (S)           FORTRAN
C   25/04/82 706031308  MEMBER NAME  SUMUNIG  (S)           FORTRAN
C   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  -
C                 SUMMARY OF MONTE CARLO GENERATION                    I
C   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  -

            * * * * * * * * * * * * * * * * * * * * * * * * *
            *   REACTION  E+E-  --->  E+E- ETAPRIME(957)    *
            * * * * * * * * * * * * * * * * * * * * * * * * *

4-VECTOR INPUT
--------------
   LIM = 1       F11OLS.ETAPRIV4     19476    (ONLY PI+PI-GAM DECAY)
   LIM = 3       F11OLS.ETAPRIV5     20524    (ONLY PI+PI-GAM DECAY)
   LIM = 5       F11OLS.ETAPRIV6     20471    (ONLY PI+PI-GAM DECAY)
   LIM = 7       F11OLS.ETAPRIV4     19310    (ONLY PI+PI-GAM DECAY)
   LIM = 9       F11OLS.ETAPRIV5     19121    (ONLY PI+PI-GAM DECAY)
   LIM = 11      F11OLS.ETAPRIV4     19626    (ONLY PI+PI-GAM DECAY)

 (PSEUGG1.ETAPRIRF.B17P3)

TRACKING   JBMCJADT TWO CHARGED PARTICLES WITH
           COSLMC FROM 227,1180 AT LEAST 16 WIRES IN JET CHAMBER
           COSLMC /0.9820/,XMOLIM/.080/,XPTLIM/.050/
--------

ETAPRIV4 (LIM1)
--------
ETPRF.NR0           0 -   312 -->   169 EVENTS
ETPRF.S1          313 -  6500 -->  3204 EVENTS
ETPRF.S2         6501 - 13000 -->  3442 EVENTS
ETPRF.S3        13001 - 19476 -->  3425 EVENTS

 MERGE:                                   MSETPRF.SUM1  10240 EVENTS

ETAPRIV5 (LIM3)
--------
             0 - 17380-400 -->       EVENTS   ERROR IN FWDDET,COORD

 MERGE:                                   MSETPRF.SUM2  9151  EVENTS

ETAPRIV4 (LIM7)
--------
ETPRF.S1            0 -  6500 -->  3399 EVENTS
ETPRF.S2         6501 - 13000 -->  3407 EVENTS
ETPRF.S3        13001 - 19310 -->  3350 EVENTS

 MERGE:                                   MSETPRF.SUM3 10156 EVENTS


ETAPRIV5,6 (LIM9,5)
--------
             0 - 22160-180 -->       EVENTS   ERROR IN FWDDET,COORD

 MERGE:                                   MSETPRF.SUM4  11556 EVENTS


ETAPRIV4 (LIM11)
--------
ETPRF.S1            0 -  6500 -->  3330 EVENTS
ETPRF.S2         6501 - 13000 -->  3492 EVENTS
ETPRF.S3        13001 - 19626 -->  3551 EVENTS

 MERGE:                                   MSETPRF.SUM5 10373 EVENTS


ETAPRIV4 (LIM13)
--------
ETPRF.S1            0 -  6500 -->  3475 EVENTS
ETPRF.S2         6501 - 13000 -->  3418 EVENTS
ETPRF.S3        13001 - 19626 -->  3703 EVENTS

 MERGE:                                   MSETPRF.SUM6 10602 EVENTS

TG21,LGECORM,RDDATE81,STANDARD SELECTION
----------------------------------------
MSETPRF.SUM1      0 - 10240 -->  4839 EVENTS   MSETPRF.BSUM811
MSETPRF.SUM2      0 -  9151 -->  4256 EVENTS   MSETPRF.BSUM812
MSETPRF.SUM3      0 - 10156 -->  4674 EVENTS   MSETPRF.BSUM813
MSETPRF.SUM4      0 - 11556 -->  5381 EVENTS   MSETPRF.BSUM814
MSETPRF.SUM5      0 - 10373 -->  4860 EVENTS   MSETPRF.BSUM815
MSETPRF.SUM6      0 - 10596 -->  5006 EVENTS   MSETPRF.BSUM816


TG21,LGECORM,RDDATE82,STANDARD SELECTION
----------------------------------------
MSETPRF.SUM1      0 - 10240 -->  4839 EVENTS   MSETPRF.BSUM821
MSETPRF.SUM2      0 -  9151 -->  4256 EVENTS   MSETPRF.BSUM822
MSETPRF.SUM3      0 - 10156 -->  4674 EVENTS   MSETPRF.BSUM823
MSETPRF.SUM4      0 - 11556 -->  5381 EVENTS   MSETPRF.BSUM824
MSETPRF.SUM5      0 - 10373 -->  4860 EVENTS   MSETPRF.BSUM825
MSETPRF.SUM6      0 - 10596 -->  5006 EVENTS   MSETPRF.BSUM826

////////////////////////////////////////////////////////////////////////

4-VECTOR INPUT
--------------
   LIM = 1       F11OLS.ETAPRIV4     23509    (ONLY GAM-GAM DECAY)
   LIM = 3       F11OLS.ETAPRIV5     21978    (ONLY GAM-GAM DECAY)

 (PSEUGG1.ETAPRIRF.B17P3)


TRACKING (INCLUDE JBMCJADS STANDARD SETTING, DEMAND 2 PHOTONS WITH
--------     COSTHE < .870)

ETAPRIV5 (LIM3)
--------
ETPRFG.S1            0 -  6100 -->  3272 EVENTS
ETPRFG.S2         6101 - 12100 -->  3190 EVENTS
ETPRFG.S3        12101 - 18100 -->  3247 EVENTS
ETAPRIV5         18101 - 21978 -->  2081 EVENTS


ETAPRIV4 (LIM1)
--------
ETPRFG.S4            0 -  6000 -->  3174 EVENTS
ETPRFG.S5         6001 - 12000 -->  3192 EVENTS
ETPRFG.S6        12001 - 18000 -->  3238 EVENTS
ETAPRIV4         18001 - 23509 -->  2929 EVENTS

 MERGE S1-3,ETAPRIV5,S4-6,ETAPRIV4        MSETPRFG.SUM1  24629 EVENTS


TG02,ENGLOSM,STANDARD SELECTION (LIM 3)
-------------------------------

PI0RF.S1            0 -  3272 -->   1931 EVENTS
PI0RF.S2            0 -  3190 -->   1915 EVENTS
PI0RF.S3            0 -  3247 -->   1937 EVENTS
ETAPRIV5            0 -  2081 -->   1241 EVENTS
                                       BS1,BS2,BS3,BS4
TR02FS.ETPRF1    3846 EVENTS
TR02FS.ETPRF2    3178 EVENTS

TG02,ENGLOSM,STANDARD SELECTION (LIM 1)
-------------------------------

PI0RF.S4            0 -  3174 -->   1888 EVENTS
PI0RF.S5            0 -  3192 -->   1899 EVENTS
PI0RF.S6            0 -  3238 -->   1997 EVENTS
ETAPRIV4            0 -  2929 -->   1825 EVENTS
                                    B15-B30
TR02FS.ETPRF3    3787 EVENTS
TR02FS.ETPRF4    3822 EVENTS

 MERGE                                    MSETPRFG.BSUM1  14633 EVENTS

////////////////////////////////////////////////////////////////////////

4-VECTOR INPUT
--------------
   LIM = 1       F11OLS.ETAPRIV4      19123   (ONLY PI+PI-ETA(GG) DECAY)
   LIM = 3       F11OLS.ETAPRIV5      17928   (ONLY PI+PI-ETA(GG) DECAY)

 (PSEUGG1.ETAPRIRF.B17P3)


TRACKING   JBMCJADT TWO CHARGED PARTICLES WITH
           COSLMC FROM 227,1180 AT LEAST 16 WIRES IN JET CHAMBER
           COSLMC /0.9820/,XMOLIM/.040/,XPTLIM/.030/
           OR AT LEAST TWO PHOTONS WITH COSTHE < .87
--------

ETAPRIV4 (LIM1)  400 EV/3MIN
--------
ETPPGG.S1            0 -  9800 -->  5800 EVENTS  (1520 TRACKS)
ETPPGG.S2         9801 - 14600 -->  2907 EVENTS
PI0RF.BS4        14601 - 19123 -->  2666 EVENTS

ETAPRIV5 (LIM3)
--------
ETPPGG.S3            0 -  6000 -->  3704 EVENTS
ETPPGG.S4         6001 - 12000 -->  3615 EVENTS
ETPPGG.S5        12001 - 17928 -->  3593 EVENTS

    MERGE ETPPGG.S1,S2,PI0RF.BS4,ETPPGG.S3-5
                                 MSETPPGG.SUM3   22473  EVENTS


TG22, PTOT>.03,RMIN<40,ZMIN<200,NMBDMX 5,NTRMAX 15,STANDARD PHOTONS
   STANDARD ENGLOS WAS USED, BY MISTAKE

ETPPGG.S1            0 -  5800 -->  927  EVENTS
ETPPGG.S2            0 -  2907 -->  426  EVENTS
PI0RF.BS4            0 -  2666 -->  426  EVENTS
                                 ON PI0RF.BS3,BS2

ETPPGG.S3            0 -  3704 -->  574  EVENTS
ETPPGG.S4            0 -  3615 -->  527  EVENTS
ETPPGG.S5            0 -  3593 -->  576  EVENTS
                                 ON ETPPGG.BS1-3
  MERGE PI0RF.BS3,BS2,ETPPGG.BS1-3      MSETPPGG.B22SUM4   3456 EVENTS

TR22FS.B22SUM4A      1779 EVENTS
TR22FS.B22SUM4B      1677 EVENTS


TG22, PTOT>.03,RMIN<40,ZMIN<200,NMBDMX 5,NTRMAX 15,STANDARD PHOTONS
   LGECORM AND TLOOP24 WERE USED

MSETPPGG.SUM3          0 - 22285 --> 3497  EVENTS, MSETPPGG.B22SUM5

TR22FS.B22SUM5A      2000 EVENTS
TR22FS.B22SUM5B      1497 EVENTS


########################################################################


4-5 1987:  ETAPRIME --> PI+PI- ETA, ETA --> GG

4-VECTOR (#PSEU40,41):   PSEUGG1.ETAPRIRF.B18P62
(18.62 GEV IS MEAN BEAM ENERGY FOR 1982-86)

ETAPRIV4.NR1:   9382
ETAPRIV4.NR2:  11384
ETAPRIV4.NR3:  10924
ETAPRIV4.NR4:  10924
ETAPRIV4.NR5:  10923
ETAPRIV4.NR6:  11436
ETAPRIV4.NR7:  11436
ETAPRIV4.NR8:  11436
ETAPRIV4.NR9:  11436
ETAPRIV4.NR10: 11436

TRACKING WITH SF5/SF6 MC, IVER56 = 1
************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETA86.SUMNR2
NR1:   4801 -  9382  --->   4582 EVENTS   ETA86.SUMNR3
NR2:      0 -  5600  --->   5600 EVENTS   ETA86.SUMNR4
NR2:   5601 -  9382  --->   5773 EVENTS   ETA86.SUMNR5
NR3:      0 -  5400  --->   5290 EVENTS   ETA86.SUMNR67
NR3:   5401 - 10720  --->   5227 EVENTS   ETA86.SUMNR8
NR4:      0 -  5400  --->   5267 EVENTS   ETA86.SUMNR9A,9B,9C
NR4:   5401 - 10798  --->   5297 EVENTS   ETA86.SUMNR1

SUM NR2-1               ETAPRI86.SUM1TO4   41836    EVENTS

NR5:      0 -  5600  --->   5600 EVENTS   ETA86.SUMNR1
NR5:   5601 - 10923  --->   5323 EVENTS   ETA86.SUMNR2
NR6:      0 -  5600  --->   5600 EVENTS   ETA86.SUMNR3
NR6:   5601 - 11429  --->   5817 EVENTS   ETA86.SUMNR4
NR7:      0 -  5600  --->   5600 EVENTS   ETA86.SUMNR5
NR7:   5601 - 11351  --->   5735 EVENTS   ETA86.SUMNR67
NR8:      0 -  5600  --->   5597 EVENTS   ETA86.SUMNR8
NR8:   5601 - 11436  --->   5836 EVENTS   ETA86.SUMNR9A,B,C

SUM NR1-9               ETAPRI86.SUM5TO8    45108   EVENTS

NR9:      0 -  5600  --->   5600 EVENTS   ETAPRI86.SUMNR2
NR9:   5601 - 10923  --->   5323 EVENTS   ETAPIR86.SUMNR3
NR10:     0 -  5600  --->   5600 EVENTS   ETAPRI86.SUMNR4
NR10:  5601 - 11405  --->   5786 EVENTS   ETAPRI86.SUMNR5

SUM NR1-9               ETAPRI86.SUM9TO10   22309   EVENTS



TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.SUM1TO4       41836 -->  4347 EVENTS, ETAP2286.ENGLOSX.BSUM1T9
ETAPRI86.SUM5TO8       45108 -->  4802 EVENTS, ETAP2286.ENGLOSX.CSUM1T9
ETAPRI86.SUM9TO10      42309 -->       EVENTS, ETAP2286.ENGLOSX.DSUM2T5

FAST FILES:   TR22FS.ENGLOSX.MCNR2T5, MCNR6T1
FAST FILES:   TR22FS.ENGLOSX.MCANR2T5, MCANR6T1
FAST FILES:   TR22FS.ENGLOSX.MCBNR2T5

                               ENGLOSM WITH LGECORX
                               ********************
                                                               (32 M)
ETAPRI86.SUM1TO4       41836 -->  4442 EVENTS, ETAP2286.ENGLOSMX.BSUM1T9

FAST FILES:   TR22FS.ENGLOSMX.BSUM1T4A,B    2200,2242



TG12, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.SUM1TO4       41836 -->  5396 EVENTS, ETAP1286.ENGLOSX.BSUM1T9
ETAPRI86.SUM5TO8       45108 -->  5780 EVENTS, ETAP1286.ENGLOSX.CSUM1T9

FAST FILES:   TR12FS.ENGLOSX.MCNR1T5, MCNR6T9
FAST FILES:   TR12FS.ENGLOSX.MCANR1T5, MCANR6T9

                               ENGLOSM WITH LGECORX
                               ********************

ETAPRI86.SUM1TO4       41836 -->  5405 EVENTS, ETAP1286.ENGLOSMX.BSUM1T9

FAST FILES:   TR12FS.ENGLOSMX.BSUM1T4A,B    2700,2705


TRACKING WITH MEIER/MAGNUSSEN TRLGSH/6
**************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETA86.SUMNR1
NR1:   4801 -  9382  --->   4582 EVENTS   ETA86.SUMNR2
NR2:      0 -  5700  --->   5700 EVENTS   ETA86.SUMNR3
NR2:   5701 - 11400  --->   5700 EVENTS   ETA86.SUMNR4
NR3:      0 -  5400  --->   5400 EVENTS   ETA86.SUMNR5
NR3:   5401 - 10860  --->   5460 EVENTS   ETA86.SUMNR67
NR4:      0 -  5400  --->   5400 EVENTS   ETA86.SUMNR8
NR4:   5401 - 10830  --->   5430 EVENTS   ETA86.SUMNR9A,B,C

SUM NR1-9               ETAPMM86.SUM1TO4    42472   EVENTS

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPMM86.SUM1TO4       42472 -->  4396 EVENTS, ETAPMM86.NR1T4,NR5T9

FAST FILES:   TR22FS.ENGLOSX.MMNR1T4, MMNR5T9




TRACKING WITH OLD TOKYO SF5 PROGRAM
***********************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETAPRI86.TUMNR1
NR1:   4801 -  9382  --->   4582 EVENTS   ETAPRI86.TUMNR2
NR2:      0 -  5600  --->   5600 EVENTS   ETAPRI86.TUMNR3
NR2:   6701 - 11406  --->   5806 EVENTS   ETAPRI86.TUMNR4
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI86.TUMNR5
NR3:   5601 - 10923  --->   5321 EVENTS   ETAPRI86.TUMNR6
NR4:      0 -  5600  --->   5599 EVENTS   ETAPRI86.TUMNR7
NR4:   5601 - 10923  --->   5328 EVENTS   ETAPRI86.TUMNR8

TUM NR1-8               ETAPRI86.TUM1TO4     42636  EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.TUM1TO4       42636 -->  4762 EVENTS, ETAP2286.TNR1T8

FAST FILES:   TR22FS.ENGLOSX.TNR1T3, TNR4T6,TNR7T8



TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, BUT WITH STANDARD NPECER
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETAPRI86.TUMNR1
NR1:   4801 -  9382  --->   4582 EVENTS   ETAPRI86.TUMNR2
NR2:      0 -  5600  --->   5200 EVENTS   ETAPRI86.TUMNR3
NR2:   6701 - 11368  --->   5754 EVENTS   ETAPRI86.TUMNR4
NR3:      0 -  5600  --->   5588 EVENTS   ETAPRI86.TUMNR5
NR3:   5601 - 10923  --->   5242 EVENTS   ETAPRI86.TUMNR6
NR4:      0 -  5600  --->   5199 EVENTS   ETAPRI86.TUMNR7
NR4:   5601 - 10923  --->   5323 EVENTS   ETAPRI86.TUMNR8

TUM NR1-8               ETAPRI86.NPEC1TO4     41688  EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.NPEC1TO4       41688 -->  4395 EVENTS, ETAP2286.NPEC1TO8

FAST FILES:   TR22FS.ENGLOSX.NPEC1T3, NPEC4T6,NPEC7T8




TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, STANDARD NPECER, 57 VERSION
(REPLACING THICK AL COIL WITH THIN LG COIL, LIKE OLD SETUP)
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETAPRI86.SUM1
NR1:   4801 -  9382  --->   4582 EVENTS   ETAPRI86.SUM2
NR2:      0 -  5600  --->   5600 EVENTS   ETAPRI86.SUM3
NR2:   5601 - 11368  --->   5720 EVENTS   ETAPRI86.SUM4
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI86.SUM5
NR3:   5601 - 10923  --->   5323 EVENTS   ETAPRI86.SUM6
NR4:      0 -  5600  --->   5600 EVENTS   ETAPRI86.SUM7
NR4:   5601 - 10923  --->   5323 EVENTS   ETAPRI86.SUM8

 SUM1-8               ETAPRI86.NP571TO4     42548  EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
**********************************************************

ETAPRI86.NP571TO4      42548  -->  4257 EVENTS, ETAP2286.NP571TO8

FAST FILES:   TR22FS.ENGLOSX.NP571T3, NP574T6,NP577T8

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
**********************************************************
OLD VERSION, NOT WITH LG-COIL BUT WITH STANDARD AL-COIL
ETAPRI86.NP571TO4      33073  -->  3572 EVENTS, ETAP2286.NP583TO8

FAST FILES:   TR22FS.ENGLOSX.NP583T5, NP585T8


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
REMAKE WITH LGCLWAR: UPDATE ALGN WITH BBLEAK, REDO LGCL,RESO
**********************************************************

ETAP2286.NP571TO8       4257  -->  4257 EVENTS, ETAP2286.NP611TO8

FAST FILES:   TR22FS.ENGLOSX.NP611T3, NP614T6, NP617T8





TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LGMC56TJ VERSION
(VARYING COIL THICKNESS ACC. TO SUBR. TJOCK)
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETAPRI.SUM1
NR1:   4801 -  9382  --->   4582 EVENTS   ETAPRI.SUM2
NR2:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM3
NR2:   5601 - 11368  --->   5696 EVENTS   ETAPRI.SUM4
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM5
NR3:   5601 - 10923  --->   5322 EVENTS   ETAPRI.SUM6
NR4:      0 -  5600  --->   4752 EVENTS   ETAPRI.SUM7
NR4:   5601 - 10923  --->   5323 EVENTS   ETAPRI.SUM8
NR6:      0 -  4400  --->   4400 EVENTS   ETAPRI.SUM11

 SUM1-11              ETAPRI86.NPTJ1TO4    46075   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.NPTJ1TO4      42548  -->  4995 EVENTS, ETAP2286.NPTJ1TO8

FAST FILES:   TR22FS.ENGLOSX.NPTJ1T3, NPTJ4T6,NPTJ7T11

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLWAR 1.05,0.95 AND BBLEAK CORR.
**********************************************************

ETAPRI86.NPTJ1TO4      42548  -->  4995 EVENTS,   NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.P5M51T3, P5M54T6,P5M57T11

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.10,1.00
**********************************************************

ETAPRI86.NPTJ1TO4      42548  -->  4995 EVENTS,   NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.P10M1T3, P10M4T6,P10M7T11





TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LGMC56TJ, LSCCTLNL
(VARYING COIL THICKNESS ACC. TO SUBR. TJOCK, BUT NO LOSS WHATSOEVER
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  4800  --->   4800 EVENTS   ETAPRI.SUM1
NR1:   4801 -  9382  --->   4582 EVENTS   ETAPRI.SUM2
NR2:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM3
NR2:   5601 - 11368  --->   5627 EVENTS   ETAPRI.SUM4
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM5
NR3:   5601 - 10923  --->   5323 EVENTS   ETAPRI.SUM6

 SUM1-6               ETAPRI86.NPTJ01T3    31532   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.NPTJ01T3       31532 -->  3474 EVENTS, ETAP2286.NPTJ01T6

FAST FILES:   TR22FS.ENGLOSX.NPTJ01T3, NPTJ04T6




TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LGMC56TJ, LSCCTL40
(VARYING COIL THICKNESS ACC. TO SUBR. TJOCK, LOSS CONST SET TO 40.
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM7
NR1:   5601 - 11368  --->   5836 EVENTS   ETAPRI.SUM8
NR2:      0 -  4800  --->   4800 EVENTS   ETAPRI.SUM9
NR2:   4801 -  9382  --->   4582 EVENTS   ETAPRI.SUM10
NR3:      0 -  5600  --->   5598 EVENTS   ETAPRI.SUM11
NR3:   5601 - 10923  --->   5322 EVENTS   ETAPRI.SUM5

 SUM7-5               ETAPRI86.NTJ401T3    31738   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.NTJ401T3       31738 -->  3490 EVENTS, ETAP2286.NTJ401T6

FAST FILES:   TR22FS.ENGLOSX.NTJ401T3, NTJ404T6


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.05,1.00
**********************************************************

ETAPRI86.NTJ401T3       31738 -->  3490 EVENTS, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40P513, TJ40P546

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.10,1.00
**********************************************************

ETAPRI86.NTJ401T3       31738 -->  3490 EVENTS, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40PA13, TJ40PA46

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.07,1.04
**********************************************************

ETAPRI86.NTJ401T3       31738 -->  3490 EVENTS, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40.P7P413, TJ40.P7P446

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.07,0.96
**********************************************************

ETAPRI86.NTJ401T3       31738 -->  3490 EVENTS, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40.P7M413, TJ40.P7M446



TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LGMC56EO, LSCCTLNL
(STANDARD AL COIL, NO LOSS, STANDARD ELGOBS LOSSES IMPOSED
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM1
NR1:   5601 - 11368  --->   5821 EVENTS   ETAPRI.SUM4
NR2:      0 -  4800  --->   5600 EVENTS   ETAPRI.SUM3
NR2:   4801 -  9382  --->   3782 EVENTS   ETAPRI.SUM2
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM5
NR3:   5601 - 10923  --->   5323 EVENTS   ETAPRI.SUM6

 SUM1-6               ETAPRI86.NPEO1TO3    31726   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.NPEO1TO3       31726 -->  3230 EVENTS, ETAP2286.NPEO1T6

FAST FILES:   TR22FS.ENGLOSX.NPEO1T3, NPEO4T6


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.05,1.00
**********************************************************

ETAPRI86.NPTJ1TO4      31726  -->  3230 EVENTS,   NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40P513, TJ40P546

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
SCALE WITH LGCLVAR 1.10,1.00
**********************************************************

ETAPRI86.NPTJ1TO4      31726  -->  3230 EVENTS,   NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40PA13, TJ40PA46




TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTL20,LGMC56TJ
(STANDARD AL COIL WITH TJOCK, 51.7-->20
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR1:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM1
NR1:   5601 - 11368  --->   5640 EVENTS   ETAPRI.SUM4
NR2:      0 -  4800  --->   4800 EVENTS   ETAPRI.SUM3
NR2:   4801 -  9382  --->   4582 EVENTS   ETAPRI.SUM2
NR3:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM5
NR3:   5601 - 10923  --->   5323 EVENTS   ETAPRI.SUM6
NR4:        -  4792  --->   4792 EVENTS   ETAPRI.SUM7

 SUM1-6               ETAPRI86.TJ201TO4    36337   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.TJ201TO4       36337 -->  3914 EVENTS, ETAP2286.TJ201T7

FAST FILES:   TR22FS.ENGLOSX.TJ201T3, TJ204T6, TJ207




UPDATE OF CONS: +7% SF5, +4% SF6

TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTL40,LGMC56TJ
(STANDARD AL COIL WITH TJOCK, 51.7-->40
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR5:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM1
NR5:   5601 - 11368  --->   5323 EVENTS   ETAPRI.SUM4
NR6:      0 -  4800  --->   5200 EVENTS   ETAPRI.SUM2
NR6:   4801 -  9382  --->   5726 EVENTS   ETAPRI.SUM3
NR7:      0 -  5600  --->   5600 EVENTS   ETAPRI.SUM5
NR7:   5601 - 10923  --->   5634 EVENTS   ETAPRI.SUM6
NR8:        -  4792  --->   5600 EVENTS   ETAPRI.SUM7
NR8:        -  4792  --->   5723 EVENTS   ETAPRI.SUM8

 SUM1-8               ETAPRI86.TJ401TO8    44406   EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORX,TLOOP24
**********************************************************

ETAPRI86.TJ401TO8       44406 -->  4880 EVENTS, ETAP2286.TJ40.P7P41TOE
                      (SUMMARY TAPE CONTAINS ALSO P7P4 FILES FROM
                       TRACKING OF 1-4)

FAST FILES:   TR22FS.ENGLOSX.TJ40.P7P479, TJ40.P7P4AC, TJ40.P7P4DE


TG22, NEUTRAL SEL. (.03,40.,5),ENLOSG WITH LGECORZ,TLOOP24
SCALE WITH LGCLVAR 1.00,1.00
**********************************************************

ETAPRI86.TJ401TO8       44406 -->  4880 EVENTS, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJ40EG.P7P479, TJ40EG.P7P4AC, TJ40EG.P7P4DE



TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTL40,LGMC56TJ
(STANDARD AL COIL WITH TJOCK, 51.7-->40
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR11:     0 -  5600  --->   5595 EVENTS   ETAPRI.SUM1
NR11   5601 - 11200  --->   3258 EVENTS   ETAPRI.SUM3
NR11  11201 - 16800  --->   5600 EVENTS   ETAPRI.SUM4
NR11  16801 - 23800  --->   5600 EVENTS   ETAPRI.SUM5
NR12      0 -  3200  --->   3200 EVENTS   ETAPRI.SUM2
NR12   3201 -  7932  --->   4732 EVENTS   ETAPRI.SUM6
NR12   9601 - 15200  --->   5348 EVENTS   ETAPRI.SUM7
NR12  15200 -        --->   5600 EVENTS   ETAPRI.SUM8
NR11,12              --->   4000 EVENTS   ETAPRI.SUM9

 SUM1-9           ETAPRI86.TJ40PP1.SUM11T12    42933  EVENTS

NR9                  --->   4800 EVENTS   ETAPRI.SUM2
NR9                  --->   5353 EVENTS   ETAPRI.SUM6
NR10                 --->   5139 EVENTS   ETAPRI.SUM7
NR10                 --->   4800 EVENTS   ETAPRI.SUM9
NR12                 --->   2423 EVENTS   ETAPRI.SUM10
NR13                 --->   5600 EVENTS   ETAPRI.SUM12
NR13                 --->   5637 EVENTS   ETAPRI.SUM13
NR13                 --->   5600 EVENTS   ETAPRI.SUM14
NR13                 --->   5600 EVENTS   ETAPRI.SUM15
NR14                 --->   5600 EVENTS   ETAPRI.SUM16
NR14                 --->   5662 EVENTS   ETAPRI.SUM17
NR14                 --->   1600 EVENTS   ETAPRI86.NR29-32

 SUM2,6,7,9,10,12-17,86..   ETAPRI86.TJ40PP1.SUM9TO14    57814  EVENTS


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORY,TLOOP24
**********************************************************

ETAPRI86.TJ40PP1.SUM11T12  42933 --> 4897 EVENTS, ETAP2286.TJ40.P7P4FM

FAST FILES:   TR22FS.ENGLOSX.TJ40PP1.NR13,NR46,NR79

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORZT,TLOOP24
RESCALE WITH 1.0,1.0
**********************************************************

USE BSUM1,2,5,3,4,10,11,12 --> BSUM6,7,8, SUM1,8,3,4,5
  THESE ARE ALL TG22 DATA FROM TJ40 TRACKING
  BSUM6-8,SUM1,8  KEPT ON ETAP2286.ENGLOSX.TJ40PPZT.SUM1TOM

FAST FILES:   TR22FS.ENGLOSX.TJ40PPZT.NR13,NR46,NR79,NRAC,NRDE
              TR22FS.ENGLOSX.TJ40PPZT.NRFH,NRIK,NRLM

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24
RESCALE WITH 1.0,1.0
**********************************************************

USE BSUM1,2,5,3,4,10,11,12 --> BSUM6,7,8, SUM1,8,3,4,5
  THESE ARE ALL TG22 DATA FROM TJ40 TRACKING
  BSUM6-8,SUM1,8  KEPT ON ETAP2286.ENGLOSX.TJ40PPWT.SUM1TOM

FAST FILES:   TR22FS.ENGLOSX.TJ40PPWT.NR13,NR46,NR79,NRAC,NRDE
              TR22FS.ENGLOSX.TJ40PPWT.NRFH,NRIK,NRLM



TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
**********************************************************

TJ40PP1.SUM9TO14  57814 -->   6365 EVENTS, ETAP2286.TJ40PPWT.SUMNTOU

FAST FILES:   TR22FS.ENGLOSX.TJ40PPWT.NRNO,NRPQ,NRRS,NRTU




TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTLEL,LGMC56TJ
(STANDARD AL COIL WITH TJOCKI, AND 51.7 --> ELODIF
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR11                 --->   5600 EVENTS   ETAPRI.SUM1
NR11                 --->   5260 EVENTS   ETAPRI.SUM2
NR11                 --->   5200 EVENTS   ETAPRI.SUM3
NR11                 --->   5600 EVENTS   ETAPRI.SUM4
NR11,13              --->   5505 EVENTS   ETAPRI.SUM5
NR13                 --->   4800 EVENTS   ETAPRI.SUM10
NR13                 --->   5600 EVENTS   ETAPRI.SUM11
NR12                 --->   5600 EVENTS   ETAPRI.SUM6
NR12                 --->   5688 EVENTS   ETAPRI.SUM7
NR12                 --->   7185 EVENTS   ETAPRI.SUM8

 SUM1-8 (NOT 10,11)    ETAPRI86.TJEL.SUM1TO8   45638   EVENTS



TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
**********************************************************

TJEL.SUM1TO8, (10,11)   56038 --> 6072 EVENTS, ETAP2286.TJELPPWT.SUM1TO4

FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.NR13,NR46,NR79   (NOT SUM8 PART)


TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
SCALE 0.95,0.95
**********************************************************

5333 EVENTS FROM SUM1-7, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.M5M5NR13,M5M5NR46,M5M5NR79

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
SCALE 0.97,1.00
**********************************************************

5333 EVENTS FROM SUM1-7, NOT KEPT

FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.M3M0NR13,M3M0NR46,M3M0NR79

FASTWRBB  (CORRECTED L7 WITH BBLEAK)
FAST FILES:   TR22FS.ENGLOSX.TJELBBWT.M3M0NR13,M3M0NR46,M3M0NR79





TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTLEL,LGMC56TJ
(STANDARD AL COIL WITH TJOCKI, AND 51.7 --> ELODIFENELMX
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR12                 --->   5200 EVENTS   ETAPRI.SUM1
NR12                 --->   5332 EVENTS   ETAPRI.SUM2
NR12                 --->   5600 EVENTS   ETAPRI.SUM3
NR11                 --->   7200 EVENTS   ETAPRI.SUM4
NR11                 --->   5300 EVENTS   ETAPRI.SUM5
NR11                 --->   5600 EVENTS   ETAPRI.SUM6
NR11                 --->   5600 EVENTS   ETAPRI.SUM7
NR13                 --->   7292 EVENTS   ETAPRI.SUM8
NR13                 --->   4800 EVENTS   ETAPRI.SUM10
NR13                 --->   4400 EVENTS   ETAPRI.SUM11

 SUM1-10               ETAPRI86.TJELMX.SUM1TO10  56324   EVENTS



TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
**********************************************************

TJEL.SUM1TO10       56324   --> 6683 EVENTS, ETAP2286.TJELMX.SUM1TO4

FASTWRBB
FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.MR13,MR46,MR79

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
SCALE WITH 1.10,1.10
**********************************************************

SOME LOST DUE TO OVERFLOW, OUTPUT NOT KEPT

FASTWRBB                            1832,1845,1860
FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.PAPAMR13,PAPAMR46,PAPAMR79

TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
SCALE WITH 1.13,1.07
**********************************************************

SOME LOST DUE TO OVERFLOW

FASTWRBB                            1832,1845,1859
FAST FILES:   TR22FS.ENGLOSX.TJELPPWT.PCP7MR13,PCP7MR46,PCP7MR79



TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTLEL,LGMC56TJ
(STANDARD AL COIL WITH TJOCKI, AND 51.7 --> ELODIF   ENELMX,MCIN56MX
****************************************************************
TRACKING WITHOUT CONDITIONS, ALL EVENTS
DATE IS 6/1986                      (EV.NR WITHOUT CONSTREC)

NR14                 --->  5600  EVENTS   ETAPRI.SUM1
NR14                 --->  5600  EVENTS   ETAPRI.SUM2
NR14                 --->  5600  EVENTS   ETAPRI.SUM3
NR14                 --->  7341  EVENTS   ETAPRI.SUM4
NR1                  --->  5600  EVENTS   ETAPRI.SUM5
NR1                  --->  5600  EVENTS   ETAPRI.SUM6
NR2                  --->  5600  EVENTS   ETAPRI.SUM7
NR2                  --->  5782  EVENTS   ETAPRI.SUM10,11
NR3                  --->  4800  EVENTS   ETAPRI.SUM9

 SUM1-9                ETAPRI86.TJELMXMX.SUM1TO9    51523  EVENTS



TG22, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
**********************************************************

SUM1TO9   51523 --> 5296 EVENTS, ETAP2286.ENGLOSX.TJELMXMX.SUM1TO3

FASTWRBB
FAST FILES:   TR22FS.ENGLOSX.TJELBBWT.PCP7MRAC,MRDF,MRGI


TG12, NEUTRAL SEL. (.03,40.,5),ENGLOS WITH LGECORWT,TLOOP24,RDALGNDB
**********************************************************

SUM1TO9   51523 --> 6745 EVENTS, ETAP1286.ENGLOSX.TJELMXMX.SUM1TO3

FASTWRBB
FAST FILES:   TR12FS.ENGLOSX.TJELPPWT.MRAB,MRCD,MREF,MRGI

************************************************************************
*                                                                      *
*          SUMMARY OF MONOCHROMATIC PHOTONS GENERATION                 *
*                                                                      *
************************************************************************

4-VECTOR DATA SETS, EACH 10000 EVENTS, PROGRAM #UNIGAM
              FROM D5 ON, 2000 EVENTS

E100 CORRESPONDS TO 100 MEV...
D1 CORRESPONDS TO Z = 40 MM, JITTER +- 20 MM, PHI ISOTROPIC TWOPI
D2 = 140 MM, D3 = 240 MM, D4 = 400 MM, D5 = 560 MM, D6 = 720 MM,
D7 = 880 MM, D8 = 1040 MM, D9 = 1200 MM, DA = 1360 MM, DB = 1520 MM,

UNIGAM4V.E100D1,D2,D3,D4,D5,D6,D7,D8,D9,DA,DB
UNIGAM4V.E200D1,E300D1,E400D1,E500D1,E600D1,E700D1,E800D1,E1000D1

TRACKING:
********

>>>>>>>>>>>>   SF5 (1982 DATE)

UNIGAM.E100D1.SF5       2000 EVENTS
UNIGAM.E200D1.SF5       1551 EVENTS
UNIGAM.E300D1.SF5       1104 EVENTS
UNIGAM.E400D1.SF5       1728 EVENTS
UNIGAM.E500D1.SF5       1393 EVENTS
UNIGAM.E600D1.SF5       1547 EVENTS
UNIGAM.E800D1.SF5       1321 EVENTS

UNIGAM.E100D2.SF5       2000 EVENTS
UNIGAM.E200D2.SF5       1565 EVENTS
UNIGAM.E300D2.SF5       1654 EVENTS
UNIGAM.E400D2.SF5       1561 EVENTS
UNIGAM.E500D2.SF5       1370 EVENTS
UNIGAM.E600D2.SF5       1344 EVENTS
UNIGAM.E800D2.SF5       1169 EVENTS

UNIGAM.E100D3.SF5       2000 EVENTS
UNIGAM.E200D3.SF5       1579 EVENTS
UNIGAM.E300D3.SF5       1657 EVENTS
UNIGAM.E400D3.SF5       1396 EVENTS
UNIGAM.E500D3.SF5       1353 EVENTS
UNIGAM.E600D3.SF5       1341 EVENTS
UNIGAM.E800D3.SF5       1012 EVENTS

>>>>>>>>>>       SF6 (1986 DATE), COS(2) = 0.86189  (SF5 VALUE)

UNIGAM.E100D1.SF6       2000 EVENTS
UNIGAM.E200D1.SF6       1436 EVENTS
UNIGAM.E300D1.SF6       1010 EVENTS
UNIGAM.E400D1.SF6       1569 EVENTS
UNIGAM.E500D1.SF6       1275 EVENTS
UNIGAM.E600D1.SF6       1411 EVENTS
UNIGAM.E800D1.SF6       1191 EVENTS

UNIGAM.E100D2.SF6       2000 EVENTS
UNIGAM.E200D2.SF6       1451 EVENTS
UNIGAM.E300D2.SF6       1548 EVENTS
UNIGAM.E400D2.SF6       1437 EVENTS
UNIGAM.E500D2.SF6       1258 EVENTS
UNIGAM.E600D2.SF6       1234 EVENTS
UNIGAM.E800D2.SF6       1055 EVENTS

UNIGAM.E100D3.SF6       2000 EVENTS
UNIGAM.E200D3.SF6       1480 EVENTS
UNIGAM.E300D3.SF6       1556 EVENTS
UNIGAM.E400D3.SF6       1304 EVENTS
UNIGAM.E500D3.SF6       1248 EVENTS
UNIGAM.E600D3.SF6       1226 EVENTS
UNIGAM.E800D3.SF6        920 EVENTS

>>  SF6 (1986 DATE), COS(2) = 1.724  (PRELIMINARY VALUE, FINAL IS 1.684)

UNIGAM.F100D1.SF6       2000 EVENTS
UNIGAM.F200D1.SF6       1428 EVENTS
UNIGAM.F400D1.SF6       1164 EVENTS
UNIGAM.F600D1.SF6       1055 EVENTS
UNIGAM.F800D1.SF6        926 EVENTS

UNIGAM.F100D2.SF6       2000 EVENTS
UNIGAM.F200D2.SF6       1443 EVENTS
UNIGAM.F400D2.SF6       1167 EVENTS
UNIGAM.F600D2.SF6       1062 EVENTS
UNIGAM.F800D2.SF6        933 EVENTS

UNIGAM.F100D3.SF6       2000 EVENTS
UNIGAM.F200D3.SF6       1464 EVENTS
UNIGAM.F400D3.SF6       1175 EVENTS
UNIGAM.F600D3.SF6       1065 EVENTS
UNIGAM.F800D3.SF6        930 EVENTS




NEW TRACKING
************
UPDATE OF CONS: +7% SF5, +4% SF6

TRACKING WITH NEW TOKYO SF5SF6 PROGRAM, NPECER8, LSCCTL40,LGMC56TJ
(STANDARD AL COIL WITH TJOCK, 51.7-->40)

UNIGAM4V.E100D1-B     22000 EVENTS      UNIGAM86.SUME100A,B
UNIGAM4V.E200D1-B     17871 EVENTS      UNIGAM86.SUME200A,B
UNIGAM4V.E300D1-B     12292 EVENTS      UNIGAM86.SUME300,A
UNIGAM4V.E400D1-B      9349 EVENTS      UNIGAM86.SUME400
UNIGAM4V.E500D1-B      6470 EVENTS      UNIGAM86.SUME500
UNIGAM4V.E600D1-B      6145 EVENTS      UNIGAM86.SUME600
UNIGAM4V.E700D1-B      5312 EVENTS      UNIGAM86.SUME700
UNIGAM4V.E800D1-B      4669 EVENTS      UNIGAM86.SUME800


