C   12/03/80 003121518  MEMBER NAME  TRAPER   (JADEGS)      FORTRAN
      SUBROUTINE TRAPER(INDEX)
      IMPLICIT INTEGER*2 (H)
      WRITE(6,1) INDEX
    1 FORMAT(' TRAPER CALLED WITH INDEX = ',I6)
      RETURN
      END
