C   23/08/85 511061940  MEMBER NAME  CMCTAG   (S)           FORTRAN
C
C   COMMON FOR NEW FORWARD TAGGER MC
C
      COMMON/CMCTAG/MARKMC,HGG(192),IHIT,INMARK,NCHANS,SIGMAS,CALIBS
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
