C   19/11/79 806150900  MEMBER NAME  COMPR    (S)           FORTRAN
      SUBROUTINE COMPR(NRUN)
#include "tfprm.for"
#include "tfadc.for"
      DIMENSION CNEW(546),COLD(546),IDIF(546)
      DATA IENTRY/0/
      CALL UCOPY(CORNOR,CNEW,378)
      IF(NRUN.LE.1659) CALL COMPR2(NRUN)
      IF(NRUN.LE.1659) RETURN
      CALL UCOPY(CADCA,CNEW(379),168)
      IF(IENTRY.EQ.0)  GOTO  10
C
      NDIF = 0
      DO   2   I=1,546
      IDIF(I) = 0
      IF(ABS(CNEW(I)-COLD(I)).LE..001)  GOTO  2
      NDIF = NDIF + 1
      IDIF(NDIF) = I
    2 CONTINUE
      IF(NDIF.LE.0)  GOTO  10
      PRINT 103,NRUN,NDIF
  103 FORMAT(1X,100('=')/' CONST CHANGE AT RUN ',I5,I10,' CHANGES'/)
      PRINT 100,((IDIF(I),COLD(IDIF(I)),CNEW(IDIF(I))),I=1,NDIF)
  100 FORMAT(1X, 5(I5,2F8.4,2X))
      PRINT 104
  104 FORMAT(1X,100('='))
C
   10 CALL UCOPY(CNEW,COLD,546)
      IENTRY = IENTRY + 1
      IF(IENTRY.NE.1) RETURN
      PRINT 101,NRUN
      PRINT 111
  111 FORMAT(/' VELSC')
      PRINT 102,VELSC
      PRINT 111
  112 FORMAT(/' CORNOR')
      PRINT 102,CORNOR
      PRINT 113
  113 FORMAT(/' COROVF')
      PRINT 102,COROVF
      PRINT 114
  114 FORMAT(/' TPARM ')
      PRINT 102,TPARM
      PRINT 115
  115 FORMAT(/' TCALM ')
      PRINT 109,TCALM
      PRINT 116
  116 FORMAT(/' TCALP ')
      PRINT 109,TCALP
      PRINT 117
  117 FORMAT(/' PEDLM ')
      PRINT 102,PEDLM
      PRINT 118
  118 FORMAT(/' PEDLP ')
      PRINT 102,PEDLP
      PRINT 119
  119 FORMAT(/' CADCA ')
      PRINT 109,CADCA
      PRINT 120
  120 FORMAT(/' CADCB ')
      PRINT 102,CADCB
  102 FORMAT(/(1X,10F10.3))
  109 FORMAT(/(1X,10F10.5))
  101 FORMAT(' PRINTOUT COMPR CALIBRATION CONSTANTS FOR RUN ',I5)
C
      RETURN
      END
