C   08/07/80 007081342  MEMBER NAME  PARCIR   (TPSOURCE)    FORTRAN
C
      SUBROUTINE PARCIR (IPATR,IND1,IND2)
C
C     M.NOZAKI   12-06-80  18:30   (COPIED FROM LCNOZ.PATR.FORT)
C     LAST MOD.
C
C         FINDS THE PATRENT CIRCLE
C
#include "cdata.for"
C
       IND2 = 0
       IND = IND1
       NLOOP = 0
 1001 CONTINUE
       CALL ADJCIR (IPATR,IND,INDP)
       IF(INDP.LE.0) RETURN
       NLOOP = NLOOP + 1
       IF(NLOOP.GT.10) GOTO 2000
       IND = INDP
       IND2 = INDP
      GOTO 1001
 2000 CONTINUE
      IPHD = IDATA(IBLN('HEAD'))
      NRUN = HDATA(IPHD*2+10)
      NREC = HDATA(IPHD*2+11)
      WRITE(6,6000) NRUN,NREC,IDATA(IND+1),IDATA(IND2+1),IPATR
 6000 FORMAT(' +++++ PARCIR  >10 PARENTS +++++',5X,
     &       'NRUN,NREC=',2I5,5X,'TRK#,PARENT#=',2I5,5X,
     &       'PATR POINTER=',I8)
      RETURN
C
      END
