C   14/08/80 008141209  MEMBER NAME  TOFBRA                 FORTRAN
      SUBROUTINE TOFBRA(NCN,LTRK,NFLG)
      INTEGER *2  HEADR(108)
      COMMON /CHEADR/ IHEADR(54)
      EQUIVALENCE (IHEADR(1),HEADR(1))
      NRUN = HEADR(18)
      IF(NRUN.LT.1660) CALL TOFCL2(NCN,LTRK,NFLG)
      IF(NRUN.GE.1660) CALL TOFCLC(NCN,LTRK,NFLG)
      RETURN
      END
