C   07/06/96 606071840  MEMBER NAME  CREAD    (S4)          FORTG1
      SUBROUTINE CREAD(IUN,IER)
C     BOS SUBPROGRAM =3.2=
      COMMON/BCS/IW(1)
      IER=0
   10 CALL BRDS(IUN,NBUFL,INIR)
      IF(INIR.EQ.0) GOTO 100
      CALL BFRD(IUN,IW(INIR),IW(INIR+1))
      IF(IW(INIR)) 20,30,10
   20 IER=IER+1
   30 IER=IER+1
  100 RETURN
      END
