C     MACRO FOR VERTEX-FIT ROUTINES ( AXIS AND STATISTICS )
      COMMON /CVTX2/ MODE,TAXIS(12),SVR,HVTXST(120)
C
C   NOTE (JEO 23.3.97)  THAT HVTXST HAS DIM. 140 ON F22KLE.VERTEX.S LIB
      DIMENSION IVTXST(1)
C
