C   08/10/80 010131213  MEMBER NAME  GGFAC5   (S)           FORTRAN
      SUBROUTINE GGFAC5
C---  COPY CALIBRATION CONSTANTS OF LEAD-GLASS INTO COMMON /CALICO/
C---  RUN 4511 TO RUN 4864
C
C     H.WRIEDT    13.09.79     19:00
C     LAST MODIFICATION    13.10.80   12:15
C
      COMMON /CFACT5/ FACT5(191)
      COMMON /CALICO/ FAKTOR(191)
C
        DO 1 I = 1,191
    1   FAKTOR(I) = FACT5(I)
      WRITE(6,600)
  600 FORMAT(/' *** FOURTH SET OF LEAD-GLASS CALIBRATION CONSTANTS',
     &        ' INCLUDED ***')
      RETURN
      END
      BLOCK DATA
C
      COMMON /CFACT5/ FACT5
C     THIS DATA APPLICABLE FROM RUN 4511 TO RUN 4864
C     THE GAIN ASSUMES ENERGY(MEV)=CHANNEL*5.0
      REAL*4 FACT5(191)/191*1.65/
      END
