C   07/04/82 311291534  MEMBER NAME  RNEXP0   (S)           FORTRAN
C
      FUNCTION RNEXP0(A)
C
C       GENERATES A RANDOM NUMBER WHICH DISTRIBUTES AS EXP(A*X)
C               A : A PARAMETER OF THE DISTRIBUTION
C               XMIN : THE MINIMUM VALUE OF THE RANDUM NUMBER
C               XMAX : THE MAXIMUM VALUE OF THE RANDUM NUMBER
C                              S. ODAKA    5-NOV-'79
C
      IF(A.GT.0.) A=-A
      RNEXP0=ALOG(1.-RN(DUM))/A
      RETURN
      END
