C   03/03/80 008141453  MEMBER NAME  TOFCL2                 FORTRAN
      SUBROUTINE TOFCL2(NCN,LTRK,NFLG)
      INTEGER *2 HADC,HTDC,HB
      REAL *8 DYC1,DYC2
      COMMON/TFPRM/ NRNC1,NRNC2,DYC1,DYC2,IFLC(42),CM(42),CP(42),
     -DTAU(42),WM(42),WP(42),SV(42),DM(42),DP(42),PEDLM(42),PEDLP(42)
      COMMON/CWORK/NR,RAW(5,42),NC,ICRT1(5,42),NTRK,ICRT2(50),TRK(5,50)
     - ,ITRC(50),NTC,ITRK(5,42),INFM(4),IRELT(14,50)
      COMMON/TFPED/ HADC(2,42),HTDC(2,42),HB(42)
C
      TRANS= SV(NCN)
      DTAU1= DTAU(NCN)
      Z1= TRK(1,LTRK)
      TAUP1= RAW(3,NCN)+Z1/TRANS
      TAUM1= RAW(2,NCN)-Z1/TRANS
      NFLG= -1
          IF(HTDC(1,NCN).GT.10.AND.HTDC(1,NCN).LT.2048) GO TO 320
            GO TO 360
C
 320        IF(HTDC(2,NCN).GT.10.AND.HTDC(2,NCN).LT.2048) GO TO 330
            GO TO 360
C
  330 IF(ABS(TAUM1-TAUP1).LE.3.*DTAU1) GO TO 350
  350 NFLG= 1
  360 RETURN
      END
