C   07/06/96 606071903  MEMBER NAME  PPEAK    (S4)          FORTG1
      SUBROUTINE PPEAK(NA)
      COMMON/BCS/IW(1)
      REAL RW(1)
      EQUIVALENCE (RW(1),IW(1))
      REAL Q(10,3)
      IF(NA.EQ.0) GOTO 10
      CALL BLOC(IND,'PEA*',NA,&100)
      GOTO 30
   10 CALL BPOS('PEA*')
   20 CALL BNXT(IND,&100)
   30 KAMAX=IW(IND+8)+1
      IF(KAMAX.EQ.0) GOTO 60
      NNA=IW(IND-2)
      IP=0
      DO 50 K=1,KAMAX
      KM=K-1
      CALL QPEAK(NNA,KM,Q)
      IF(Q(1,1).EQ.0.0) GOTO 50
      IF(IP.EQ.0) WRITE(6,101) NNA
      IP=1
      JJ=Q(2,1)+0.5
      WRITE(6,102) KM,((Q(I,J),I=1,10),J=1,JJ)
      IF(NA.EQ.0) GOTO 50
      NB=IW(IND+7)
      INDK=IND+10+KM*(NB+2)
      CALL HISTPR(RW(INDK+1),NB,RW(IND+5),RW(IND+6))
   50 CONTINUE
   60 IF(NA.EQ.0) GOTO 20
  100 RETURN
  101 FORMAT('0-------------'/' UPEAK',I8,7X,'KA',5X,'ENTR.',
     1   5X,'POSITION',5X,'SIGMA',6X,'LEFT',5X,'RIGHT',4X,
     2   'FRACTION  SIGNIF CONTENT    +-')
  102 FORMAT(13X,I10,F10.0,F5.0,G12.5,3G10.3,4F8.2/
     1   (23X,F10.0,F5.0,G12.5,3G10.3,4F8.2))
      END
