C   03/10/83 310032055  MEMBER NAME  HDDUMP   (S)           FORTRAN
      SUBROUTINE HDDUMP
C
C COPIED FROM F22FIN.MAIN.S  ON 3.10.83       J.OLSSON
C    MACRO CDATA INTRODUCED
C
       IMPLICIT INTEGER*2 (H)
#include "cdata.for"
C
       CALL BLOC(IHEAD,'HEAD',0,&1000)
       IHHEAD=IHEAD *2
       HEBEAM = HDATA(IHHEAD +29)
       NEXP=HDATA(IHHEAD+9)
       NRUN=HDATA(IHHEAD+10)
       NEVEN = HDATA(IHHEAD + 11)
        WRITE(6,600) HEBEAM,NEXP,NRUN,NEVEN
 600    FORMAT(1X,'  ENERGY ,EXP. ,RUN NO.,EVENT NO. ',4(I7,2X)
     1)
 1000   RETURN
        END
