C   07/09/79 C9090801   MEMBER NAME  KPRINT   (JADEGS)      FORTRAN
      SUBROUTINE KPRINT(NBANK,LIM0,NDMP,ITYPE)
      IMPLICIT INTEGER*2 (H)
C---
C---     DUMPS INDIVIDUAL BANKS FROM COMMON/CALIBR/.
C---
      COMMON/CALIBR/JPOINT(1)
      DIMENSION ICALIB(1)
      DIMENSION HCALIB(2)
      DIMENSION RCALIB(1)
      EQUIVALENCE(JPOINT(1),ICALIB(1))
      EQUIVALENCE(JPOINT(1),HCALIB(1))
      EQUIVALENCE(JPOINT(1),RCALIB(1))
C---
      WRITE(6,100) NBANK
  100 FORMAT('0    CALIBRATION BANK ',I4,/)
      IF(ITYPE.EQ.1) WRITE(6,201)
  201 FORMAT(' INTEGER*2',/)
      IF(ITYPE.EQ.2) WRITE(6,202)
  202 FORMAT(' INTEGER*4',/)
      IF(ITYPE.EQ.3) WRITE(6,203)
  203 FORMAT(' REAL*4',/)
      IPNTR=JPOINT(NBANK)
      INXT =JPOINT(NBANK+1)
      IF(ITYPE.EQ.1) IPNTR=IPNTR*2
      IF(ITYPE.EQ.1) INXT =INXT*2
      GO TO (1,2,3),ITYPE
    1 CONTINUE
      LINES=1+(NDMP-1)/20
      DO 11 LINE=1,LINES
      LIM1=20*(LINE-1)+1
      LIM2=20* LINE
      IWRT=LIM0+LIM1
      IF(LIM2.GT.NDMP) LIM2=NDMP
      IF((LIM2+LIM0+IPNTR).GT.INXT) LIM2=INXT-LIM0-IPNTR
      WRITE(6,101) IWRT,(HCALIB(IPNTR+LIM0+KLM),KLM=LIM1,LIM2)
  101 FORMAT(1X,I6,I12,19I6)
      IF(LIM2.GE.(INXT-LIM0-IPNTR)) GO TO 2000
   11 CONTINUE
      GO TO 2000
    2 CONTINUE
      LINES=1+(NDMP-1)/10
      DO 12 LINE=1,LINES
      LIM1=10*(LINE-1)+1
      LIM2=10* LINE
      IWRT=LIM0+LIM1
      IF(LIM2.GT.NDMP) LIM2=NDMP
      IF((LIM2+LIM0+IPNTR).GT.INXT) LIM2=INXT-LIM0-IPNTR
      WRITE(6,102) IWRT,(ICALIB(IPNTR+LIM0+KLM),KLM=LIM1,LIM2)
  102 FORMAT(1X,I6,10I12)
      IF(LIM2.GE.(INXT-LIM0-IPNTR)) GO TO 2000
   12 CONTINUE
      GO TO 2000
    3 CONTINUE
      LINES=1+(NDMP-1)/10
      DO 13 LINE=1,LINES
      LIM1=10*(LINE-1)+1
      LIM2=10* LINE
      IWRT=LIM0+LIM1
      IF(LIM2.GT.NDMP) LIM2=NDMP
      IF((LIM2+LIM0+IPNTR).GT.INXT) LIM2=INXT-LIM0-IPNTR
      WRITE(6,103) IWRT,(RCALIB(IPNTR+LIM0+KLM),KLM=LIM1,LIM2)
  103 FORMAT(1X,I6,10E12.4)
      IF(LIM2.GE.(INXT-LIM0-IPNTR)) GO TO 2000
   13 CONTINUE
 2000 CONTINUE
      RETURN
      END
