C   11/09/79 404162023  MEMBER NAME  MUMESS   (JADEMUS)     FORTRAN
C LAST CHANGE 10.30 11/09/79 JOHN ALLISON.
      SUBROUTINE MUMESS(NAME,INF,MESS)
C
      INTEGER*2 NAME(3)
      LOGICAL*1 MESS(1)
C
C PRINTS MU MESSAGES.
C
C PROVIDE SUBROUTINE NAME IN NAME.
C PROVIDE INFORMATION IN INTEGER*4 WORD INF.
C PROVIDE MESSAGE IN MESS TERMINATED BY '^'.
C
      COMMON /CMUPRN/MUPRIN
C
      LOGICAL*1 BAR/'^'/
C
C COUNT NUMBER OF CHARACTERS.
C
      IF(MUPRIN.LT.2)GO TO 99
C
      N=1
 1    CONTINUE
      IF(MESS(N).EQ.BAR)GO TO 2
      N=N+1
      IF(N.LE.200)GO TO 1
C
 2    CONTINUE
C
      N=N-1
C
      WRITE(6,100)NAME,INF,(MESS(I),I=1,N)
 100  FORMAT('0MU MESSAGE FROM ',3A2,4X,', INFORMATION --->',I10,',',
     *4X,70A1/(1X,132A1))
C
 99   CONTINUE
      RETURN
      END
