C   03/03/82 203031541  MEMBER NAME  MUDUMP   (JADEMUS)     FORTRAN
C   17/02/82 202171616  MEMBER NAME  ERMUDUMP (S)           FORTRAN
C   03/02/81 104100736  MEMBER NAME  MUDUMP   (JADEMUS)     FORTRAN
      SUBROUTINE MUDUMP(IER,IP)
      IMPLICIT INTEGER*2 (H)
C LAST CHANGE 15.45  03/03/82   HUGH MCCANN  - BUG REMOVED.
C      CHANGE 13.30  22/02/82   HUGH MCCANN  - FOR IMPROVED ERROR OUTPUT
C      CHANGE 07.30  10/04/81 HUGH MCCANN  - JADEMUS UPDATE.
C      CHANGE 14.40  12/02/81 HUGH MCCANN.
C   THIS ROUTINE DUMPS THE MUEV BANK, ALONG WITH OTHER INFO ON EVENT.
C
C----------START OF MACRO CMUBCS----------------------------------------
      COMMON /BCS/IDATA(1)
      DIMENSION HDATA(1),ADATA(1)
      EQUIVALENCE (HDATA(1),ADATA(1),IDATA(1))
C----------END OF MACRO CMUBCS------------------------------------------
C
C  WRITE HEADER.
      WRITE(6,10)IER,IP
   10 FORMAT('0 ERROR',I3,' AT WORD',I4,
     *'   DUMP OF RAW DATA BANK (MUEV) :')
C
C WRITE OUT MUEV BANK.
C
      IPMU=IDATA(IBLN('MUEV'))
      IF(IPMU.LE.0)GO TO 97
      IP2=2*IPMU
      IPLAST=2*IDATA(IPMU)
      DO 100 I=1,IPLAST,20
      J=I+19
      IF(J.GT.IPLAST)J=IPLAST
  100 WRITE(6,20)I,(HDATA(IP2+K),K=I,J)
   20 FORMAT('0 ',I4,':',20I6)
      RETURN
   97 CONTINUE
      WRITE(6,970)
  970 FORMAT('0 ******** MUEV BANK NOT FOUND ********')
      RETURN
      END
