C   16/06/79 005061141  MEMBER NAME  GNUREC   (JADEGS)      FORTRAN
C   24/11/78 C9032101   MEMBER NAME  GNUREC   (JADEGS)      FORTRAN
         SUBROUTINE GNUREC (NFTN,NEVNT,NUREC)
C---
C---     COUNTS NORMAL EVENTS AND TOTAL RECORDS ON A DATA SET.
C---     MODIFIED BY W.YEN TO HANDLE BOSM FORMAT
C---     IMPLEMENTED 19.06.1979 BY J.OLSSON
C---
      IMPLICIT INTEGER*2 (H)
#include "cdata.for"
      IPHEAD=IBLN('HEAD')
      NEVNT=0
      NUREC=0
    1 CALL BSLT
      CALL BDLG
      CALL BREAD(NFTN,&3,&2)
      NUREC=NUREC+1
      IF(IDATA(IPHEAD).LT.1) GO TO 1
      NEVNT=NEVNT+1
      GO TO 1
    2 CONTINUE
      REWIND NFTN
      CALL BDLS('+BUF',NFTN)
      RETURN
    3 CALL MESSAG(1)
      GO TO 1
      END
