C   14/08/84 408271209  MEMBER NAME  MUPR20   (PWMUS)       FORTRAN
C   26/02/80 004231736  MEMBER NAME  MUPR20   (JADEMUS)     FORTRAN
C   16/02/80 002180915  MEMBER NAME  MUPR20   (JADEMUS1)    FORTRAN
C
C   LAST CHANGE 14/08/84 P.WARMING : OUTPUT COMMENTED
C-----------------------------------------------------------------------
C
      SUBROUTINE MUPR20
C
C
C  THIS ROUTINE PRINTS WORDS 1 AND 2 OF MUR2/0
C
      IMPLICIT INTEGER*2 (H)
#include "cmubcs.for"
C
C  FIND MUR2/0
C
      CALL CLOC(INDEX,'MUR2',0)
      IF(INDEX.LE.0)GO TO 1
      NUMTRK=IDATA(INDEX+1)
      NUMWTR=IDATA(INDEX+2)
      WRITE(6,10)NUMTRK,NUMWTR
   10 FORMAT('0 MUR2/0    NO. OF I.D. TRACKS =',I3,
     *4X,'NO. OF 4-BYTE WORDS PER TRACK IN MUR2/1 =',I3)
      RETURN
    1 CONTINUE
C------MUR2/0 DOES NOT EXIST
      WRITE(6,2)
    2 FORMAT('0',20X,'***** MUR2/0 DOES NOT EXIST. *****')
      RETURN
      END
