C   05/04/79 C9040501   MEMBER NAME  DUMMOT   (JADEGS)      FORTRAN
      SUBROUTINE PATREC(INDEX)
      RETURN
      END
      SUBROUTINE PTJADE(INDEX)
      RETURN
      END
      SUBROUTINE LGANAL
      RETURN
      END
