C   10/04/84            MEMBER NAME  RECTAN   (JADEGS)      FORTRAN
      SUBROUTINE RECTAN(X0,Y0,X1,Y1,L)
C     DRAW RECTANGLE
      CALL MOVEA(X0,Y0)
      IF(L.GT.0) GO TO 101
      CALL DRAWA(X0,Y1)
      CALL DRAWA(X1,Y1)
      CALL DRAWA(X1,Y0)
      CALL DRAWA(X0,Y0)
      RETURN
101   CALL DASHA(X0,Y1,L)
      CALL DASHA(X1,Y1,L)
      CALL DASHA(X1,Y0,L)
      CALL DASHA(X0,Y0,L)
      RETURN
      END
