C   12/11/84 411121739  MEMBER NAME  TAGALL   (S)           FORTRAN
#include "acol.for"
#include "aftp83.for"
#include "anatag.for"
#include "calad.for"
#include "clsps.for"
#include "clusfn.for"
#include "comfil.for"
#include "ffityp.for"
#include "fhtos.for"
#include "fitag.for"
#include "frtype.for"
#include "fstoh.for"
#include "ggblck.for"
#include "listgn.for"
#include "pedfix.for"
#include "sort.for"
#include "sort1.for"
#include "sort2.for"
#include "srsum.for"
#include "tagan.for"
#include "tagchk.for"
#include "tagdat.for"
#include "tagint.for"
#include "tagmrk.for"
#include "tagset.for"
#include "tagsto.for"
#include "tgdcos.for"
