C   18/05/79            MEMBER NAME  DUMMY0   (JADEGS)      FORTRAN
C   10/04/79 C9041001   MEMBER NAME  DUMMY0   (JADESR)      FORTRAN
      SUBROUTINE DUMMY
      CALL VZERO
      RETURN
      ENTRY PATREC
      RETURN
      ENTRY LGANAL
      RETURN
      ENTRY MUANAC
      RETURN
      ENTRY MUANAF
      RETURN
      ENTRY MUANAL
      RETURN
      ENTRY MUANAJ
      RETURN
      END
