C   23/06/78 601062121  MEMBER NAME  AVABS5   (JADEMC2)     FORTRAN

      FUNCTION  AVABS(ALAMDA)
C---- S.YAMADA     14-11-77
C     LAST MODIFICATION  18-10-78  21:15
C     MEASURED ATTENUATION LENGTH OF THE JADE LG IS *2 BETTER.
C
C---- CALCULATE MEAN ABSORPTION LENGTH IN SF5 FOR WAVE LENGTH ALAMDA.
C     UNIT OF ALAMDA  IS NANOO-METER.
C     UNIT   OF AVABS IS CM.
C
      IF(ALAMDA.GE.450.) GO TO  3
      IF(ALAMDA-390.) 1,2,2
CCC 1 AVABS = 10.**(0.030303*ALAMDA-10.5155)
    1 AVABS = 10.**(0.030303*ALAMDA-10.2154)
      RETURN
CCC 2 AVABS = 10.**(0.013699*ALAMDA-4.027)
    2 AVABS = 10.**(0.013699*ALAMDA-3.726)
      RETURN
CCC 3 AVABS = 10.**(0.00284*ALAMDA+0.847)
    3 AVABS = 10.**(0.00284*ALAMDA+1.148)
      RETURN
      END
