C   14/10/82            MEMBER NAME  BSCOM11  (S)           FORTRAN77
      SUBROUTINE BSCOM
C     -----------------------------------------------------------------900000200
C     10.  BANKS ON DIRACT ACCESS DATA SETS
C
C     THE DIRECT ACCESS BOS ROUTINES ALLOW TO STORE BANKS ON A DIRECT
C     ACCESS DATA SET, CALLED DADS, AND, IN THE SAME JOB OR IN A LATER
C     JOB, TO GET THE BANKS BACK TO THE COMMON/BCS/ OR TO DELETE BANKS
C     ON THE DADS (SEE CH. 11.2). THE ROUTINES USE THE IBM-FORTRAN
C     DIRECT ACCESS FEATURES (E.G. DEFINE FILE), THEY WORK WITH
C     RECORDS OF FIXED LENGTH 1610 WORDS, HOWEVER THE BANKS MAY HAVE
C     ANY LENGTH BETWEEN 1 WORD AND 3200 WORDS.
C     THE DADS HAS TO BE INITIALIZED (SEE CH 11.1) BEFORE THE FIRST
C     BANK IS ADDED TO THE DADS.
C
C
C     11.1  INITILIZATION OF A DADS
C
C     A DADS IS INITIALIZED BY THE FOLLOWING STATEMENTS, USING THE
C     DD-CARD SHOWN.
C
C          DEFINE FILE IU(NREC,1610,U,IVAR)
C          CALL BINLDA(IU,NREC)
C
C     //FTIUF001 DD DSN=DSNAME,DISP=(NEW,CATLG),UNIT=FAST,
C     //   SPACE=(6440,(NREC))
C
C          WHERE    IU = (CONSTANT) FORTRAN=NR. OF THE DADS, EQUAL
C                        TO 17, 18 OR 19
C                 NREC = (CONSTANT) NR OF RECORDS, OF LENGTH 1610 WORDS
C                 IVAR = DUMMY VARIABLE
C               DSNAME = DSNAME OF THE DADS
C






















