C   13/02/81 102141841  MEMBER NAME  COMPR2   (S)           FORTRAN
      SUBROUTINE COMPR2(NRUN)
      IMPLICIT INTEGER*2 (H)
      COMMON/TFPRM/ NRNC1,NRNC2,DYC(4),IFLC(42),CM(42),CP(42),
     -DTAU(42),WM(42),WP(42),SV(42),DM(42),DP(42),PEDLM(42),PEDLP(42)
      DIMENSION CNEW(378),COLD(378),IDIF(378)
      DATA IENTRY/0/
C
      DO   1   N=1,378
      IDUM = 0
      IF(N.GT.84) IDUM = 42
      CNEW(N) = CM(N+IDUM)
    1 CONTINUE
C
      IF(IENTRY.EQ.0)  GOTO  10
      NDIF = 0
      DO   2   I=1,378
      IDIF(I) = 0
      IF(ABS(CNEW(I)-COLD(I)).LE..001)  GOTO  2
      NDIF = NDIF + 1
      IDIF(NDIF) = I
    2 CONTINUE
      IF(NDIF.LE.0)  GOTO  10
      PRINT 103,NRUN,NDIF
  103 FORMAT(1X,100('=')/' CONST CHANGE AT RUN ',I5,I10,' CHANGES'/)
      PRINT 100,((IDIF(I),COLD(IDIF(I)),CNEW(IDIF(I))),I=1,NDIF)
  100 FORMAT(1X, 5(I5,2F7.1,2X))
      PRINT 104
  104 FORMAT(1X,100('='))
C
   10 CALL UCOPY(CNEW,COLD,378)
      IENTRY = IENTRY + 1
      IF(IENTRY.NE.1) RETURN
      PRINT 101,NRUN
      PRINT 102,CM
      PRINT 102,CP
      PRINT 102,WM
      PRINT 102,WP
      PRINT 102,SV
      PRINT 102,DM
      PRINT 102,DP
      PRINT 102,PEDLM
      PRINT 102,PEDLP
  102 FORMAT(/(1X,10F10.3))
  101 FORMAT(' CALIBRATION CONSTANTS FOR RUN (COMPR2) ',I5)
C
      RETURN
      END
