C   31/08/79 C9083101   MEMBER NAME  EVDUMP   (JADENS)      FORTRAN
      SUBROUTINE EVDUMP
      IMPLICIT INTEGER*2 (H)
#include "cdata.for"
#include "cgraph.for"
      IHHEAD=2*IDATA(IBLN('HEAD'))
      NRUN=HDATA(IHHEAD+10)
      NEVT=HDATA(IHHEAD+11)
      WRITE(JUSCRN,100)
  100 FORMAT('1 EVENT DUMP ROUTINE CALLED.',/)
      WRITE(JUSCRN,101) NRUN, NEVT, ICREC
  101 FORMAT('  RUN',I6,' EVENT',I6,' SEQUENTIAL RECORD',I8,/)
      CALL BSLW
      CALL BPRL(1000)
      RETURN
      END
