C   14/10/82            MEMBER NAME  BSCOM1   (S)           FORTRAN77
      SUBROUTINE BSCOM1
C
C     INDEX    VARIABLE     MEANING
C
C       1      ICOND        ERROR CONDITION
C       2      NLAST        LENGTH OF COMMON/BCS/
C       3      NDUMP        NR OF WORDS PRINTED IN A DUMP
C       4      NSPL         NR OF WORDS FOR LOW PRIORITY BANKS
C       5      NAMAX        NR OF DIFFERENT NAMES ALLOWED
C       6      NAMAX1       NAMAX+1
C       7      NLIST        NR OF ENTRIES IN LISTS ALLOWED
C       8      NPRIME       PRIME NR USED IN IBLN
C       9      NFRS         FIRST LOCATION FOR BANKS
C      10      NLST         LAST LOCATION FOR BANKS
C
C      11      NEXT         NEXT LOCATION FOR BANKS
C      12      NCI          ACTUAL NR OF DIFFERENT NAMES
C      13      NFRE         NR OF FREE LOCATIONS
C      14      IN           ACTUAL NR OF NAMES IN LIST
C      15      KPOS         INDEX FROM BPOS/CPOS
C      16      LIND         INDEX OF LAST CREATED BANK
C      17      ILOW         LOWEST INDEX OF DELETED BANK
C      18      LFDI         LAST I-INDEX
C      19      LFDK         LAST K-INDEX
C      20      NCPL         ACTUAL NR OF WORDS OF LOW PRIORITY SPACE
C
C      21-30   NHISTH(10)   HISTOGRAM FOR TOTAL SPACE
C
C      31      NHIST(11)    OVERFLOWS TOTAL SPACE
C      32      NCOL         NR OF GARBAGE COLLECTIONS
C      33      NZT          TIME OF BOS-START
C      34      IBFI         INDEX FOR BUFF-BANK
C      35      NLAST1       COPY OF NLAST
C      36      ISLST        INDEX FOR SPECIAL LIST OF NAMES
C      37      IMLST        INDEX FOR MARKERS OF SP. LIST O.N.
C      38      INAMV        INDEX FOR NAMES
C      39      IOLST        INDEX FOR IO-LIST
C      40      IPLST        INDEX FOR POINTERS TO NAMES
C
C      41-50   NER(10)      INPUT ERROR CODES FROM BINP/BRDS
C
C      51      NRECL        DEFAULT RECORD LENGTH FOR OUTPUT
C      52      NERRL        NR OF ERRORS ALLOWED
C      53      NRIN         NR OF INPUT EVENTS
C      54      NROUT        NR OF OUTPUT EVENTS
C      55      NS           ACTUAL NR OF NAMES IN SPECIAL LIST
C      56      NEXTI        NEXT INDEX FOR BANKS IN BRDS
C      57      NEXTA        INDEX OF BEGIN OF NEW EVENT
C      58      NEXTB        INDEX BEHIND NEW EVENT
C      59      ISAVB        INDEX OF SAVED LOCATION IN BWRS
C      60      NSAVB        CONTENT OF SAVED LOCATION IN BWRS
C
C      61-70   NHISTL(10)   HISTOGRAM FOR LOW PRIORITY SPACE
C
C      71      NHISTL(11)   OVERFLOWS OF LOW PRIORITY SPACE
C      72      MARKWR       MARKER FOR BSEQ
C      73-75   NOUT(3)      OUTPUT UNITS FOR BSEQ
C      76      IASW         SWITCH FOR FORTRAN/ASSEMBLER READ (BSEQ)
C      77      NPRE         NR OF BPRE PRINTOUTS
C      78-80   IDUMMY(2)    TWO DUMMY WORDS (ZERO)
C      80      NDUMP1       SAME AS NDUMP
C
      END
