C---------------START OF MACRO CUNIT (LOGICAL UNIT NUMBERS)-------------
C
      COMMON /CUNIT/LUNMUC,LUNMUE
C
C LUNMUC  LOGICAL UNIT FOR MU CALIBRATION DATA.
C LUNMUE  LOGICAL UNIT FOR MU CALIBRATION DATA EDIT FILE.
C
C---------------END OF MACRO CUNIT--------------------------------------
