C   10/04/84            MEMBER NAME  DRAMOV   (JADEGS)      FORTRAN
      SUBROUTINE DRAMOV(X1,Y1,X2,Y2,L)
C
C     DRAW LINE FROM X1,Y1 TO X2,Y2
C     IF L NONZERO, A DASHED CODE WILL BE GENERATED
C
      CALL MOVEA(X1,Y1)
      IF(L.LE.0) CALL DRAWA(X2,Y2)
      IF(L.GT.0) CALL DASHA(X2,Y2,L)
      RETURN
      END
