C   03/03/80 007281528  MEMBER NAME  TOFCLC   (S)           FORTRAN
      SUBROUTINE TOFCLC(NCN,LTRK,NFLG)
      INTEGER *2 HADC,HTDC
#include "tfprm.for"
      COMMON/CWORK/NR,RAW(5,42),NC,ICRT1(5,42),NTRK,ICRT2(50),TRK(5,50)
     - ,ITRC(50),NTC,ITRK(5,42),INFM(4),IRELT(14,50)
      COMMON/TFPED/ HADC(2,42),HTDC(2,42)
      DATA DTAU1/1./
C
      Z1= TRK(1,LTRK)
      TAUP1= RAW(3,NCN)+Z1/VELSC
      TAUM1= RAW(2,NCN)-Z1/VELSC
      NFLG= -1
          IF(HTDC(1,NCN).GT.10.AND.HTDC(1,NCN).LT.2048) GO TO 320
            GO TO 360
C
 320        IF(HTDC(2,NCN).GT.10.AND.HTDC(2,NCN).LT.2048) GO TO 330
            GO TO 360
C
  330 IF(ABS(TAUM1-TAUP1).LE.3.*DTAU1) GO TO 350
  350 NFLG= 1
  360 RETURN
      END
