C   26/09/79 C9092601   MEMBER NAME  MUCONP   (S)           FORTRAN
C LAST CHANGE 10.00 26/09/79 JOHN ALLISON.
C LAST CHANGE 20.16 21/09/79 HARRISON PROSPER
      SUBROUTINE MUCONP
C
      IMPLICIT INTEGER*2 (H)
C
C-----------------------------------------------------------------------
C
C MUCONP PRINTS MUON CALIBRATION DATA.
C
C-----------------------------------------------------------------------
C
C COMMONS.
C
#include "cmucalib.for"
C
C-----------------------------------------------------------------------
C
C PRINT DATA.
      WRITE(6,1001)NVERSN,DESCRP
 1001 FORMAT('1MU CALIBRATION DATA, VERSION',I5,', ',15A4)
      WRITE(6,1002)(HOVALL(I),I=1,5)
 1002 FORMAT('0OVERALL TRANSLATION PARAMETERS...'/
     *'    UNIT 1, FAR SIDE (-X) WALL',T45,I6/
     *'    UNIT 2, NEAR SIDE (+X, RUCKSACK) WALL',T45,I6/
     *'    UNIT 3, MAGNET (-Y AND INNER)',T45,I6/
     *'    UNIT 4, FAR ARCH',T45,I6/
     *'    UNIT 5, NEAR ARCH',T45,I6)
      WRITE(6,1003)
      WRITE (6,1010)
      WRITE(6,1004)
      WRITE(6,1011)
      DO 5 IF=1,NFRAMS
    5 WRITE(6,1005) IF,HFACE(IF),HLAYER(IF),HSECT(IF),HUNIT(IF),
     * HNORM(IF),HLONG(IF),HTRANS(IF),HDIST(IF),HANG(IF),HCLLO(IF),
     * HCLHI(IF),HCTLO(IF),HCTHI(IF),HAC(IF),HAL(IF)
      WRITE(6,1006)
      WRITE(6,1007)
      IX=NCHAMS/4+1
      DO 6 IC=1,IX
      JC=IC
      JC1 = JC+IX
      JC2 = JC+2*IX
      JC3 = JC+3*IX
      IF(JC3.GT.NCHAMS)JC3=NCHAMS
      WRITE(6,1008)JC,HFR(JC),HCTW(JC),HD1(JC),JC1,HFR(JC1),HCTW(JC1),
     * HD1(JC1),JC2,HFR(JC2),HCTW(JC2),HD1(JC2),JC3,HFR(JC3),HCTW(JC3),
     * HD1(JC3)
    6 CONTINUE
C
      WRITE(6,1100)
 1100 FORMAT('1CHAMBER ''ELECTRONIC'' DATA.'/
     *'0  VDR    = DRIFT VELOCITY IN MICRONS PER CLOCK PULSE (50 NS),'/
     *'   DTP    = DRIFT TIME PEDESTAL,'/
     *'   LTP    = LONGITUDINAL TIME PEDESTAL,'/
     *'   LSF1-4 = LONGITUDINAL SCALING FACTORS, HITS 1-4, 1/100MM PER C
     *LOCK PULSE (0.5 NS),'/
     *'   STA    = STATUS, =0 OK, .NE.0 DOWN FOR SOME REASON.'/
     *'0 CH  VDR DTP LTP LSF1 LSF2 LSF3 LSF4 STA',
     *2('      CH  VDR DTP LTP LSF1 LSF2 LSF3 LSF4 STA'))
      IX=NCHAMS/3+1
      DO 7 IC=1,IX
      J1=IC
      J2=IC+IX
      J3=IC+2*IX
      IF(J3.GT.NCHAMS)J3=NCHAMS
      WRITE(6,1101)
     * J1,HVDRFT(J1),HDTP(J1),HLTP(J1),(HLSF(J,J1),J=1,4),HMCSTA(J1),
     * J2,HVDRFT(J2),HDTP(J2),HLTP(J2),(HLSF(J,J2),J=1,4),HMCSTA(J2),
     * J3,HVDRFT(J3),HDTP(J3),HLTP(J3),(HLSF(J,J3),J=1,4),HMCSTA(J3)
 1101 FORMAT(I4,I5,2I4,4I5,I4,2(I8,I5,2I4,4I5,I4))
 7    CONTINUE
C
      DO 150 IFA=1,6
      WRITE(6,1102) IFA
      WRITE(6,1103) HBLLO(IFA),HBLHI(IFA),HBTLO(IFA),HBTHI(IFA)
      IARG=6*(IFA-1) +1
      JARG=6*IFA
      WRITE(6,1104)(HBNLIM(J),J=IARG,JARG)
  150 CONTINUE
      WRITE(6,1114)IFCIND
 1114 FORMAT('0BLOCK PARAMETER IFCIND...',6I10)
C
      WRITE(6,2000)HYKNMI,HYKNMO,HYKLDM,HYKTDM,BYOKE,IYKIND
 2000 FORMAT('0YOKE PARAMETERS....'/
     *'   HYKNMI',4I10/
     *'   HYKNMO',4I10/
     *'   HYKLDM',4I10/
     *'   HYKTDM',4I10/
     *'   FLUX  ',F10.4/
     *'   IYKIND',I10)
C
      WRITE(6,2001)IZEII,IZEIO,IREP1,IREP2,IREP3,IREP4,IXYEP5,
     *              IZOEP1,IZOEP2,IZOEP3,IZOEP4,IZOEP5,CAEP2,
     *              IEPIND,IEPSCT
 2001 FORMAT('0END PLUG PARAMS....'/
     *'   IZEII ',I10/
     *'   IZEIO ',I10/
     *'   IREP1 ',I10/
     *'   IREP2 ',I10/
     *'   IREP3 ',I10/
     *'   IREP4 ',I10/
     *'   IXYEP5',I10/
     *'   IZOEP1',I10/
     *'   IZOEP2',I10/
     *'   IZOEP3',I10/
     *'   IZOEP4',I10/
     *'   IZOEP5',I10/
     *'   CAEP2 ',F10.4/
     *'   IEPIND',I10/
     *'   IEPSCT',I10)
C
C-----------------------------------------------------------------------
C
C OTHER FORMAT STATEMENTS.
C
C
 1003 FORMAT('0HERE IS THE DATA FOR THE MUON FILTER FRAMES')
 1004 FORMAT(' ',1X,'FRAME',3X,'FACE',3X,'LAYER',1X,'SECTION',2X,
     *'UNIT',3X,
     *' N L T',1X,'PERP DIST',1X,'   TWIST ',3X,'   CLLO ',2X,'   CLHI '
     *,2X,'   CTLO ',2X,'   CTHI ',1X,'1ST & LAST')
 1005 FORMAT(1X,I6,4I7,4X,3I2,6I10,2I5)
 1006 FORMAT('1HERE IS THE DATA FOR THE MU FILTER CHAMBERS')
 1007 FORMAT('     CH NO FRAME CTW(MM) D1(MM)',4X,'CH NO FRAME CTW(MM) D
     *1(MM)',4X,'CH NO FRAME CTW(MM) D1(MM)',4X,'CH NO FRAME CTW(MM) D1(
     *MM)')
 1008 FORMAT(4(2X,2I6,I8,I6,2X))
 1010 FORMAT(' ',T10,' FRAME INDICES ',T72,' SENSITIVE AREA LIMITS')
 1011 FORMAT(' ',T52,'(MM)',T60,'(1/10MR)',T73,'(MM)',T83,'(MM)',T93,
     * '(MM)',T103,'(MM)')
 1102 FORMAT(///,T5,'CONCRETE BLOCK LIMITS FOR FACE ',I4,5X,'(ALL IN MM)
     *')
 1103 FORMAT(/,T5,'LONGITUDINAL',I5,' TO ',I5,' TRANSVERSE ',I5,' TO ',
     * I5)
 1104 FORMAT(/,T5,'NORMAL LIMITS BLK#1',3X,I5,' TO ',I5,'   BLK#2',3X,
     *I5,' TO ',I5,'   BLK#3',3X,I5,' TO ',I5)
C
C-----------------------------------------------------------------------
C
      RETURN
      END
