C   07/06/96 606071812  MEMBER NAME  BFRD     (S4)          FORTG1
      SUBROUTINE BFRD(IUN,NTOT,BUFF)
C     BOS SUBPROGRAM =3.6=
      INTEGER BUFF(NTOT)
      READ(IUN,ERR=101,END=102) NTOT,BUFF
  100 RETURN
  101 NTOT=0
      READ(IUN,ERR=101,END=102)
      GOTO 100
  102 NTOT=-1
      GOTO 100
C
      ENTRY BFWR(IUN,NTOT,BUFF)
      WRITE(IUN) BUFF
      GOTO 100
      END
