C   15/11/83 311281210  MEMBER NAME  RADIAT   (S)           FORTRAN
      FUNCTION   RADIAT(XI)
      COMMON /CFUNK/ BT,CONS,RHS
C
C     ANALYTICAL FORM OF THE INTEGRAL OVER THE BREMSSTRAHLUNG
C     SPECTRUM, WHICH IS THE SOLUTION OF THE DIFFUSION EQUATION
C     TAKING INTO ACCOUNT MULTIPLE PHOTON EMISSION.
C     RADIAT HAS TO BE SOLVED FOR XI TO OBTAIN THE BREMS SPECTRUM.
C     THE INVERSION ROUTINE IS CALLED FROM JELOSS.
C                                    W.BARTEL     28./11./83
C
      F = XI**BT/BT - XI**(BT+1.)/(BT+1.) + 0.75/(BT+2.)*XI**(BT+2.)
      RADIAT = F * CONS - RHS
      RETURN
      END
