C   23/06/78 509272145  MEMBER NAME  CONVEF   (WORKS)       FORTRAN
      FUNCTION CONVEF(ALAMDA)
C---- S.YAMADA   14-11-77
C     LAST MODIFICATION  20-10-78  16:45
C
C---- NEW DATA FROM HTV IS USED.
C---- CONVERSION  EFFICIENCY OF R594 PHOTOTUBE.
C---- ALAMDA = WAVE LENGTH IN NANO-METER.
C
      CONVEF = 0.0
      IF(ALAMDA.LE.280.1 .OR. ALAMDA.GT.700.0) RETURN
C---- CHANGE UNIT OF WAVE LENGTH TO MICRON-METER.
      A = 0.001*ALAMDA
      CONVEF = ((14.25*A-22.66)*A+10.77)*A-1.32-0.001/(A-0.28)
      IF(CONVEF.LT.0.) CONVEF = 0.
      RETURN
      END
