C   07/06/96 606071851  MEMBER NAME  INDAR    (S4)          FORTG1
      SUBROUTINE INDAR(NAME,N,INDA,NLIM)
#include "acs.for"
      COMMON/BCS/IW(1)
      INTEGER INDA(1)
      IW(INAMV)=NAME
      LFDI=MOD(IABS(NAMEV),NPRIM)+NAMAX1
    1 LFDI=IW(LFDI+IPLST)
      IF(IW(LFDI+INAMV).NE.IW(INAMV)) GOTO 1
      IF(LFDI.EQ.0) LFDI=IBLN(IW(INAMV))
      K=LFDI+1
      DO 10 I=1,NLIM
      K=IW(K-1)
      IF(K.EQ.0) GOTO 100
   10 INDA(I)=K
      I=NLIM+1
  100 N=I-1
      RETURN
      END
