C   03/03/89 903031439  MEMBER NAME  GEANTDUM (S)        M  FORTRAN
      SUBROUTINE GEANTI
C
C  dummy routine to be used with JADE MC program, linking without geant
C
      WRITE(6,200)
200   FORMAT(' Warning:  dummy geant used')
      RETURN
      END
      SUBROUTINE TGEANT(P1,X1)
C
C  dummy routine to be used with JADE MC program, linking without geant
C
      RETURN
      END
