C   17/03/79 310171346  MEMBER NAME  EVT      (MTLINKS)     FORTRAN
C=======================================================================
C  #EVT1 IS FOR ONE NORD TAPE TO ONE EXTEST(+1) TAPE
C  #EVT2 IS FOR ONE NORD TAPE WITH SEVERAL EOFS
C  #EVT3 IS FOR SEVERAL NORD TAPES TO ONE M TAPE
C  #EVT4 IS FOR ONE NORD TAPE TO ONE SPECIFIC EXDATA TAPE
C  #EVT5 IS FOR ONE NORD TAPE TO ONE M TAPE
C=======================================================================
      IMPLICIT INTEGER*2 (H)
      COMMON/CDATA/LENG,ID1(2),ID(10000)
      INTEGER*2 IARR,IBUFF
      INTEGER*2 J,HB(20)
      INTEGER*4 BUFFL,DALEN,LUN
      COMMON/MNF/IRUN,IREC,NEV,ISTAT,IFLAG,NWPR,BUFFL,DALEN,
     C   IND,ISPEC,LUN
      COMMON/BUFFER/IBUFF(2048)
      DIMENSION IARR(20004)
      EQUIVALENCE(IARR(5),ID(1))
      REAL*8 DATE(2)
      DATA HB/1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20/
    1 FORMAT(' ',I5,21I6)
    2 FORMAT('0',I10,19I6)
    3 FORMAT(' RUN=',I5,3X,'NEV=',I5,3X,'ISTAT=',I5,3X,'IARR(1-6)=',7I8)
    4 FORMAT('0',' JOB DATE ',A8,' TIME ',A8)
      CALL DAY(DATE(1),DATE(2))
      WRITE(6,4) DATE
C
      CALL LISTRN(1)
C
      CALL RTA
      LUN=9
      BUFFL=4096
      IFLAG=1
      IARR(1)=20000
      IRUN=0
  100 CONTINUE
      IREC=0
      CALL EVTIN
      NEV=0
  200 CALL EVPK
  300 CONTINUE
      CALL RTE
      WRITE(6,2)
      WRITE(6,2)
      PRINT 3,IRUN,NEV,ISTAT,(IARR(I),I=1,6),IBUFF(5)
      WRITE(6,2)
      WRITE(6,2) HB
      WRITE(6,2)
      IJK=IARR(2)/20+1
      DO 400 I=1,IJK
      IJ=20*I
      IK=IJ-19
  400 WRITE(6,1) IK,(IARR(K),K=IK,IJ),IJ
C
      CALL LISTRN(3)
C
      STOP
      END
