C   20/08/80 008221358  MEMBER NAME  FTDLHO                 FORTRAN
      SUBROUTINE FTDLHO(IPNTH,ICNT,MPROJ,X0,Y0,DX,DY)
      IMPLICIT INTEGER*2 (H)
#include "cdata.for"
      DIMENSION ADJ(8)
      DATA ADJ/3*0.5,0.0,0.5,3*0.0/
      SIZE=75.
      IRAD=2*ICNT-1
      IADR=IPNTH+240+IRAD/8+IRAD
      ITOF0=HDATA(IADR)
      ITOF1=HDATA(IADR+1)
      IF(ITOF0.GE.2048) ITOF0=0
      IF(ITOF1.GE.2048) ITOF1=0
      GO TO (1,2,3),MPROJ
    1 CONTINUE
      IS=1
      IF(X0.GT.0.) IS=-1
      X=X0+6*IS*DX+1.5*(IS-1)*SIZE
      ICYL=ICNT/8
      IHT=ICNT-8*ICYL-4
      Y=SIZE*(2*IHT-0.5)
      GO TO 200
    2 CONTINUE
      IS=1
      IF(X0.GT.0.) IS=-1
      X=X0+6*IS*DX+2*(IS-1)*SIZE
      Y=Y0-0.5*SIZE
      GO TO 200
    3 CONTINUE
      ICY=ICNT/8+1
      X=X0-2*SIZE+ADJ(ICY)*SIZE
      Y=Y0-DY-4*SIZE
      CALL DNUM(ITOF0,X,Y,SIZE,0.)
      Y=Y0+DY+2*SIZE
      CALL DNUM(ITOF1,X,Y,SIZE,0.)
      GO TO 300
  200 CONTINUE
      ITHR=ITOF0+ITOF1
      IF(ITHR.LT.1) GO TO 300
      ITHB=ITOF0*ITOF1
      IF(ITOF0.GT.0) ITOFA=ITOF0
      IF(ITOF1.GT.0) ITOFA=ITOF1
      IF(ITHB.GT.0) ITOFA=(ITOF0+ITOF1)/2
      CALL DNUM(ITOFA,X,Y,SIZE,0.)
  300 CONTINUE
      RETURN
      END
