C   19/10/79 411291542  MEMBER NAME  TOFRPR5  (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
       SUBROUTINE TOFRPR
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
#include "tcalcm.for"
      COMMON/EVRUN/NRUN,IEV,ITYP,NEV,IMISS
      INTEGER *2 HDATA
      COMMON/BCS/IDATA(1)
      DIMENSION DATA(1),HDATA(2)
      EQUIVALENCE(IDATA(1),DATA(1)),(HDATA(1),IDATA(1))
      DIMENSION RTOF(14,50),ITOF(14,50)
      EQUIVALENCE (RTOF(1,1),ITOF(1,1))
C
      DATA CVEL/ 2.9979246E2/ ,RADTOF/920./
      DATA IBUG/ 0/
      DATA IENTRY/0/
      IF(IENTRY.NE.0)  GOTO  800
      IENTRY = 1
  800 CONTINUE
C
C
   34 IBUG = IBUG + 1
      IF(IBUG.LE.50) PRINT 300,IBUG,NRUN,NEV,IEV
  300 FORMAT(//'  NEW EVENT ',I8,' RUN...',3I10)

      IPTOFR = IDATA(IBLN('TOFR'))
C
   32 NTR = IDATA(IPTOFR+1)
C     IF(NTR.LE.0) GOTO  60
      PRINT 400 ,NTR
  400 FORMAT(' TOFR BANK        ',I10,'  TRACKS'/)
C
      DO   40  N=1,NTR
      DO   41  I=1,14
      RTOF(I,N) = DATA(IPTOFR+4+(N-1)*14+I)
   41 CONTINUE
      PRINT 401,N,ITOF(1,N),ITOF(2,N),ITOF(3,N),
     1                        (RTOF(KK,N),KK=4,11),RTOF(13,N)
  401 FORMAT(1X,4I3,F6.2,5F6.0,2F6.2,F8.4)
   40 CONTINUE
C
      RETURN
       END
