C   04/05/81 807262012  MEMBER NAME  MUNEWS   (JADEMUS)     FORTRAN

            THIS MEMBER CONTAINS INFORMATION ABOUT DEVELOPMENT OF
            MUON CALIBRATION/SOFTWARE

THE LAST ISSUE OF JCN 22 WAS NO. 4 AND WAS ISSUED ON 01/02/84.


26/07/88 :CB    MUCON ONLY PRINTS ITS MESSAGES ONCE AND A WARNING OF
--------        THIS IS ALSO PRINTED.

07/06/88 :PW    MUCUTS CHANGED. RMSZUP INCREASED FOR 1986 DATA
--------  (JH)  BY A FACTOR OF 2.

26/05/88 :PW    MUANAF,MUFFLE,MUFFLT,MUFFLY UPDATED.
--------  (JH)  USE CORRECT ERROR CALCULATION.

 8/02/88 :CB    MUFFLE NO LONGER CALLS MUFFLM.
--------        MUFFLM IS NOW OBSOLETE AND COULD BE DELETED.

18/12/87 :CB    MUCON CHANGED TO SHORT CIRCUIT ROUTINE IF NON-MUON MC
--------        DATASET IS BEING PROCESSED. MUMESS MESSAGE PRINTED.

20/03/86 :CB    MUANAF CHANGED TO ENSURE MUR2/0 CREATED BEFORE
--------        TERMINATING ANALYSIS IF NREGS = 0.

 9/10/85 :CB    MUANAC CHANGED TO MAKE HLUN AND HC ARRAYS BIGGER.
--------        CAN NOW HANDLE 400 HITS. MUINI,MUINIG CHANGED TO
                PRINT CORRECT STATISTICS (HITS>400). MUSTAT
                DESCRIPTION ALSO UPDATED.

23/04/85 :PW    MUCONE & MUCHAN GAVE WRONG RESULTS IN UPDATE MODE.
--------        (CORRECT ELSEWHERE)                ---------------
                IF CTW'S WERE CHANGED  CTLO, CTHI WERE WRONG.
                ACTW, AANG WERE POSSIBLE ALTHOUGH ILLEGAL IN THIS MODE.
                THE ABOVE ERRORS CORRECTED,
                INITIALISATION OF VARIABLES COMPLETED,
                ALGORITHM FOR CTLO/CTHI HANDLING GREATLY IMPROVED.
                ALSO SOME SMALLER BUGS (WRONG CONSTANTS) FIXED.


29/03/85 :CB    NEW VERSION OF MUANA NOW CALLS MUANAB, A NEW ROUTINE
--------        WHICH EXTRACTS HEADER INFO AND CORRECTS IT IF NEEDED.


13/02/85 :CB    SMALL BUG IN S/R MUONS REMOVED. THIS WILL HAVE HAD
--------        NO EFFECT ON USERS PROGRAMS.


11/10/84 :CB    MUFFLE CHANGED TO ELIMINATE TEMPORARY ALTERATION LEFT
--------        IN MEMBER SINCE CHANGE OF 10/8/84. NO EFFECT ON USAGE.
                NEW STAND-ALONE ROUTINE  CALLED MUONS ADDED. THIS
                EXAMINES THE MUON RESULTS BANKS AND RETURNS INFORMATION
                ABOUT MUONS IN THE EVENT. SEE MEMBER LISTING.

29/09/84 :CB    CHECK FOR CALIBRATION IN MUANAC NOW.
--------

27/08/84 :PW    MUPR10-MUPR23: OUTPUT OF THESE ROUTINES MADE MORE
--------        TRANSPARENT BY A FEW COMMENTS ADDED TO THE PRINTOUT

10/08/84 :CB    NEW VERSION OF MUFFLE AND CMUFFL TO ALLOW CHANGES TO
--------        BE MADE TO NUMBER OF ALLOWED MISSING HITS AND
                MAX VALUE OF MOMENTUM USED FOR TRACK EXTRAPOLATION.
                IF THIS VALUE IS EXCEEDED, P IS SET TO MAX VALUE.
                NALLWM, PMXFLG ARE PRESET IN CMUFFL BY BLOCK DATA.

18/06/84 :CB    MUPIC NOW DRAWS NOTHING IF THERE IS NO CALIBRATION.
--------

16/04/84 :CB    MUREG NOW HAS CORRECT TEST FOR MONTE CARLO EVENTS.
--------        MUMESS ALTERED TO MATCH MUERRY.

30/03/84 :CB    MUCUTS NOW PROTECTED AGAINST EVENTS WITH MORE THAN 60
--------        TRACKS. PREVIOUSLY ARRAYS WERE SIZE 40 AND UNPROTECTED.

23/03/84 :CB    MUFFLE NOW STORES NGLAYR IN MUR2/1 I*4 WORD 7 / TRACK
--------        MUTIM UPDATED.


15/03/84 :PH/CB MULDSP NOW HANDLES MUPT 9000
--------

12/03/84 :CB    MUCUTS TAKEN FROM HUGH'S LIBRARY AND TIDIED-UP.
--------        NOW FLAGS TYPE 9 GOOD MUONS. MUINI/MUINIG CHANGED FOR
                NEW STATISTICS INFO. MUERRY TIDIED-UP.@MUSTAT UPDATED.

 9/03/84 :CB    MUCOOR NOW CALLS MU2PUL TO GET MULTI-PULSING CUT  AND
--------        MUFSTA TO FIX UP BAD STATUS INFO. OTHER SMALL IMPROVE-
                MENTS INCLUDE BETTER ERROR CHECKING. MUINI CHANGED TO
                PRINT TITLE FOR SCALAR 65 (MUINIG TOO). MUANAC UPDATED.
                MUREG NOW CHECK THAT CALIBRATION READ. IF NOT, IT STOPS.
                (BUT ONLY FOR REAL DATA)
                MUPIC NOW ALSO CALLS MUFSTA.
                MUFFLE NOW CALLS MUSAFE FOR ALL TRACKS, NOT ONLY MUONS
                MUANAF NOW CHECKS THAT NREGS IS GREATER THAN ZERO.

21/02/84 :CB    IMPROVED VERSION OF MUCONW  RELEASED. MUINIG UPDATED.
--------

19/02/84 :CB    IMPROVED VERSION OF MUCON RELEASED.
--------

 1/02/84 :PH/CB NEW VERSION OF MULDSP FOR MUPT 5000
 -------

 1/02/84 :TG/CB NEW VERSIONS OF MUCOOR,MUINI,MUCUTS & MUANAF
 -------        WITH IMPROVED STATISTICS LAYOUT, BETTER ERROR HANDLING
                AND PRINTOUT IF BANKS MISSING AND NEW STATISTICS DATA.
                MEMBER @MUSTAT GIVES DETAILS OF STATISTICS

13/01/84 :CB    MUCOOR CHANGED TO RECORD MULTI-PULSED HITS IN BIT 9
--------        OF EVERY WORD IN MUR1/2. MUCOOR ERROR MESSAGES IMPROVED
                AND MUANAC CHANGED TO REFLECT NEW MUCOOR VERSION.
                MUFINI CHANGED. NO STATISTICS ARE PRINTED IF ALL VALUES
                ARE ZERO. TITLES UPDATED IN MUINI WRT STATISTICS.

16/12/83 :CB    NEW VERSION OF MULOCH NOW INSTALLED. THIS VERSION
--------        DIFFERS ONLY IN BEING EASIER TO READ AND UNDERSTAND.
                THUS CERTAIN VARIABLES HAVE BEEN RENAMED.

13/12/83 :HMCC
--------                MODIFIED MUON CALIBRATION
                        -------------------------

                THE MUON CHAMBER CALIBRATION DEPENDS ON THE JET-CHAMBER
                CALIBRATION AND FITTING PROCEDURE IN THAT SMALL CORRECT-
                IONS ARE MADE TO THE MU HIT COORDINATES TO CORRECT FOR
                MISALIGNMENTS BETWEEN THE MU HITS AND THE EXTRAPOLATED
                'PATR' TRACKS. THE RECENT RE-CALIBRATION OF THE JET-
                CHAMBER HAS NECESSITATED RE-CALCULATION OF THESE SHIFTS.
                THEY HAVE BEEN CALCULATED USING THE MU-PAIR EVENTS SELE-
                CTED BY BEATE NAROSKA AND RE-FITTED BY PETER STEFFEN
                IN EXACTLY THE SAME WAY AS THE MULTI-HADRON DATA HAS
                BEEN RE-FITTED  I.E. NEW R-PHI CALIBN , NEW R-Z CALIBN,
                R-Z FIT DONE WITH Z-VERTEX CONSTRAINT  ( FOR DATA TAKEN
                IN 1980 AND THE LOW ENERGY DATA TAKEN IN 1981, ONLY THE
                LAST TWO IMPROVEMENTS APPLY ). THE Z RE-CALIBRATION WAS
                DONE WITHOUT HIT-CLEANING.  THE RESULTING CORRECTIONS
                ARE NOW INSTALLED IN THE STANDARD MU CALIBRATION FILES.
                USERS SHOULD NOTE THAT THE SHIFTS FOR THE END-WALLS ARE
                LARGE ( TYPICALLY 20 MM ) AND ARE VERY SENSITIVE TO THE
                JET-CHAMBER Z CALIBRATION AND R-Z FITTING PROCEDURE.
                ( THESE CORRECTIONS ARE IGNORED FOR MONTE-CARLO TRACKING
                  AND ANALYSIS. )

08/12/83 :CB    MULDSP HAS BEEN CHANGED SO THAT IN GRAPHICS, MUPT 1000
--------        NOW DRAWS ALL MUON TRACKS WITH THE MUCUTS FLAG (1/2 WORD
                53 FOR A GIEVN TRACK IN MUR2/1) GREATER THAN 0.

07/12/83 :HMCC  THE FOLLOWING ROUTINES WERE CHANGED :
--------
                MUCUTS    A SUBSET OF THOSE TRACKS WHICH GET A
                          NON-ZERO FLAG NOW GET FLAG '5' IN
                          HALF-WORD 53 IF THEY HAVE NO MISSING HITS
                          AND PENETRATE MORE THAN 5.8 ABS LENGTHS.

02/12/83 :HMCC  THE FOLLOWING ROUTINES WERE CHANGED :
--------

                MUFFLE ( AND MACRO CMUFFL )   FOR NEW LEAD GLASS ;
                MUINI     STANDARD USER NOW HAS LEVEL 2 ;
                MUANAF    FOR EBEAM = ZERO , SET EBEAM = 50.

23/11/83 :HMCC  THE FOLLOWING ROUTINES WERE CHANGED :
--------
                MUFFLY    PROTECT CERTAIN ARRAYS FROM OVERFLOW ;
                MUREG     FURTHER ITERATION OF YOKE PARAMETERS.

25/10/83 :HMCC  THE FOLLOWING ROUTINES WERE CHANGED :
--------        MUCOOR    BUGS CONCERNING MISSING-CRATE EVENTS
                          AND CRATES WITH NON-ZERO TIME REFERENCE
                          REMOVED ;
                MUANAC    DATE OF THIS CHANGE ENTERED FOR MUR1/0 .

22/10/83 :HMCC  THE FOLLOWING ROUTINES WERE CHANGED :
--------        MUFFLE    SOME BUGS REMOVED AND MUFFLE/MUREGY "ERROR"
                          SOLVED ;
                MUREG     THE YOKE END PLATE THICKNESS SET TO 340 MM ;
                MUFFLY    CHANGES TO TAKE ACCOUNT OF VARYING YOKE
                          END PLATE THICKNESS  ( CALLS MUENDP ) ;
                MUFFLT        D I T T O     ;

                THE FOLLOWING NEW ROUTINE WAS ADDED :
                MUENDP    DECIDES HOW MUCH IRON A TRACK REALLY GOES
                          THROUGH IN THE YOKE END PLATES ( IN THE
                          CURRENT MUFFLY/MUFFLT STEP FOR WHICH IT
                          HAS BEEN CALLED ) .

 8/08/83 :CB    UPDATE OF JADEMUS/L TODAY
 -------

30/05/83 :HMCC  MUHITS WAS CHANGED AGAIN TO CALL MUANAC DIRECTLY, WITH
--------        COMMON /CMUIEV/ FILLED. THIS WAS REQUIRED IN ORDER THAT
                THE GRAPHICS OVERLAY STRUCTURE COULD BE RETAINED.
                NOTE:
                -----    THIS ROUTINE IS PROVIDED PURELY TO TELL THE
                GRAPHICS PROGRAMME THE NO. OF MUHITS IN AN EVENT.THE
                GENERAL MORAL OF THE COMMENT BELOW STILL APPLIES FOR
                BATCH USAGE.

25/05/83 :HMCC  MUHITS WAS CHANGED TO CALL MUANA(0) INSTEAD OF MUANAC.
--------        CALLS DIRECT TO MUANAC , I.E. WITHOUT GOING THRO' MUANA,
                ARE STRICTLY FORBIDDEN, SINCE SOME HEADER INFORMATION
                FROM THE EVENT IS REQUIRED IN MUCOOR ( AND IN OTHER
                ROUTINES TOO ).  THE EFFECT OF THE PREVIOUS VERSION
                OF MUHITS WAS TO MARK 4 CHAMBERS 'DEAD' INCORRECTLY
                IN THE GRAPHICS MODULE IN THE CASE WHERE THE EVENTS
                BEING EXAMINED HAD NO MUR1 BANK BEFORE INPUT.

30/03/83 :HMCC  MUCOOR CHANGED TO TREAT MONTE-CARLO DATA DIFFERENTLY
--------        FROM REAL DATA. ALSO, I CHANGED THE LOWER LIMIT ON
                KKTD FROM 5 TO 0 FOR SETTING THE RECONSTRUCTED DRIFT
                TIME TO KKTD FOR OVERWRITTEN HIT1'S.

16/03/83 :HMCC  NEW CALIBRATION INSTALLED & THE FOLLOWING ROUTINES
--------        CHANGED :
                MUCOOR    SIGNAL-TO-COORDINATE CONVERSION PROCEDURE
                          RADICALLY CHANGED;
                MUFFLY    CHAMBER TWIST CORRECTIONS TO HIT POSITIONS
                          NOW DONE USING TRACK "Z" COORDINATE ;
                MUANAC    NEW DATE;
                MUFFLE    BLOCK DATA NOW HAS RESOLUTIONS 5MM (BARREL)
                          AND 10MM(ENDWALLS) AND OVLCUT=15MM;
                MUFFLS    MULTIPLE SCATTERING CONSTANT = 15 MEV/C .
                TANTHM IS A NEW ROUTINE.

12/01/83 :HMCC  MUFFLY PROTECTED AGAINST > 20 HITS ASSOCIATED WITH
---------       ONE TRACK ; MESSAGES CHANGED ; MUERRY BUG IN THE
                COUNTING OF MUANAC ERRORS CORRECTED.

11/10/82 :HMCC  A BUG WAS CORRECTED IN THE ROUTINE   MUCUTS  .
---------       THE CORRECTION WAS TO ENSURE THAT HALF-WORD 53 IN
                MUR2/1 IS ALWAYS SET TO ZERO FOR EACH TRACK BEFORE
                CONSIDERING WHETHER THE TRACK SHOULD HAVE IT SET TO 1 .

30/09/82 :HMCC  THE FOLLOWING NOTE WAS ISSUED TO ALL JADE MEMBERS :
---------
                AN ERROR HAS BEEN FOUND IN THE CALIBRATION FILES
                REGARDING THE  ON/OFF  STATUS OF ABOUT 120 MU CHAMBERS
                DURING THE PERIOD  00:00  10/02/82  -  17:00  11/02/82.
                THE ERROR WAS CORRECTED AT 14:00 ON 21/09/82.

                ANYONE WHO IS ANALYSING DATA FROM THIS PERIOD IS
                ADVISED TO RE-ANALYSE IT IN LIGHT OF THE ABOVE CHANGE.
                THE INTEGRATED LUMINOSITY DURING THIS PERIOD WAS AROUND
                OR LESS THAN 200 NB**(-1) .

29/06/82 :HMCC  CMUEDWRK WAS CHANGED.... NCHAN WAS PUT IN /CMUED/
---------       IN ORDER THAT WE DIDN'T HAVE TO INITIALISE
                LOCATIONS IN /CWORK/.   /CMUED/ IS IN A NEW MEMBER
                CALLED CMUED. THE NECESSARY CHANGES WERE MADE TO
                MUCHAN , MUCONE & MUCONW.
          +
                MUINI WAS CHANGED TO REDUCE THE LIMIT ON THE NO.
                OF ERROR MESSAGES FROM MUCOOR ( NOW 50 ).

22/06/82 :HMCC  THE BLOCK DATA BELOW MUCHAN WAS STILL TAKING UP
---------       MORE CORE THAN NECCESSARY DUE TO ABSENCE OF
                THE STATEMENT   '  IMPLICIT INTEGER*2 (H) '   !!
                ------- NOW FIXED.

28/05/82 :HMCC  THE MUCONE-MUCHAN SYSTEM FOR PRODUCING UPDATES IS
---------       NOW INSTALLED ON JADEMUS. A LOT OF CORE WHICH WAS
                BEING NEEDLESSLY TAKEN UP BY /CMUED/ AND LOCAL ARRAY
                IN MUCONW IS NOW SAVED.  IN SUMMARY :
                CMUED        SCRATCHED
                CMUEDWRK     ADDED = NEW VERSION OF CMUED, USES /CWORK/
                MUCONE       NEW VERSION
                            (PREVIOUSLY ON JADEMUS1. MODIFIED AS ABOVE.)
                MUCHAN       NEW ROUTINE.
                            (PREVIOUSLY ON JADEMUS1. MODIFIED AS ABOVE.)
                MUCONW       NEW VERSION. (MODIFIED AS ABOVE.)

24/05/82 :HMCC  MUANAF BUG NOW FIXED. BEAM ENERGY IS NOW CHECKED TO
---------       BE BETWEEN 1 - 50 GEV.

16/03/82 :HMCC  BODGED DEAD CHAMBERS IN MUCOOR ARE NOW CORRECTLY
---------       DISPLAYED IN GRAPHICS REGARDLESS OF RE-ANALYSIS ETC.
                THIS HAS BEEN DONE BY APPLYING THE SAME BODGE TO MUPIC.

23/02/82 :HMCC  SEE (+) ADDITIONAL COMMENT ON 04/02/82 NOTE.
---------

22/02/82 :HMCC  MUCH IMPROVED ERROR OUTPUT INSTALLED.
-----------
            (A) STANDARD USER GETS LEVEL 1 (=MUPRIN IN /CMUPRN/) O/P.
                THIS INCLUDES MISSING BANK ERRORS ETC. FROM
                MUANAC (DEFAULT=20 MUANAC MESSAGES ONLY+OVERFLOW O/P)
                MUANAF   "       " MUANAF   "       ""
                MUCOOR   "      200 MUCOOR  "      ""(SEE (C)  )
                MUCUTS   "       20 MUCUTS  "       "            "
                ALL MUFFLE,M,S,T,R,X,Y,Z ERRORS ARE PRINTED AT LEVEL1.
                MUMESS CALLS ARE PRINTED AT LEVEL 1.
            (B) MUFINI O/P OCCURS AT LEVEL 2.
            (C) MUEV DUMP IS CALLED FOR MUCOOR ERRORS AT LEVEL 3.
            (D) MUDCHK O/P OCCURS AT LEVEL 5.
            (E) MUREG CALLS MUMESS AT LEVELS >5 & <10  .
            (F) IN ORDER TO SUPPRESS ERROR O/P ON GRAPHICS, A VERSION
                OF MUINI CALLED MUINIG HAS BEEN CREATED FOR THE GRAPHICS
                MODULE.


08/02/82 :HMCC THE CHANGE IN KDEPTH LIMIT IN MUFFLY ( BELOW) REQUIRES
-----------   ALSO THAT THE KDEPTH LIMIT IN MUFFLT SHOULD BE INCREASED
              TO 4.   THIS WAS DONE TODAY AT 14.55 .

04/02/82 :HMCC THE FOLLOWING ROUTINES HAVE BEEN ADDED / CHANGED TODAY :
-----------
             MUANA      NOW CALLS MUCUTS  ;
             MUANAF     NOW HAS NTPH=4    ;
             MUCOOR     HAS A BODGE TO SWITCH OFF SEVERAL CHAMBERS
                        ---- THIS IS TEMPORARY UNTIL THE CALIBRATION
                        FILES ARE MODIFIED. NOTE THAT THE GRAPHICS
                        PICTURE SHOWS CHAMBERS AS ACTIVE IF THE
                        CALIBRATION FILES SAY SO(+). THE EFFECT OF THIS
                        MUCOOR BODGE IS TO ENSURE THAT THE MU ANALYSIS
                        IS CORRECT ( WHETHER IN GRAPHICS OR BATCH ) SO
                        NO HITS WILL APPEAR IN THESE CHAMBERS AT THE
                        GRAPHICS TERMINAL FOR THE SPECIFIED PERIODS.
                (+)     IF RE-ANALYSIS IS DONE , EITHER BY MUPT -1
                        OR BY WORKING AT LEVEL 9, THESE CHAMBERS WILL
                        BE SHOWN AS 'OFF' ON THE GRAPHICS SCREEN.
             MUCUTS     NEW ROUTINE. CALLED FROM MUANA AFTER PHIL2
                        ANALYSIS TO EXAMINE THE MUR2 RESULTS BANKS.
                        TRACKS SATISFYING CERTAIN CUTS GET FLAGGED
                        WITH A '1' IN 1/2 WORD 53 OF THE MUR2/1 INFO
                        FOR THIS TRACK.
             MUFFLE     NOW HAS ASSOCIATION 'WINDOW' = 2 STANDARD
                        DEVIATIONS + BUG REMOVED.
             MUFFLX     BUG REMOVED.
             MUFFLY     BUG REMOVED ( KDEPTH LIMIT INCREASED TO 4 ).

02/12/81 :          CALIBRATION UPDATES       HMCC
----------          -------------------
            THE NAMES OF THE CALIBRATION UPDATES HAVE BEEN CHANGED
            FROM E.G.
                      F22ALL.UPDATE01.JADE0017
              TO
                      F22ALL.JADE0017.UPDATE01 .

            THIS MAKES F22ALL'S CATALOGUE LOOK PRETTIER !

12/11/81 :  NEW VERSIONS OF MUCONR AND MUCONW HAVE BEEN PLACED ON
----------  JADEMUS/L . THE PRINCIPAL DIFFERENCES BETWEEN THE NEW
  (C.B.)    VERSIONS AND THE OLD ONES ARE:
            A)  CHANGES ARGUMENTS :
                  -->  CALL MUCONR(LUNIN,HERR)
                                      LUNIN = LOGICAL UNIT NUMBER
                                              OF INPUT CALIBRATION
                                      HERR  = 0 IF NO ERROR
                                              (SEE LISTING FOR DETAILS)
                  -->   CALL MUCONW(IFLG,BOSOUT,JADOUT,HERR)
                                      ILFG  = 1 FOR FULL DS OUTPUT
                                              0 FOR UPDATES ONLY
                                      BOSOUT = LOGICAL UNIT NUMBER OF
                                               THE BOS CALIBRATION O/P
                                      JADOUT = LOGICAL UNIT NUMBER OF
                                               THE JADE FORMAT O/P
                                               (STANDARD JADE CAL. SYS)
                                      HERR   = 0 IF NO ERRORS
            B) COMMON /CMULUN/ IS NO LONGER USED BY MUCONR.
               THIS COMMON IS NOW OBSOLETE.
            C) MUCONW DOES NOT REQUIRE THAT THE OUTPUT LUNS HAVE ANY
               SPECIAL VALUES OR SEQUENCE.
            D) MUCONW OUTPUTS CALIBRATION DATASETS IN BOS (AS BEFORE)
               AND IN THE NEW JADE FORMAT (INSTEAD OF THE OLD NBOS
               FORMAT. THE DIFFERENCE IS THAT JADE FORMAT INCLUDES
               A HEADER.
            E) THE JADE FORMAT OUTPUT CAN BE A FULL DS IF IFLG = 1 ON
               INPUT OR ONLY UPDATES IF IFLG = 0.
            F) MUCONW USES A NEW COMMON MACRO CMUED NOW ON THE JADEMUS/L
               LIBRARY. TO GET UPDATES ONE ALSO NEEDS THE NEW MUCONE AND
               MUCHAN WHICH ARE ON JADEMUS1/L1 AT PRESENT.
            ************************************************************
            *                                                          *
            *   A NEW CALIBRATION PROGRAM WILL SOON REPLACE THE USE    *
            *   OF MUCONE/MUCHAN IN THE NEAR FUTURE.                   *
            *                                                          *
            *   THIS NEW PROGRAM CALLED  E X C A L I B U R  WORKS      *
            *   INTERACTIVELY IN FULL SCREEN MODE.                     *
            *                                                          *
            ************************************************************

05/11/81 :  A TRIVIAL ERROR IN MUANA WAS FIXED. ALTHOUGH TRIVIAL,
----------  THIS CODING ERROR HAD THE EFFECT OF (A) NOT INCREASING
(HMCC)    ITMCUT IN MUCOOR FOR THE BAD GAS PERIOD( RUNS 4220 -
            - 4480 (APPROX)) ;  (B) NOT BODGING THE CRATE 6 VDR
            FOR BAD GAS PERIOD & ALL RUNS JANUARY TILL SUMMER 1981.
              THE ERROR WAS INITIATED ON 20/10/81.

******************************************************************
***   ON 20/10/81 , A NEW VERSION OF THE MUON SOFTWARE WAS     ***
***   IMPLEMENTED .  SEE 'F22ALL.JADEMUS(@MUINFOM)' & JADE     ***
***   COMPUTER NOTE 52 .                                       ***
***     THE MAIN CHANGES ARE AS FOLLOWS :                      ***
***   (A) THE MUON CHAMBER REGIONS ARE ARTIFICIALLY 'EXTENDED' ***
***       SO THAT, EVEN IF AN EXTRAPOLATED TRACK IS SUPPOSED   ***
***       TO (NARROWLY) MISS A CHAMBER REGION , THAT REGION IS ***
***       STILL SEARCHED FOR HITS WITHIN 3 SIGMA.              ***
***   (B) MANY CHANGES HAVE BEEN MADE TO THE GRAPHICS ROUTINES.***
***       THESE ARE EXPLAINED FULLY IN JADE COMPUTER NOTE 52.  ***
***    A COMPLETE RE-ISSUE OF JADE COMPUTER NOTE 22 IS NOT     ***
***    BEING DONE NOW DUE TO THE POSSIBILITY OF FURTHER IMPRO- ***
***    VEMENTS IN THE NEAR FUTURE.                             ***
******************************************************************


