      COMMON/TFPRM/ CORNOR(84),COROVF(84),TPARM(41),VELSC,TCALM(42),
     1 TCALP(42),PEDLM(42),PEDLP(42),TCPDM(42),TCPDP(42),DUM(6)
      COMMON/TFPRM1/ TCALM2(42),TCALP2(42),TCPDM2(42),TCPDP2(42)
     1 ,VSC(84)
