C   07/06/96 606071803  MEMBER NAME  BCHL     (S4)          FORTG1
      SUBROUTINE BCHL(NW,*)
C     BOS SUBPROGRAM =1.19=
C   18/10/82            MEMBER NAME  ACS      (S)           FORTRAN
      COMMON/ACS/
     1   ICOND,NLAST,NDUMP,NSPL,NAMAX,NAMAX1,NLIST,NPRIM,NFRS,NLST,
     2   NEXT,NCI,NFRE,IN,KPOS,LIND,ILOW,LFDI,LFDK,NCPL,
     3   NHISTH(11),
     4        NCOL,NZT,IBFI,NLAST1,ISLST,IMLST,INAMV,IOLST,IPLST,
     5   NER(10),
     6   NRECL,NERRL,NRIN,NROUT,NS,NEXTI,NEXTA,NEXTB,ISAVB,NSAVB,
     7   NHISTL(11),
     8        MARKWR,NOUT(3),IASW,NPRE,IDUMMY(1),NEOTP,NDUMP1
      COMMON/BCS/IW(1)
      CALL BCHM(LIND,NW,IER)
      GOTO 100
C
      ENTRY BMVE(NW,*)
      CALL BCHM(NW,0,IER)
      LIND=NW
C
  100 IF(IER.EQ.2) GOTO 101
      RETURN
  101 RETURN 1
      END
