C   19/02/79 C9021901   MEMBER NAME  LGCRN2   (JADELGS)     FORTRAN
      SUBROUTINE LGCRN2( HADR, ISUMC )
C
C     S.YAMADA   19-02-79  16:45
C     LAST MODIFICATION    19-02-79  21:25
C
C---- COUNT THE EDGE COUNTERS
C
C---- INPUT:
C           HADR=ADC ADDRESS
C        ISUMC=COUNTER FOR THE EDGE BLOCKS
C---- OUTPUT:
C           ISUMC IS INCREMENTED IF THE HADR IS AN EDGE ONE.
C
      INTEGER *2 HADR
C
C
      IF(HADR.GE.2688) GO TO 10
C
C----       BARREL
C
      IPH = HADR/32
      IZ = HADR-32*IPH
C---- CHECK CORNER HIT
      CALL LGCRNR( 0, IZ, IPHI, ISUMC)
      RETURN
C
C            END CAP
C
   10 ID = HADR-2687
      IPART = -1
      IF(ID.LE.96) GO TO 3
      ID = ID-96
      IPART = 1
C---- ILLEGAL COMPONENT NO.IS  NEGLECTED.
      IF(ID.GT.96) RETURN
C
    3 MB = (ID-1)/24
      ID = ID-24*MB
C
      CALL LGCRNR( IPART, ID,MB, ISUMC )
C
      RETURN
      END
