C   25/06/78            MEMBER NAME  BREMS1   (LGSOURCE)    FORTRAN
      SUBROUTINE BREMS1(ENE,EPSI)
C
C SUBROUTINE BREMS1,2,M0LLRE
C     A.SATO
C     LATEST MODIFICATION 05-04-78 21:55
C
      COMMON /FB1PAR/ BGAM,PROSWD
      COMMON /BRPAR/ BRA,BRB,BDEL
      COMMON/SFCPA/SFP,SFE
      BH(X)=4.184*ALOG(X+0.952)-0.280
      XR=RN(DAM)
      IF (XR-0.5) 10,11,11
 10    EPSI=EXP(-BGAM*XR)
      GO TO 1
 11    EPSI=SQRT(EXP(-2.*BGAM*XR)-PROSWD)
1     XR=RN(DAM)
      DEL=BDEL*EPSI/(ENE*(1.-EPSI))
      IF(DEL-1.)20,20,21
 20    G1=(1.-EPSI)*(1.-BRA*DEL*(3.898-0.9805*DEL))
      GOTO 2
 21    G1=(1.-EPSI)*(1.-BRA*BH(DEL))
 2    IF(XR*SFE-G1)30,30,31
 30    IF(EPSI.LE. 1.-1./ENE) RETURN
 31    EPSI=0.
      RETURN
      END
