C   09/08/82 303101253  MEMBER NAME  TANTHM   (JADEMUS)     FORTRAN
      FUNCTION TANTHM( ICH )
C GETS COORDS OF THE WIRE OF THE GIVEN CHAMBER
C X IS THE NORMAL DIRECTION
C Y IS THE DRIFT  DIRECTION
C BOTH X AND Y ARE MADE POSITIVE
C RETURNS THE TANGENT OF THE ANGLE OF THE "MUON" TRACK
C (ASSUMED FROM THE ORIGIN) TO THE NORMAL TO THE CHAMBER
      IMPLICIT INTEGER*2 (H)
#include "cmucalib.for"
      IFRAME = HFR(ICH)
      IOR = HNORM(IFRAME)
      IARCH = HOVALL(HUNIT(IFRAME))
      ICNORM = HDIST(IFRAME) + HD1(ICH)
      GOTO( 11, 12, 13 ),IOR
   11 X = ICNORM + IARCH
      Y = HCTW(ICH)
      GOTO 20
   12 Y = HCTW(ICH) + IARCH
      X = ICNORM
      GOTO 20
   13 Y = HCTW(ICH) + IARCH
      X = ICNORM
      GOTO 20
   20 IF(X.LT.0.0) X = -X
      IF(Y.LT.0.0) Y = -Y
      TANTHM =  Y/X
      RETURN
      END
