C   02/02/79 C9032101   MEMBER NAME  EVREA1   (JADEGS)      FORTRAN
      SUBROUTINE EVREA1(NUNIT,NWORD,IDATA,IRET)
      IMPLICIT INTEGER*2 (H)
      DIMENSION IDATA(NWORD)
      READ(NUNIT,ERR=1,END=2) NWORD,IDATA
      IRET=0
      RETURN
    1 CONTINUE
      IRET=1
      RETURN
    2 IRET=2
      RETURN
      END
