C   25/06/78 C8062601   MEMBER NAME  SETECT   (LGSOURCE)    FORTRAN
      SUBROUTINE SETECT(ECUTIN)
C
C     S.YAMADA    04-03-78
C
C     LAST MODIFICATION  14-03-77 14:35  BY A.SATO
C
C---- RESULT TABLE
C
C    2.0<=ECUTIN
C       ECUTEL=ECUTIN, ECUTPS=ECUTIN, ECUTPH=ECUTIN-1.0, ECUT=ECUTIN
C
C    1.05<ECUTIN<2.0
C       ECUTEL=ECUTIN, ECUTPS=0.9999, ECUTPH=0.05, ECUT=1.0
C
C    1.0<ECUTIN<1.05
C       ECUTEL=ECUTIN, ECUTPS=0.9999, ECUTPH=0.05, ECUT=1.0
C
C    ECUTIN<=1.0
C       ECUTEL=1.0, ECUTPS=0.9999, ECUTPH=0.05, ECUT=1.0
C
      COMMON/ENECUT/ECUT,ECUTEL,ECUTPH,ECUTPS
       DATA RM/.511/
      DIMENSION ECUTLS(3)
      EQUIVALENCE (ECUTLS(1),ECUTEL)
C
C     IF(ECUTIN .GT.0.) GOTO 2
C     CALL MSG('ECUT IN MEV =? (F8.2);;')
C     READ(5,500) ECUTIN
C 500 FORMAT(F8.2)
C   2 CONTINUE
      ECUTIN=ECUTIN/RM
C
      ECUTEL=ECUTIN
      IF(ECUTEL.LT.1.0) ECUTEL=1.0
      ECUTPH = ECUTEL-1.0
      IF(ECUTPH.LT.0.05) ECUTPH=0.05
      ECUTPS = ECUTEL
      IF(ECUTPH.LT.1.0) ECUTPS= 0.9999
C
      ECUT = ECUTPS
      IF(ECUT .LT. 1.0) ECUT=1.0
C     GOTO 1
C
C     ENTRY SETEC0
C
C     CALL MSG('ECUT IN MEV =? (F8.2);;')
C     READ(5,500) ECUTIN
C     ECUTIN=ECUTIN/.511
C     IF(ECUTIN.LT.1.)ECUTIN=1.
C     ECUT=ECUTIN;ECUTEL=ECUTIN;ECUTPH=ECUTIN;ECUTPS=ECUTIN
C
    1 FCUT=ECUT*RM
      FCUTEL = ECUTEL*RM
      FCUTPH = ECUTPH*RM
      FCUTPS = ECUTPS*RM
      PRINT 600,FCUT,FCUTEL,FCUTPH,FCUTPS
600   FORMAT(' ECUT,ECUTEL,ECUTPH,ECUTPS IN MEV=',4G12.4)
      RETURN
      END
