C   12/03/84 412041226  MEMBER NAME  CTAGGO   (S)           FORTRAN
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C HERE ARE THE COMMONS THAT EVENTUALLY BECOME THE TP BANKS ACCLS -
C TAGG/O ,1,2,3
C CONVENTION IN NAMING -
C
C FIRST LETTER -
C         C - NAME OF COMMON
C         H - NAME OF VARIABLES *2 TYPE      INTEGER
C         I -   "       "       *4 TYPE         "
C         A -   "       "                    REAL
C
C REST OF NAME AS FOR TAGG BANKS SEE JADE COMPUTER NOTE 16 FOR MORE DETA
C
C ACTUALLY ALL THIS COULD ALSO GO IN WORKSPACE BUT I CANT BE BOTHERED!
C
C**** IMPORTANT :  IF YOU CHANGE THE SIZE OF THESE COMMONS PLEASE
C                  REMEMBER TO CHANGE 'TAGINT' WHICH CLEARS THEM.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C
      COMMON / CACLS  / HID1,HID2,HIPM,HIPZ,HDUM,HIPL,HDUMM1(134)
      DIMENSION HACLS(140)
      EQUIVALENCE ( HACLS(1) , HID1 )
C
      COMMON / CTAGG0 / HID3,HID4,HTRACK,HTRZMI,HTRZPL,HCLST,
     *                  HCLZMI,HCLZPL,HNEUT,HCOL,HTYPE,HER,HCORR,
     *                  HPBLAT,HDUM1,HDUM2,HSCAL(36),HWPCL,HWPTR,
     *                  HDUMM2(14)
      DIMENSION     ATAGG0(34)
      EQUIVALENCE ( HID3 , ATAGG0(1) )
C
      COMMON / CTAGG1 / HMAP(2,20)
C
      COMMON / CTAGG2 / ATAGG2(260)
      DIMENSION         ITAGG2(260)
      INTEGER*2         HTAGG2(520)
      EQUIVALENCE ( HTAGG2(1) , ITAGG2(1) , ATAGG2(1) )
C
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
