C   12/08/87 708121048  MEMBER NAME  SHWCPR   (S)           FORTRAN77
      SUBROUTINE SHWCPR(VERT,CHI22)
C
C   COPIED FROM F11HEL.ES(SHWCPR)
C
C
C     THIS SUBROUTINE COMPARES A SINGLE SHOWER PROFILE WITH
C     A CLUSTER IN THE 'LGCL' BANK
C     CLUSTER DATA HAVE TO BE STORED IN /CLDAT/ FOR THIS VERSION
C
C     INPUT  -->  VERT   =  VERTEX COORDINATES (3-DIM)
C
C     OUTPUT -->  CHI22  =  CHI**2 (RESULT OF COMPARISON)
C
C                                                    09/08/82
C     IBLIST-ERROR CORRECTED 9/8/82   16.00
C
      DIMENSION PSSF(2),IBLIST(40),BLCFRC(40),VERT(3)
      COMMON /CLDAT/ NUMBLO,NBLIST(40),ENLIST(40),IPACL,ECLCO,ECLUN,
     *               PIMP1,PIMP2
C
      DO 11 IL = 1,NUMBLO
   11 IBLIST(IL)=NBLIST(IL)
C
      PSSF(1) = PIMP1
      PSSF(2) = PIMP2
C
      CALL EXPECT(IPACL,ECLCO,PSSF,VERT,NUMBLO,IBLIST,BLCFRC,AVGSUM)
      CHI22 = 0.
      DO 12 I=1,NUMBLO
      ENEXPT = BLCFRC(I)*ECLCO
      SIGSQU = 21.6*ENLIST(I)
      STHEO2 = .25*ENEXPT**2
      CHI22 = CHI22+(ENEXPT-ENLIST(I))**2/(SIGSQU+STHEO2)
   12 CONTINUE
      RETURN
C
      END
