C   31/08/79 C9083101   MEMBER NAME  SPELST   (JADENS)      FORTRAN
      SUBROUTINE SPELST
      IMPLICIT INTEGER*2 (H)
#include "cgraph.for"
#include "cdata.for"
C---
C---     SHOWS CONTENTS OF THE SPECIAL LIST.
C---
      DIMENSION LIST(200)
      CALL BSLT
      CALL BMRT(N,LIST,200)
      WRITE(JUSCRN,100) N
  100 FORMAT(' SPELST CALLED.',I4,' BANKS ARE IN THE SPECIAL LIST:',/)
      IF(N.LT.1) RETURN
      WRITE(JUSCRN,101) (LIST(I),I=1,N)
  101 FORMAT(10(' ',A4))
      DO 2 I=1,N
      IPNTR=IDATA(IBLN(LIST(I)))
      WRITE(JUSCRN,102) I,LIST(I),IPNTR
  102 FORMAT(1X,I4,' ',A4,I8)
    2 CONTINUE
      RETURN
      END
