C   06/06/84 406142232  MEMBER NAME  FINCMD   (S)           FORTRAN
      SUBROUTINE FINCMD(H,N,I,M)
      IMPLICIT INTEGER*2 (H)
C     WRITE(6,1)
C1    FORMAT(' UNKNOWN COMMAND (TEMP)')
      I = 0
      RETURN
      END
