C   07/06/96 606071806  MEMBER NAME  BDMP     (S4)          FORTG1
      SUBROUTINE BDMP
C     BOS SUBPROGRAM =1.16=
C   18/10/82            MEMBER NAME  ACS      (S)           FORTRAN
      COMMON/ACS/
     1   ICOND,NLAST,NDUMP,NSPL,NAMAX,NAMAX1,NLIST,NPRIM,NFRS,NLST,
     2   NEXT,NCI,NFRE,IN,KPOS,LIND,ILOW,LFDI,LFDK,NCPL,
     3   NHISTH(11),
     4        NCOL,NZT,IBFI,NLAST1,ISLST,IMLST,INAMV,IOLST,IPLST,
     5   NER(10),
     6   NRECL,NERRL,NRIN,NROUT,NS,NEXTI,NEXTA,NEXTB,ISAVB,NSAVB,
     7   NHISTL(11),
     8        MARKWR,NOUT(3),IASW,NPRE,IDUMMY(1),NEOTP,NDUMP1
      COMMON/BCS/IW(1)
C   07/06/96 606071821  MEMBER NAME  CCS      (S4)          FORTG1
      COMMON/CCS/IUND,INDT,INDC,NPT,INDA,LISTE(5),IPAS
      INTEGER TEXT(4)/'IW()','LFDI','LFDK','NLST'/
      REAL*8 TEXTB(10)
   10 WRITE(6,101) ICOND
      WRITE(6,102)
      CALL UWP(ICOND,1,80)
      CALL UWP(IUND,1,10)
C     PRINTOUT OF TRACEBACK
*xxx 09.01.98      M=ITRACE(TEXTB,10)
       	TEXTB(1) = 'PEDR'
       	TEXTB(2) = 'ANTO'
       	TEXTB(3) = 'MOVI'
       	TEXTB(4) = 'FERN'
     	M=20
*xxx
      WRITE(6,105) (TEXTB(J),J=1,M)
C
      IF(NLAST.NE.NLAST1) GOTO 20
      IF(NDUMP.NE.NDUMP1) GOTO 20
      GOTO 30
   20 WRITE(6,103)
      CALL UWU(IW,1,1000)
      GOTO 100
   30 WRITE(6,104) TEXT(2)
      IF(LFDI.GE.11.AND.LFDI.LT.NLAST) CALL UWP(IW,LFDI-10,LFDI+10)
      IF(LFDI.GT.0.AND.LFDI.LT.11.AND.LFDI.LT.NLAST)
     1   CALL UWP(IW,LFDI,LFDI+10)
      WRITE(6,104) TEXT(3)
      IF(LFDK.GT.0.AND.LFDK.LT.NLAST) CALL UWP(IW,LFDK-10,LFDK+10)
      WRITE(6,104) TEXT(4)
      IF(NLST.GE.0.AND.NLST.LT.NLAST) CALL UWU(IW,NLST,NLAST)
      IF(NDUMP.LT.0.OR.NDUMP.GT.NLAST) GOTO 20
      WRITE(6,104) TEXT(1)
      CALL UWU(IW,1,NDUMP)
  100 CALL ABEND
      STOP
C
      ENTRY BDMPF
      ICOND=31
      GOTO 10
  101 FORMAT('0','++++++++++','  DUMP  -  ERROR  CODE',I3,'  ',
     1   '+++++++++++++++++++++++++++++++++'/)
  102 FORMAT('0PRINTOUT OF COMMON/ACS/'/
     112X,' ICOND,NLAST,NDUMP,NSPL,NAMAX,NAMAX1,NLIST,NPRIM,NFRS,NLST,'/
     212X,' NEXT,NCI,NFRE,IN,KPOS,LIND,ILOW,LFDI,LFDK,NCPL,'/
     312X,' NHISTH(11),                              '/
     412X,'      NCOL,NZT,IBFI,NLAST1,ISLST,IMLST,INAMV,IOLST,IPLST,'/
     512X,' NER(10),                                 '/
     612X,' NRECL,NERRL,NRIN,NROUT,NS,NEXTI,NEXTA,NEXTB,ISAVB,NSAVB,'/
     712X,' NHISTL(11),                              '/
     812X,'      MARKWR,NOUT(3),IASW,NPRE,IDUMMY(2),NDUMP1 '/)
  103 FORMAT('0COMMON/ACS/ DESTROYED'/)
  104 FORMAT('0',6X,A4)
  105 FORMAT('0TRACEBACK OF SUBPROGRAMS'/(1X,10(2X,A8)))
      END
