C   07/06/96 606071828  MEMBER NAME  BPOS     (S4)          FORTG1
      SUBROUTINE BPOS(NAME)
C     BOS SUBPROGRAM =1.9=
#include "acs.for"
      COMMON/BCS/IW(1)
      LOGICAL POS/.FALSE./
      EXTERNAL BDLG
      ENTRY CPOS(NAME)
      IW(INAMV)=NAME
      LFDI=MOD(IABS(NAMEV),NPRIM)+NAMAX1
    1 LFDI=IW(LFDI+IPLST)
      IF(IW(LFDI+INAMV).NE.IW(INAMV)) GOTO 1
      IF(LFDI.EQ.0) LFDI=IBLN(IW(INAMV))
      KPOS=LFDI
      GOTO 100
C
      ENTRY BPRL(NAME)
      IF(NPRE.GE.NAME) GOTO 100
      NPRE=NPRE+1
      CALL BPRM
  100 RETURN
      END
