C   31/05/79 912061908  MEMBER NAME  ANOMAL   (S)           FORTRAN
      SUBROUTINE ANOMAL
C---  SPECIFY ANOMALIES OF INDIVIDUAL RUNS
C---  (SHIFTS FROM JUNE TO NOVEMBER 1979;
C---   THE CORRESPONDING PROGRAM FOR THE MAY SHIFTS IS ON GAMGAM.S/L)
C
C     H.WRIEDT    31.05.79     11:20
C     LAST MODIFICATION     06.12.79     19:05
C
      IMPLICIT INTEGER*2 (H)
C
      COMMON /CRUNCO/ HRUN
C
      COMMON /CPHASE/ LIMEVT,KCONST(192),LIMIT(192),LCHANN(192),
     &                LTHRES(192),LDEAD(192),LSUB(240)
      LOGICAL LCHANN,LTHRES,LDEAD,LSUB
C
C---  LCHANN:  CHANNELS WITH CONSTANT PEDESTALS
C---  LDEAD:   CHANNELS WHICH MUST BE SET TO 0 (E.G. FOR MISSING BITS
C              IN THE ADC
C---  KCONST:  CHANNELS FOR WHICH THE SUBTRACTION CONSTANT MUST BE
C              HIGHER (-1) OR LOWER (+1) THAN THE PROGRAM WOULD
C              AUTOMATICALLY CALCULATE
C---  LIMIT:   GIVES THE LOWER BOUND OF THE SUBTRACTION CONSTANT
C---  LTHRES:  CHANNELS FOR WHICH THE LOWER CUT BOUND IS SET TO 100
C              INSTEAD OF 50
C
      DO 1 I = 1,192
      KCONST(I) = 0
      LIMIT(I) = 0
      LCHANN(I) = .FALSE.
      LDEAD(I) = .FALSE.
    1 LTHRES(I) = .FALSE.
        DO 2 I = 1,240
    2   LSUB(I) = .FALSE.
      LIMEVT = 0
C
      IF (HRUN.GT.564) GOTO 5
      IRUN = HRUN - 539
      IF (IRUN.LE.0) RETURN
C---  13.6 GEV - RUNS
      CALL ANOM01(IRUN)
      RETURN
C
    5 IF (HRUN.GT.672) GOTO 6
      IRUN = HRUN - 580
      IF (IRUN.LE.0) RETURN
C---  13.86 GEV - RUNS
      CALL ANOM02(IRUN)
      RETURN
C
    6 IF (HRUN.GT.709) GOTO 7
      IRUN = HRUN - 698
      IF (IRUN.LE.0) RETURN
C---  15.8 GEV - RUNS
      CALL ANOM11(IRUN)
      RETURN
C
    7 IF (HRUN.GT.893) GOTO 8
      IRUN = HRUN - 763
      IF (IRUN.LE.0) RETURN
C---  15.8 GEV - RUNS
      CALL ANOM12(IRUN)
      RETURN
C
    8 IF (HRUN.GT.960) GOTO 9
      IRUN = HRUN - 913
      IF (IRUN.LE.0) RETURN
C---  15.8 GEV - RUNS
      CALL ANOM13(IRUN)
      RETURN
C
    9 IF (HRUN.GT.1082) GOTO 10
      IRUN = HRUN - 971
      IF (IRUN.LE.0) RETURN
C---  15.8 GEV - RUNS
      CALL ANOM14(IRUN)
      RETURN
C
   10 IF (HRUN.GT.1083) GOTO 11
      IRUN = HRUN - 1082
      IF (IRUN.LE.0) RETURN
C---  11.0 GEV - RUN
      CALL ANOM21(IRUN)
      RETURN
C
   11 IF (HRUN.GT.1121) GOTO 12
      IRUN = HRUN - 1083
      IF (IRUN.LE.0) RETURN
C---  13.86 GEV - RUNS
      CALL ANOM31(IRUN)
      RETURN
C
   12 IF (HRUN.GT.1162) GOTO 13
      IRUN = HRUN - 1121
      IF (IRUN.LE.0) RETURN
C---  11.0 GEV - RUNS
      CALL ANOM41(IRUN)
      RETURN
C
   13 IF (HRUN.GT.1397) GOTO 20
      IRUN = HRUN - 1209
      IF (IRUN.LE.0) RETURN
C---  15.0 GEV - RUNS
      CALL ANOM51(IRUN)
      RETURN
C
   20 IF (HRUN.GT.1559) GOTO 21
      IRUN = HRUN - 1496
      IF (IRUN.LE.0) RETURN
C---  15.25 GEV - RUNS
      CALL ANOM61(IRUN)
      RETURN
C
   21 IF (HRUN.GT.1576) GOTO 22
      IRUN = HRUN - 1560
      IF (IRUN.LE.0) RETURN
C---  15.26 GEV - RUNS
      CALL ANOM62(IRUN)
      RETURN
C
   22 IF (HRUN.GT.1604) GOTO 23
      IRUN = HRUN - 1577
      IF (IRUN.LE.0) RETURN
C---  15.27 GEV - RUNS
      CALL ANOM63(IRUN)
      RETURN
C
   23 IF (HRUN.GT.1626) GOTO 24
      IRUN = HRUN - 1608
      IF (IRUN.LE.0) RETURN
C---  15.28 GEV - RUNS
      CALL ANOM64(IRUN)
      RETURN
C
   24 IF (HRUN.GT.1637) GOTO 25
      IRUN = HRUN - 1626
      IF (IRUN.LE.0) RETURN
C---  15.29 GEV - RUNS
      CALL ANOM65(IRUN)
      RETURN
C
   25 IF (HRUN.GT.1648) GOTO 26
      IRUN = HRUN - 1638
      IF (IRUN.LE.0) RETURN
C---  15.30 GEV - RUNS
      CALL ANOM66(IRUN)
      RETURN
C
   26 IF (HRUN.GT.1661) GOTO 27
      IRUN = HRUN - 1648
      IF (IRUN.LE.0) RETURN
C---  15.31 GEV - RUNS
      CALL ANOM67(IRUN)
      RETURN
C
   27 IF (HRUN.GT.1686) GOTO 28
      IRUN = HRUN - 1661
      IF (IRUN.LE.0) RETURN
C---  15.32 GEV - RUNS
      CALL ANOM68(IRUN)
      RETURN
C
   28 IF (HRUN.GT.1713) GOTO 29
      IRUN = HRUN - 1710
      IF (IRUN.LE.0) RETURN
C---  15.33 GEV - RUNS
      CALL ANOM69(IRUN)
      RETURN
C
   29 IF (HRUN.GT.1724) GOTO 30
      IRUN = HRUN - 1713
      IF (IRUN.LE.0) RETURN
C---  15.34 GEV - RUNS
      CALL ANOM70(IRUN)
      RETURN
C
   30 IF (HRUN.GT.1729) GOTO 31
      IRUN = HRUN - 1724
      IF (IRUN.LE.0) RETURN
C---  15.35 GEV - RUNS
      CALL ANOM71(IRUN)
      RETURN
C
   31 IF (HRUN.GT.1739) GOTO 32
      IRUN = HRUN - 1731
      IF (IRUN.LE.0) RETURN
C---  15.36 GEV - RUNS
      CALL ANOM72(IRUN)
      RETURN
C
   32 IF (HRUN.GT.1749) GOTO 33
      IRUN = HRUN - 1739
      IF (IRUN.LE.0) RETURN
C---  15.37 GEV - RUNS
      CALL ANOM73(IRUN)
      RETURN
C
   33 IF (HRUN.GT.1755) GOTO 34
      IRUN = HRUN - 1749
      IF (IRUN.LE.0) RETURN
C---  15.38 GEV - RUNS
      CALL ANOM74(IRUN)
      RETURN
C
   34 IF (HRUN.GT.1762) GOTO 35
      IRUN = HRUN - 1755
      IF (IRUN.LE.0) RETURN
C---  15.39 GEV - RUNS
      CALL ANOM75(IRUN)
      RETURN
C
   35 IF (HRUN.GT.1769) GOTO 36
      IRUN = HRUN - 1762
      IF (IRUN.LE.0) RETURN
C---  15.40 GEV - RUNS
      CALL ANOM76(IRUN)
      RETURN
C
   36 IF (HRUN.GT.1778) GOTO 37
      IRUN = HRUN - 1769
      IF (IRUN.LE.0) RETURN
C---  15.41 GEV - RUNS
      CALL ANOM77(IRUN)
      RETURN
C
   37 IF (HRUN.GT.1783) GOTO 38
      IRUN = HRUN - 1778
      IF (IRUN.LE.0) RETURN
C---  15.42 GEV - RUNS
      CALL ANOM78(IRUN)
      RETURN
C
   38 IF (HRUN.GT.1796) GOTO 39
      IRUN = HRUN - 1783
      IF (IRUN.LE.0) RETURN
C---  15.43 GEV - RUNS
      CALL ANOM79(IRUN)
      RETURN
C
   39 IF (HRUN.GT.1801) GOTO 40
      IRUN = HRUN - 1796
      IF (IRUN.LE.0) RETURN
C---  15.44 GEV - RUNS
      CALL ANOM80(IRUN)
      RETURN
C
   40 IF (HRUN.GT.1809) GOTO 41
      IRUN = HRUN - 1801
      IF (IRUN.LE.0) RETURN
C---  15.45 GEV - RUNS
      CALL ANOM81(IRUN)
      RETURN
C
   41 IF (HRUN.GT.1813) GOTO 42
      IRUN = HRUN - 1809
      IF (IRUN.LE.0) RETURN
C---  15.46 GEV - RUNS
      CALL ANOM82(IRUN)
      RETURN
C
   42 IF (HRUN.GT.1865) GOTO 43
      IRUN = HRUN - 1845
      IF (IRUN.LE.0) RETURN
C---  15.46 GEV - RUNS (AFTER SHUT-DOWN)
      CALL ANOM83(IRUN)
      RETURN
C
   43 IF (HRUN.GT.1868) GOTO 44
      IRUN = HRUN - 1865
      IF (IRUN.LE.0) RETURN
C---  15.47 GEV - RUNS
      CALL ANOM84(IRUN)
      RETURN
C
   44 IF (HRUN.GT.1871) GOTO 45
      IRUN = HRUN - 1868
      IF (IRUN.LE.0) RETURN
C---  15.50 GEV - RUNS
      CALL ANOM85(IRUN)
      RETURN
C
   45 IF (HRUN.GT.1875) GOTO 46
      IRUN = HRUN - 1871
      IF (IRUN.LE.0) RETURN
C---  15.47 GEV - RUNS
      CALL ANOM86(IRUN)
      RETURN
C
   46 IF (HRUN.GT.1881) GOTO 47
      IRUN = HRUN - 1875
      IF (IRUN.LE.0) RETURN
C---  15.48 GEV - RUNS
      CALL ANOM87(IRUN)
      RETURN
C
   47 IF (HRUN.GT.1888) GOTO 48
      IRUN = HRUN - 1881
      IF (IRUN.LE.0) RETURN
C---  15.49 GEV - RUNS
      CALL ANOM88(IRUN)
      RETURN
C
   48 IF (HRUN.GT.1892) GOTO 49
      IRUN = HRUN - 1888
      IF (IRUN.LE.0) RETURN
C---  15.50 GEV - RUNS
      CALL ANOM89(IRUN)
      RETURN
C
   49 IF (HRUN.GT.1897) GOTO 50
      IRUN = HRUN - 1892
      IF (IRUN.LE.0) RETURN
C---  15.51 GEV - RUNS
      CALL ANOM90(IRUN)
      RETURN
C
   50 IF (HRUN.GT.1904) GOTO 51
      IRUN = HRUN - 1897
      IF (IRUN.LE.0) RETURN
C---  15.52 GEV - RUNS
      CALL ANOM91(IRUN)
      RETURN
C
   51 IF (HRUN.GT.1908) GOTO 52
      IRUN = HRUN - 1904
      IF (IRUN.LE.0) RETURN
C---  15.53 GEV - RUNS
      CALL ANOM92(IRUN)
      RETURN
C
   52 IF (HRUN.GT.1911) GOTO 53
      IRUN = HRUN - 1908
      IF (IRUN.LE.0) RETURN
C---  15.54 GEV - RUNS
      CALL ANOM93(IRUN)
      RETURN
C
   53 IF (HRUN.GT.1919) GOTO 54
      IRUN = HRUN - 1911
      IF (IRUN.LE.0) RETURN
C---  15.55 GEV - RUNS
      CALL ANOM94(IRUN)
      RETURN
C
   54 IF (HRUN.GT.1928) GOTO 55
      IRUN = HRUN - 1919
      IF (IRUN.LE.0) RETURN
C---  15.56 GEV - RUNS
      CALL ANOM95(IRUN)
      RETURN
C
   55 IF (HRUN.GT.1934) GOTO 56
      IRUN = HRUN - 1930
      IF (IRUN.LE.0) RETURN
C---  15.57 GEV - RUNS
      CALL ANOM96(IRUN)
      RETURN
C
   56 IF (HRUN.GT.1940) GOTO 57
      IRUN = HRUN - 1934
      IF (IRUN.LE.0) RETURN
C---  15.58 GEV - RUNS
      CALL ANOM97(IRUN)
      RETURN
C
   57 IF (HRUN.GT.1945) GOTO 58
      IRUN = HRUN - 1940
      IF (IRUN.LE.0) RETURN
C---  15.59 GEV - RUNS
      CALL ANOM98(IRUN)
      RETURN
C
   58 IF (HRUN.GT.1952) GOTO 59
      IRUN = HRUN - 1945
      IF (IRUN.LE.0) RETURN
C---  15.60 GEV - RUNS
      CALL ANOM99(IRUN)
      RETURN
C
   59 IF (HRUN.GT.1958) GOTO 60
      IRUN = HRUN - 1952
      IF (IRUN.LE.0) RETURN
C---  15.61 GEV - RUNS
      CALL ANO100(IRUN)
      RETURN
C
   60 IF (HRUN.GT.1965) GOTO 61
      IRUN = HRUN - 1958
      IF (IRUN.LE.0) RETURN
C---  15.62 GEV - RUNS
      CALL ANO101(IRUN)
      RETURN
C
   61 IF (HRUN.GT.1969) GOTO 62
      IRUN = HRUN - 1965
      IF (IRUN.LE.0) RETURN
C---  15.63 GEV - RUNS
      CALL ANO102(IRUN)
      RETURN
C
   62 IF (HRUN.GT.1972) GOTO 63
      IRUN = HRUN - 1969
      IF (IRUN.LE.0) RETURN
C---  15.64 GEV - RUNS
      CALL ANO103(IRUN)
      RETURN
C
   63 IF (HRUN.GT.1975) GOTO 64
      IRUN = HRUN - 1972
      IF (IRUN.LE.0) RETURN
C---  15.65 GEV - RUNS
      CALL ANO104(IRUN)
      RETURN
C
   64 IF (HRUN.GT.1986) GOTO 65
      IRUN = HRUN - 1978
      IF (IRUN.LE.0) RETURN
C---  15.66 GEV - RUNS
      CALL ANO105(IRUN)
      RETURN
C
   65 IF (HRUN.GT.2008) GOTO 66
      IRUN = HRUN - 1986
      IF (IRUN.LE.0) RETURN
C---  15.67 GEV - RUNS
      CALL ANO106(IRUN)
      RETURN
C
   66 IF (HRUN.GT.2017) GOTO 67
      IRUN = HRUN - 2008
      IF (IRUN.LE.0) RETURN
C---  15.68 GEV - RUNS
      CALL ANO107(IRUN)
      RETURN
C
   67 IF (HRUN.GT.2025) GOTO 68
      IRUN = HRUN - 2017
      IF (IRUN.LE.0) RETURN
C---  15.69 GEV - RUNS
      CALL ANO108(IRUN)
      RETURN
C
   68 IF (HRUN.GT.2032) GOTO 69
      IRUN = HRUN - 2025
      IF (IRUN.LE.0) RETURN
C---  15.70 GEV - RUNS
      CALL ANO109(IRUN)
      RETURN
C
   69 IF (HRUN.GT.2041) GOTO 70
      IRUN = HRUN - 2032
      IF (IRUN.LE.0) RETURN
C---  15.71 GEV - RUNS
      CALL ANO110(IRUN)
      RETURN
C
   70 IF (HRUN.GT.2051) GOTO 71
      IRUN = HRUN - 2041
      IF (IRUN.LE.0) RETURN
C---  15.72 GEV - RUNS
      CALL ANO111(IRUN)
      RETURN
C
   71 IF (HRUN.GT.2055) GOTO 80
      IRUN = HRUN - 2051
      IF (IRUN.LE.0) RETURN
C---  15.73 GEV - RUNS
      CALL ANO112(IRUN)
      RETURN
C
   80 IF (HRUN.GT.2062) GOTO 81
      IRUN = HRUN - 2056
      IF (IRUN.LE.0) RETURN
C---  15.00 GEV - RUNS
      CALL ANO120(IRUN)
      RETURN
C
   81 IF (HRUN.GT.2068) GOTO 82
      IRUN = HRUN - 2062
      IF (IRUN.LE.0) RETURN
C---  15.01 GEV - RUNS
      CALL ANO121(IRUN)
      RETURN
C
   82 IF (HRUN.GT.2076) GOTO 83
      IRUN = HRUN - 2069
      IF (IRUN.LE.0) RETURN
C---  15.02 GEV - RUNS
      CALL ANO122(IRUN)
      RETURN
C
   83 IF (HRUN.GT.2082) GOTO 84
      IRUN = HRUN - 2076
      IF (IRUN.LE.0) RETURN
C---  15.03 GEV - RUNS
      CALL ANO123(IRUN)
      RETURN
C
   84 IF (HRUN.GT.2091) GOTO 85
      IRUN = HRUN - 2082
      IF (IRUN.LE.0) RETURN
C---  15.04 GEV - RUNS
      CALL ANO124(IRUN)
      RETURN
C
   85 IF (HRUN.GT.2096) GOTO 86
      IRUN = HRUN - 2091
      IF (IRUN.LE.0) RETURN
C---  15.05 GEV - RUNS
      CALL ANO125(IRUN)
      RETURN
C
   86 IF (HRUN.GT.2110) GOTO 87
      IRUN = HRUN - 2096
      IF (IRUN.LE.0) RETURN
C---  15.06 GEV - RUNS
      CALL ANO126(IRUN)
      RETURN
C
   87 IF (HRUN.GT.2116) GOTO 88
      IRUN = HRUN - 2111
      IF (IRUN.LE.0) RETURN
C---  15.07 GEV - RUNS
      CALL ANO127(IRUN)
      RETURN
C
   88 IF (HRUN.GT.2121) GOTO 89
      IRUN = HRUN - 2116
      IF (IRUN.LE.0) RETURN
C---  15.08 GEV - RUNS
      CALL ANO128(IRUN)
      RETURN
C
   89 IF (HRUN.GT.2125) GOTO 90
      IRUN = HRUN - 2121
      IF (IRUN.LE.0) RETURN
C---  15.09 GEV - RUNS
      CALL ANO129(IRUN)
      RETURN
C
   90 IF (HRUN.GT.2129) GOTO 91
      IRUN = HRUN - 2125
      IF (IRUN.LE.0) RETURN
C---  15.10 GEV - RUNS
      CALL ANO130(IRUN)
      RETURN
C
   91 IF (HRUN.GT.2133) GOTO 92
      IRUN = HRUN - 2129
      IF (IRUN.LE.0) RETURN
C---  15.11 GEV - RUNS
      CALL ANO131(IRUN)
      RETURN
C
   92 IF (HRUN.GT.2145) GOTO 93
      IRUN = HRUN - 2133
      IF (IRUN.LE.0) RETURN
C---  15.12 GEV - RUNS
      CALL ANO132(IRUN)
      RETURN
C
   93 IF (HRUN.GT.2149) GOTO 94
      IRUN = HRUN - 2145
      IF (IRUN.LE.0) RETURN
C---  15.13 GEV - RUNS
      CALL ANO133(IRUN)
      RETURN
C
   94 IF (HRUN.GT.2152) GOTO 95
      IRUN = HRUN - 2149
      IF (IRUN.LE.0) RETURN
C---  15.14 GEV - RUNS
      CALL ANO134(IRUN)
      RETURN
C
   95 IF (HRUN.GT.2154) GOTO 96
      IRUN = HRUN - 2152
      IF (IRUN.LE.0) RETURN
C---  15.15 GEV - RUNS
      CALL ANO135(IRUN)
      RETURN
C
   96 IF (HRUN.GT.2159) GOTO 97
      IRUN = HRUN - 2154
      IF (IRUN.LE.0) RETURN
C---  15.16 GEV - RUNS
      CALL ANO136(IRUN)
      RETURN
C
   97 IF (HRUN.GT.2163) GOTO 98
      IRUN = HRUN - 2159
      IF (IRUN.LE.0) RETURN
C---  15.17 GEV - RUNS
      CALL ANO137(IRUN)
      RETURN
C
   98 IF (HRUN.GT.2167) GOTO 99
      IRUN = HRUN - 2163
      IF (IRUN.LE.0) RETURN
C---  15.18 GEV - RUNS
      CALL ANO138(IRUN)
      RETURN
C
   99 IF (HRUN.GT.2175) GOTO 100
      IRUN = HRUN - 2167
      IF (IRUN.LE.0) RETURN
C---  15.19 GEV - RUNS
      CALL ANO139(IRUN)
      RETURN
C
  100 IF (HRUN.GT.2182) GOTO 101
      IRUN = HRUN - 2176
      IF (IRUN.LE.0) RETURN
C---  15.20 GEV - RUNS
      CALL ANO140(IRUN)
      RETURN
C
  101 IF (HRUN.GT.2187) GOTO 102
      IRUN = HRUN - 2182
      IF (IRUN.LE.0) RETURN
C---  15.21 GEV - RUNS
      CALL ANO141(IRUN)
      RETURN
C
  102 IF (HRUN.GT.2190) GOTO 103
      IRUN = HRUN - 2187
      IF (IRUN.LE.0) RETURN
C---  15.22 GEV - RUNS
      CALL ANO142(IRUN)
      RETURN
C
  103 IF (HRUN.GT.2194) GOTO 104
      IRUN = HRUN - 2190
      IF (IRUN.LE.0) RETURN
C---  15.23 GEV - RUNS
      CALL ANO143(IRUN)
      RETURN
C
  104 IF (HRUN.GT.2201) GOTO 110
      IRUN = HRUN - 2194
      IF (IRUN.LE.0) RETURN
C---  15.24 GEV - RUNS
      CALL ANO144(IRUN)
      RETURN
C
  110 IF (HRUN.GT.2207) GOTO 111
      IRUN = HRUN - 2201
      IF (IRUN.LE.0) RETURN
C---  14.95 GEV - RUNS
      CALL ANO150(IRUN)
      RETURN
C
  111 IF (HRUN.GT.2216) GOTO 112
      IRUN = HRUN - 2208
      IF (IRUN.LE.0) RETURN
C---  14.96 GEV - RUNS
      CALL ANO151(IRUN)
      RETURN
C
  112 IF (HRUN.GT.2219) GOTO 113
      IRUN = HRUN - 2216
      IF (IRUN.LE.0) RETURN
C---  14.97 GEV - RUNS
      CALL ANO152(IRUN)
      RETURN
C
  113 IF (HRUN.GT.2222) GOTO 114
      IRUN = HRUN - 2219
      IF (IRUN.LE.0) RETURN
C---  14.98 GEV - RUNS
      CALL ANO153(IRUN)
      RETURN
C
  114 IF (HRUN.GT.2226) GOTO 120
      IRUN = HRUN - 2222
      IF (IRUN.LE.0) RETURN
C---  14.99 GEV - RUNS
      CALL ANO154(IRUN)
      RETURN
C
  120 IF (HRUN.GT.2385) GOTO 121
      IRUN = HRUN - 2305
      IF (IRUN.LE.0) RETURN
C---  6 GEV - RUNS
      CALL ANO160(IRUN)
      RETURN
C
  121 IF (HRUN.GT.2447) GOTO 122
      IRUN = HRUN - 2385
      IF (IRUN.LE.0) RETURN
C---  6 GEV - RUNS
      CALL ANO161(IRUN)
      RETURN
C
  122 IF (HRUN.GT.2520) RETURN
      IRUN = HRUN - 2447
      IF (IRUN.LE.0) RETURN
C---  6 GEV - RUNS
      CALL ANO162(IRUN)
      RETURN
C
      END
