C   25/06/78            MEMBER NAME  BREMS2   (LGSOURCE)    FORTRAN
      SUBROUTINE BREMS2(ENE,EPSI)
      COMMON /BRPAR/ BRA,BRB,BDEL
      COMMON/SFCPA/SFP,SFE
      BH(X)=4.184*ALOG(X+0.952)-0.280
      XR=RN(DAM)
      EPSI=SQRT(XR)
      XR=RN(DAM)
      DEL=BDEL*EPSI/(ENE*(1.-EPSI))
      IF(DEL-1.)20,20,21
 20    G2=1.-BRB*DEL*(3.242-0.625*DEL)
      GO TO 2
 21    G2=1.-BRB*BH(DEL)
 2    IF(XR*SFE-G2)30,30,31
 30    IF(EPSI.LE. 1.-1./ENE) RETURN
 31    EPSI=0.
      RETURN
      END
